@@ -2,8 +2,6 @@
 
 namespace Doctrine\DBAL;
 
-use Doctrine\DBAL\Driver\Exception;
-use Doctrine\DBAL\Driver\Statement as DriverStatement;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\Deprecations\Deprecation;
@@ -40,7 +38,7 @@ class Statement
     /**
      * The underlying driver statement.
      *
-     * @var DriverStatement
+     * @var Driver\Statement
      */
     protected $stmt;
 
@@ -61,26 +59,19 @@ class Statement
     /**
      * Creates a new <tt>Statement</tt> for the given SQL and <tt>Connection</tt>.
      *
-     * @internal The statement can be only instantiated by {@link Connection}.
+     * @internal The statement can be only instantiated by {@see Connection}.
      *
-     * @param string     $sql  The SQL of the statement.
-     * @param Connection $conn The connection on which the statement should be executed.
+     * @param Connection       $conn      The connection for handling statement errors.
+     * @param Driver\Statement $statement The underlying driver-level statement.
+     * @param string           $sql       The SQL of the statement.
      *
      * @throws Exception
      */
-    public function __construct($sql, Connection $conn)
+    public function __construct(Connection $conn, Driver\Statement $statement, string $sql)
     {
-        $driverConnection = $conn->getWrappedConnection();
-
-        try {
-            $stmt = $driverConnection->prepare($sql);
-        } catch (Exception $ex) {
-            throw $conn->convertExceptionDuringQuery($ex, $sql);
-        }
-
-        $this->sql      = $sql;
-        $this->stmt     = $stmt;
         $this->conn     = $conn;
+        $this->stmt     = $statement;
+        $this->sql      = $sql;
         $this->platform = $conn->getDatabasePlatform();
     }
 
@@ -122,7 +113,7 @@ class Statement
 
         try {
             return $this->stmt->bindValue($param, $value, $bindingType);
-        } catch (Exception $e) {
+        } catch (Driver\Exception $e) {
             throw $this->conn->convertException($e);
         }
     }
@@ -153,7 +144,7 @@ class Statement
             }
 
             return $this->stmt->bindParam($param, $variable, $type);
-        } catch (Exception $e) {
+        } catch (Driver\Exception $e) {
             throw $this->conn->convertException($e);
         }
     }
@@ -189,7 +180,7 @@ class Statement
                 $this->stmt->execute($params),
                 $this->conn
             );
-        } catch (Exception $ex) {
+        } catch (Driver\Exception $ex) {
             throw $this->conn->convertExceptionDuringQuery($ex, $this->sql, $this->params, $this->types);
         } finally {
             if ($logger !== null) {
@@ -233,7 +224,7 @@ class Statement
     /**
      * Gets the wrapped driver statement.
      *
-     * @return DriverStatement
+     * @return Driver\Statement
      */
     public function getWrappedStatement()
     {
