@@ -3,19 +3,19 @@ OC.L10N.register(
     {
     "Personal activity feed for %s" : "Fonte delle attività personali per %s",
     "Your feed URL is invalid" : "L'URL della fonte non è valido",
-    "Activity feed for %1$s" : "Flusso di attività per %1$s",
+    "Activity feed for %1$s" : "Fonte delle attività per %1$s",
     "Activity feed" : "Fonte delle attività",
     "Your settings have been updated." : "Le tue impostazioni sono state aggiornate.",
     "Settings have been updated." : "Le impostazioni sono state aggiornate.",
     "Recent activity" : "Attività recente",
     "No activities" : "Nessuna attività",
-    "More activities" : "Più attività",
+    "More activities" : "Altre attività",
     "Daily activity summary for %s" : "Riepilogo giornaliero delle attività per %s",
     "_and %n more _::_and %n more _" : ["e %n altro ","e %n altri ","e %n altri "],
     "All activities" : "Tutte le attività",
     "By others" : "Di altri",
     "By you" : "Tue",
-    "Activity at %s" : "Attività a %s",
+    "Activity at %s" : "Attività su %s",
     "Hello %s" : "Ciao %s",
     "Hello %s," : "Ciao %s,",
     "There was some activity at %s" : "Attività registrata su %s",
@@ -24,44 +24,43 @@ OC.L10N.register(
     "Activity" : "Attività",
     "Notifications" : "Notifiche",
     "This application enables people to view a log of activities about them, their files or other data." : "Questa applicazione consente agli utenti di visualizzare lo storico delle loro attività, dei loro file o di altri dati.",
-    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Questa applicazione consente agli utenti di vedere le azioni possibili per i loro file o dati in Nextcloud. \t\tChiunque può configurare impostazioni specifiche per le proprie attività nelle impostazioni personali, \t\tper scegliere quale attività debba essere trasmessa ai dispositivi mobili o inviata via email, \t\t o se inviare un rapporto giornaliero ogni mattina. \t\t Maggiori informazioni sono disponibili nella documentazione delle \"Atttività\".",
+    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Questa applicazione consente agli utenti di visualizzare le possibili azioni correlate ai propri file o dati in Nextcloud.\n\t\tChiunque può configurare impostazioni specifiche per le proprie attività nelle impostazioni personali,\n\t\tper scegliere quale attività debba essere comunicata ai dispositivi mobili o inviata tramite email,\n\t\t o se inviare un rapporto giornaliero ogni mattina.\n\t\t Maggiori informazioni sono disponibili nella documentazione di Atttività.",
     "Activity notification configuration" : "Configurazione notifica attività",
     "Send email" : "Invia email",
     "Send push notification" : "Invia notifica push",
     "Today" : "Oggi",
     "Yesterday" : "Ieri",
-    "You need to set up your email address before you can receive notification emails." : "Devi impostare l'indirizzo del tuo utente prima di poter ricevere le email di notifica.",
-    "Send activity emails" : "Invia messaggi di posta delle attività",
+    "You need to set up your email address before you can receive notification emails." : "Devi impostare l'indirizzo di posta del tuo utente prima di poter ricevere le email di notifica.",
+    "Send activity emails" : "Invia email delle attività",
     "As soon as possible" : "Non appena possibile",
     "Hourly" : "Ogni ora",
-    "Daily" : "Quotidiano",
-    "Weekly" : "Settimanale",
+    "Daily" : "Giornalmente",
+    "Weekly" : "Settimanalmente",
     "You commented" : "Hai commentato",
     "Message deleted by author" : "Messaggio eliminato dall'autore",
     "Open {filename}" : "Apri {filename}",
     "in {path}" : "in {path}",
     "Home" : "Home",
-    "Your activities" : "Le tue attività",
     "Loading activities" : "Caricamento delle attività",
     "This stream will show events like additions, changes & shares" : "Questo flusso mostrerà gli eventi come aggiunte, cambiamenti e condivisioni",
     "No activity yet" : "Ancora nessuna attività",
     "Loading more activities" : "Caricamento di altre attività",
     "No more activities." : "Nessun'altra attività.",
     "Could not load activities" : "Impossibile caricare le attività",
-    "Activity settings" : "Impostazioni attività",
-    "Enable RSS feed" : "Abilita fonte RSS",
+    "Activity settings" : "Impostazioni delle attività",
+    "Enable RSS feed" : "Abilita la fonte RSS",
     "RSS feed" : "Fonte RSS",
-    "Copy RSS feed link" : "Copia il link del feed RSS",
-    "Personal notification settings" : "Impostazioni notifica personale",
+    "Copy RSS feed link" : "Copia il collegamento della fonte RSS",
+    "Personal notification settings" : "Impostazioni di notifica personali",
     "Could not enable RSS link" : "Impossibile attivare il collegamento RSS",
     "RSS link copied to clipboard" : "Collegamento RSS copiato negli appunti",
-    "Could not copy the RSS link, please copy manually:" : "Impossibile copiare il collegamento RSS, copialo a mano.",
+    "Could not copy the RSS link, please copy manually:" : "Impossibile copiare il collegamento RSS, copialo manualmente:",
     "Unable to load the activity list" : "Impossibile caricare l'elenco delle attività",
     "Notification" : "Notifica",
     "Enable notification emails" : "Abilita notifica tramite email",
     "Choose for which activities you want to get an email or push notification." : "Scegli per quali attività desideri ricevere un'email o una notifica push.",
     "Choose for which activities you want to get a push notification." : "Scegli per quali attività desideri ricevere una notifica push.",
-    "Daily activity summary" : "Sommario giornaliero delle attività",
+    "Daily activity summary" : "Riepilogo dell'attività giornaliera",
     "Send daily activity summary in the morning" : "Invia un riepilogo giornaliero delle attività ogni mattina",
     "Default settings" : "Impostazioni predefinite",
     "Configure the default notification settings for new accounts." : "Configura le impostazioni predefinite di notifica per i nuovi account.",
