@@ -41,12 +41,12 @@ OC.L10N.register(
     "Open {filename}" : "Åpne {filename}",
     "in {path}" : "i {path}",
     "Home" : "Hjem",
-    "Your activities" : "Dine aktiviteter",
     "Loading activities" : "Laster aktiviteter",
     "This stream will show events like additions, changes & shares" : "Denne strømmen vil vise hendelser som f.eks. innlegging, endring og deling",
     "No activity yet" : "Ingen aktivitet ennå",
     "Loading more activities" : "Laster flere aktiviteter",
     "No more activities." : "Ingen flere aktiviteter.",
+    "Could not load activities" : "Kunne ikke laste aktiviteter",
     "Activity settings" : "Aktivitetsinnstillinger",
     "Enable RSS feed" : "Skru på RSS-strøm",
     "RSS feed" : "RSS-strøm",
