@@ -41,13 +41,12 @@ OC.L10N.register(
     "Open {filename}" : "開啟 {filename}",
     "in {path}" : "在 {path}",
     "Home" : "首頁",
-    "Your activities" : "您的活動",
     "Loading activities" : "正在載入活動",
     "This stream will show events like additions, changes & shares" : "這裡將顯示檔案的新增、更動、分享等動態",
     "No activity yet" : "尚無活動",
     "Loading more activities" : "正在載入更多活動",
     "No more activities." : "無更多活動",
-    "Could not load activites" : "無法載入活動",
+    "Could not load activities" : "無法載入活動",
     "Activity settings" : "活動設定",
     "Enable RSS feed" : "啟用 RSS 摘要",
     "RSS feed" : "RSS 摘要",
@@ -74,9 +73,7 @@ OC.L10N.register(
     "{name} (invisible)" : "{name} （隱藏）",
     "{name} (restricted)" : "{name} （受限）",
     "There are no events for this filter" : "在此篩選器下沒有活動",
-    "This application enables users to view a log of activities about them or about files." : "本應用程式可以讓使用者檢視有關自己或檔案的活動記錄。",
-    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓使用者能夠在 Nextcloud 中查看與其檔案相關的操作。\n\t\t啟用後，使用者將在其選單中看到一個「活動」新圖示。\n\t\t點選後，將顯示一個新頁面，以供使用者追蹤與文件相關的活動 ─ 包含新增檔案、已刪除檔案、移動、重新命名、更新和分享活動。\n\t\t使用者可以在其個人選單中配置其各自的活動設定。\n\t\t此設定了想要記錄的活動類型，以及使用者是否可看到自己的活動，\n\t\t並是否僅為線上提供，以及是否定期收到電子郵件摘要。\n\t\t活動說明文件中提供了更多訊息。",
     "Activities" : "活動",
-    "Configure the default notification settings for new users." : "為新使用者設定預設的通知設定。"
+    "Could not load activites" : "無法載入活動"
 },
 "nplurals=1; plural=0;");
