@@ -466,7 +466,8 @@ class MailQueueHandler {
 		foreach ($this->activityManager->getProviders() as $provider) {
 			try {
 				$event = $provider->parse($lang, $event);
-			} catch (\InvalidArgumentException $e) {
+			} catch (\Throwable $e) {
+				$this->logger->error('Error while parsing activity event', ['exception' => $e]);
 			}
 		}
 		$this->activityManager->setFormattingObject('', 0);
