@@ -2,24 +2,21 @@ OC.L10N.register(
     "circles",
     {
     "Personal" : "Persoonlik",
+    "System" : "Stelsel",
+    "Visible" : "Sigbaar",
+    "Open" : "Open",
+    "Hidden" : "Versteek",
+    "Email address" : "E-posadres",
     "Contact" : "Kontak",
     "Admin" : "Admin",
     "Owner" : "Eienaar",
     "Open »%s«" : "Open »%s«",
     "Accept" : "Aanvaar",
-    "now" : "nou",
     "No files in here" : "Geen lêers hier nie",
     "No entries found in this folder" : "Geen inskrwyings in hierdie gids gevind",
     "Name" : "Naam",
     "Size" : "Grootte",
     "Modified" : "Gewysig",
-    "Secret" : "Geheim",
-    "Unknown" : "Onbekend",
-    "Mail Address" : "Posadres",
-    "Settings" : "Instellings",
-    "Username" : "Gebruikersnaam",
-    "Link" : "Skakel",
-    "Description" : "Beskrywing",
-    "Change password" : "Verander wagwoord"
+    "now" : "nou"
 },
 "nplurals=2; plural=(n != 1);");
