@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Кръгове",
-    "Circles' files" : "Файлове на кръгове",
-    "Select circles to filter by" : "Изберете кръгове, по които да филтрирате",
-    "No circles found" : "Няма намерени кръгове",
-    "Please select circles to filter by" : "Моля, изберете кръгове по които да филтрирате",
-    "No files found for the selected circles" : "Няма намерени файлове за избраните кръгове",
-    "You created the circle {circle}" : "Вие създадохте кръгът {circle}",
-    "{author} created the circle {circle}" : "{author} създаде кръгът {circle}",
     "You deleted {circle}" : "Вие изтрихте {circle}",
     "{author} deleted {circle}" : "{author} изтри {circle}",
-    "You linked {group} to {circle}" : "Вие свързахте {group} към {circle}",
-    "{group} has been linked to {circle} by {author}" : "{group} бе свързана с {circle} от {author}",
-    "You unlinked {group} from {circle}" : "Вие прекъснахте връзката на {group} с {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "На {group} е прекратена връзката с {circle} от {author}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Вие променихте нивото на свързаната група {group} в {circle} на %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} промени нивото на свързаната група {group} в {кръг} на %1$s",
-    "You sent a request to link {circle} with {remote}" : "Изпратихте заявка за свързване на {circle} с {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} изпрати заявка за свързване на {circle} с {remote}",
-    "{remote} requested a link with {circle}" : "{remote} поиска заявка за връзка с {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "Искането за свързване на {circle} с {remote} беше отхвърлено",
-    "The request to link {remote} with {circle} has been canceled remotely" : "Искането за свързване на {remote} с {circle} беше отменено от разстояние",
-    "The request to link {circle} with {remote} has been accepted" : "Заявката за свързване на {circle} с {remote} беше приета",
-    "You dismissed the request to link {remote} with {circle}" : "Отхвърлихте заявката за свързване на {remote} с {circle}",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} отхвърли заявката за свързване на {remote} с {circle}",
-    "You canceled the request to link {circle} with {remote}" : "Отменихте заявката за свързване на {circle} с {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} отмени заявката за свързване на {circle} с {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Приехте заявката за свързване на {remote} с {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} прие заявката за свързване на {remote} с {circle}",
-    "A link between {circle} and {remote} is now up and running" : "Връзката между {circle} и {remote} вече е създадена и работи",
-    "The link between {circle} and {remote} has been shutdown remotely" : "Връзката между {circle} и {remote} беше изключена от разстояние",
-    "You closed the link between {circle} and {remote}" : "Затворихте връзката между {circle} и {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} затвори връзката между {circle} и {remote}",
     "You joined {circle}" : "Вие се присъединихте към {circle}",
     "{member} joined {circle}" : "{member} се присъедини към {circle}",
     "You accepted the invitation to join {circle}" : "Приехте поканата да се присъедините към {circle}",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Отказахте поканата да се присъедините към {circle}",
     "{member} declined an invitation to join {circle}" : "{member} отказа поканата да се присъедини към  {circle}",
     "You cancelled your request to join {circle}" : "Отменихте заявката си за присъединяване към {circle}",
-    "{member} cancelled his request to join {circle}" : "{member} отмени заявката си за присъединяване към {circle}",
     "You removed {member} from {circle}" : "Премахнахте {member} от {circle}",
     "You have been removed from {circle} by {author}" : "Бяхте премахнат от {circle} от {author}",
     "{member} has been removed from {circle} by {author}" : "{member} беше премахнат от {circle} от {author}",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} изпрати заявка за присъединяване към {circle}",
     "You are the new owner of {circle}" : "Вие сте новият собственик на {circle}",
     "{member} is the new owner of {circle}" : "{member} е новият собственик на {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "На събития, случващи се в <strong>Circle</strong>, в който вие сте член",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Всяко важно събитие в <strong>Circle</strong>, което вие модерирате",
-    "On global events happening in any <strong>Circle</strong>" : "На глобални събития, които се случват във всеки <strong>Circle</strong>",
     "Shared to Circles" : "Споделено с Кръгове",
     "Single" : "Единичен",
     "Personal" : "Лични",
@@ -82,20 +48,18 @@ OC.L10N.register(
     "Visible" : "Видимо",
     "Open" : "Отвори",
     "Invite" : "Покани",
-    "Join Request" : "Заявка за присъединяване",
     "Friends" : "Приятели",
-    "Password Protected" : "Защитено с парола",
+    "Password protected" : "Защитено с парола",
     "No Owner" : "Няма собственик",
     "Hidden" : "Скрит",
     "Backend" : " Сървър",
     "Local" : "Локален",
     "Root" : "Основен",
-    "Circle Invite" : "Покана за Circle/кръг/",
     "Federated" : "Федериран",
     "Mount point" : "Точка на монтиране",
     "Nextcloud Account" : "Nextcloud профил",
     "Nextcloud Group" : "Nextcloud Група",
-    "Email Address" : "Имейл адрес",
+    "Email address" : "Имейл адрес",
     "Contact" : "Контакт",
     "Circle" : "Кръг",
     "Nextcloud App" : "Приложение Nextcloud App",
@@ -127,23 +91,15 @@ OC.L10N.register(
     "Building Local Database" : "Изграждане на Локална База Данни",
     "Testing Basic Circle Creation" : "Тестване на създаването на основен кръг",
     "Adding local users and moderators" : "Добавяне на локални потребители и модератори",
-    "Circle not found" : "Кръгът не е намерен",
-    "Circle not found " : "Кръгът не е намерен",
-    "This member does not exist" : "Този член не съществува",
-    "This account is already a member of the circle" : "Този профил вече е член на кръга",
-    "Federated link not found" : "Федерираната връзка не е намерена",
     "This feature is not available for personal circles" : "Тази функция не е налична за лични кръгове",
-    "The circle is not federated" : "Кръгът не е федериран",
-    "You cannot join this circle" : "Не можете да се присъедините към този кръг",
     "This member is not a moderator" : "Този член не е модератор",
     "Insufficient privileges" : "Недостатъчни привилегии",
-    "This member is the owner of the circle" : "Този член е собственикът на кръга",
+    "This member does not exist" : "Този член не съществува",
     "Level cannot be changed for this type of member" : "Нивото не може да се променя за член от този тип ",
     "You are already a member of this circle" : "Вече сте член на този кръг",
     "You have been blocked from this circle" : "Бяхте блокиран от този кръг",
     "The account is already a member of this circle" : "Този профил вече е член на този кръг",
     "The account has already been invited into this circle" : "Този профил вече е бил поканен в този кръг",
-    "%s (Circle owned by %s)" : "%s (Кръг, притежаван от %s)",
     "You are now a member of the Circle \"%2$s\"" : " \nВече сте член на Кръга \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Вие сте поканени от %1$s в Кръга \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s са изпратили заявка да бъдат членове на Кръга \"%2$s\"",
@@ -151,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "Отказ",
     "Leave the circle" : "Напускане на кръга",
     "%s" : "%s",
-    "Personal Circle" : "Личен кръг",
     "%s owned by %s" : "%s притежаван от  %s",
+    "%s shared a file with \"%s\"." : "%s сподели файл с „%s“.",
+    "%s shared a file with you." : "%sсподели файл с вас. ",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.",
+    "Password to access content shared with you by %1$s" : "Парола за достъп до съдържание, споделени с вас от %1$s",
+    "Password to access content" : "Парола за достъп до съдържание",
+    "Bring cloud-users closer together." : "Доближете потребителите на облака по-близо.",
+    "No files in here" : "Няма файлове",
+    "No entries found in this folder" : "Папката е празна",
+    "Name" : "Име",
+    "Size" : "Размер",
+    "Modified" : "Променен на",
+    "Circles" : "Кръгове",
+    "Circles' files" : "Файлове на кръгове",
+    "Select circles to filter by" : "Изберете кръгове, по които да филтрирате",
+    "No circles found" : "Няма намерени кръгове",
+    "Please select circles to filter by" : "Моля, изберете кръгове по които да филтрирате",
+    "No files found for the selected circles" : "Няма намерени файлове за избраните кръгове",
+    "You created the circle {circle}" : "Вие създадохте кръгът {circle}",
+    "{author} created the circle {circle}" : "{author} създаде кръгът {circle}",
+    "You linked {group} to {circle}" : "Вие свързахте {group} към {circle}",
+    "{group} has been linked to {circle} by {author}" : "{group} бе свързана с {circle} от {author}",
+    "You unlinked {group} from {circle}" : "Вие прекъснахте връзката на {group} с {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "На {group} е прекратена връзката с {circle} от {author}",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Вие променихте нивото на свързаната група {group} в {circle} на %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} промени нивото на свързаната група {group} в {кръг} на %1$s",
+    "You sent a request to link {circle} with {remote}" : "Изпратихте заявка за свързване на {circle} с {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{author} изпрати заявка за свързване на {circle} с {remote}",
+    "{remote} requested a link with {circle}" : "{remote} поиска заявка за връзка с {circle}",
+    "The request to link {circle} with {remote} has been rejected" : "Искането за свързване на {circle} с {remote} беше отхвърлено",
+    "The request to link {remote} with {circle} has been canceled remotely" : "Искането за свързване на {remote} с {circle} беше отменено от разстояние",
+    "The request to link {circle} with {remote} has been accepted" : "Заявката за свързване на {circle} с {remote} беше приета",
+    "You dismissed the request to link {remote} with {circle}" : "Отхвърлихте заявката за свързване на {remote} с {circle}",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} отхвърли заявката за свързване на {remote} с {circle}",
+    "You canceled the request to link {circle} with {remote}" : "Отменихте заявката за свързване на {circle} с {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} отмени заявката за свързване на {circle} с {remote}",
+    "You accepted the request to link {remote} with {circle}" : "Приехте заявката за свързване на {remote} с {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} прие заявката за свързване на {remote} с {circle}",
+    "A link between {circle} and {remote} is now up and running" : "Връзката между {circle} и {remote} вече е създадена и работи",
+    "The link between {circle} and {remote} has been shutdown remotely" : "Връзката между {circle} и {remote} беше изключена от разстояние",
+    "You closed the link between {circle} and {remote}" : "Затворихте връзката между {circle} и {remote}",
+    "{author} closed the link between {circle} and {remote}" : "{author} затвори връзката между {circle} и {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} отмени заявката си за присъединяване към {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "На събития, случващи се в <strong>Circle</strong>, в който вие сте член",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Всяко важно събитие в <strong>Circle</strong>, което вие модерирате",
+    "On global events happening in any <strong>Circle</strong>" : "На глобални събития, които се случват във всеки <strong>Circle</strong>",
+    "Join Request" : "Заявка за присъединяване",
+    "Password Protected" : "Защитено с парола",
+    "Circle Invite" : "Покана за Circle/кръг/",
+    "Email Address" : "Имейл адрес",
+    "Initialisation Nextcloud" : "Nextcloud Инициализация",
+    "Initialisation Circles App" : "Инициализация на Приложението Circles",
+    "Circle not found" : "Кръгът не е намерен",
+    "Circle not found " : "Кръгът не е намерен",
+    "This account is already a member of the circle" : "Този профил вече е член на кръга",
+    "Federated link not found" : "Федерираната връзка не е намерена",
+    "The circle is not federated" : "Кръгът не е федериран",
+    "You cannot join this circle" : "Не можете да се присъедините към този кръг",
+    "This member is the owner of the circle" : "Този член е собственикът на кръга",
+    "%s (Circle owned by %s)" : "%s (Кръг, притежаван от %s)",
+    "Personal Circle" : "Личен кръг",
     "You need a specify a type of circle" : "Трябва да посочите тип кръг",
     "A circle with that name exists" : "Съществува кръг с това име",
     "This member is not the owner of the circle" : "Този член не е собственик на кръга",
@@ -167,21 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "Невалиден Имейл формат",
     "This contact is not available" : "Този контакт е недостъпен",
     "You have no permission to create a new circle" : "Нямате право да създавате нов кръг /circle/",
-    "%s shared a file with \"%s\"." : "%s сподели файл с „%s“.",
-    "%s shared a file with you." : "%sсподели файл с вас. ",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s сподели някакво съдържание с вас.\nВече трябва да сте получили отделен имейл с връзка за достъп до него.",
-    "Password to access content shared with you by %1$s" : "Парола за достъп до съдържание, споделени с вас от %1$s",
-    "Password to access content" : "Парола за достъп до съдържание",
     "This item is already shared with this circle" : "Елементът вече е споделен с този кръг",
-    "Bring cloud-users closer together." : "Доближете потребителите на облака по-близо.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Приложението Circles /Кръгове/, позволява на хората да създават свои собствени групи от хора/колеги/приятели.\nТези групи от хора (или \"кръгове\") след това могат да се използват от всяко друго приложение за споделяне.",
-    "No files in here" : "Няма файлове",
-    "No entries found in this folder" : "Папката е празна",
-    "Name" : "Име",
-    "Size" : "Размер",
-    "Modified" : "Променен на",
-    "Initialisation Nextcloud" : "Nextcloud Инициализация",
-    "Initialisation Circles App" : "Инициализация на Приложението Circles"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Приложението Circles /Кръгове/, позволява на хората да създават свои собствени групи от хора/колеги/приятели.\nТези групи от хора (или \"кръгове\") след това могат да се използват от всяко друго приложение за споделяне."
 },
 "nplurals=2; plural=(n != 1);");
