@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Cercles",
-    "Circles' files" : "Fitxers de cercles",
-    "Select circles to filter by" : "Seleccioneu els cercles pels quals voleu filtrar",
-    "No circles found" : "No s'ha trobat cap cercle",
-    "Please select circles to filter by" : "Seleccioneu els cercles pels quals voleu filtrar",
-    "No files found for the selected circles" : "No s'ha trobat cap fitxer per als cercles seleccionats",
-    "You created the circle {circle}" : "Heu creat el cercle {circle}",
-    "{author} created the circle {circle}" : "{author} ha creat el cercle {circle}",
     "You deleted {circle}" : "Heu suprimit {circle}",
     "{author} deleted {circle}" : "{author} ha suprimit {circle}",
-    "You linked {group} to {circle}" : "Heu enllaçat {group} a {circle}",
-    "{group} has been linked to {circle} by {author}" : "{author} ha enllaçat {group} a {circle}",
-    "You unlinked {group} from {circle}" : "Heu desenllaçat {group} del cercle {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{author} ha desenllaçat {group} del cercle {circle}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Heu canviat el nivell del grup enllaçat {group} del cercle {circle} a %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ha canviat el nivell del grup enllaçat {group} del cercle {circle} a %1$s",
-    "You sent a request to link {circle} with {remote}" : "Heu enviat una sol·licitud per a enllaçar {circle} amb {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} ha enviat una sol·licitud per a enllaçar {circle} amb {remote}",
-    "{remote} requested a link with {circle}" : "{remote} ha sol·licitat enllaçar {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "S'ha rebutjat la sol·licitud per a enllaçar {circle} amb {remote}",
-    "The request to link {remote} with {circle} has been canceled remotely" : "La sol·licitud per a enllaçar {remote} amb {circle} s'ha cancel·lat de manera remota",
-    "The request to link {circle} with {remote} has been accepted" : "S'ha acceptat la sol·licitud per a enllaçar {circle} amb {remote}",
-    "You dismissed the request to link {remote} with {circle}" : "Heu descartat la sol·licitud per a enllaçar {remote} amb {circle}",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} ha descartat la sol·licitud per a enllaçar {remote} amb {circle}",
-    "You canceled the request to link {circle} with {remote}" : "Heu cancel·lat la sol·licitud per a enllaçar {circle} amb {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} ha cancel·lat la sol·licitud per a enllaçar {circle} amb {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Heu acceptat la sol·licitud per a enllaçar {remote} amb {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} ha acceptat la sol·licitud per a enllaçar {remote} amb {circle}",
-    "A link between {circle} and {remote} is now up and running" : "Hi ha un enllaç actiu entre {circle} i {remote}",
-    "The link between {circle} and {remote} has been shutdown remotely" : "L'enllaç entre {circle} i {remote} s'ha tancat de manera remota",
-    "You closed the link between {circle} and {remote}" : "Heu tancat l'enllaç entre {circle} i {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} ha tancat l'enllaç entre {circle} i {remote}",
     "You joined {circle}" : "Us heu unit a {circle}",
     "{member} joined {circle}" : "{member} s'ha unit a {circle}",
     "You accepted the invitation to join {circle}" : "Heu acceptat la invitació per a unir-vos a {circle}",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Heu rebutjat la invitació per a unir-vos a {circle}",
     "{member} declined an invitation to join {circle}" : "{member} ha rebutjat la invitació per a unir-se a {circle}",
     "You cancelled your request to join {circle}" : "Heu cancel·lat la sol·licitud per a unir-vos a {circle}",
-    "{member} cancelled his request to join {circle}" : "{member} ha cancel·lat la sol·licitud per a unir-se a {circle}",
     "You removed {member} from {circle}" : "Heu suprimit {member} del cercle {circle}",
     "You have been removed from {circle} by {author}" : "{author} us ha suprimit del cercle {circle}",
     "{member} has been removed from {circle} by {author}" : "{author} ha suprimit {member} del cercle {circle}",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} ha enviat una sol·licitud per a unir-se a {circle}",
     "You are the new owner of {circle}" : "Ara teniu la propietat del cercle {circle}",
     "{member} is the new owner of {circle}" : "{member} ara té la propietat del cercle {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Quan es produeixin esdeveniments en un <strong>cercle</strong> del qual sigueu membre",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Quan es produeixi qualsevol esdeveniment important en un <strong>cercle</strong> que modereu",
-    "On global events happening in any <strong>Circle</strong>" : "Quan es produeixin esdeveniments globals en qualsevol <strong>cercle</strong>",
     "Shared to Circles" : "Compartits en cercles",
     "Single" : "Individual",
     "Personal" : "Personal",
@@ -82,20 +48,18 @@ OC.L10N.register(
     "Visible" : "Visible",
     "Open" : "Obert",
     "Invite" : "Invitació",
-    "Join Request" : "Sol·licitud per a unir-s'hi",
     "Friends" : "Amics",
-    "Password Protected" : "Protegit amb contrasenya",
+    "Password protected" : "Protegit amb contrasenya",
     "No Owner" : "Sense propietari",
     "Hidden" : "Ocult",
     "Backend" : "Rerefons",
     "Local" : "Local",
     "Root" : "Arrel",
-    "Circle Invite" : "Invitació al cercle",
     "Federated" : "Federat",
     "Mount point" : "Punt de muntatge",
     "Nextcloud Account" : "Compte del Nextcloud",
     "Nextcloud Group" : "Grup del Nextcloud",
-    "Email Address" : "Adreça electrònica",
+    "Email address" : "Adreça electrònica",
     "Contact" : "Contacte",
     "Circle" : "Cercle",
     "Nextcloud App" : "Aplicació del Nextcloud",
@@ -127,23 +91,15 @@ OC.L10N.register(
     "Building Local Database" : "S'està creant la base de dades local",
     "Testing Basic Circle Creation" : "S'està provant la creació d'un cercle bàsic",
     "Adding local users and moderators" : "S'estan afegint usuaris i moderadors locals",
-    "Circle not found" : "No s'ha trobat el cercle",
-    "Circle not found " : "No s'ha trobat el cercle ",
-    "This member does not exist" : "Aquest membre no existeix",
-    "This account is already a member of the circle" : "Aquest compte ja és membre del cercle",
-    "Federated link not found" : "No s'ha trobat l'enllaç federat",
     "This feature is not available for personal circles" : "Aquesta característica no està disponible per als cercles personals",
-    "The circle is not federated" : "El cercle no és federat",
-    "You cannot join this circle" : "No podeu unir-vos a aquest cercle",
     "This member is not a moderator" : "Aquest membre no té permisos de moderació",
     "Insufficient privileges" : "Privilegis insuficients",
-    "This member is the owner of the circle" : "Aquest membre té la propietat del cercle",
+    "This member does not exist" : "Aquest membre no existeix",
     "Level cannot be changed for this type of member" : "No es pot canviar el nivell per a aquest tipus de membre",
     "You are already a member of this circle" : "Ja sou membre d'aquest cercle",
     "You have been blocked from this circle" : "Se us ha blocat d'aquest cercle",
     "The account is already a member of this circle" : "El compte ja és membre d'aquest cercle",
     "The account has already been invited into this circle" : "El compte ja ha rebut una invitació per a aquest cercle",
-    "%s (Circle owned by %s)" : "%s (cercle propietat de %s)",
     "You are now a member of the Circle \"%2$s\"" : "Ara sou membre del cercle «%2$s»",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s us ha convidat al cercle «%2$s»",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha enviat una sol·licitud per a ser membre del cercle «%2$s»",
@@ -151,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "Rebutja",
     "Leave the circle" : "Surt del cercle",
     "%s" : "%s",
-    "Personal Circle" : "Cercle personal",
     "%s owned by %s" : "%s propietat de %s",
+    "%s shared a file with \"%s\"." : "%s ha compartit un fitxer amb «%s».",
+    "%s shared a file with you." : "%s ha compartit un fitxer amb vós.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha compartit contingut amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha compartit contingut amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
+    "Password to access content shared with you by %1$s" : "Contrasenya per a accedir al contingut que %1$s ha compartit amb vós",
+    "Password to access content" : "Contrasenya per a accedir al contingut",
+    "Bring cloud-users closer together." : "Acosteu els usuaris del núvol.",
+    "No files in here" : "No hi ha cap fitxer aquí",
+    "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
+    "Name" : "Nom",
+    "Size" : "Mida",
+    "Modified" : "Data de modificació",
+    "Circles" : "Cercles",
+    "Circles' files" : "Fitxers de cercles",
+    "Select circles to filter by" : "Seleccioneu els cercles pels quals voleu filtrar",
+    "No circles found" : "No s'ha trobat cap cercle",
+    "Please select circles to filter by" : "Seleccioneu els cercles pels quals voleu filtrar",
+    "No files found for the selected circles" : "No s'ha trobat cap fitxer per als cercles seleccionats",
+    "You created the circle {circle}" : "Heu creat el cercle {circle}",
+    "{author} created the circle {circle}" : "{author} ha creat el cercle {circle}",
+    "You linked {group} to {circle}" : "Heu enllaçat {group} a {circle}",
+    "{group} has been linked to {circle} by {author}" : "{author} ha enllaçat {group} a {circle}",
+    "You unlinked {group} from {circle}" : "Heu desenllaçat {group} del cercle {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{author} ha desenllaçat {group} del cercle {circle}",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Heu canviat el nivell del grup enllaçat {group} del cercle {circle} a %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ha canviat el nivell del grup enllaçat {group} del cercle {circle} a %1$s",
+    "You sent a request to link {circle} with {remote}" : "Heu enviat una sol·licitud per a enllaçar {circle} amb {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{author} ha enviat una sol·licitud per a enllaçar {circle} amb {remote}",
+    "{remote} requested a link with {circle}" : "{remote} ha sol·licitat enllaçar {circle}",
+    "The request to link {circle} with {remote} has been rejected" : "S'ha rebutjat la sol·licitud per a enllaçar {circle} amb {remote}",
+    "The request to link {remote} with {circle} has been canceled remotely" : "La sol·licitud per a enllaçar {remote} amb {circle} s'ha cancel·lat de manera remota",
+    "The request to link {circle} with {remote} has been accepted" : "S'ha acceptat la sol·licitud per a enllaçar {circle} amb {remote}",
+    "You dismissed the request to link {remote} with {circle}" : "Heu descartat la sol·licitud per a enllaçar {remote} amb {circle}",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} ha descartat la sol·licitud per a enllaçar {remote} amb {circle}",
+    "You canceled the request to link {circle} with {remote}" : "Heu cancel·lat la sol·licitud per a enllaçar {circle} amb {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} ha cancel·lat la sol·licitud per a enllaçar {circle} amb {remote}",
+    "You accepted the request to link {remote} with {circle}" : "Heu acceptat la sol·licitud per a enllaçar {remote} amb {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} ha acceptat la sol·licitud per a enllaçar {remote} amb {circle}",
+    "A link between {circle} and {remote} is now up and running" : "Hi ha un enllaç actiu entre {circle} i {remote}",
+    "The link between {circle} and {remote} has been shutdown remotely" : "L'enllaç entre {circle} i {remote} s'ha tancat de manera remota",
+    "You closed the link between {circle} and {remote}" : "Heu tancat l'enllaç entre {circle} i {remote}",
+    "{author} closed the link between {circle} and {remote}" : "{author} ha tancat l'enllaç entre {circle} i {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} ha cancel·lat la sol·licitud per a unir-se a {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "Quan es produeixin esdeveniments en un <strong>cercle</strong> del qual sigueu membre",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Quan es produeixi qualsevol esdeveniment important en un <strong>cercle</strong> que modereu",
+    "On global events happening in any <strong>Circle</strong>" : "Quan es produeixin esdeveniments globals en qualsevol <strong>cercle</strong>",
+    "Join Request" : "Sol·licitud per a unir-s'hi",
+    "Password Protected" : "Protegit amb contrasenya",
+    "Circle Invite" : "Invitació al cercle",
+    "Email Address" : "Adreça electrònica",
+    "Initialisation Nextcloud" : "Inicialització del Nextcloud",
+    "Initialisation Circles App" : "Inicialització de l’aplicació Cercles",
+    "Circle not found" : "No s'ha trobat el cercle",
+    "Circle not found " : "No s'ha trobat el cercle ",
+    "This account is already a member of the circle" : "Aquest compte ja és membre del cercle",
+    "Federated link not found" : "No s'ha trobat l'enllaç federat",
+    "The circle is not federated" : "El cercle no és federat",
+    "You cannot join this circle" : "No podeu unir-vos a aquest cercle",
+    "This member is the owner of the circle" : "Aquest membre té la propietat del cercle",
+    "%s (Circle owned by %s)" : "%s (cercle propietat de %s)",
+    "Personal Circle" : "Cercle personal",
     "You need a specify a type of circle" : "Heu d'especificar un tipus de cercle",
     "A circle with that name exists" : "Ja existeix un cercle amb aquest nom",
     "This member is not the owner of the circle" : "Aquest membre no té la propietat del cercle",
@@ -167,21 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "El format de l'adreça electrònica no és vàlid",
     "This contact is not available" : "Aquest contacte no està disponible",
     "You have no permission to create a new circle" : "No teniu permís per a crear un cercle nou",
-    "%s shared a file with \"%s\"." : "%s ha compartit un fitxer amb «%s».",
-    "%s shared a file with you." : "%s ha compartit un fitxer amb vós.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha compartit contingut amb vós.\nJa hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha compartit contingut amb vós. Ja hauríeu d'haver rebut un altre correu electrònic amb un enllaç per a accedir-hi.",
-    "Password to access content shared with you by %1$s" : "Contrasenya per a accedir al contingut que %1$s ha compartit amb vós",
-    "Password to access content" : "Contrasenya per a accedir al contingut",
     "This item is already shared with this circle" : "Aquest element ja està compartit amb aquest cercle",
-    "Bring cloud-users closer together." : "Acosteu els usuaris del núvol.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Els cercles permeten que les persones creïn els seus propis grups de persones, companys i amics.\nQualsevol altra aplicació pot utilitzar aquests grups de persones (o «cercles») per a compartir contingut.",
-    "No files in here" : "No hi ha cap fitxer aquí",
-    "No entries found in this folder" : "No s'ha trobat cap entrada en aquesta carpeta",
-    "Name" : "Nom",
-    "Size" : "Mida",
-    "Modified" : "Data de modificació",
-    "Initialisation Nextcloud" : "Inicialització del Nextcloud",
-    "Initialisation Circles App" : "Inicialització de l’aplicació Cercles"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Els cercles permeten que les persones creïn els seus propis grups de persones, companys i amics.\nQualsevol altra aplicació pot utilitzar aquests grups de persones (o «cercles») per a compartir contingut."
 },
 "nplurals=2; plural=(n != 1);");
