@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Cirkler",
-    "Circles' files" : "Cirklen's filer",
-    "Select circles to filter by" : "Vælg cirkler at filtrere efter",
-    "No circles found" : "Ingen cirkler fundet",
-    "Please select circles to filter by" : "Vælg venligst cirkler at filtrere efter",
-    "No files found for the selected circles" : "Der blev ikke fundet nogen filer for de valgte cirkler",
-    "You created the circle {circle}" : "Du oprettede cirklen {circle}",
-    "{author} created the circle {circle}" : "{author} oprettede cirklen {circle}",
     "You deleted {circle}" : "Du slettede {circle}",
     "{author} deleted {circle}" : "{author} slettede {circle}",
-    "You linked {group} to {circle}" : "Du forbandt {group} til {circle}",
-    "{group} has been linked to {circle} by {author}" : "{group} er blevet forbundet til {circle} af {author}",
-    "You unlinked {group} from {circle}" : "Du fjernede linket til {group} fra {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{group} er blevet fjernet fra {circle} af {author}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Du ændrede niveauet for den linkede gruppe {group} i {circle} til%1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ændrede niveauet for den linkede gruppe {gruppe} i {cirkel} til %1$s",
-    "You sent a request to link {circle} with {remote}" : "Du sendte en anmodning om at linke {circle} med {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} sendte en anmodning om at linke {circle} med {remote}",
-    "{remote} requested a link with {circle}" : "{remote} anmodede om et link med {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "Anmodningen om at linke {circle} med {remote} er blevet afvist",
-    "The request to link {remote} with {circle} has been canceled remotely" : "Anmodningen om at linke {remote} til {circle} er blevet annulleret eksternt",
-    "The request to link {circle} with {remote} has been accepted" : "Anmodningen om at forbinde {circle} med {remote} er blevet accepteret",
-    "You dismissed the request to link {remote} with {circle}" : "Du afviste anmodningen om at linke {remote} til {circle}",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} afviste anmodningen om at linke {remote} til {circle}",
-    "You canceled the request to link {circle} with {remote}" : "Du annullerede anmodningen om at linke {circle} med {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} annullerede anmodningen om at linke {circle} med {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Du accepterede anmodningen om at linke {remote} til {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} accepterede anmodningen om at linke {remote} med {circle}",
-    "A link between {circle} and {remote} is now up and running" : "Et link mellem {circle} og {remote} er nu oppe at køre",
-    "The link between {circle} and {remote} has been shutdown remotely" : "Linket mellem {circle} og {remote} er blevet lukket fra fjernt",
-    "You closed the link between {circle} and {remote}" : "Du lukkede linket mellem {circle} og {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} lukkede linket mellem {circle} og {remote}",
     "You joined {circle}" : "Du har forbundet med {circle}",
     "{member} joined {circle}" : "{member} sluttede sig til {circle}",
     "You accepted the invitation to join {circle}" : "Du accepterede invitationen til at deltage i {circle}",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Du har afvist en invitation om at forbinde med {circle}",
     "{member} declined an invitation to join {circle}" : "{member} afviste invitation om at forbinde med {circle}",
     "You cancelled your request to join {circle}" : "Du har annulleret din anmodning om at deltage i {circle}",
-    "{member} cancelled his request to join {circle}" : "{member} annullerede hans anmodning om at deltage i {circle}",
     "You removed {member} from {circle}" : "Du fjernede {member} fra {circle}",
     "You have been removed from {circle} by {author}" : "Du er blevet fjernet fra {circle} af {author}",
     "{member} has been removed from {circle} by {author}" : "{member} er blevet fjernet fra {circle} af {author}",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} sendte en anmodning om at deltage i {circle}",
     "You are the new owner of {circle}" : "Du er den nye ejer af {circle}",
     "{member} is the new owner of {circle}" : "{member} er den nye ejer af {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Om begivenheder, der finder sted i en <strong>Circle</strong>, som du er medlem af ",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Enhver vigtig begivenhed i en <strong>Circle</strong>, du modererer",
-    "On global events happening in any <strong>Circle</strong>" : "På globale begivenheder, der sker i enhver <strong>Circle</strong>",
     "Shared to Circles" : "Delt til Cirkler",
     "Single" : "Enkelt",
     "Personal" : "Personlig",
@@ -82,20 +48,18 @@ OC.L10N.register(
     "Visible" : "Synlig",
     "Open" : "Åbn",
     "Invite" : "Invitere",
-    "Join Request" : "Tilmeldingsanmodning",
     "Friends" : "Venner",
-    "Password Protected" : "Adgangskodebeskyttet",
+    "Password protected" : "Beskyt med adgangskode",
     "No Owner" : "Ingen ejer",
     "Hidden" : "Skjult",
     "Backend" : "Bagende",
     "Local" : "Lokal",
     "Root" : "Root",
-    "Circle Invite" : "Cirkel invitation",
     "Federated" : "Forbundet",
     "Mount point" : "Monteringspunkt",
     "Nextcloud Account" : "Nextcloud-konto",
     "Nextcloud Group" : "Nextcloud gruppe",
-    "Email Address" : "Email adresse",
+    "Email address" : "Email adresse",
     "Contact" : "Kontakt",
     "Circle" : "Cirkel",
     "Nextcloud App" : "Nextcloud app",
@@ -127,23 +91,15 @@ OC.L10N.register(
     "Building Local Database" : "Opsætning af lokal database",
     "Testing Basic Circle Creation" : "Test af grundlæggende cirkeloprettelse",
     "Adding local users and moderators" : "Tilføjelse af lokale brugere og moderatorer",
-    "Circle not found" : "Cirklen blev ikke fundet",
-    "Circle not found " : "Cirklen blev ikke fundet",
-    "This member does not exist" : "Dette medlem eksisterer ikke",
-    "This account is already a member of the circle" : "Denne konto er allerede medlem af cirklen",
-    "Federated link not found" : "Fødereret link blev ikke fundet",
     "This feature is not available for personal circles" : "Denne funktion er ikke tilgængelig for personlige cirkler",
-    "The circle is not federated" : "Cirklen er ikke fødereret",
-    "You cannot join this circle" : "Du kan ikke forbinde med cirklen",
     "This member is not a moderator" : "Dette medlem er ikke en moderator",
     "Insufficient privileges" : "Utilstrækkelige rettigheder",
-    "This member is the owner of the circle" : "Dette medlem ejer cirklen",
+    "This member does not exist" : "Dette medlem eksisterer ikke",
     "Level cannot be changed for this type of member" : "Niveau kan ikke ændres for denne type medlem",
     "You are already a member of this circle" : "Du er allerede medlem af cirklen",
     "You have been blocked from this circle" : "Du er blevet blokeret fra denne cirkel",
     "The account is already a member of this circle" : "Kontoen er allerede medlem af denne cirkel",
     "The account has already been invited into this circle" : "Kontoen er allerede inviteret til denne cirkel",
-    "%s (Circle owned by %s)" : "%s (cirkel ejet af %s)",
     "You are now a member of the Circle \"%2$s\"" : "Du er nu medlem af cirklen \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Du er blevet inviteret af %1$s ind i cirklen \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s sendte en anmodning om at blive medlem af cirklen \"%2$s\"",
@@ -151,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "Afvis",
     "Leave the circle" : "Forlad cirklen",
     "%s" : "%s",
-    "Personal Circle" : "Personlig cirkel",
     "%s owned by %s" : "%s ejet af %s",
+    "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
+    "%s shared a file with you." : "%s delte en fil med dig.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delt indhold med dig.\nDu burde allerede have modtaget en separat e-mail med et link for at få adgang...\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delt indhold med dig. Du burde allerede have modtaget en e-mail med et link for at få adgang...",
+    "Password to access content shared with you by %1$s" : "Adgangskode for at få adgang til indhold, der deles med dig af %1$s",
+    "Password to access content" : "Adgangskode for at få adgang til indhold",
+    "Bring cloud-users closer together." : "Bring cloud-brugere tættere på hinanden.",
+    "No files in here" : "Ingen filer herinde",
+    "No entries found in this folder" : "Intet fundet i denne mappe",
+    "Name" : "Navn",
+    "Size" : "Størrelse",
+    "Modified" : "Ændret",
+    "Circles" : "Cirkler",
+    "Circles' files" : "Cirklen's filer",
+    "Select circles to filter by" : "Vælg cirkler at filtrere efter",
+    "No circles found" : "Ingen cirkler fundet",
+    "Please select circles to filter by" : "Vælg venligst cirkler at filtrere efter",
+    "No files found for the selected circles" : "Der blev ikke fundet nogen filer for de valgte cirkler",
+    "You created the circle {circle}" : "Du oprettede cirklen {circle}",
+    "{author} created the circle {circle}" : "{author} oprettede cirklen {circle}",
+    "You linked {group} to {circle}" : "Du forbandt {group} til {circle}",
+    "{group} has been linked to {circle} by {author}" : "{group} er blevet forbundet til {circle} af {author}",
+    "You unlinked {group} from {circle}" : "Du fjernede linket til {group} fra {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{group} er blevet fjernet fra {circle} af {author}",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Du ændrede niveauet for den linkede gruppe {group} i {circle} til%1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ændrede niveauet for den linkede gruppe {gruppe} i {cirkel} til %1$s",
+    "You sent a request to link {circle} with {remote}" : "Du sendte en anmodning om at linke {circle} med {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{author} sendte en anmodning om at linke {circle} med {remote}",
+    "{remote} requested a link with {circle}" : "{remote} anmodede om et link med {circle}",
+    "The request to link {circle} with {remote} has been rejected" : "Anmodningen om at linke {circle} med {remote} er blevet afvist",
+    "The request to link {remote} with {circle} has been canceled remotely" : "Anmodningen om at linke {remote} til {circle} er blevet annulleret eksternt",
+    "The request to link {circle} with {remote} has been accepted" : "Anmodningen om at forbinde {circle} med {remote} er blevet accepteret",
+    "You dismissed the request to link {remote} with {circle}" : "Du afviste anmodningen om at linke {remote} til {circle}",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} afviste anmodningen om at linke {remote} til {circle}",
+    "You canceled the request to link {circle} with {remote}" : "Du annullerede anmodningen om at linke {circle} med {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} annullerede anmodningen om at linke {circle} med {remote}",
+    "You accepted the request to link {remote} with {circle}" : "Du accepterede anmodningen om at linke {remote} til {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} accepterede anmodningen om at linke {remote} med {circle}",
+    "A link between {circle} and {remote} is now up and running" : "Et link mellem {circle} og {remote} er nu oppe at køre",
+    "The link between {circle} and {remote} has been shutdown remotely" : "Linket mellem {circle} og {remote} er blevet lukket fra fjernt",
+    "You closed the link between {circle} and {remote}" : "Du lukkede linket mellem {circle} og {remote}",
+    "{author} closed the link between {circle} and {remote}" : "{author} lukkede linket mellem {circle} og {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} annullerede hans anmodning om at deltage i {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "Om begivenheder, der finder sted i en <strong>Circle</strong>, som du er medlem af ",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Enhver vigtig begivenhed i en <strong>Circle</strong>, du modererer",
+    "On global events happening in any <strong>Circle</strong>" : "På globale begivenheder, der sker i enhver <strong>Circle</strong>",
+    "Join Request" : "Tilmeldingsanmodning",
+    "Password Protected" : "Adgangskodebeskyttet",
+    "Circle Invite" : "Cirkel invitation",
+    "Email Address" : "Email adresse",
+    "Initialisation Nextcloud" : "Initialisering Nextcloud",
+    "Initialisation Circles App" : "Initialisering Cirkler App",
+    "Circle not found" : "Cirklen blev ikke fundet",
+    "Circle not found " : "Cirklen blev ikke fundet",
+    "This account is already a member of the circle" : "Denne konto er allerede medlem af cirklen",
+    "Federated link not found" : "Fødereret link blev ikke fundet",
+    "The circle is not federated" : "Cirklen er ikke fødereret",
+    "You cannot join this circle" : "Du kan ikke forbinde med cirklen",
+    "This member is the owner of the circle" : "Dette medlem ejer cirklen",
+    "%s (Circle owned by %s)" : "%s (cirkel ejet af %s)",
+    "Personal Circle" : "Personlig cirkel",
     "You need a specify a type of circle" : "Du skal angive en type cirkel",
     "A circle with that name exists" : "Der findes en cirkel med det navn",
     "This member is not the owner of the circle" : "Dette medlem ejer ikke cirklen",
@@ -167,23 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "Email format er ugyldigt",
     "This contact is not available" : "Denne kontakt er ikke tilgængelig ",
     "You have no permission to create a new circle" : "Du har ikke tilladelse til at oprette en ny cirkel",
-    "%s shared a file with \"%s\"." : "%s delte en fil med \"%s\".",
-    "%s shared a file with you." : "%s delte en fil med dig.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delt indhold med dig.\nDu burde allerede have modtaget en separat e-mail med et link for at få adgang...\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delt indhold med dig. Du burde allerede have modtaget en e-mail med et link for at få adgang...",
-    "Password to access content shared with you by %1$s" : "Adgangskode for at få adgang til indhold, der deles med dig af %1$s",
-    "Password to access content" : "Adgangskode for at få adgang til indhold",
     "This item is already shared with this circle" : "Dette element er allerede delt med denne cirkel",
-    "Bring cloud-users closer together." : "Bring cloud-brugere tættere på hinanden.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirkler giver dine brugere mulighed for at oprette deres egne grupper af brugere/kolleger/venner.\nDisse grupper af brugere (eller \"cirkler\") kan derefter bruges af enhver anden app til delingsformål.",
-    "No files in here" : "Ingen filer herinde",
-    "No entries found in this folder" : "Intet fundet i denne mappe",
-    "Name" : "Navn",
-    "Size" : "Størrelse",
-    "Modified" : "Ændret",
-    "Initialisation Nextcloud" : "Initialisering Nextcloud",
-    "Initialisation Circles App" : "Initialisering Cirkler App",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Du kan ikke bruge Cirkel-applikationen, før din administrator har tilladt mindst én type cirkler",
-    "Could not find share" : "Kunne ikke finde deling"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirkler giver dine brugere mulighed for at oprette deres egne grupper af brugere/kolleger/venner.\nDisse grupper af brugere (eller \"cirkler\") kan derefter bruges af enhver anden app til delingsformål."
 },
 "nplurals=2; plural=(n != 1);");
