@@ -1,38 +1,23 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Kreise",
-    "Circles' files" : "Dateien des Kreises",
-    "Select circles to filter by" : "Kreise wählen, um hiernach zu filtern",
-    "No circles found" : "Keine Kreise gefunden",
-    "Please select circles to filter by" : "Bitte wählen Sie Kreise, um hiernach zu filtern",
-    "No files found for the selected circles" : "Keine Dateien für die ausgewählten Kreise gefunden",
-    "You created the circle {circle}" : "Sie haben den Kreis {circle} erstellt",
-    "{author} created the circle {circle}" : "{author} hat den Kreis {circle} erstellt",
+    "Teams" : "Teams",
+    "Teams' files" : "Team-Dateien",
+    "Select team to filter by" : "Team auswählen, nach dem gefiltert werden soll",
+    "No teams found" : "Keine Teams gefunden",
+    "Please select teams to filter by" : "Bitte wählen Sie Teams, nach denen gefiltert werden soll",
+    "No files found for the selected teams" : "Keine Dateien für die ausgewählten Teams gefunden",
+    "You created the team {circle}" : "Du hast das Team {circle} erstellt",
+    "{author} created the team {circle}" : "{author} hat das Team {circle} erstellt",
     "You deleted {circle}" : "Sie haben {circle} gelöscht",
     "{author} deleted {circle}" : "{author} hat {circle} gelöscht",
-    "You linked {group} to {circle}" : "Sie haben eine Verknüpfung von {group} mit {circle} hinzugefügt",
-    "{group} has been linked to {circle} by {author}" : "{group} wurde von {author} mit {circle} verknüpft",
-    "You unlinked {group} from {circle}" : "Sie haben die Verknüpfung der {group} mit {circle} entfernt",
-    "{group} has been unlinked from {circle} by {author}" : "Verknüpfung von {group} zu {circle} wurde von {author} gelöst",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Sie haben den Rang der verknüpften Gruppe {group} in {circle} zu %1$s geändert",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} hat den Rang der verknüpften Gruppe {group} in {circle} zu %1$s geändert",
-    "You sent a request to link {circle} with {remote}" : "Sie haben eine Anfrage zum Verknüpfen von {circle} mit {remote} gesendet",
-    "{author} sent a request to link {circle} with {remote}" : "{author} hat eine Verknüpfung von {circle} mit {remote} angefordert",
-    "{remote} requested a link with {circle}" : "{remote} hat eine Verknüpfung mit {circle} angefordert",
-    "The request to link {circle} with {remote} has been rejected" : "Die Anfrage {circle} mit {remote} zu verknüpfen wurde auf dem entfernten System zurückgewiesen",
-    "The request to link {remote} with {circle} has been canceled remotely" : "Die Anfrage {remote} mit {circle} zu verknüpfen wurde auf dem entfernten System abgebrochen",
-    "The request to link {circle} with {remote} has been accepted" : "Die Anfrage {circle} mit {remote} zu verknüpfen wurde auf dem entfernten System angenommen",
-    "You dismissed the request to link {remote} with {circle}" : "Sie haben eine Anfrage zum Verknüpfen von {remote} mit {circle} verworfen",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} hat eine Anfrage zum Verknüpfen von {remote} mit {circle} verworfen",
-    "You canceled the request to link {circle} with {remote}" : "Sie haben eine Anfrage zum Verknüpfen von {circle} mit {remote} abgebrochen",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} hat eine Anfrage zum Verknüpfen von {circle} mit {remote} abgebrochen",
-    "You accepted the request to link {remote} with {circle}" : "Sie haben eine Anfrage zum Verknüpfen von {remote} mit {circle} angenommen",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} hat eine Anfrage zum Verknüpfen von {remote} mit {circle} angenommen",
-    "A link between {circle} and {remote} is now up and running" : "Die Verknüpfung von {circle} mit {remote} wurde erstellt und funktioniert.",
-    "The link between {circle} and {remote} has been shutdown remotely" : "Die Verknüpfung von {circle} mit {remote} wurde auf dem entfernten System beendet",
-    "You closed the link between {circle} and {remote}" : "Sie haben die Verknüpfung von {circle} mit {remote} beendet",
-    "{author} closed the link between {circle} and {remote}" : "{author} hat die Verknüpfung von {circle} mit {remote} beendet",
+    "You made {member} join {circle}" : "Sie haben {member} {circle} beitreten lassen.",
+    "{author} made {member} join {circle}" : "{author} hat {member} {circle} beitreten lassen",
+    "You added team {member} as member to {circle}" : "Sie haben das Team {member} als Mitglied zu {circle} hinzugefügt",
+    "{author} added team {member} has been added as member to {circle}" : "{author} hat das Team {member} als Mitglied zu {circle} hinzugefügt",
+    "You made {member} leave {circle}" : "Sie haben {member} aus {circle} entfernt",
+    "{author} made {member} leave {circle}" : "{author} hat {member} aus {circle} entfernt",
+    "You removed {member} leave {circle}" : "Sie haben {member} aus {circle} entfernt",
     "You joined {circle}" : "Sie sind dem {circle} beigetreten",
     "{member} joined {circle}" : "{member} ist {circle} beigetreten",
     "You accepted the invitation to join {circle}" : "Sie haben die Einladung angenommen {circle} beizutreten",
@@ -50,7 +35,7 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Sie haben die Einladung {circle} beizutreten abgelehnt",
     "{member} declined an invitation to join {circle}" : "{member} hat es abgelehnt {circle} beizutreten",
     "You cancelled your request to join {circle}" : "Sie haben Ihre Anfrage {circle} beizutreten zurückgezogen",
-    "{member} cancelled his request to join {circle}" : "{member} hat seine Anfrage {circle} beizutreten zurückgezogen",
+    "{member} cancelled a request to join {circle}" : "{member} hat seine Anfrage {circle} beizutreten abgebrochen",
     "You removed {member} from {circle}" : "Sie haben {member} aus {circle} entfernt",
     "You have been removed from {circle} by {author}" : "Sie wurden von {author} aus {circle} entfernt",
     "{member} has been removed from {circle} by {author}" : "{member} wurde von {author} aus {circle} entfernt",
@@ -72,9 +57,9 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} hat eine Anfrage gestellt in {circle} aufgenommen zu werden",
     "You are the new owner of {circle}" : "Sie sind der neue Eigentümer von {circle}",
     "{member} is the new owner of {circle}" : "{member} ist der neue Eigentümer von {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Kreis</strong> , in dem Du Mitglied bist",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Irgend ein wichtiger Termin in einem <strong>Kreis</strong> den Sie moderieren",
-    "On global events happening in any <strong>Circle</strong>" : "Bei globalen Ereignissen in irgendeinem <strong>Kreis</strong> ",
+    "On events happening in a <strong>team</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Team</strong>, in dem Sie Mitglied sind",
+    "Any important event in a <strong>team</strong> you are moderating" : "Irgend ein wichtiger Termin in einem <strong>Team</strong>, das Sie moderieren",
+    "On global events happening in any <strong>team</strong>" : "Bei globalen Ereignissen, in einem beliebigen <strong>Team</strong>",
     "Shared to Circles" : "Geteilt mit Kreisen",
     "Single" : "Einzeln",
     "Personal" : "Persönlich",
@@ -82,20 +67,20 @@ OC.L10N.register(
     "Visible" : "Sichtbar",
     "Open" : "Offen",
     "Invite" : "Einladen",
-    "Join Request" : "Betrittsanfrage",
+    "Join request" : "Betrittsanfrage",
     "Friends" : "Freunde",
-    "Password Protected" : "Passwortgeschützt",
+    "Password protected" : "Passwortgeschützt",
     "No Owner" : "Kein Besitzer",
     "Hidden" : "Versteckt",
     "Backend" : "Backend",
     "Local" : "Lokal",
     "Root" : "Root",
-    "Circle Invite" : "Einladung zu Kreis",
+    "Team invite" : "Teameinladung",
     "Federated" : "Federated",
     "Mount point" : "Einhängepunkt",
     "Nextcloud Account" : "Nextcloud-Konto",
     "Nextcloud Group" : "Nextcloud-Gruppe",
-    "Email Address" : "E-Mail-Adresse",
+    "Email address" : "E-Mail-Adresse",
     "Contact" : "Kontakt",
     "Circle" : "Kreis",
     "Nextcloud App" : "Nextcloud-App",
@@ -127,23 +112,19 @@ OC.L10N.register(
     "Building Local Database" : "Lokale Datenbank wird erstellt",
     "Testing Basic Circle Creation" : "Testen der grundlegenden Kreiserstellung",
     "Adding local users and moderators" : "Lokale Benutzer und Moderatoren werden hinzugefügt",
-    "Circle not found" : "Kreis nicht gefunden",
-    "Circle not found " : "Kreis nicht gefunden",
-    "This member does not exist" : "Dieses Mitglied existiert nicht",
-    "This account is already a member of the circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
-    "Federated link not found" : "Federated-Verknüpfung nicht gefunden",
     "This feature is not available for personal circles" : "Diese Funktion steht für persönliche Kreise nicht zur Verfügung",
-    "The circle is not federated" : "Der Kreis ist nicht federated",
-    "You cannot join this circle" : "Sie können diesem Kreis nicht beitreten",
+    "The team is not federated" : "Das Team ist nicht federiert",
+    "You cannot join this team" : "Du kannst diesem Team nicht beitreten",
     "This member is not a moderator" : "Dieses Mitglied ist kein Moderator",
     "Insufficient privileges" : "Unzureichende Berechtigungen ",
-    "This member is the owner of the circle" : "Dieses Mitglied ist der Besitzer des Kreises",
+    "This member does not exist" : "Dieses Mitglied existiert nicht",
+    "This member is the owner of the team" : "Dieses Mitglied ist der Besitzer des Teams",
     "Level cannot be changed for this type of member" : "Berechtigungsstufe kann für diesen Mitgliedstyp nicht geändert werden",
     "You are already a member of this circle" : "Sie sind bereits Mitglied dieses Kreises",
     "You have been blocked from this circle" : "Sie wurden für diesen Kreis blockiert",
     "The account is already a member of this circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
     "The account has already been invited into this circle" : "Dieses Konto wurde bereits zu diesem Kreis eingeladen.",
-    "%s (Circle owned by %s)" : "%s (Kreis im Besitz von%s)",
+    "%s (Team owned by %s)" : "%s (Team im Besitz von %s)",
     "You are now a member of the Circle \"%2$s\"" : "Sie sind jetzt ein Mitglied des Kreises \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Sie wurden von %1$s zum Kreis \"%2$s\" eingeladen",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s hat eine Mitgliedschaftsanfrage für den Kreis \"%2$s\" gesendet",
@@ -151,8 +132,72 @@ OC.L10N.register(
     "Refuse" : "Ablehnen",
     "Leave the circle" : "Diesen Kreis verlassen",
     "%s" : "%s",
-    "Personal Circle" : "Persönlicher Kreis",
+    "Personal team" : "Persönliches Team",
     "%s owned by %s" : "%s gehört %s",
+    "You have no permission to create a new team" : "Sie haben nicht die Berechtigung, ein neues Team zu erstellen",
+    "%s shared a file with \"%s\"." : "%s hat eine Datei mit \"%s\" geteilt.",
+    "%s shared a file with you." : "%s hat eine Datei mit Ihnen geteilt.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat einigen Inhalt mit Ihnen geteilt.\nSie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einigen Inhalt mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
+    "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit Ihnen geteilt wurde.",
+    "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
+    "This item is already shared with this team" : "Dieses Element wurde bereits mit diesem Team geteilt",
+    "Bring cloud-users closer together." : "Bringen Sie Cloudnutzer näher zueinander.",
+    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Mittels Teams können Personen ihre eigenen Gruppen mit Personen/Kollegen/Freunden erstellen.\nDiese Benutzergruppen können anderen Apps zum Erstellen von Freigaben verwenden.",
+    "No files in here" : "Keine Dateien vorhanden",
+    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden ",
+    "Name" : "Name",
+    "Size" : "Größe",
+    "Modified" : "Geändert",
+    "Circles" : "Kreise",
+    "Circles' files" : "Dateien des Kreises",
+    "Select circles to filter by" : "Kreise wählen, um hiernach zu filtern",
+    "No circles found" : "Keine Kreise gefunden",
+    "Please select circles to filter by" : "Bitte wählen Sie Kreise, um hiernach zu filtern",
+    "No files found for the selected circles" : "Keine Dateien für die ausgewählten Kreise gefunden",
+    "You created the circle {circle}" : "Sie haben den Kreis {circle} erstellt",
+    "{author} created the circle {circle}" : "{author} hat den Kreis {circle} erstellt",
+    "You linked {group} to {circle}" : "Sie haben eine Verknüpfung von {group} mit {circle} hinzugefügt",
+    "{group} has been linked to {circle} by {author}" : "{group} wurde von {author} mit {circle} verknüpft",
+    "You unlinked {group} from {circle}" : "Sie haben die Verknüpfung der {group} mit {circle} entfernt",
+    "{group} has been unlinked from {circle} by {author}" : "Verknüpfung von {group} zu {circle} wurde von {author} gelöst",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Sie haben den Rang der verknüpften Gruppe {group} in {circle} zu %1$s geändert",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} hat den Rang der verknüpften Gruppe {group} in {circle} zu %1$s geändert",
+    "You sent a request to link {circle} with {remote}" : "Sie haben eine Anfrage zum Verknüpfen von {circle} mit {remote} gesendet",
+    "{author} sent a request to link {circle} with {remote}" : "{author} hat eine Verknüpfung von {circle} mit {remote} angefordert",
+    "{remote} requested a link with {circle}" : "{remote} hat eine Verknüpfung mit {circle} angefordert",
+    "The request to link {circle} with {remote} has been rejected" : "Die Anfrage {circle} mit {remote} zu verknüpfen wurde auf dem entfernten System zurückgewiesen",
+    "The request to link {remote} with {circle} has been canceled remotely" : "Die Anfrage {remote} mit {circle} zu verknüpfen wurde auf dem entfernten System abgebrochen",
+    "The request to link {circle} with {remote} has been accepted" : "Die Anfrage {circle} mit {remote} zu verknüpfen wurde auf dem entfernten System angenommen",
+    "You dismissed the request to link {remote} with {circle}" : "Sie haben eine Anfrage zum Verknüpfen von {remote} mit {circle} verworfen",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} hat eine Anfrage zum Verknüpfen von {remote} mit {circle} verworfen",
+    "You canceled the request to link {circle} with {remote}" : "Sie haben eine Anfrage zum Verknüpfen von {circle} mit {remote} abgebrochen",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} hat eine Anfrage zum Verknüpfen von {circle} mit {remote} abgebrochen",
+    "You accepted the request to link {remote} with {circle}" : "Sie haben eine Anfrage zum Verknüpfen von {remote} mit {circle} angenommen",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} hat eine Anfrage zum Verknüpfen von {remote} mit {circle} angenommen",
+    "A link between {circle} and {remote} is now up and running" : "Die Verknüpfung von {circle} mit {remote} wurde erstellt und funktioniert.",
+    "The link between {circle} and {remote} has been shutdown remotely" : "Die Verknüpfung von {circle} mit {remote} wurde auf dem entfernten System beendet",
+    "You closed the link between {circle} and {remote}" : "Sie haben die Verknüpfung von {circle} mit {remote} beendet",
+    "{author} closed the link between {circle} and {remote}" : "{author} hat die Verknüpfung von {circle} mit {remote} beendet",
+    "{member} cancelled his request to join {circle}" : "{member} hat seine Anfrage {circle} beizutreten zurückgezogen",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "Bei Ereignissen in einem <strong>Kreis</strong> , in dem Du Mitglied bist",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Irgend ein wichtiger Termin in einem <strong>Kreis</strong> den Sie moderieren",
+    "On global events happening in any <strong>Circle</strong>" : "Bei globalen Ereignissen in irgendeinem <strong>Kreis</strong> ",
+    "Join Request" : "Betrittsanfrage",
+    "Password Protected" : "Passwortgeschützt",
+    "Circle Invite" : "Einladung zu Kreis",
+    "Email Address" : "E-Mail-Adresse",
+    "Initialisation Nextcloud" : "Initialisierung von Nextcloud",
+    "Initialisation Circles App" : "Initialisierung der Circles-App",
+    "Circle not found" : "Kreis nicht gefunden",
+    "Circle not found " : "Kreis nicht gefunden",
+    "This account is already a member of the circle" : "Dieses Konto ist bereits Mitglied dieses Kreises",
+    "Federated link not found" : "Federated-Verknüpfung nicht gefunden",
+    "The circle is not federated" : "Der Kreis ist nicht federated",
+    "You cannot join this circle" : "Sie können diesem Kreis nicht beitreten",
+    "This member is the owner of the circle" : "Dieses Mitglied ist der Besitzer des Kreises",
+    "%s (Circle owned by %s)" : "%s (Kreis im Besitz von %s)",
+    "Personal Circle" : "Persönlicher Kreis",
     "You need a specify a type of circle" : "Sie benötigen einen bestimmten Kreis-Typ",
     "A circle with that name exists" : "Ein Kreis mit diesem Namen existiert bereits",
     "This member is not the owner of the circle" : "Dieses Mitglied ist nicht der Besitzer des Kreises",
@@ -167,21 +212,7 @@ OC.L10N.register(
     "Email format is not valid" : "Das E-Mail-Format ist ungültig",
     "This contact is not available" : "Dieser Kontakt ist nicht verfügbar",
     "You have no permission to create a new circle" : "Sie haben nicht die Berechtigung einen neuen Kreis zu erstellen",
-    "%s shared a file with \"%s\"." : "%s hat eine Datei mit \"%s\" geteilt.",
-    "%s shared a file with you." : "%s hat eine Datei mit Ihnen geteilt.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s hat einigen Inhalt mit Ihnen geteilt.\nSie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s hat einigen Inhalt mit Ihnen geteilt. Sie sollten bereits eine weitere E-Mail mit einem Link für den Zugriff erhalten haben.",
-    "Password to access content shared with you by %1$s" : "Passwort für den Zugriff auf den Inhalt, der von %1$s mit Ihnen geteilt wurde.",
-    "Password to access content" : "Passwort für den Zugriff auf den Inhalt",
     "This item is already shared with this circle" : "Dieses Element wird bereits mit diesem Kreis geteilt",
-    "Bring cloud-users closer together." : "Bringen Sie Cloudnutzer näher zueinander.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Mit Kreisen können Benutzer ihre eigenen Gruppen von Benutzern/Kollegen/Freunden erstellen.\nDiese Benutzergruppen (oder \"Kreise\") können dann von jeder anderen App zum Zweck der gemeinsamen Nutzung verwendet werden.",
-    "No files in here" : "Keine Dateien vorhanden",
-    "No entries found in this folder" : "Keine Einträge in diesem Ordner gefunden ",
-    "Name" : "Name",
-    "Size" : "Größe",
-    "Modified" : "Geändert",
-    "Initialisation Nextcloud" : "Initialisierung von Nextcloud",
-    "Initialisation Circles App" : "Initialisierung der Circles-App"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Mit Kreisen können Benutzer ihre eigenen Gruppen von Benutzern/Kollegen/Freunden erstellen.\nDiese Benutzergruppen (oder \"Kreise\") können dann von jeder anderen App zum Zweck der gemeinsamen Nutzung verwendet werden."
 },
 "nplurals=2; plural=(n != 1);");
