@@ -1,12 +1,11 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Círculos",
-    "The link between {circle} and {remote} has been shutdown remotely" : "El enlace entre {círculo} y {remoto} se ha cerrado de forma remota",
     "Personal" : "Personal",
     "System" : "Sistema",
     "Visible" : "Visible",
     "Open" : "Abrir",
+    "Password protected" : "Protegido con contraseña",
     "Hidden" : "Oculto",
     "Local" : "Local",
     "Root" : "Raíz",
@@ -21,27 +20,25 @@ OC.L10N.register(
     "Password to access »%s«" : "Contraseña para acceder  »%s«",
     "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
     "Open »%s«" : "Abrir »%s«",
-    "This member does not exist" : "Este miembro no existe",
-    "You cannot join this circle" : "Usted no puede unirse a este cículo",
     "This member is not a moderator" : "Este miembro no es un moderador",
-    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
+    "This member does not exist" : "Este miembro no existe",
     "You are already a member of this circle" : "Usted ya es un miembro de este círculo",
     "You have been blocked from this circle" : "Usted ha sido bloqueado de este círculo",
     "Accept" : "Aceptar",
     "%s" : "%s",
-    "Personal Circle" : "Círculo Personal",
-    "You need a specify a type of circle" : "Usted necesita especificar un tipo de círculo",
-    "A circle with that name exists" : "Un círculo con ese nombre ya existe",
-    "This member is not the owner of the circle" : "Este miembro no es el dueño del círculo",
-    "You cannot edit level in a personal circle" : "No puede editar el nivel en un círculo personal",
     "No files in here" : "No hay archivos aqui",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
     "Name" : "Nombre",
     "Size" : "Tamaño",
     "Modified" : "Modificado",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Usted no puede usar la Aplicación de Círculos hasta que su adminsitrador haya permitido al menos un tipo de círculo",
-    "This user is already a member of the circle" : "El usuario ya es un miembro del círculo",
-    "This user does not exist" : "Este usuario no existe",
-    "Could not find share" : "No fue posible encontrar el elemento compartido"
+    "Circles" : "Círculos",
+    "The link between {circle} and {remote} has been shutdown remotely" : "El enlace entre {círculo} y {remoto} se ha cerrado de forma remota",
+    "You cannot join this circle" : "Usted no puede unirse a este cículo",
+    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
+    "Personal Circle" : "Círculo Personal",
+    "You need a specify a type of circle" : "Usted necesita especificar un tipo de círculo",
+    "A circle with that name exists" : "Un círculo con ese nombre ya existe",
+    "This member is not the owner of the circle" : "Este miembro no es el dueño del círculo",
+    "You cannot edit level in a personal circle" : "No puede editar el nivel en un círculo personal"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
