@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Círculos",
-    "Circles' files" : "Archivos de los círculos",
-    "Select circles to filter by" : "Seleccionar los círculos a filtrar",
-    "No circles found" : "No se encontraron círculos",
-    "Please select circles to filter by" : "Por favor selecciona los círculos a filtrar",
-    "No files found for the selected circles" : "No se encontraron archivos para los círculos seleccionados",
-    "You created the circle {circle}" : "Creaste el círculo {circle}",
-    "{author} created the circle {circle}" : "{author} creó el círculo {circle}",
     "You deleted {circle}" : "Borraste el círculo {circle}",
     "{author} deleted {circle}" : "{author} borró {circle}",
-    "You linked {group} to {circle}" : "Vinculaste a {group} a {circle}",
-    "{group} has been linked to {circle} by {author}" : "{author} vinculó {group} a {circle}",
-    "You unlinked {group} from {circle}" : "Desvinculaste a {group} de {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{author} desvinculó {group} de {circle}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Cambiaste el nivel del grupo vinculado {group} en {circle} a %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} cambió el nivel del grupo vinculado {group} en {circle} a %1$s",
-    "You sent a request to link {circle} with {remote}" : "Enviaste una solicitud para vincular {circle} con {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} envió una solicitud para vincular {circle} con {remote}",
-    "{remote} requested a link with {circle}" : "{remote} solicitó una liga para {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "La solicitud para vincular{circle} con {remote} fue rechazada",
-    "The request to link {remote} with {circle} has been canceled remotely" : "La solicitud para vincular {remote} con {circle} ha sido cancelada remotamente",
-    "The request to link {circle} with {remote} has been accepted" : "La solicitud para vincular {circle} con {rempte} ha sido aceptada",
-    "You dismissed the request to link {remote} with {circle}" : "Descartaste la solicitud para vincular {remote} con {circle}",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} descartó la solicitud para vincular {remote} con {circle}",
-    "You canceled the request to link {circle} with {remote}" : "Cancelaste la solicitud para vincular {circle} con {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} canceló la solicitud para vincular {circle} con {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Aceptaste la solicitud para vincular {remote} con {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} aceptó la solicitud para vincular {remote} con {circle}",
-    "A link between {circle} and {remote} is now up and running" : "La liga entre {circle} y {remote} está ahora lista y funcionando",
-    "The link between {circle} and {remote} has been shutdown remotely" : "La liga entre {circle} y {remote} ha sido deshabilitada remotamente",
-    "You closed the link between {circle} and {remote}" : "Cerraste la liga entre {cirlce} y {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} cerró la liga entre {circle} y {remote}",
     "You joined {circle}" : "Te uniste a {circle}",
     "{member} joined {circle}" : "{member} se unió a {circle}",
     "You accepted the invitation to join {circle}" : "Aceptaste la invitación para unirte a {cirlce}",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Declinaste la invitacion a unirte a {circle}",
     "{member} declined an invitation to join {circle}" : "{member} declinó la invitación para unirse a {cricle}",
     "You cancelled your request to join {circle}" : "Cancelaste tu solicitud para unirte a {cricle}",
-    "{member} cancelled his request to join {circle}" : "{member} canceló su solicitud para unirse a {circle}",
     "You removed {member} from {circle}" : "Eliminaste a {member} de {circle}",
     "You have been removed from {circle} by {author}" : "Has sido eliminado de {circle} por {author}",
     "{member} has been removed from {circle} by {author}" : "{member} ha sido eliminado de {circle} por {author}",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} envió una solicitud para unirse a {circle}",
     "You are the new owner of {circle}" : "Eres el nuevo dueño de {circle}",
     "{member} is the new owner of {circle}" : "{member} es el nuevo dueño de {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "En eventos que ocurren en un <strong>Círculo</strong> del que eres miembro",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Cualquier evento importante en un <strong>Círculo</strong> que estés moderando",
-    "On global events happening in any <strong>Circle</strong>" : "En eventos globales que ocurren en cualquier <strong>Círculo</strong>",
     "Shared to Circles" : "Compartido a Círculos",
     "Single" : "Individual",
     "Personal" : "Personal",
@@ -82,20 +48,18 @@ OC.L10N.register(
     "Visible" : "Visible",
     "Open" : "Abrir",
     "Invite" : "Invitar",
-    "Join Request" : "Solicitud de unirse",
     "Friends" : "Amigos",
-    "Password Protected" : "Protegido por contraseña",
+    "Password protected" : "Protegido con contraseña",
     "No Owner" : "Sin propietario",
     "Hidden" : "Oculto",
     "Backend" : "Backend",
     "Local" : "Local",
     "Root" : "Raíz",
-    "Circle Invite" : "Invitación a Círculo",
     "Federated" : "Federado",
     "Mount point" : "Punto de montaje",
     "Nextcloud Account" : "Cuenta de Nextcloud",
     "Nextcloud Group" : "Grupo de Nextcloud",
-    "Email Address" : "Dirección de correo electrónico",
+    "Email address" : "Dirección de correo electrónico",
     "Contact" : "Contacto",
     "Circle" : "Círculo",
     "Nextcloud App" : "Aplicación de Nextcloud",
@@ -127,23 +91,15 @@ OC.L10N.register(
     "Building Local Database" : "Creando la base de datos local",
     "Testing Basic Circle Creation" : "Probando la creación básica de un Círculo",
     "Adding local users and moderators" : "Agregando usuarios locales y moderadores",
-    "Circle not found" : "Círculo no encontrado",
-    "Circle not found " : "Círculo no encontrado ",
-    "This member does not exist" : "Este miembro no existe",
-    "This account is already a member of the circle" : "Esta cuenta ya es miembro del círculo",
-    "Federated link not found" : "No se encontró la liga",
     "This feature is not available for personal circles" : "Esta característica no está disponible para círculos personales",
-    "The circle is not federated" : "El círculo no es federado",
-    "You cannot join this circle" : "No puedes unirte a este cículo",
     "This member is not a moderator" : "Este miembro no es un moderador",
     "Insufficient privileges" : "Privilegios insuficientes",
-    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
+    "This member does not exist" : "Este miembro no existe",
     "Level cannot be changed for this type of member" : "El nivel no puede ser cambiado para este tipo de miembro",
     "You are already a member of this circle" : "Ya eres un miembro de este círculo",
     "You have been blocked from this circle" : "Has sido bloqueado de este círculo",
     "The account is already a member of this circle" : "La cuenta ya es miembro de este círculo",
     "The account has already been invited into this circle" : "La cuenta ya ha sido invitada a este círculo",
-    "%s (Circle owned by %s)" : "%s (Círculo propiedad de %s)",
     "You are now a member of the Circle \"%2$s\"" : "Ahora eres miembro del Círculo \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Has sido invitado por %1$s al Círculo \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s envió una solicitud para ser miembro del Círculo \"%2$s\"",
@@ -151,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "Rechazar",
     "Leave the circle" : "Dejar el círculo",
     "%s" : "%s",
-    "Personal Circle" : "Círculo Personal",
     "%s owned by %s" : "%s propiedad de %s",
+    "%s shared a file with \"%s\"." : "%s compartió un archivo con \"%s\".",
+    "%s shared a file with you." : "%s compartió un archivo contigo.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió contenido contigo.\n      Deberías haber recibido un correo electrónico por separado con un enlace para acceder a él.\n      ",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartió contenido contigo. Deberías haber recibido un correo electrónico por separado con un enlace para acceder a él.",
+    "Password to access content shared with you by %1$s" : "Contraseña para acceder al contenido compartido contigo por %1$s",
+    "Password to access content" : "Contraseña para acceder al contenido",
+    "Bring cloud-users closer together." : "Acerca a los usuarios de la nube.",
+    "No files in here" : "No hay archivos aquí",
+    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
+    "Name" : "Nombre",
+    "Size" : "Tamaño",
+    "Modified" : "Modificado",
+    "Circles" : "Círculos",
+    "Circles' files" : "Archivos de los círculos",
+    "Select circles to filter by" : "Seleccionar los círculos a filtrar",
+    "No circles found" : "No se encontraron círculos",
+    "Please select circles to filter by" : "Por favor selecciona los círculos a filtrar",
+    "No files found for the selected circles" : "No se encontraron archivos para los círculos seleccionados",
+    "You created the circle {circle}" : "Creaste el círculo {circle}",
+    "{author} created the circle {circle}" : "{author} creó el círculo {circle}",
+    "You linked {group} to {circle}" : "Vinculaste a {group} a {circle}",
+    "{group} has been linked to {circle} by {author}" : "{author} vinculó {group} a {circle}",
+    "You unlinked {group} from {circle}" : "Desvinculaste a {group} de {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{author} desvinculó {group} de {circle}",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Cambiaste el nivel del grupo vinculado {group} en {circle} a %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} cambió el nivel del grupo vinculado {group} en {circle} a %1$s",
+    "You sent a request to link {circle} with {remote}" : "Enviaste una solicitud para vincular {circle} con {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{author} envió una solicitud para vincular {circle} con {remote}",
+    "{remote} requested a link with {circle}" : "{remote} solicitó una liga para {circle}",
+    "The request to link {circle} with {remote} has been rejected" : "La solicitud para vincular{circle} con {remote} fue rechazada",
+    "The request to link {remote} with {circle} has been canceled remotely" : "La solicitud para vincular {remote} con {circle} ha sido cancelada remotamente",
+    "The request to link {circle} with {remote} has been accepted" : "La solicitud para vincular {circle} con {rempte} ha sido aceptada",
+    "You dismissed the request to link {remote} with {circle}" : "Descartaste la solicitud para vincular {remote} con {circle}",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} descartó la solicitud para vincular {remote} con {circle}",
+    "You canceled the request to link {circle} with {remote}" : "Cancelaste la solicitud para vincular {circle} con {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} canceló la solicitud para vincular {circle} con {remote}",
+    "You accepted the request to link {remote} with {circle}" : "Aceptaste la solicitud para vincular {remote} con {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} aceptó la solicitud para vincular {remote} con {circle}",
+    "A link between {circle} and {remote} is now up and running" : "La liga entre {circle} y {remote} está ahora lista y funcionando",
+    "The link between {circle} and {remote} has been shutdown remotely" : "La liga entre {circle} y {remote} ha sido deshabilitada remotamente",
+    "You closed the link between {circle} and {remote}" : "Cerraste la liga entre {cirlce} y {remote}",
+    "{author} closed the link between {circle} and {remote}" : "{author} cerró la liga entre {circle} y {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} canceló su solicitud para unirse a {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "En eventos que ocurren en un <strong>Círculo</strong> del que eres miembro",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Cualquier evento importante en un <strong>Círculo</strong> que estés moderando",
+    "On global events happening in any <strong>Circle</strong>" : "En eventos globales que ocurren en cualquier <strong>Círculo</strong>",
+    "Join Request" : "Solicitud de unirse",
+    "Password Protected" : "Protegido por contraseña",
+    "Circle Invite" : "Invitación a Círculo",
+    "Email Address" : "Dirección de correo electrónico",
+    "Initialisation Nextcloud" : "Inicialización de Nextcloud",
+    "Initialisation Circles App" : "Inicialización de la aplicación Círculos",
+    "Circle not found" : "Círculo no encontrado",
+    "Circle not found " : "Círculo no encontrado ",
+    "This account is already a member of the circle" : "Esta cuenta ya es miembro del círculo",
+    "Federated link not found" : "No se encontró la liga",
+    "The circle is not federated" : "El círculo no es federado",
+    "You cannot join this circle" : "No puedes unirte a este cículo",
+    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
+    "%s (Circle owned by %s)" : "%s (Círculo propiedad de %s)",
+    "Personal Circle" : "Círculo Personal",
     "You need a specify a type of circle" : "Necesitas especificar un tipo de círculo",
     "A circle with that name exists" : "Un círculo con ese nombre ya existe",
     "This member is not the owner of the circle" : "Este miembro no es el dueño del círculo",
@@ -167,21 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "El formato de la dirección de correo electrónico no es válido",
     "This contact is not available" : "Este contacto no está disponible",
     "You have no permission to create a new circle" : "No tienes permiso para crear un nuevo círculo",
-    "%s shared a file with \"%s\"." : "%s compartió un archivo con \"%s\".",
-    "%s shared a file with you." : "%s compartió un archivo contigo.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s compartió contenido contigo.\n      Deberías haber recibido un correo electrónico por separado con un enlace para acceder a él.\n      ",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s compartió contenido contigo. Deberías haber recibido un correo electrónico por separado con un enlace para acceder a él.",
-    "Password to access content shared with you by %1$s" : "Contraseña para acceder al contenido compartido contigo por %1$s",
-    "Password to access content" : "Contraseña para acceder al contenido",
     "This item is already shared with this circle" : "Este elemento ya está compartido con este círculo",
-    "Bring cloud-users closer together." : "Acerca a los usuarios de la nube.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Círculos permite a las personas crear sus propios grupos de personas/colegas/amigos.\n      Esos grupos de personas (o \"círculos\") pueden ser utilizados por cualquier otra aplicación para compartir propósitos.",
-    "No files in here" : "No hay archivos aquí",
-    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
-    "Name" : "Nombre",
-    "Size" : "Tamaño",
-    "Modified" : "Modificado",
-    "Initialisation Nextcloud" : "Inicialización de Nextcloud",
-    "Initialisation Circles App" : "Inicialización de la aplicación Círculos"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Círculos permite a las personas crear sus propios grupos de personas/colegas/amigos.\n      Esos grupos de personas (o \"círculos\") pueden ser utilizados por cualquier otra aplicación para compartir propósitos."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
