@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Zirkuluak",
-    "Circles' files" : "Zirkuluen fitxategiak",
-    "Select circles to filter by" : "Hautatu zirkuluak nola iragazi",
-    "No circles found" : "Ez da zirkulurik aurkitu",
-    "Please select circles to filter by" : "Hautatu zirkuluak nola iragazi",
-    "No files found for the selected circles" : "Ez da fitxategirik aurkitu hautatutako zirkuluetarako",
-    "You created the circle {circle}" : "{circle} zirkulua zuk sortu duzu",
-    "{author} created the circle {circle}" : "{author}(e)k {circle} zirkulua sortu du",
     "You deleted {circle}" : "{circle} ezabatu duzu",
     "{author} deleted {circle}" : "{author}(e)k {circle} ezabatu du",
-    "You linked {group} to {circle}" : "{group} taldea {circle} zirkuluarekin lotu duzu",
-    "{group} has been linked to {circle} by {author}" : "{group} taldea {circle} zirkuluarekin lotu du {author}(e)k",
-    "You unlinked {group} from {circle}" : "{group} taldea {circle} zirkulutik atera duzu",
-    "{group} has been unlinked from {circle} by {author}" : "{group} taldea {circle} zirkulutik atera du {author}(e)k",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Lotuta dagoen {group} taldearen maila aldatu duzu {circle} zirkuluan %1$s-ra",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author}(e)k lotuta dagoen {group} taldearen maila aldatu du {circle} zirkuluan %1$s-ra",
-    "You sent a request to link {circle} with {remote}" : "Eskaera bidali duzu {circle} lotzeko [remote]rekin",
-    "{author} sent a request to link {circle} with {remote}" : "{author}(e)k eskaera bidali du {circle} lotzeko [remote]rekin",
-    "{remote} requested a link with {circle}" : "{remote}(e)k eskaera egin du {circle} zirkuluarekin lotzeko ",
-    "The request to link {circle} with {remote} has been rejected" : "{circle} eta {remote} lotzeko eskaera baztertua izan da ",
-    "The request to link {remote} with {circle} has been canceled remotely" : "{circle} eta {remote} lotzeko eskaera urrunetik bertan behera utzia izan da ",
-    "The request to link {circle} with {remote} has been accepted" : "{circle} eta {remote} lotzeko eskaera onartua izan da ",
-    "You dismissed the request to link {remote} with {circle}" : "{circle} eta [remote] lotzeko eskaera baztertu duzu",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author}(e)k baztertu egin du {circle} eta [remote] lotzeko eskaera",
-    "You canceled the request to link {circle} with {remote}" : "{circle} eta [remote] lotzeko eskaera bertan behera utzi duzu",
-    "{author} canceled the request to link {circle} with {remote}" : "{author}(e)k bertan behera utzi du {circle} eta [remote] lotzeko eskaera",
-    "You accepted the request to link {remote} with {circle}" : "{circle} eta [remote] lotzeko eskaera onartu duzu",
-    "{author} accepted the request to link {remote} with {circle}" : "{author}(e)k onartu egin du {circle} eta [remote] lotzeko eskaera",
-    "A link between {circle} and {remote} is now up and running" : "{circle} eta {remote}(r)en arteko lotura martxan da eta badabil ",
-    "The link between {circle} and {remote} has been shutdown remotely" : "{circle} eta {remote}(r)en arteko lotura urrunetik itzali da ",
-    "You closed the link between {circle} and {remote}" : "{circle} eta [remote](r)en arteko lotura eten egin duzu",
-    "{author} closed the link between {circle} and {remote}" : "{author}(e)k eten egin du {circle} eta [remote](r)en arteko lotura",
     "You joined {circle}" : "{circle} zirkuluan sartu zara",
     "{member} joined {circle}" : "{member} kidea {circle} zirkuluan sartu da",
     "You accepted the invitation to join {circle}" : "{circle} zirkuluan sartzeko gonbidapena onartu duzu",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : " {circle} zirkuluan sartzeko gonbidapenari uko egin diozu",
     "{member} declined an invitation to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko gonbidapenari uko egin dio",
     "You cancelled your request to join {circle}" : "{circle} zirkuluan sartzeko eskaera bertan behera utzi duzu",
-    "{member} cancelled his request to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera bertan behera utzi du",
     "You removed {member} from {circle}" : "{member} kidea atera duzu {circle} zirkulutik",
     "You have been removed from {circle} by {author}" : "{circle} zirkulutik atera zaitu {author}(e)k",
     "{member} has been removed from {circle} by {author}" : "{member} kidea atera du {circle} zirkulutik {author}(e)k",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera egin du",
     "You are the new owner of {circle}" : "{circle} zirkuluaren jabe zara orain",
     "{member} is the new owner of {circle}" : "{member} kidea {circle} zirkuluaren jabe da orain",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Kide zaren <strong>zirkuluetako</strong> gertaeretan",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Moderatzen ari zaren <strong>zirkulu</strong> bateko edozein gertaera garrantzitsu",
-    "On global events happening in any <strong>Circle</strong>" : "<strong>Zirkulu</strong> batean gertatzen diren gertaera orokorretan",
     "Shared to Circles" : "Zirkuluetara partekatua",
     "Single" : "Bakana",
     "Personal" : "Pertsonala",
@@ -82,20 +48,18 @@ OC.L10N.register(
     "Visible" : "Ikusgai",
     "Open" : "Ireki",
     "Invite" : "Gonbidatu",
-    "Join Request" : "Sartzeko eskaera",
     "Friends" : "Lagunak",
-    "Password Protected" : "Pasahitzez babestua",
+    "Password protected" : "Pasahitz bidez babestuta",
     "No Owner" : "Jaberik ez",
     "Hidden" : "Ezkutuan",
     "Backend" : "Atzealdea",
     "Local" : "Lokala",
     "Root" : "Erroa",
-    "Circle Invite" : "Zirkulu gonbidapena",
     "Federated" : "Federatua",
     "Mount point" : "Muntatze-puntua",
     "Nextcloud Account" : "Nextcloud kontua",
     "Nextcloud Group" : "Nextcloud taldea",
-    "Email Address" : "Helbide elektronikoa",
+    "Email address" : "Helbide elektronikoa",
     "Contact" : "Kontaktua",
     "Circle" : "Zirkulua",
     "Nextcloud App" : "Nextcloud aplikazioa",
@@ -127,23 +91,15 @@ OC.L10N.register(
     "Building Local Database" : "Datu-base lokala eraikitzen",
     "Testing Basic Circle Creation" : "Oinarrizko zirkulu sorrera probatzen",
     "Adding local users and moderators" : "Erabiltzaile eta moderatzaile lokalak gehitzen",
-    "Circle not found" : "Ez da zirkulua aurkitu",
-    "Circle not found " : "Ez da zirkulua aurkitu",
-    "This member does not exist" : "Kide hau ez da existitzen",
-    "This account is already a member of the circle" : "Kontu hau zirkuluko kidea da dagoeneko",
-    "Federated link not found" : "Ez da esteka federatua aurkitu",
     "This feature is not available for personal circles" : "Ezaugarri hau ez da existitzen zirkulu pertsonaletarako",
-    "The circle is not federated" : "Zirkulua ez dago federatuta",
-    "You cannot join this circle" : "Ezin zara zirkulu honetan sartu",
     "This member is not a moderator" : "Kide hau ez da moderatzailea",
     "Insufficient privileges" : "Baimen gutxiegi",
-    "This member is the owner of the circle" : "Kide hau da zirkuluaren jabea",
+    "This member does not exist" : "Kide hau ez da existitzen",
     "Level cannot be changed for this type of member" : "Ezin da mota honetako kideen maila aldatu",
     "You are already a member of this circle" : "Zirkulu honetako kide zara dagoeneko",
     "You have been blocked from this circle" : "Zirkulu honetan blokeatu egin zaituzte",
     "The account is already a member of this circle" : "Kontu hau zirkulu honetako kidea da dagoeneko",
     "The account has already been invited into this circle" : "Kontua zirkulu honetara gonbidatua izan da dagoeneko",
-    "%s (Circle owned by %s)" : "%s (%s-(r)en jabetzako zirkulua)",
     "You are now a member of the Circle \"%2$s\"" : "«%2$s» zirkuluaren kide zara orain",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s(e)k «%2$s» zirkulura gonbidatu zaitu",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s(e)k «%2$s» zirkuluaren kide izateko eskaera bidali du",
@@ -151,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "Ukatu",
     "Leave the circle" : "Utzi zirkulua",
     "%s" : "%s",
-    "Personal Circle" : "Zirkulu pertsonala",
     "%s owned by %s" : "%s jabea: %s",
+    "%s shared a file with \"%s\"." : "%s fitxategi bat partekatu du \"%s\"(r)ekin.",
+    "%s shared a file with you." : "%s zurekin fitxategi bat partekatu du.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s(e)k eduki batzuk partekatu ditu zurekin.\nBertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s(e)k eduki batzuk partekatu ditu zurekin. Bertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
+    "Password to access content shared with you by %1$s" : "%1$s-k zurekin partekatutako edukiera atzitzeko pasahitza",
+    "Password to access content" : "Edukia atzitzeko pasahitza",
+    "Bring cloud-users closer together." : "Elkartu gehiago hodei erabiltzaileak.",
+    "No files in here" : "Ez dago fitxategirik hemen",
+    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan ",
+    "Name" : "Izena",
+    "Size" : "Tamaina",
+    "Modified" : "Aldatua",
+    "Circles" : "Zirkuluak",
+    "Circles' files" : "Zirkuluen fitxategiak",
+    "Select circles to filter by" : "Hautatu zirkuluak nola iragazi",
+    "No circles found" : "Ez da zirkulurik aurkitu",
+    "Please select circles to filter by" : "Hautatu zirkuluak nola iragazi",
+    "No files found for the selected circles" : "Ez da fitxategirik aurkitu hautatutako zirkuluetarako",
+    "You created the circle {circle}" : "{circle} zirkulua zuk sortu duzu",
+    "{author} created the circle {circle}" : "{author}(e)k {circle} zirkulua sortu du",
+    "You linked {group} to {circle}" : "{group} taldea {circle} zirkuluarekin lotu duzu",
+    "{group} has been linked to {circle} by {author}" : "{group} taldea {circle} zirkuluarekin lotu du {author}(e)k",
+    "You unlinked {group} from {circle}" : "{group} taldea {circle} zirkulutik atera duzu",
+    "{group} has been unlinked from {circle} by {author}" : "{group} taldea {circle} zirkulutik atera du {author}(e)k",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Lotuta dagoen {group} taldearen maila aldatu duzu {circle} zirkuluan %1$s-ra",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author}(e)k lotuta dagoen {group} taldearen maila aldatu du {circle} zirkuluan %1$s-ra",
+    "You sent a request to link {circle} with {remote}" : "Eskaera bidali duzu {circle} lotzeko [remote]rekin",
+    "{author} sent a request to link {circle} with {remote}" : "{author}(e)k eskaera bidali du {circle} lotzeko [remote]rekin",
+    "{remote} requested a link with {circle}" : "{remote}(e)k eskaera egin du {circle} zirkuluarekin lotzeko ",
+    "The request to link {circle} with {remote} has been rejected" : "{circle} eta {remote} lotzeko eskaera baztertua izan da ",
+    "The request to link {remote} with {circle} has been canceled remotely" : "{circle} eta {remote} lotzeko eskaera urrunetik bertan behera utzia izan da ",
+    "The request to link {circle} with {remote} has been accepted" : "{circle} eta {remote} lotzeko eskaera onartua izan da ",
+    "You dismissed the request to link {remote} with {circle}" : "{circle} eta [remote] lotzeko eskaera baztertu duzu",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author}(e)k baztertu egin du {circle} eta [remote] lotzeko eskaera",
+    "You canceled the request to link {circle} with {remote}" : "{circle} eta [remote] lotzeko eskaera bertan behera utzi duzu",
+    "{author} canceled the request to link {circle} with {remote}" : "{author}(e)k bertan behera utzi du {circle} eta [remote] lotzeko eskaera",
+    "You accepted the request to link {remote} with {circle}" : "{circle} eta [remote] lotzeko eskaera onartu duzu",
+    "{author} accepted the request to link {remote} with {circle}" : "{author}(e)k onartu egin du {circle} eta [remote] lotzeko eskaera",
+    "A link between {circle} and {remote} is now up and running" : "{circle} eta {remote}(r)en arteko lotura martxan da eta badabil ",
+    "The link between {circle} and {remote} has been shutdown remotely" : "{circle} eta {remote}(r)en arteko lotura urrunetik itzali da ",
+    "You closed the link between {circle} and {remote}" : "{circle} eta [remote](r)en arteko lotura eten egin duzu",
+    "{author} closed the link between {circle} and {remote}" : "{author}(e)k eten egin du {circle} eta [remote](r)en arteko lotura",
+    "{member} cancelled his request to join {circle}" : "{member} kideak {circle} zirkuluan sartzeko eskaera bertan behera utzi du",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "Kide zaren <strong>zirkuluetako</strong> gertaeretan",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Moderatzen ari zaren <strong>zirkulu</strong> bateko edozein gertaera garrantzitsu",
+    "On global events happening in any <strong>Circle</strong>" : "<strong>Zirkulu</strong> batean gertatzen diren gertaera orokorretan",
+    "Join Request" : "Sartzeko eskaera",
+    "Password Protected" : "Pasahitzez babestua",
+    "Circle Invite" : "Zirkulu gonbidapena",
+    "Email Address" : "Helbide elektronikoa",
+    "Initialisation Nextcloud" : "Hasieratze Nextcloud",
+    "Initialisation Circles App" : "Hasieratze zirkulu aplikazioa",
+    "Circle not found" : "Ez da zirkulua aurkitu",
+    "Circle not found " : "Ez da zirkulua aurkitu",
+    "This account is already a member of the circle" : "Kontu hau zirkuluko kidea da dagoeneko",
+    "Federated link not found" : "Ez da esteka federatua aurkitu",
+    "The circle is not federated" : "Zirkulua ez dago federatuta",
+    "You cannot join this circle" : "Ezin zara zirkulu honetan sartu",
+    "This member is the owner of the circle" : "Kide hau da zirkuluaren jabea",
+    "%s (Circle owned by %s)" : "%s (%s-(r)en jabetzako zirkulua)",
+    "Personal Circle" : "Zirkulu pertsonala",
     "You need a specify a type of circle" : "Zirkulu mota zehaztu behar duzu",
     "A circle with that name exists" : "Badago izen bereko beste zirkulu bat ",
     "This member is not the owner of the circle" : "Kide hau ez da zirkuluaren jabea",
@@ -167,23 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "Posta-helbidearen formatua ez da baliozkoa",
     "This contact is not available" : "Kontaktu hori ez dago erabilgarri",
     "You have no permission to create a new circle" : "Ez duzu zirkulu berri bat sortzeko baimenik",
-    "%s shared a file with \"%s\"." : "%s fitxategi bat partekatu du \"%s\"(r)ekin.",
-    "%s shared a file with you." : "%s zurekin fitxategi bat partekatu du.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s(e)k eduki batzuk partekatu ditu zurekin.\nBertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s(e)k eduki batzuk partekatu ditu zurekin. Bertara iristeko esteka mezu batean eduki behar zenuke dagoeneko zure posta elektronikoan.",
-    "Password to access content shared with you by %1$s" : "%1$s-k zurekin partekatutako edukiera atzitzeko pasahitza",
-    "Password to access content" : "Edukia atzitzeko pasahitza",
     "This item is already shared with this circle" : "Elementu hau dagoeneko partekatu da zirkulu honekin",
-    "Bring cloud-users closer together." : "Elkartu gehiago hodei erabiltzaileak.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Circles jendeak erabiltzaile/lankide/lagun taldeak sortzen ahalbidetzen die.\nPertsona talde (edo \"zirkulu\") hauek beste aplikazio batzuetan erabili daitezke partekatzeko xedearekin. ",
-    "No files in here" : "Ez dago fitxategirik hemen",
-    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan ",
-    "Name" : "Izena",
-    "Size" : "Tamaina",
-    "Modified" : "Aldatua",
-    "Initialisation Nextcloud" : "Hasieratze Nextcloud",
-    "Initialisation Circles App" : "Hasieratze zirkulu aplikazioa",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Ezin duzu Zirkuluak aplikazioa erabili administratzaileak gutxienez zirkulu mota bat baimendu arte",
-    "Could not find share" : "Ezin da partekatzea topatu"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Circles jendeak erabiltzaile/lankide/lagun taldeak sortzen ahalbidetzen die.\nPertsona talde (edo \"zirkulu\") hauek beste aplikazio batzuetan erabili daitezke partekatzeko xedearekin. "
 },
 "nplurals=2; plural=(n != 1);");
