@@ -1,34 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "מעגלים",
-    "Circles' files" : "קבצים של מעגלים",
-    "Select circles to filter by" : "נא לבחור מעגלים לסינון",
-    "No circles found" : "לא נמצאו מעגלים",
-    "Please select circles to filter by" : "נא לבחור מעגלים לסינון",
-    "No files found for the selected circles" : "לא נמצאו קבצים למעגלים הנבחרים",
-    "You created the circle {circle}" : "יצרת את המעגל {circle}",
-    "{author} created the circle {circle}" : "המעגל {circle} נוצר על ידי {author}",
     "You deleted {circle}" : "מחקת את {circle}",
     "{author} deleted {circle}" : "{circle} נמחק על ידי {author}",
-    "You linked {group} to {circle}" : "קישרת את {group} אל {circle}",
-    "{group} has been linked to {circle} by {author}" : "{group} קושרה אל {circle} על ידי {author}",
-    "You unlinked {group} from {circle}" : "ניתקת את {group} מהמעגל {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{group} נותקה מהמעגל {circle} על ידי {author}",
-    "You sent a request to link {circle} with {remote}" : "שלחת בקשה לקשר את {circle} אל {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "נשלחה בקשה על ידי {author} לקשר את {circle} אל {remote}",
-    "{remote} requested a link with {circle}" : "התקבלה בקשה לקישור מול {circle} על ידי {remote}",
-    "The request to link {circle} with {remote} has been rejected" : "הבקשה לקשר את {circle} אל {remote} נדחתה",
-    "The request to link {remote} with {circle} has been canceled remotely" : "הבקשה לקשר את {circle} אל {remote} בוטלה מהצד השני",
-    "The request to link {circle} with {remote} has been accepted" : "הבקשה לקשר את {circle} אל {remote} התקבלה",
-    "You canceled the request to link {circle} with {remote}" : "ביטלת את הבקשה לקשר את {circle} אל {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "הבקשה לקשר את {circle} אל {remote} בוטלה על ידי {author}",
-    "You accepted the request to link {remote} with {circle}" : "נענית לבקשה לקשר את {remote} אל {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "הבקשה לקשר את {circle} אל {remote} נענתה על ידי {author}",
-    "A link between {circle} and {remote} is now up and running" : "קישור בין {circle} לבין {remote} פעיל כעת",
-    "The link between {circle} and {remote} has been shutdown remotely" : "הקישור בין {circle} לבין {remote} נכבה מרחוק",
-    "You closed the link between {circle} and {remote}" : "סגרת את הקישור בין {circle} לבין {remote}",
-    "{author} closed the link between {circle} and {remote}" : "הקישור בין {circle} לבין {remote} נסגר על ידי {author}",
     "You joined {circle}" : "הטרפת אל {circle}",
     "You accepted the invitation to join {circle}" : "קיבלת את הבקשה להצטרף אל {circle}",
     "{member} accepted the invitation to join {circle}" : "הבקשה להצטרף אל {circle} התקבלה על ידי {member}",
@@ -57,19 +31,17 @@ OC.L10N.register(
     "Visible" : "גלוי",
     "Open" : "פתוח",
     "Invite" : "הזמנה",
-    "Join Request" : "בקשת הצטרפות",
     "Friends" : "חברים",
-    "Password Protected" : "מוגן בססמה",
+    "Password protected" : "מוגן בססמה",
     "No Owner" : "אין בעלים",
     "Hidden" : "מוסתר",
     "Backend" : "מנגנון",
     "Local" : "מקומי",
     "Root" : "בסיס",
-    "Circle Invite" : "הזמנה למעגל",
     "Federated" : "Federated",
     "Mount point" : "נקודת עיגון",
     "Nextcloud Group" : "קבוצת Nextcloud",
-    "Email Address" : "כתובת דוא״ל",
+    "Email address" : "כתובת דוא״ל",
     "Contact" : "איש/אשת קשר",
     "Circle" : "מעגל",
     "Nextcloud App" : "יישומון Nextcloud",
@@ -88,13 +60,9 @@ OC.L10N.register(
     "Building Local Database" : "מסד הנתונים המקומי נבנה",
     "Testing Basic Circle Creation" : "נבדקת יצירת מעגל בסיסי",
     "Adding local users and moderators" : "הוספת משתמשים ומפקחים מקומיים",
-    "Circle not found" : "המעגל לא נמצא",
-    "Circle not found " : "המעגל לא נמצא",
-    "This member does not exist" : "חבר זה אינו קיים",
     "This feature is not available for personal circles" : "תכונה זו אינה זמינה למעגלים אישיים",
-    "You cannot join this circle" : "אין לך אפשרות להצטרף למעגל הזה",
     "Insufficient privileges" : "אין מספיק הרשאות",
-    "This member is the owner of the circle" : "חבר זה הוא בעל המעגל",
+    "This member does not exist" : "חבר זה אינו קיים",
     "You are already a member of this circle" : "כבר יש לך חברות במעגל זה",
     "You have been blocked from this circle" : "גישתך למעגל הזה נחסמה",
     "You are now a member of the Circle \"%2$s\"" : "התקבלת לחברות במעגל „%2$s”",
@@ -103,6 +71,46 @@ OC.L10N.register(
     "Refuse" : "סירוב",
     "Leave the circle" : "לעזוב את המעגל",
     "%s" : "%s",
+    "No files in here" : "אין כאן קבצים",
+    "No entries found in this folder" : "לא נמצאו רשומות בתיקייה הזאת",
+    "Name" : "שם",
+    "Size" : "גודל",
+    "Modified" : "מועד שינוי",
+    "Circles" : "מעגלים",
+    "Circles' files" : "קבצים של מעגלים",
+    "Select circles to filter by" : "נא לבחור מעגלים לסינון",
+    "No circles found" : "לא נמצאו מעגלים",
+    "Please select circles to filter by" : "נא לבחור מעגלים לסינון",
+    "No files found for the selected circles" : "לא נמצאו קבצים למעגלים הנבחרים",
+    "You created the circle {circle}" : "יצרת את המעגל {circle}",
+    "{author} created the circle {circle}" : "המעגל {circle} נוצר על ידי {author}",
+    "You linked {group} to {circle}" : "קישרת את {group} אל {circle}",
+    "{group} has been linked to {circle} by {author}" : "{group} קושרה אל {circle} על ידי {author}",
+    "You unlinked {group} from {circle}" : "ניתקת את {group} מהמעגל {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{group} נותקה מהמעגל {circle} על ידי {author}",
+    "You sent a request to link {circle} with {remote}" : "שלחת בקשה לקשר את {circle} אל {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "נשלחה בקשה על ידי {author} לקשר את {circle} אל {remote}",
+    "{remote} requested a link with {circle}" : "התקבלה בקשה לקישור מול {circle} על ידי {remote}",
+    "The request to link {circle} with {remote} has been rejected" : "הבקשה לקשר את {circle} אל {remote} נדחתה",
+    "The request to link {remote} with {circle} has been canceled remotely" : "הבקשה לקשר את {circle} אל {remote} בוטלה מהצד השני",
+    "The request to link {circle} with {remote} has been accepted" : "הבקשה לקשר את {circle} אל {remote} התקבלה",
+    "You canceled the request to link {circle} with {remote}" : "ביטלת את הבקשה לקשר את {circle} אל {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "הבקשה לקשר את {circle} אל {remote} בוטלה על ידי {author}",
+    "You accepted the request to link {remote} with {circle}" : "נענית לבקשה לקשר את {remote} אל {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "הבקשה לקשר את {circle} אל {remote} נענתה על ידי {author}",
+    "A link between {circle} and {remote} is now up and running" : "קישור בין {circle} לבין {remote} פעיל כעת",
+    "The link between {circle} and {remote} has been shutdown remotely" : "הקישור בין {circle} לבין {remote} נכבה מרחוק",
+    "You closed the link between {circle} and {remote}" : "סגרת את הקישור בין {circle} לבין {remote}",
+    "{author} closed the link between {circle} and {remote}" : "הקישור בין {circle} לבין {remote} נסגר על ידי {author}",
+    "Join Request" : "בקשת הצטרפות",
+    "Password Protected" : "מוגן בססמה",
+    "Circle Invite" : "הזמנה למעגל",
+    "Email Address" : "כתובת דוא״ל",
+    "Initialisation Circles App" : "יישומון המעגלים נטען",
+    "Circle not found" : "המעגל לא נמצא",
+    "Circle not found " : "המעגל לא נמצא",
+    "You cannot join this circle" : "אין לך אפשרות להצטרף למעגל הזה",
+    "This member is the owner of the circle" : "חבר זה הוא בעל המעגל",
     "Personal Circle" : "מעגל אישי",
     "You need a specify a type of circle" : "עליך לציין את סוג המעגל",
     "A circle with that name exists" : "כבר קיים מעגל בשם הזה",
@@ -114,13 +122,6 @@ OC.L10N.register(
     "now" : "עכשיו",
     "Email format is not valid" : "תצורת הדוא״ל שגויה",
     "This contact is not available" : "איש קשר זה אינו זמין",
-    "This item is already shared with this circle" : "פריט זה כבר שותף עם המעגל הזה",
-    "No files in here" : "אין כאן קבצים",
-    "No entries found in this folder" : "לא נמצאו רשומות בתיקייה הזאת",
-    "Name" : "שם",
-    "Size" : "גודל",
-    "Modified" : "מועד שינוי",
-    "Initialisation Circles App" : "יישומון המעגלים נטען",
-    "Could not find share" : "לא ניתן למצוא את השיתוף"
+    "This item is already shared with this circle" : "פריט זה כבר שותף עם המעגל הזה"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
