@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Krugovi",
-    "Circles' files" : "Datoteke krugova",
-    "Select circles to filter by" : "Odaberite krugove koje želite filtrirati",
-    "No circles found" : "Nije pronađen nijedan krug",
-    "Please select circles to filter by" : "Odaberite krugove koje želite filtrirati",
-    "No files found for the selected circles" : "Nije pronađena nijedna datoteka za odabrane krugove",
-    "You created the circle {circle}" : "Stvorili ste krug {circle}",
-    "{author} created the circle {circle}" : "{author} je stvorio krug {circle}",
     "You deleted {circle}" : "Izbrisali ste {circle}",
     "{author} deleted {circle}" : "{author} je izbrisao {circle}",
-    "You linked {group} to {circle}" : "Povezali ste {group} s {circle}",
-    "{group} has been linked to {circle} by {author}" : "{author} je povezao {group} s {circle}",
-    "You unlinked {group} from {circle}" : "Prekinuli ste vezu {group} s {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{author} je prekinuo vezu {group} s {circle}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Promijenili ste razinu povezane grupe {group} u {circle} na %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} je promijenio razinu povezane grupe {group} u {circle} na %1$s",
-    "You sent a request to link {circle} with {remote}" : "Poslali ste zahtjev za povezivanje {circle} s {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{autor} je poslao zahtjev za povezivanje {circle} s {remote}",
-    "{remote} requested a link with {circle}" : "{remote} je zatražio vezu s {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "Zahtjev za povezivanjem {circle} s {remote} je odbijen",
-    "The request to link {remote} with {circle} has been canceled remotely" : "Zahtjev za povezivanjem {remote} s {circle} je daljinski otkazan",
-    "The request to link {circle} with {remote} has been accepted" : "Zahtjev za povezivanjem {circle} s {remote} je prihvaćen",
-    "You dismissed the request to link {remote} with {circle}" : "Zanemarili ste zahtjev za povezivanjem {remote} s {circle}",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} je zanemario zahtjev za povezivanjem {remote} s {circle}",
-    "You canceled the request to link {circle} with {remote}" : "Otkazali ste zahtjev za povezivanjem {circle} s {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{autor} je otkazao zahtjev za povezivanjem {circle} s {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Prihvatili ste zahtjev za povezivanjem {remote} s {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} je prihvatio zahtjev za povezivanjem {remote} s {circle}",
-    "A link between {circle} and {remote} is now up and running" : "Veza između {circle} i {remote} je inicijalizirana",
-    "The link between {circle} and {remote} has been shutdown remotely" : "Veza između {circle} i {remote} isključena je daljinski",
-    "You closed the link between {circle} and {remote}" : "Zatvorili ste vezu između {circle} i {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} je zatvorio vezu između {circle} i {remote}",
     "You joined {circle}" : "Pridružili ste se {circle}",
     "{member} joined {circle}" : "{member} se pridružio {circle}",
     "You accepted the invitation to join {circle}" : "Prihvatili ste pozivnicu za pridruživanje {circle}",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Odbili ste poziv za pridruživanje {circle}",
     "{member} declined an invitation to join {circle}" : "{član} je odbio poziv za pridruživanje {circle}",
     "You cancelled your request to join {circle}" : "Otkazali ste zahtjev za pridruživanje {circle}",
-    "{member} cancelled his request to join {circle}" : "{member} je otkazao svoj zahtjev za pridruživanje {circle}",
     "You removed {member} from {circle}" : "Uklonili ste {member} iz {circle}",
     "You have been removed from {circle} by {author}" : "{author} vas je uklonio iz {circle}",
     "{member} has been removed from {circle} by {author}" : "{author} je uklonio {member} iz {circle}",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} je poslao zahtjev za pridruživanje {circle}",
     "You are the new owner of {circle}" : "Vi ste novi vlasnik {circle}",
     "{member} is the new owner of {circle}" : "{member} je novi vlasnik {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "O događajima koji se događaju u <strong>krugu</strong> čiji ste član",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Bilo koji važan događaj u <strong>krugu</strong> koji moderirate",
-    "On global events happening in any <strong>Circle</strong>" : "O globalnim događajima koji pripadaju bilo kojem <strong>krugu</strong>",
     "Shared to Circles" : "Dijeljeno u krugovima",
     "Single" : "Jedan",
     "Personal" : "Osobno",
@@ -82,19 +48,17 @@ OC.L10N.register(
     "Visible" : "Vidljivo",
     "Open" : "Otvori",
     "Invite" : "Poziv",
-    "Join Request" : "Zahtjev za pridruživanje",
     "Friends" : "Prijatelji",
-    "Password Protected" : "Zaštićeno zaporkom",
+    "Password protected" : "Zaštićeno zaporkom",
     "No Owner" : "Nema vlasnika",
     "Hidden" : "Skriveno",
     "Backend" : "Pozadinski sustav",
     "Local" : "Lokalno",
     "Root" : "Korijen",
-    "Circle Invite" : "Poziv u krug",
     "Federated" : "Udruženo",
     "Mount point" : "Točka postavljanja",
     "Nextcloud Group" : "Nextcloud grupa",
-    "Email Address" : "Adresa e-pošte",
+    "Email address" : "Adresa e-pošte",
     "Contact" : "Kontakt",
     "Circle" : "Krug",
     "Nextcloud App" : "Nextcloud aplikacija",
@@ -124,16 +88,10 @@ OC.L10N.register(
     "Building Local Database" : "Izgradnja lokalne baze podataka",
     "Testing Basic Circle Creation" : "Ispitivanje stvaranja osnovnog kruga",
     "Adding local users and moderators" : "Dodavanje lokalnih korisnika i moderatora",
-    "Circle not found" : "Krug nije pronađen",
-    "Circle not found " : "Krug nije pronađen ",
-    "This member does not exist" : "Ovaj član ne postoji",
-    "Federated link not found" : "Udružena poveznica nije pronađena",
     "This feature is not available for personal circles" : "Ova značajka nije dostupna za osobne krugove",
-    "The circle is not federated" : "Krug nije udruženi",
-    "You cannot join this circle" : "Ne možete se pridružiti ovom krugu",
     "This member is not a moderator" : "Ovaj član nije moderator",
     "Insufficient privileges" : "Nedovoljne ovlasti",
-    "This member is the owner of the circle" : "Ovaj član je vlasnik kruga",
+    "This member does not exist" : "Ovaj član ne postoji",
     "Level cannot be changed for this type of member" : "Razina se ne može promijeniti za ovu vrstu člana",
     "You are already a member of this circle" : "Već ste član ovog kruga",
     "You have been blocked from this circle" : "Blokirani ste iz ovog kruga",
@@ -144,8 +102,61 @@ OC.L10N.register(
     "Refuse" : "Odbij",
     "Leave the circle" : "Napusti krug",
     "%s" : "%s",
-    "Personal Circle" : "Osobni krug",
     "%s owned by %s" : "%s u vlasništvu %s",
+    "%s shared a file with you." : "%s dijeli datoteku s vama.",
+    "Bring cloud-users closer together." : "Približite korisnike oblaka.",
+    "No files in here" : "Nema datoteka",
+    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
+    "Name" : "Naziv",
+    "Size" : "Veličina",
+    "Modified" : "Promijenjeno",
+    "Circles" : "Krugovi",
+    "Circles' files" : "Datoteke krugova",
+    "Select circles to filter by" : "Odaberite krugove koje želite filtrirati",
+    "No circles found" : "Nije pronađen nijedan krug",
+    "Please select circles to filter by" : "Odaberite krugove koje želite filtrirati",
+    "No files found for the selected circles" : "Nije pronađena nijedna datoteka za odabrane krugove",
+    "You created the circle {circle}" : "Stvorili ste krug {circle}",
+    "{author} created the circle {circle}" : "{author} je stvorio krug {circle}",
+    "You linked {group} to {circle}" : "Povezali ste {group} s {circle}",
+    "{group} has been linked to {circle} by {author}" : "{author} je povezao {group} s {circle}",
+    "You unlinked {group} from {circle}" : "Prekinuli ste vezu {group} s {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{author} je prekinuo vezu {group} s {circle}",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Promijenili ste razinu povezane grupe {group} u {circle} na %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} je promijenio razinu povezane grupe {group} u {circle} na %1$s",
+    "You sent a request to link {circle} with {remote}" : "Poslali ste zahtjev za povezivanje {circle} s {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{autor} je poslao zahtjev za povezivanje {circle} s {remote}",
+    "{remote} requested a link with {circle}" : "{remote} je zatražio vezu s {circle}",
+    "The request to link {circle} with {remote} has been rejected" : "Zahtjev za povezivanjem {circle} s {remote} je odbijen",
+    "The request to link {remote} with {circle} has been canceled remotely" : "Zahtjev za povezivanjem {remote} s {circle} je daljinski otkazan",
+    "The request to link {circle} with {remote} has been accepted" : "Zahtjev za povezivanjem {circle} s {remote} je prihvaćen",
+    "You dismissed the request to link {remote} with {circle}" : "Zanemarili ste zahtjev za povezivanjem {remote} s {circle}",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} je zanemario zahtjev za povezivanjem {remote} s {circle}",
+    "You canceled the request to link {circle} with {remote}" : "Otkazali ste zahtjev za povezivanjem {circle} s {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "{autor} je otkazao zahtjev za povezivanjem {circle} s {remote}",
+    "You accepted the request to link {remote} with {circle}" : "Prihvatili ste zahtjev za povezivanjem {remote} s {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} je prihvatio zahtjev za povezivanjem {remote} s {circle}",
+    "A link between {circle} and {remote} is now up and running" : "Veza između {circle} i {remote} je inicijalizirana",
+    "The link between {circle} and {remote} has been shutdown remotely" : "Veza između {circle} i {remote} isključena je daljinski",
+    "You closed the link between {circle} and {remote}" : "Zatvorili ste vezu između {circle} i {remote}",
+    "{author} closed the link between {circle} and {remote}" : "{author} je zatvorio vezu između {circle} i {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} je otkazao svoj zahtjev za pridruživanje {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "O događajima koji se događaju u <strong>krugu</strong> čiji ste član",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Bilo koji važan događaj u <strong>krugu</strong> koji moderirate",
+    "On global events happening in any <strong>Circle</strong>" : "O globalnim događajima koji pripadaju bilo kojem <strong>krugu</strong>",
+    "Join Request" : "Zahtjev za pridruživanje",
+    "Password Protected" : "Zaštićeno zaporkom",
+    "Circle Invite" : "Poziv u krug",
+    "Email Address" : "Adresa e-pošte",
+    "Initialisation Nextcloud" : "Inicijalizacija Nextclouda",
+    "Initialisation Circles App" : "Inicijalizacija aplikacije Circles",
+    "Circle not found" : "Krug nije pronađen",
+    "Circle not found " : "Krug nije pronađen ",
+    "Federated link not found" : "Udružena poveznica nije pronađena",
+    "The circle is not federated" : "Krug nije udruženi",
+    "You cannot join this circle" : "Ne možete se pridružiti ovom krugu",
+    "This member is the owner of the circle" : "Ovaj član je vlasnik kruga",
+    "Personal Circle" : "Osobni krug",
     "You need a specify a type of circle" : "Trebate odrediti vrstu kruga",
     "A circle with that name exists" : "Postoji krug s tim nazivom",
     "This member is not the owner of the circle" : "Ovaj član nije vlasnik kruga",
@@ -158,15 +169,6 @@ OC.L10N.register(
     "now" : "sada",
     "Email format is not valid" : "Format e-pošte nije važeći",
     "This contact is not available" : "Ovaj kontakt nije dostupan",
-    "%s shared a file with you." : "%s dijeli datoteku s vama.",
-    "This item is already shared with this circle" : "Ova se stavka već dijeli s ovim krugom",
-    "Bring cloud-users closer together." : "Približite korisnike oblaka.",
-    "No files in here" : "Nema datoteka",
-    "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
-    "Name" : "Naziv",
-    "Size" : "Veličina",
-    "Modified" : "Promijenjeno",
-    "Initialisation Nextcloud" : "Inicijalizacija Nextclouda",
-    "Initialisation Circles App" : "Inicijalizacija aplikacije Circles"
+    "This item is already shared with this circle" : "Ova se stavka već dijeli s ovim krugom"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
