@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Cerchie",
-    "Circles' files" : "File delle cerchie",
-    "Select circles to filter by" : "Seleziona le cerchie per filtrare",
-    "No circles found" : "Nessuna cerchia trovata",
-    "Please select circles to filter by" : "Seleziona le cerchie per filtrare",
-    "No files found for the selected circles" : "Nessun file trovato per le cerchie selezionate",
-    "You created the circle {circle}" : "Hai creato la cerchia {circle}",
-    "{author} created the circle {circle}" : "{author} ha creato la cerchia {circle}",
     "You deleted {circle}" : "Hai eliminato {circle}",
     "{author} deleted {circle}" : "{author} ha eliminato {circle}",
-    "You linked {group} to {circle}" : "Hai collegato {group} a {circle}",
-    "{group} has been linked to {circle} by {author}" : "{group} è stato collegato a {circle} da {author}",
-    "You unlinked {group} from {circle}" : "Hai scollegato {group} da {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{group} è stato scollegato da {circle} da {author}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Hai modificato il livello del gruppo collegato {group} in {circle} a %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ha modificato il tuo livello del gruppo collegato {group} in {circle} a %1$s",
-    "You sent a request to link {circle} with {remote}" : "Hai inviato una richiesta di collegare {circle} a {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} ha inviato una richiesta di collegare {circle} a {remote}",
-    "{remote} requested a link with {circle}" : "{remote} ha richiesto un collegamento con {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "La richiesta di collegare {circle} a {remote} è stata rifiutata",
-    "The request to link {remote} with {circle} has been canceled remotely" : "La richiesta di collegare {remote} a {circle} è stata annullata da remoto",
-    "The request to link {circle} with {remote} has been accepted" : "La richiesta di collegare {circle} a {remote} è stata accettata",
-    "You dismissed the request to link {remote} with {circle}" : "Hai scartato la richiesta di collegare {remote} a {circle}",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} ha scartato la richiesta di collegare {remote} a {circle}",
-    "You canceled the request to link {circle} with {remote}" : "Hai annullato la richiesta di collegare {circle} a {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} ha annullato la richiesta di collegare {circle} a {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Hai accettato la richiesta di collegare {remote} a {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} ha accettato la richiesta di collegare {remote} a {circle}",
-    "A link between {circle} and {remote} is now up and running" : "Un collegamento tra {circle} e {remote} è ora attivo e funzionante",
-    "The link between {circle} and {remote} has been shutdown remotely" : "Il collegamento tra {circle} e {remote} è stato interrotto da remoto",
-    "You closed the link between {circle} and {remote}" : "Hai chiuso il collegamento tra {circle} e {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} ha chiuso il collegamento tra {circle} e {remote}",
     "You joined {circle}" : "Sei entrato a far parte di {circle}",
     "{member} joined {circle}" : "{member} si è unito a {circle}",
     "You accepted the invitation to join {circle}" : "Hai accettato l'invito per unirti {circle}",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Hai rifiutato l'invito per unirti a {circle}",
     "{member} declined an invitation to join {circle}" : "{member} ha rifiutato un invito per unirsi a {circle}",
     "You cancelled your request to join {circle}" : "Hai annullato la tua richiesta di unirti a {circle}",
-    "{member} cancelled his request to join {circle}" : "{member} ha annullato la sua richiesta di unirsi a {circle}",
     "You removed {member} from {circle}" : "Hai rimosso {member} da {circle}",
     "You have been removed from {circle} by {author}" : "Sei stato rimosso da {circle} da {author}",
     "{member} has been removed from {circle} by {author}" : "{member} è stato rimosso da {circle} da {author}",
@@ -72,29 +41,25 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} ha inviato una richiesta di unirsi a {circle}",
     "You are the new owner of {circle}" : "Sei il nuovo proprietario di {circle}",
     "{member} is the new owner of {circle}" : "{member} è il nuovo proprietario di {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Per gli eventi che si verificano in una <strong>cerchia</strong> di cui sei membro",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Qualsiasi evento importante in una <strong>cerchia</strong> di cui sei moderatore",
-    "On global events happening in any <strong>Circle</strong>" : "Per eventi globali che si verificano in qualsiasi <strong>cerchia</strong>",
+    "Shared to Circles" : "Condivisi con cerchie",
     "Single" : "Singola",
     "Personal" : "Personale",
     "System" : "Sistema",
     "Visible" : "Visibile",
     "Open" : "Apri",
     "Invite" : "Invita",
-    "Join Request" : "Richiesta di unirsi",
     "Friends" : "Amici",
-    "Password Protected" : "Protetta da password",
+    "Password protected" : "Protetto da password",
     "No Owner" : "Nessun proprietario",
     "Hidden" : "Nascosta",
     "Backend" : "Motore",
     "Local" : "Locale",
     "Root" : "Radice",
-    "Circle Invite" : "Invito della cerchia",
     "Federated" : "Federata",
     "Mount point" : "Punto di mount",
     "Nextcloud Account" : "Account Nextcloud",
     "Nextcloud Group" : "Gruppo Nextcloud",
-    "Email Address" : "Indirizzo email",
+    "Email address" : "Indirizzo email",
     "Contact" : "Contatto",
     "Circle" : "Cerchia",
     "Nextcloud App" : "Applicazione Nextcloud",
@@ -120,27 +85,21 @@ OC.L10N.register(
     "%s shared multiple files with \"%s\"." : "%s ha condiviso più file con \"%s\".",
     "%s shared multiple files with you." : "%s ha condiviso più file con te.",
     "Boot up" : "Avvia",
+    "Nextcloud Initialization" : "Inizializzazione Nextcloud",
+    "Circles App Initialization" : "Inizializzazione app Cerchie",
     "Fresh installation status" : "Stato nuova installazione",
     "Building Local Database" : "Costruzione database locale",
     "Testing Basic Circle Creation" : "Test creazione cerchia di base",
     "Adding local users and moderators" : "Aggiunta di utenti locali e moderatori",
-    "Circle not found" : "Cerchia non trovata",
-    "Circle not found " : "Cerchia non trovata",
-    "This member does not exist" : "Questo membro non esiste",
-    "This account is already a member of the circle" : "Questo account è già un membro della cerchia",
-    "Federated link not found" : "Collegamento federato non trovato",
     "This feature is not available for personal circles" : "Questa funzionalità non è disponibile nelle cerchie personali",
-    "The circle is not federated" : "La cerchia non è federata",
-    "You cannot join this circle" : "Non puoi unirti a questa cerchia",
     "This member is not a moderator" : "Questo membro non è un moderatore",
     "Insufficient privileges" : "Permessi insufficienti",
-    "This member is the owner of the circle" : "Questo membro non è il proprietario della cerchia",
+    "This member does not exist" : "Questo membro non esiste",
     "Level cannot be changed for this type of member" : "Il livello non può essere modificato per questo tipo di membro",
     "You are already a member of this circle" : "Sei già un membro di questa cerchia",
     "You have been blocked from this circle" : "Sei stato bloccato da questa cerchia",
     "The account is already a member of this circle" : "L'account è già membro di questa cerchia",
     "The account has already been invited into this circle" : "L'account è già stato invitato in questa cerchia",
-    "%s (Circle owned by %s)" : "%s (Cerchi di proprietà di %s)",
     "You are now a member of the Circle \"%2$s\"" : "Ora sei membro della cerchia \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Sei stato invitato da %1$s nella cerchia \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s ha inviato una richiesta per essere membro della cerchia \"%2$s\"",
@@ -148,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "Rifiuta",
     "Leave the circle" : "Abbandona la cerchia",
     "%s" : "%s",
-    "Personal Circle" : "Cerchia personale",
     "%s owned by %s" : "%s posseduto da %s",
+    "%s shared a file with \"%s\"." : "%s ha condiviso un file con \"%s\".",
+    "%s shared a file with you." : "%s ha condiviso un file con te.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso qualcosa con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso qualcosa con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
+    "Password to access content shared with you by %1$s" : "Password per accedere ai contenuti condivisi con te da %1$s",
+    "Password to access content" : "Password per accedere ai contenuti",
+    "Bring cloud-users closer together." : "Avvicina gli utenti del cloud",
+    "No files in here" : "Nessun file qui",
+    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
+    "Name" : "Nome",
+    "Size" : "Dimensione",
+    "Modified" : "Modificato",
+    "Circles" : "Cerchie",
+    "Circles' files" : "File delle cerchie",
+    "Select circles to filter by" : "Seleziona le cerchie per filtrare",
+    "No circles found" : "Nessuna cerchia trovata",
+    "Please select circles to filter by" : "Seleziona le cerchie per filtrare",
+    "No files found for the selected circles" : "Nessun file trovato per le cerchie selezionate",
+    "You created the circle {circle}" : "Hai creato la cerchia {circle}",
+    "{author} created the circle {circle}" : "{author} ha creato la cerchia {circle}",
+    "You linked {group} to {circle}" : "Hai collegato {group} a {circle}",
+    "{group} has been linked to {circle} by {author}" : "{group} è stato collegato a {circle} da {author}",
+    "You unlinked {group} from {circle}" : "Hai scollegato {group} da {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{group} è stato scollegato da {circle} da {author}",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Hai modificato il livello del gruppo collegato {group} in {circle} a %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ha modificato il tuo livello del gruppo collegato {group} in {circle} a %1$s",
+    "You sent a request to link {circle} with {remote}" : "Hai inviato una richiesta di collegare {circle} a {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{author} ha inviato una richiesta di collegare {circle} a {remote}",
+    "{remote} requested a link with {circle}" : "{remote} ha richiesto un collegamento con {circle}",
+    "The request to link {circle} with {remote} has been rejected" : "La richiesta di collegare {circle} a {remote} è stata rifiutata",
+    "The request to link {remote} with {circle} has been canceled remotely" : "La richiesta di collegare {remote} a {circle} è stata annullata da remoto",
+    "The request to link {circle} with {remote} has been accepted" : "La richiesta di collegare {circle} a {remote} è stata accettata",
+    "You dismissed the request to link {remote} with {circle}" : "Hai scartato la richiesta di collegare {remote} a {circle}",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} ha scartato la richiesta di collegare {remote} a {circle}",
+    "You canceled the request to link {circle} with {remote}" : "Hai annullato la richiesta di collegare {circle} a {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} ha annullato la richiesta di collegare {circle} a {remote}",
+    "You accepted the request to link {remote} with {circle}" : "Hai accettato la richiesta di collegare {remote} a {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} ha accettato la richiesta di collegare {remote} a {circle}",
+    "A link between {circle} and {remote} is now up and running" : "Un collegamento tra {circle} e {remote} è ora attivo e funzionante",
+    "The link between {circle} and {remote} has been shutdown remotely" : "Il collegamento tra {circle} e {remote} è stato interrotto da remoto",
+    "You closed the link between {circle} and {remote}" : "Hai chiuso il collegamento tra {circle} e {remote}",
+    "{author} closed the link between {circle} and {remote}" : "{author} ha chiuso il collegamento tra {circle} e {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} ha annullato la sua richiesta di unirsi a {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "Per gli eventi che si verificano in una <strong>cerchia</strong> di cui sei membro",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Qualsiasi evento importante in una <strong>cerchia</strong> di cui sei moderatore",
+    "On global events happening in any <strong>Circle</strong>" : "Per eventi globali che si verificano in qualsiasi <strong>cerchia</strong>",
+    "Join Request" : "Richiesta di unirsi",
+    "Password Protected" : "Protetta da password",
+    "Circle Invite" : "Invito della cerchia",
+    "Email Address" : "Indirizzo email",
+    "Initialisation Nextcloud" : "Inizializzazione di Nextcloud",
+    "Initialisation Circles App" : "Inizializzazione applicazione Cerchie",
+    "Circle not found" : "Cerchia non trovata",
+    "Circle not found " : "Cerchia non trovata",
+    "This account is already a member of the circle" : "Questo account è già un membro della cerchia",
+    "Federated link not found" : "Collegamento federato non trovato",
+    "The circle is not federated" : "La cerchia non è federata",
+    "You cannot join this circle" : "Non puoi unirti a questa cerchia",
+    "This member is the owner of the circle" : "Questo membro non è il proprietario della cerchia",
+    "%s (Circle owned by %s)" : "%s (Cerchi di proprietà di %s)",
+    "Personal Circle" : "Cerchia personale",
     "You need a specify a type of circle" : "Devi specificare un tipo di cerchia",
     "A circle with that name exists" : "Una cerchia con quel nome esiste già",
     "This member is not the owner of the circle" : "Questo membro non è il proprietario della cerchia",
@@ -164,29 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "Il formato dell'indirizzo di posta non è valido",
     "This contact is not available" : "Questa contatto non è disponibile",
     "You have no permission to create a new circle" : "Non ti è consentito creare un nuovo circolo",
-    "%s shared a file with \"%s\"." : "%s ha condiviso un file con \"%s\".",
-    "%s shared a file with you." : "%s ha condiviso un file con te.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s ha condiviso qualcosa con te.\nDovresti aver già ricevuto un'email separata con un collegamento per accedervi.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s ha condiviso qualcosa con te. Dovresti aver già ricevuto un'email separata con un collegamento per accedervi.",
-    "Password to access content shared with you by %1$s" : "Password per accedere ai contenuti condivisi con te da %1$s",
-    "Password to access content" : "Password per accedere ai contenuti",
     "This item is already shared with this circle" : "Questo elemento è già condiviso con questa cerchia",
-    "Bring cloud-users closer together." : "Avvicina gli utenti del cloud",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Le cerchie consentono alle persone di creare i propri gruppi di persone/colleghi/amici.\nQuesti gruppi di persone (o \"cerchie\") possono quindi essere utilizzati da qualsiasi altra app per scopi di condivisione.",
-    "No files in here" : "Nessun file qui",
-    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
-    "Name" : "Nome",
-    "Size" : "Dimensione",
-    "Modified" : "Modificato",
-    "Nextcloud User" : "Utente Nextcloud",
-    "Initialisation Nextcloud" : "Inizializzazione di Nextcloud",
-    "Initialisation Circles App" : "Inizializzazione applicazione Cerchie",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Non puoi utilizzare l'applicazione Cerchie fino a quando il tuo amministratore avrà consentito almeno un tipo di cerchia",
-    "This user is already a member of the circle" : "L'utente è già membro di una cerchia",
-    "The user is already a member of this circle" : "L'utente è già membro di questa cerchia",
-    "The user has already been invited into this circle" : "L'utente è stato già invitato in questa cerchia",
-    "This user does not exist" : "Questo utente non esiste",
-    "Could not find share" : "Impossibile trovare la condivisione",
-    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Le cerchie permettono ai tuoi utenti di creare i propri gruppi di utenti/colleghi/amici.\nQuei gruppi di utenti (o \"cerchie\") possono poi essere usati da qualsiasi altra applicazione per condividere."
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Le cerchie consentono alle persone di creare i propri gruppi di persone/colleghi/amici.\nQuesti gruppi di persone (o \"cerchie\") possono quindi essere utilizzati da qualsiasi altra app per scopi di condivisione."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
