@@ -5,6 +5,8 @@ OC.L10N.register(
     "System" : "Sistēma",
     "Visible" : "Redzams",
     "Open" : "Atvērt",
+    "Invite" : "Uzaicināt",
+    "Password protected" : "Aizsargāts ar paroli",
     "Hidden" : "Paslēpts",
     "Local" : "Lokāls",
     "Root" : "Root",
@@ -16,11 +18,11 @@ OC.L10N.register(
     "Open »%s«" : "Atvērt »%s«",
     "Accept" : "Akceptēt",
     "%s" : "%s",
-    "now" : "šobrīd",
     "No files in here" : "Šeit nav datņu",
     "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
     "Name" : "Vārds",
     "Size" : "Izmērs",
-    "Modified" : "Mainīts"
+    "Modified" : "Mainīts",
+    "now" : "šobrīd"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
