@@ -1,20 +1,18 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Кругови",
-    "Select circles to filter by" : "Изберете кругови за да филтрирате",
-    "Please select circles to filter by" : "Изберете кругови за да филтрирате",
-    "No files found for the selected circles" : "Нема пронајдено датотеки за селектиранате кругови",
     "Shared to Circles" : "Споделено со кругови",
     "Personal" : "Сопствен",
     "System" : "Систем",
     "Visible" : "Видлив",
     "Open" : "Отвори",
     "Invite" : "Покани",
+    "Password protected" : "Заштитено со лозинка",
     "Hidden" : "Сокриен",
     "Local" : "Локално",
     "Root" : "Корен",
     "Federated" : "Федерален",
+    "Email address" : "Е-пошта адреса",
     "Contact" : "Контакт",
     "Circle" : "Круг",
     "Member" : "Член",
@@ -30,12 +28,16 @@ OC.L10N.register(
     "Open »%s«" : "Отвори »%s«",
     "Accept" : "Прифати",
     "%s" : "%s",
-    "Personal Circle" : "Сопствен круг",
-    "now" : "сега",
     "No files in here" : "Тука нема датотеки",
     "No entries found in this folder" : "Нема ништо во оваа папка",
     "Name" : "Име",
     "Size" : "Големина",
-    "Modified" : "Изменето"
+    "Modified" : "Изменето",
+    "Circles" : "Кругови",
+    "Select circles to filter by" : "Изберете кругови за да филтрирате",
+    "Please select circles to filter by" : "Изберете кругови за да филтрирате",
+    "No files found for the selected circles" : "Нема пронајдено датотеки за селектиранате кругови",
+    "Personal Circle" : "Сопствен круг",
+    "now" : "сега"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
