@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Kringen",
-    "Circles' files" : "Kringbestanden",
-    "Select circles to filter by" : "Selecteer kring om te filteren",
-    "No circles found" : "Geen kringen gevonden",
-    "Please select circles to filter by" : "Selecteer kringen om te filteren",
-    "No files found for the selected circles" : "Geen bestanden gevonden voor de geselecteerde kringen",
-    "You created the circle {circle}" : "Je hebt de kring {circle} gecreëerd",
-    "{author} created the circle {circle}" : "{author} maakte de {circle} kring",
     "You deleted {circle}" : "Je hebt {circle} verwijderd",
     "{author} deleted {circle}" : "{author} verwijderde {circle}",
-    "You linked {group} to {circle}" : "Je koppelde {group} met {circle}",
-    "{group} has been linked to {circle} by {author}" : "{group} is gekoppeld met {circle} door {author}",
-    "You unlinked {group} from {circle}" : "Je ontkoppelde {group} met {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{group} is ontkoppeld met {circle} door {author}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Je veranderde het niveau van de gekoppelde groep {group} in {circle} naar %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} veranderde het niveau van de gekoppelde groep {group} in {circle} naar %1$s",
-    "You sent a request to link {circle} with {remote}" : "Je verzond een {circle} link verzoek met met {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} verzonden een {circle} link verzoek met {remote}",
-    "{remote} requested a link with {circle}" : "{remote} verzocht een link verzoek met {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "Het {circle} link verzoek met {remote} is afgewezen",
-    "The request to link {remote} with {circle} has been canceled remotely" : "Het {remote} link verzoek met {circle} is op afstand afgesloten",
-    "The request to link {circle} with {remote} has been accepted" : "Het {circle} link verzoek met {remote} is geaccepteerd",
-    "You dismissed the request to link {remote} with {circle}" : "Je hebt het {remote} link verzoek met {circle} afgewezen",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} heeft het {remote} link verzoek met {circle} afgewezen",
-    "You canceled the request to link {circle} with {remote}" : "Je hebt het {circle} link verzoek met {remote} afgewezen",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} heeft het {circle} link verzoek met {remote} afgewezen",
-    "You accepted the request to link {remote} with {circle}" : "Je accepteerde het {remote} link verzoek met {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} accepteerde het {remote} link verzoek met {circle}",
-    "A link between {circle} and {remote} is now up and running" : "De link tussen {circle} en {remote} is nu verbonden",
-    "The link between {circle} and {remote} has been shutdown remotely" : "De link tussen {circle} en {remote} is op afstand afgesloten",
-    "You closed the link between {circle} and {remote}" : "Je sloot de link tussen {circle} en {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} sloot de link tussen {circle} en {remote}",
     "You joined {circle}" : "Je bent lid geworden van {circle}",
     "{member} joined {circle}" : "{member} werd lid van {circle}",
     "You accepted the invitation to join {circle}" : "Je hebt de uitnodiging voor {circle} geaccepteerd",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Je hebt de uitnodiging om lid te worden van {circle} afgewezen",
     "{member} declined an invitation to join {circle}" : "{member} heeft de uitnodiging om lid te worden van {circle} afgewezen",
     "You cancelled your request to join {circle}" : "Je hebt je verzoek om lid te worden van {circle} ingetrokken",
-    "{member} cancelled his request to join {circle}" : "{member} trok verzoek om lid te worden van {circle} weer in",
     "You removed {member} from {circle}" : "Je hebt {member} van {circle} verwijderd",
     "You have been removed from {circle} by {author}" : "Je werd van {circle} door {author} verwijderd",
     "{member} has been removed from {circle} by {author}" : "{member} is van {circle} door {author} verwijderd",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} verzond een verzoek om lid te worden van {circle}",
     "You are the new owner of {circle}" : "Je bent de nieuwe eigenaar van {circle}",
     "{member} is the new owner of {circle}" : "{member} is de nieuwe eigenaar van {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Over gebeurtenissen in een <strong>Kring</strong> waarvan je lid bent",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Belangrijke gebeurtenissen in <strong>Kring</strong> die je modereert",
-    "On global events happening in any <strong>Circle</strong>" : "Over globale afspraken die gebereuren binnen een <strong>Kring</strong>",
     "Shared to Circles" : "Gedeeld met Kringen",
     "Single" : "Alleen",
     "Personal" : "Persoonlijk",
@@ -82,19 +48,18 @@ OC.L10N.register(
     "Visible" : "Zichtbaar",
     "Open" : "Open",
     "Invite" : "Uitnodigen",
-    "Join Request" : "Deelnameverzoek",
     "Friends" : "Vrienden",
-    "Password Protected" : "Beveiligd met wachtwoord",
+    "Password protected" : "Wachtwoord-beveiligd",
     "No Owner" : "Geen eigenaar",
     "Hidden" : "Verborgen",
     "Backend" : "Backend",
     "Local" : "Lokaal",
     "Root" : "Root",
-    "Circle Invite" : "Kringuitnodiging",
     "Federated" : "Gefedereerd",
     "Mount point" : "Aankoppelpunt",
+    "Nextcloud Account" : "Nextcloud Account",
     "Nextcloud Group" : "Nextcloud Groep",
-    "Email Address" : "E-mailadres",
+    "Email address" : "E-mailadres",
     "Contact" : "Contact",
     "Circle" : "Kring",
     "Nextcloud App" : "Nextcloud App",
@@ -120,27 +85,21 @@ OC.L10N.register(
     "%s shared multiple files with \"%s\"." : "%s deelde meerdere bestanden met \"%s\".",
     "%s shared multiple files with you." : "%s deelde meerdere bestanden met jou.",
     "Boot up" : "Opstarten",
+    "Nextcloud Initialization" : "Nextcloud Initialisatie",
+    "Circles App Initialization" : "Circles App Initialisatie",
     "Fresh installation status" : "Nieuwe installatiestatus",
     "Building Local Database" : "Aanmaken lokale database",
     "Testing Basic Circle Creation" : "Testen basis kringcreatie",
     "Adding local users and moderators" : "Toevoegen lokale gebruikers en moderatoren",
-    "Circle not found" : "Kring niet gevonden",
-    "Circle not found " : "Kring niet gevonden",
-    "This member does not exist" : "Dit lid bestaat niet",
-    "This account is already a member of the circle" : "Dit account is al lid van de cirkel",
-    "Federated link not found" : "Gefedereerde link is niet gevonden",
     "This feature is not available for personal circles" : "Deze functie is niet beschikbaar voor persoonlijke kringen",
-    "The circle is not federated" : "De kring is niet gefedereerd",
-    "You cannot join this circle" : "Je kunt niet lid worden van deze kring",
     "This member is not a moderator" : "Dit lid is geen moderator",
     "Insufficient privileges" : "Onvoldoende rechten",
-    "This member is the owner of the circle" : "Dit lid is de eigenaar van de kring",
+    "This member does not exist" : "Dit lid bestaat niet",
     "Level cannot be changed for this type of member" : "Het niveau van dit type lid kan niet veranderd worden.",
     "You are already a member of this circle" : "Je bent al lid van deze kring",
     "You have been blocked from this circle" : "Je bent geblokkeerd van deze kring",
     "The account is already a member of this circle" : "Dit account is al lid van deze cirkel",
     "The account has already been invited into this circle" : "Dit account is al uitgenodigt voor deze cirkel",
-    "%s (Circle owned by %s)" : "%s (kring is eigendom van %s)",
     "You are now a member of the Circle \"%2$s\"" : "Je bent nu lid van Kring \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Je bent uitgenodigd door %1$sin Kring voor  \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s verstuurde een lidmaatschapsverzoek voor Kring \"%2$s\"",
@@ -148,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "Weigeren",
     "Leave the circle" : "Verlaat de kring",
     "%s" : "%s",
-    "Personal Circle" : "Persoonlijke kring",
     "%s owned by %s" : "%s is eigendom van %s",
+    "%s shared a file with \"%s\"." : "%s deelde een bestand met \"%s\".",
+    "%s shared a file with you." : "%s heeft een bestand met u gedeeld",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
+    "Password to access content shared with you by %1$s" : "Wachtwoord om toegang te krijgen tot inhoud gedeeld met u door %1$s",
+    "Password to access content" : "Wachtwoord voor toegang tot info",
+    "Bring cloud-users closer together." : "Breng cloudgebruikers dichter bij elkaar.",
+    "No files in here" : "Hier geen bestanden",
+    "No entries found in this folder" : "Niets in deze map gevonden",
+    "Name" : "Naam",
+    "Size" : "Omvang",
+    "Modified" : "Gewijzigd",
+    "Circles" : "Kringen",
+    "Circles' files" : "Kringbestanden",
+    "Select circles to filter by" : "Selecteer kring om te filteren",
+    "No circles found" : "Geen kringen gevonden",
+    "Please select circles to filter by" : "Selecteer kringen om te filteren",
+    "No files found for the selected circles" : "Geen bestanden gevonden voor de geselecteerde kringen",
+    "You created the circle {circle}" : "Je hebt de kring {circle} gecreëerd",
+    "{author} created the circle {circle}" : "{author} maakte de {circle} kring",
+    "You linked {group} to {circle}" : "Je koppelde {group} met {circle}",
+    "{group} has been linked to {circle} by {author}" : "{group} is gekoppeld met {circle} door {author}",
+    "You unlinked {group} from {circle}" : "Je ontkoppelde {group} met {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{group} is ontkoppeld met {circle} door {author}",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Je veranderde het niveau van de gekoppelde groep {group} in {circle} naar %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} veranderde het niveau van de gekoppelde groep {group} in {circle} naar %1$s",
+    "You sent a request to link {circle} with {remote}" : "Je verzond een {circle} link verzoek met met {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{author} verzonden een {circle} link verzoek met {remote}",
+    "{remote} requested a link with {circle}" : "{remote} verzocht een link verzoek met {circle}",
+    "The request to link {circle} with {remote} has been rejected" : "Het {circle} link verzoek met {remote} is afgewezen",
+    "The request to link {remote} with {circle} has been canceled remotely" : "Het {remote} link verzoek met {circle} is op afstand afgesloten",
+    "The request to link {circle} with {remote} has been accepted" : "Het {circle} link verzoek met {remote} is geaccepteerd",
+    "You dismissed the request to link {remote} with {circle}" : "Je hebt het {remote} link verzoek met {circle} afgewezen",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} heeft het {remote} link verzoek met {circle} afgewezen",
+    "You canceled the request to link {circle} with {remote}" : "Je hebt het {circle} link verzoek met {remote} afgewezen",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} heeft het {circle} link verzoek met {remote} afgewezen",
+    "You accepted the request to link {remote} with {circle}" : "Je accepteerde het {remote} link verzoek met {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} accepteerde het {remote} link verzoek met {circle}",
+    "A link between {circle} and {remote} is now up and running" : "De link tussen {circle} en {remote} is nu verbonden",
+    "The link between {circle} and {remote} has been shutdown remotely" : "De link tussen {circle} en {remote} is op afstand afgesloten",
+    "You closed the link between {circle} and {remote}" : "Je sloot de link tussen {circle} en {remote}",
+    "{author} closed the link between {circle} and {remote}" : "{author} sloot de link tussen {circle} en {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} trok verzoek om lid te worden van {circle} weer in",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "Over gebeurtenissen in een <strong>Kring</strong> waarvan je lid bent",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Belangrijke gebeurtenissen in <strong>Kring</strong> die je modereert",
+    "On global events happening in any <strong>Circle</strong>" : "Over globale afspraken die gebereuren binnen een <strong>Kring</strong>",
+    "Join Request" : "Deelnameverzoek",
+    "Password Protected" : "Beveiligd met wachtwoord",
+    "Circle Invite" : "Kringuitnodiging",
+    "Email Address" : "E-mailadres",
+    "Initialisation Nextcloud" : "Initialisatie Nextcloud",
+    "Initialisation Circles App" : "Initialisatie Circles App",
+    "Circle not found" : "Kring niet gevonden",
+    "Circle not found " : "Kring niet gevonden",
+    "This account is already a member of the circle" : "Dit account is al lid van de cirkel",
+    "Federated link not found" : "Gefedereerde link is niet gevonden",
+    "The circle is not federated" : "De kring is niet gefedereerd",
+    "You cannot join this circle" : "Je kunt niet lid worden van deze kring",
+    "This member is the owner of the circle" : "Dit lid is de eigenaar van de kring",
+    "%s (Circle owned by %s)" : "%s (kring is eigendom van %s)",
+    "Personal Circle" : "Persoonlijke kring",
     "You need a specify a type of circle" : "Een specifieke kring type is benodigd",
     "A circle with that name exists" : "Er bestaat al een kring met deze naam",
     "This member is not the owner of the circle" : "Dit lid is niet de eigenaar van de kring",
@@ -164,23 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "E-mailformaat niet geldig",
     "This contact is not available" : "Deze contact is niet beschikbaar",
     "You have no permission to create a new circle" : "U heeft geen machtiging om een nieuwe kring aan te maken",
-    "%s shared a file with \"%s\"." : "%s deelde een bestand met \"%s\".",
-    "%s shared a file with you." : "%s heeft een bestand met u gedeeld",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s heeft enige informatie met je gedeeld.\nJe moet al een aparte e-mail hebben ontvangen met een link om er te komen.",
-    "Password to access content shared with you by %1$s" : "Wachtwoord om toegang te krijgen tot inhoud gedeeld met u door %1$s",
-    "Password to access content" : "Wachtwoord voor toegang tot info",
     "This item is already shared with this circle" : "Dit object is al gedeeld met deze kring",
-    "Bring cloud-users closer together." : "Breng cloudgebruikers dichter bij elkaar.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirkels maakt het mogelijk om zelf groepen te maken met bijvoorbeeld collega's of vrienden.\nDeze gemeenschappen (of \"cirkels\") kunnen vervolgens gebruikt worden door andere applicaties om dingen te delen",
-    "No files in here" : "Hier geen bestanden",
-    "No entries found in this folder" : "Niets in deze map gevonden",
-    "Name" : "Naam",
-    "Size" : "Omvang",
-    "Modified" : "Gewijzigd",
-    "Initialisation Nextcloud" : "Initialisatie Nextcloud",
-    "Initialisation Circles App" : "Initialisatie Circles App",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "De beheerder dient minimaal een kring te maken voordat je de kring-app kan gebruiken.",
-    "Could not find share" : "De gedeelde folder kan niet worden gevonden"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirkels maakt het mogelijk om zelf groepen te maken met bijvoorbeeld collega's of vrienden.\nDeze gemeenschappen (of \"cirkels\") kunnen vervolgens gebruikt worden door andere applicaties om dingen te delen"
 },
 "nplurals=2; plural=(n != 1);");
