@@ -1,22 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Círculos",
-    "Circles' files" : "Ficheiros de Círculos",
-    "Select circles to filter by" : "Selecione círculos para filtrar por",
-    "No circles found" : "Não foram encontrados círculos",
-    "Please select circles to filter by" : "Por favor, selecione os círculos para filtrar por",
-    "No files found for the selected circles" : "Não foram encontrados ficheiros para os círculos selecionados",
-    "You created the circle {circle}" : "Criou o círculo {circle}",
-    "{author} created the circle {circle}" : "{author} criou o círculo {circle}",
     "You deleted {circle}" : "Eliminou {circle}",
     "{author} deleted {circle}" : "{author} eliminou {circle}",
-    "You linked {group} to {circle}" : "Associou {group} a {circle}",
-    "{group} has been linked to {circle} by {author}" : "{group} foi associado de {circle} por {author}",
-    "You unlinked {group} from {circle}" : "Desassociou {group} de {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{group} foi desassociado do {circle} por [author]",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Alterou o nível do grupo associado {group} no {circle} para %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} alterou o nível do grupo associado {group} no {circle} para %1$s",
     "You joined {circle}" : "Juntou-se a {circle}",
     "{member} joined {circle}" : "{member} juntou-se a {circle}",
     "You left {circle}" : "Saiu de {circle}",
@@ -26,10 +12,12 @@ OC.L10N.register(
     "System" : "Sistema",
     "Visible" : "Visível",
     "Open" : "Abrir",
+    "Password protected" : "Protegido com Palavra-passe",
     "Hidden" : "Escondido",
     "Local" : "Local",
     "Root" : "Root",
     "Federated" : "Federada",
+    "Email address" : "Endereço de email",
     "Contact" : "Contacto",
     "Circle" : "Círculo",
     "Member" : "membro",
@@ -44,24 +32,38 @@ OC.L10N.register(
     "%1$s via %2$s" : "%1$s via %2$s",
     "Click the button below to open it." : "Clicar no botão abaixo para o abrir.",
     "Open »%s«" : "Abrir »%s«",
-    "Circle not found" : "Círculo não encontrado",
-    "You cannot join this circle" : "Não pode juntar-se a este círculo",
     "This member is not a moderator" : "Este membro não é um moderador",
     "Insufficient privileges" : "Privilégios insuficientes",
-    "This member is the owner of the circle" : "Este membro é o proprietário do círculo",
     "You are already a member of this circle" : "Já é um membro deste círculo",
     "You have been blocked from this circle" : "Foi bloqueado neste círculo",
     "Accept" : "Aceitar",
     "%s" : "%s",
-    "Personal Circle" : "Círculo Pessoal",
-    "A circle with that name exists" : "Já existe um círculo com esse nome",
-    "now" : "agora",
-    "Email format is not valid" : "O formato de e-mail não é válido",
-    "This contact is not available" : "Este contacto não está disponível",
     "No files in here" : "Sem ficheiros aqui",
     "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
     "Name" : "Nome",
     "Size" : "Tamanho",
-    "Modified" : "Modificado"
+    "Modified" : "Modificado",
+    "Circles" : "Círculos",
+    "Circles' files" : "Ficheiros de Círculos",
+    "Select circles to filter by" : "Selecione círculos para filtrar por",
+    "No circles found" : "Não foram encontrados círculos",
+    "Please select circles to filter by" : "Por favor, selecione os círculos para filtrar por",
+    "No files found for the selected circles" : "Não foram encontrados ficheiros para os círculos selecionados",
+    "You created the circle {circle}" : "Criou o círculo {circle}",
+    "{author} created the circle {circle}" : "{author} criou o círculo {circle}",
+    "You linked {group} to {circle}" : "Associou {group} a {circle}",
+    "{group} has been linked to {circle} by {author}" : "{group} foi associado de {circle} por {author}",
+    "You unlinked {group} from {circle}" : "Desassociou {group} de {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{group} foi desassociado do {circle} por [author]",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Alterou o nível do grupo associado {group} no {circle} para %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} alterou o nível do grupo associado {group} no {circle} para %1$s",
+    "Circle not found" : "Círculo não encontrado",
+    "You cannot join this circle" : "Não pode juntar-se a este círculo",
+    "This member is the owner of the circle" : "Este membro é o proprietário do círculo",
+    "Personal Circle" : "Círculo Pessoal",
+    "A circle with that name exists" : "Já existe um círculo com esse nome",
+    "now" : "agora",
+    "Email format is not valid" : "O formato de e-mail não é válido",
+    "This contact is not available" : "Este contacto não está disponível"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
