@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Круги",
-    "Circles' files" : "Файлы кругов",
-    "Select circles to filter by" : "Выберите круги, что бы отфильтровать их по",
-    "No circles found" : "Кругов не найдено",
-    "Please select circles to filter by" : "Выберите круги, что бы отфильтровать их по",
-    "No files found for the selected circles" : "Для выбранных кругов не найдено ни одного файла",
-    "You created the circle {circle}" : "Вы создали круг «{circle}»",
-    "{author} created the circle {circle}" : "{author} создал(а) круг «{circle}»",
     "You deleted {circle}" : "Вы удалили круг «{circle}»",
     "{author} deleted {circle}" : "{author} удалил(а) круг «{circle}»",
-    "You linked {group} to {circle}" : "Вы связали группу «{group}» с кругом «circle»",
-    "{group} has been linked to {circle} by {author}" : "{author} связал(а) группа «{group}» с кругом «{circle}»",
-    "You unlinked {group} from {circle}" : "Вы убрали связь группы «{group}» с кругом «{circle}»",
-    "{group} has been unlinked from {circle} by {author}" : "{author} убрал(а) связь группы «{group}» с кругом «{circle}»",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Вы изменили уровень связанной с кругом «{circle}» группы «{group}» на %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} изменил(а) уровень связанной с кругом «{circle}» группы «{group}» на %1$s",
-    "You sent a request to link {circle} with {remote}" : "Вы отправили запрос на связывание круга «{circle}» с {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} отправил(а) запрос на связывание круга «{circle}» с {remote}",
-    "{remote} requested a link with {circle}" : "{remote} запросил(а) связывание с кругом «{circle}»",
-    "The request to link {circle} with {remote} has been rejected" : "Запрос на связывание круга «{circle}» с {remote} был отклонён",
-    "The request to link {remote} with {circle} has been canceled remotely" : "Запрос на связывание {remote} с кругом «{circle}» был отклонён на другом сервере",
-    "The request to link {circle} with {remote} has been accepted" : "Запрос на связывание круга «{circle}» с {remote} был одобрен",
-    "You dismissed the request to link {remote} with {circle}" : "Вы отклонили запрос на связывание {remote} с кругом «{circle}»",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} отклонил(а) запрос на связывание {remote} с кругом «{circle}»",
-    "You canceled the request to link {circle} with {remote}" : "Вы отменили запрос на связывание круга «{circle}» с {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} отменил(а) запрос на связывание круга «{circle}» с {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Вы приняли запрос на связывание {remote} с кругом «{circle}»",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} принял(а) запрос на связывание {remote} с кругом «{circle}»",
-    "A link between {circle} and {remote} is now up and running" : "Связь между кругом «{circle}» и {remote} установлена и действует",
-    "The link between {circle} and {remote} has been shutdown remotely" : "Связь между кругом «{circle}» и {remote} была прекращена на другом сервере",
-    "You closed the link between {circle} and {remote}" : "Вы прекратили связь между кругом «{circle}» и {link}",
-    "{author} closed the link between {circle} and {remote}" : "{author} прекратил связь между кругом «{circle}» и {remote}",
     "You joined {circle}" : "Вы присоединились к «{circle}»",
     "{member} joined {circle}" : "{member} присоединился(ась) к «{circle}»",
     "You accepted the invitation to join {circle}" : "Вы приняли приглашение на присоединение к «{circle}»",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Вы отклонили приглашение в круг «{circle}»",
     "{member} declined an invitation to join {circle}" : "{member} отклонил(а) приглашение в круг «{circle}»",
     "You cancelled your request to join {circle}" : "Вы отменили свой запрос на присоединение к кругу «{circle}»",
-    "{member} cancelled his request to join {circle}" : "{member} отменил(а) свой запрос на присоединение к кругу «{circle}»",
     "You removed {member} from {circle}" : "Вы удалили пользователя {member} из круга «{circle}»",
     "You have been removed from {circle} by {author}" : "{author} удалил вас из круга «{circle}»",
     "{member} has been removed from {circle} by {author}" : "{author} удалил(а) участника {member} из круга «{circle}»",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} отправил(а) запрос на присоединение к кругу «{circle}»",
     "You are the new owner of {circle}" : "Вы стали владельцем круга «{circle}»",
     "{member} is the new owner of {circle}" : "{member} стал владельцем круга «{circle}»",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "При событии в <strong>круге</strong>, которому вы принадлежите ",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Любое важное событие в модерируемом вами <strong>круге </strong> ",
-    "On global events happening in any <strong>Circle</strong>" : "При глобальном событии в <strong>круге</strong>, которому вы принадлежите ",
     "Shared to Circles" : "Предоставленный кругам общий доступ",
     "Single" : "Единственный",
     "Personal" : "Личный",
@@ -82,20 +48,18 @@ OC.L10N.register(
     "Visible" : "Видимый",
     "Open" : "Открыть",
     "Invite" : "Приглашение",
-    "Join Request" : "Запрос на вступление",
     "Friends" : "Друзья",
-    "Password Protected" : "Защищено паролем",
+    "Password protected" : "Защищено паролем",
     "No Owner" : "Новый владелец",
     "Hidden" : "Скрыто",
     "Backend" : "Внутренний",
     "Local" : "Локальный",
     "Root" : "Корневой каталог",
-    "Circle Invite" : "Приглашение в круг",
     "Federated" : "Федеративный",
     "Mount point" : "Место установки",
     "Nextcloud Account" : "Учётная запись Nextcloud",
     "Nextcloud Group" : "Группа Nextcloud",
-    "Email Address" : "Адрес электронной почты",
+    "Email address" : "Адрес эл. почты",
     "Contact" : "Контакт",
     "Circle" : "Круг",
     "Nextcloud App" : "Приложение Nextcloud",
@@ -127,23 +91,15 @@ OC.L10N.register(
     "Building Local Database" : "Создание локальной базы данных",
     "Testing Basic Circle Creation" : "Тестирование базового созданного Круга",
     "Adding local users and moderators" : "Добавление локальных пользователей и модераторов",
-    "Circle not found" : "Круг не найден",
-    "Circle not found " : "Круг не найден",
-    "This member does not exist" : "Этот участник не существует",
-    "This account is already a member of the circle" : "Эта учётная запись уже участник круга",
-    "Federated link not found" : "Федеративная связь не найдена",
     "This feature is not available for personal circles" : "Эта возможность недоступна для личных кругов",
-    "The circle is not federated" : "К этому кругу не предоставлен федеративный доступ",
-    "You cannot join this circle" : "Вы не можете присоединиться к этому кругу",
     "This member is not a moderator" : "Это участник — не модератор",
     "Insufficient privileges" : "Недостаточно прав доступа",
-    "This member is the owner of the circle" : "Этот участник — владелец круга",
+    "This member does not exist" : "Этот участник не существует",
     "Level cannot be changed for this type of member" : "Невозможно изменить уровень участника такого типа",
     "You are already a member of this circle" : "Вы уже участник этого круга",
     "You have been blocked from this circle" : "Вы заблокированы от участия в этом круге",
     "The account is already a member of this circle" : "Эта учётная запись уже участник этого круга",
     "The account has already been invited into this circle" : "Эта учётная запись уже приглашена в этот круг",
-    "%s (Circle owned by %s)" : "%s (круг, принадлежащий %s)",
     "You are now a member of the Circle \"%2$s\"" : "Вы теперь участник Круга \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Вы были приглашены %1$s в круг \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s отправил запрос на членство в круге \"%2$s\"",
@@ -151,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "Отказаться",
     "Leave the circle" : "Покинуть Круг",
     "%s" : "%s",
-    "Personal Circle" : "Личный круг",
     "%s owned by %s" : "%sпринадлежащий %s",
+    "%s shared a file with \"%s\"." : "%s поделился файлом с \"%s\".",
+    "%s shared a file with you." : "%s поделился с вами файлом.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поделился с вами некоторыми материалами.\nВы уже должны были получить отдельное письмо со ссылкой для доступа к нему.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поделился с вами некоторыми материалами. Вы уже должны были получить отдельное письмо со ссылкой для доступа к нему.",
+    "Password to access content shared with you by %1$s" : "Пароль для доступа к содержимому, предоставленному вам %1$s",
+    "Password to access content" : "Пароль для доступа к содержимому",
+    "Bring cloud-users closer together." : "Собирайте вокруг себе пользователей Вашего облака пользователей.",
+    "No files in here" : "Здесь нет файлов",
+    "No entries found in this folder" : "В этой папке ничего нет",
+    "Name" : "Имя",
+    "Size" : "Размер",
+    "Modified" : "Изменён",
+    "Circles" : "Круги",
+    "Circles' files" : "Файлы кругов",
+    "Select circles to filter by" : "Выберите круги, что бы отфильтровать их по",
+    "No circles found" : "Кругов не найдено",
+    "Please select circles to filter by" : "Выберите круги, что бы отфильтровать их по",
+    "No files found for the selected circles" : "Для выбранных кругов не найдено ни одного файла",
+    "You created the circle {circle}" : "Вы создали круг «{circle}»",
+    "{author} created the circle {circle}" : "{author} создал(а) круг «{circle}»",
+    "You linked {group} to {circle}" : "Вы связали группу «{group}» с кругом «circle»",
+    "{group} has been linked to {circle} by {author}" : "{author} связал(а) группа «{group}» с кругом «{circle}»",
+    "You unlinked {group} from {circle}" : "Вы убрали связь группы «{group}» с кругом «{circle}»",
+    "{group} has been unlinked from {circle} by {author}" : "{author} убрал(а) связь группы «{group}» с кругом «{circle}»",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Вы изменили уровень связанной с кругом «{circle}» группы «{group}» на %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} изменил(а) уровень связанной с кругом «{circle}» группы «{group}» на %1$s",
+    "You sent a request to link {circle} with {remote}" : "Вы отправили запрос на связывание круга «{circle}» с {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{author} отправил(а) запрос на связывание круга «{circle}» с {remote}",
+    "{remote} requested a link with {circle}" : "{remote} запросил(а) связывание с кругом «{circle}»",
+    "The request to link {circle} with {remote} has been rejected" : "Запрос на связывание круга «{circle}» с {remote} был отклонён",
+    "The request to link {remote} with {circle} has been canceled remotely" : "Запрос на связывание {remote} с кругом «{circle}» был отклонён на другом сервере",
+    "The request to link {circle} with {remote} has been accepted" : "Запрос на связывание круга «{circle}» с {remote} был одобрен",
+    "You dismissed the request to link {remote} with {circle}" : "Вы отклонили запрос на связывание {remote} с кругом «{circle}»",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} отклонил(а) запрос на связывание {remote} с кругом «{circle}»",
+    "You canceled the request to link {circle} with {remote}" : "Вы отменили запрос на связывание круга «{circle}» с {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} отменил(а) запрос на связывание круга «{circle}» с {remote}",
+    "You accepted the request to link {remote} with {circle}" : "Вы приняли запрос на связывание {remote} с кругом «{circle}»",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} принял(а) запрос на связывание {remote} с кругом «{circle}»",
+    "A link between {circle} and {remote} is now up and running" : "Связь между кругом «{circle}» и {remote} установлена и действует",
+    "The link between {circle} and {remote} has been shutdown remotely" : "Связь между кругом «{circle}» и {remote} была прекращена на другом сервере",
+    "You closed the link between {circle} and {remote}" : "Вы прекратили связь между кругом «{circle}» и {link}",
+    "{author} closed the link between {circle} and {remote}" : "{author} прекратил связь между кругом «{circle}» и {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} отменил(а) свой запрос на присоединение к кругу «{circle}»",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "При событии в <strong>круге</strong>, которому вы принадлежите ",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Любое важное событие в модерируемом вами <strong>круге </strong> ",
+    "On global events happening in any <strong>Circle</strong>" : "При глобальном событии в <strong>круге</strong>, которому вы принадлежите ",
+    "Join Request" : "Запрос на вступление",
+    "Password Protected" : "Защищено паролем",
+    "Circle Invite" : "Приглашение в круг",
+    "Email Address" : "Адрес электронной почты",
+    "Initialisation Nextcloud" : "Инициализация Nextcloud",
+    "Initialisation Circles App" : "Инициализация приложения Круги",
+    "Circle not found" : "Круг не найден",
+    "Circle not found " : "Круг не найден",
+    "This account is already a member of the circle" : "Эта учётная запись уже участник круга",
+    "Federated link not found" : "Федеративная связь не найдена",
+    "The circle is not federated" : "К этому кругу не предоставлен федеративный доступ",
+    "You cannot join this circle" : "Вы не можете присоединиться к этому кругу",
+    "This member is the owner of the circle" : "Этот участник — владелец круга",
+    "%s (Circle owned by %s)" : "%s (круг, принадлежащий %s)",
+    "Personal Circle" : "Личный круг",
     "You need a specify a type of circle" : "Необходимо указать тип круга",
     "A circle with that name exists" : "Круг с таким именем существует",
     "This member is not the owner of the circle" : "Этот участник — не владелец круга",
@@ -167,23 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "Неверный формат электронной почты",
     "This contact is not available" : "Контакт не доступен",
     "You have no permission to create a new circle" : "У вас нет разрешения на создание нового круга",
-    "%s shared a file with \"%s\"." : "%s поделился файлом с \"%s\".",
-    "%s shared a file with you." : "%s поделился с вами файлом.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s поделился с вами некоторыми материалами.\nВы уже должны были получить отдельное письмо со ссылкой для доступа к нему.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s поделился с вами некоторыми материалами. Вы уже должны были получить отдельное письмо со ссылкой для доступа к нему.",
-    "Password to access content shared with you by %1$s" : "Пароль для доступа к содержимому, предоставленному вам %1$s",
-    "Password to access content" : "Пароль для доступа к содержимому",
     "This item is already shared with this circle" : "Этот элемент уже используется в этом круге",
-    "Bring cloud-users closer together." : "Собирайте вокруг себе пользователей Вашего облака пользователей.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Круги позволяют пользователям создавать свои собственные группы пользователей, коллег или друзей.\nЭти группы пользователей («круги») могут затем использоваться любым другим приложением для обмена информацией.",
-    "No files in here" : "Здесь нет файлов",
-    "No entries found in this folder" : "В этой папке ничего нет",
-    "Name" : "Имя",
-    "Size" : "Размер",
-    "Modified" : "Изменён",
-    "Initialisation Nextcloud" : "Инициализация Nextcloud",
-    "Initialisation Circles App" : "Инициализация приложения Круги",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "В не можете использовать это приложение до тех пор, пока администратор не разрешит использовать как минимум один тип кругов.",
-    "Could not find share" : "Невозможно найти общий ресурс"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Круги позволяют пользователям создавать свои собственные группы пользователей, коллег или друзей.\nЭти группы пользователей («круги») могут затем использоваться любым другим приложением для обмена информацией."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
