@@ -1,38 +1,13 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "Cirklar",
-    "Circles' files" : "Cirklars filer",
-    "Select circles to filter by" : "Välj cirklar att filtrera efter",
-    "No circles found" : "Inga cirklar hittade",
-    "Please select circles to filter by" : "Vänligen välj cirklar att filtrera",
-    "No files found for the selected circles" : "Inga filer hittade för de valda cirklarna",
-    "You created the circle {circle}" : "Du skapade cirkeln {circle}",
-    "{author} created the circle {circle}" : "{author} skapade cirkeln {circle}",
     "You deleted {circle}" : "Du tog bort {circle}",
     "{author} deleted {circle}" : "{author} tog bort {circle}",
-    "You linked {group} to {circle}" : "Du länkade {group} till {circle}",
-    "{group} has been linked to {circle} by {author}" : "{group} har länkats till {circle} av {author}",
-    "You unlinked {group} from {circle}" : "Du avlänkade {group} från {circle}",
-    "{group} has been unlinked from {circle} by {author}" : "{group} har avlänkats från {circle} av {author}",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "Du ändrade nivån av den länkade gruppen {group} i {circle} till %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ändrade nivån av den länkade gruppen {group} i {circle} till %1$s",
-    "You sent a request to link {circle} with {remote}" : "Du skickade en begäran att länka {circle} med {remote}",
-    "{author} sent a request to link {circle} with {remote}" : "{author} skickade en begäran att länka {circle} med {remote}",
-    "{remote} requested a link with {circle}" : "{remote} begärde en länk med {circle}",
-    "The request to link {circle} with {remote} has been rejected" : "Begäran att länka {circle} med {remote} har avslagits",
-    "The request to link {remote} with {circle} has been canceled remotely" : "Begäran att länka {remote} med {circle} har avbrutits av extern part",
-    "The request to link {circle} with {remote} has been accepted" : "Begäran att länka {circle} med {remote} har accepterats",
-    "You dismissed the request to link {remote} with {circle}" : "Du avfärdade begäran att länka {remote} med {circle}",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} avfärdade begäran att länka {remote} med {circle}",
-    "You canceled the request to link {circle} with {remote}" : "Du avbröt begäran att länka {circle} med {remote}",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} avbröt begäran att länka {circle} med {remote}",
-    "You accepted the request to link {remote} with {circle}" : "Du accepterade begäran att länka {remote} med {circle}",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} accepterade begäran att länka {remote} med {circle}",
-    "A link between {circle} and {remote} is now up and running" : "En länk mellan {circle} och {remote} är nu uppe och fungerande",
-    "The link between {circle} and {remote} has been shutdown remotely" : "Länken mellan {circle} och {remote} har blivit avstängt av extern part",
-    "You closed the link between {circle} and {remote}" : "Du stängde länken mellan {circle} och {remote}",
-    "{author} closed the link between {circle} and {remote}" : "{author} stängde länken mellan {circle} och {remote}",
+    "You made {member} join {circle}" : "Du fick {member} att gå med i {circle}",
+    "{author} made {member} join {circle}" : "{author} fick {member} att gå med i {circle}",
+    "You made {member} leave {circle}" : "Du fick {member} att lämna {circle}",
+    "{author} made {member} leave {circle}" : "{author} fick {member} att lämna {circle}",
+    "You removed {member} leave {circle}" : "Du tog bort {member} lämna {circle}",
     "You joined {circle}" : "Du gick med i {circle}",
     "{member} joined {circle}" : "{member} gick med i {circle}",
     "You accepted the invitation to join {circle}" : "Du accepterade inbjudan att gå med i {circle}",
@@ -50,7 +25,7 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "Du avslog inbjudan att gå med i {circle}",
     "{member} declined an invitation to join {circle}" : "{member} avslog inbjudan att gå med i {circle}",
     "You cancelled your request to join {circle}" : "Du avbröt din begäran att gå med i {circle}",
-    "{member} cancelled his request to join {circle}" : "{member} avbröt sin begäran att gå med i {circle}",
+    "{member} cancelled a request to join {circle}" : "{member} avbröt sin begäran att gå med i {circle}",
     "You removed {member} from {circle}" : "Du tog bort {member} från {circle}",
     "You have been removed from {circle} by {author}" : "Du har tagits bort från {circle} av {author}",
     "{member} has been removed from {circle} by {author}" : "{member} har tagits bort från {circle} av {author}",
@@ -72,9 +47,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} skickade en begäran att gå med i {circle}",
     "You are the new owner of {circle}" : "Du är ny ägare av {circle}",
     "{member} is the new owner of {circle}" : "{member} är ny ägare av {circle}",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "Vid händelser i en <strong>Cirkel</strong> där du är medlem",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "Någon viktig händelse i en <strong>Cirkel</strong> du modererar",
-    "On global events happening in any <strong>Circle</strong>" : "Vid globala händelser som händer i någon <strong>Cirkel</strong>",
     "Shared to Circles" : "Delad med Cirklar",
     "Single" : "Singel",
     "Personal" : "Personlig",
@@ -82,20 +54,20 @@ OC.L10N.register(
     "Visible" : "Synlig",
     "Open" : "Öppen",
     "Invite" : "Bjud in",
-    "Join Request" : "Anslutningsbegäran",
+    "Join request" : "Anslutningsförfrågan",
     "Friends" : "Vänner",
-    "Password Protected" : "Lösenordsskyddad",
+    "Password protected" : "Lösenordsskyddad",
     "No Owner" : "Ingen ägare",
     "Hidden" : "Gömd",
     "Backend" : "Backend",
     "Local" : "Lokal",
     "Root" : "Rot",
-    "Circle Invite" : "Cirkel-inbjudan",
+    "Team invite" : "Teaminbjudan",
     "Federated" : "Federerad",
     "Mount point" : "Monteringspunkt",
     "Nextcloud Account" : "Nextcloudkonto",
     "Nextcloud Group" : "Nextcloud-grupp",
-    "Email Address" : "E-postadress",
+    "Email address" : "E-postadress",
     "Contact" : "Kontakta",
     "Circle" : "Cirkel",
     "Nextcloud App" : "Nextcloud-app",
@@ -127,23 +99,15 @@ OC.L10N.register(
     "Building Local Database" : "Bygger lokal databas",
     "Testing Basic Circle Creation" : "Testar grundläggande Cirkel-skapande",
     "Adding local users and moderators" : "Lägger till lokala användare och moderatorer ",
-    "Circle not found" : "Cirkel kunde inte hittas",
-    "Circle not found " : "Cirkel kunde inte hittas",
-    "This member does not exist" : "Medlemmen finns inte",
-    "This account is already a member of the circle" : "Detta konto är redan medlem av denna cirkel",
-    "Federated link not found" : "Federerad länk hittades inte",
     "This feature is not available for personal circles" : "Funktionen är inte tillgänglig för personliga cirklar",
-    "The circle is not federated" : "Cirkeln är inte federerad",
-    "You cannot join this circle" : "Du kan inte gå med i denna cirkel",
     "This member is not a moderator" : "Medlemmen är inte en moderator",
     "Insufficient privileges" : "Otillräckliga privilegier",
-    "This member is the owner of the circle" : "Medlemmen är ägare av cirkeln",
+    "This member does not exist" : "Medlemmen finns inte",
     "Level cannot be changed for this type of member" : "Nivå kan inte ändras för medlemstypen",
     "You are already a member of this circle" : "Du är redan medlem i denna cirkel",
     "You have been blocked from this circle" : "Du har blockerats från denna cirkel",
     "The account is already a member of this circle" : "Kontot är redan medlem av denna cirkel",
     "The account has already been invited into this circle" : "Kontot har redan bjudits in till denna cirkel",
-    "%s (Circle owned by %s)" : "1%s (Cirkel ägs av 1%s)",
     "You are now a member of the Circle \"%2$s\"" : "Du är nu medlem i cirkel \"%2$s\"",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "Du har blivit inbjuden av %1$s till cirkel \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s skickade en förfrågan att bli medlem i cirkel \"%2$s\"",
@@ -151,8 +115,68 @@ OC.L10N.register(
     "Refuse" : "Neka",
     "Leave the circle" : "Lämna cirkeln",
     "%s" : "%s",
-    "Personal Circle" : "Personlig cirkel",
     "%s owned by %s" : "%s ägd av %s",
+    "%s shared a file with \"%s\"." : "%s delade en fil med \"%s\".",
+    "%s shared a file with you." : "%s delade en fil med dig.",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delade innehåll med dig.\nDu borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delade innehåll med dig. Du borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
+    "Password to access content shared with you by %1$s" : "Lösenord för tillgång till innehåll delat med dig av 1%1$s",
+    "Password to access content" : "Lösenord för att komma åt innehåll",
+    "Bring cloud-users closer together." : "För moln-användare närmare varandra.",
+    "No files in here" : "Inga filer här",
+    "No entries found in this folder" : "Inga objekt funna i denna mapp",
+    "Name" : "Namn",
+    "Size" : "Storlek",
+    "Modified" : "Ändrad",
+    "Circles" : "Cirklar",
+    "Circles' files" : "Cirklars filer",
+    "Select circles to filter by" : "Välj cirklar att filtrera efter",
+    "No circles found" : "Inga cirklar hittade",
+    "Please select circles to filter by" : "Vänligen välj cirklar att filtrera",
+    "No files found for the selected circles" : "Inga filer hittade för de valda cirklarna",
+    "You created the circle {circle}" : "Du skapade cirkeln {circle}",
+    "{author} created the circle {circle}" : "{author} skapade cirkeln {circle}",
+    "You linked {group} to {circle}" : "Du länkade {group} till {circle}",
+    "{group} has been linked to {circle} by {author}" : "{group} har länkats till {circle} av {author}",
+    "You unlinked {group} from {circle}" : "Du avlänkade {group} från {circle}",
+    "{group} has been unlinked from {circle} by {author}" : "{group} har avlänkats från {circle} av {author}",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "Du ändrade nivån av den länkade gruppen {group} i {circle} till %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ändrade nivån av den länkade gruppen {group} i {circle} till %1$s",
+    "You sent a request to link {circle} with {remote}" : "Du skickade en begäran att länka {circle} med {remote}",
+    "{author} sent a request to link {circle} with {remote}" : "{author} skickade en begäran att länka {circle} med {remote}",
+    "{remote} requested a link with {circle}" : "{remote} begärde en länk med {circle}",
+    "The request to link {circle} with {remote} has been rejected" : "Begäran att länka {circle} med {remote} har avslagits",
+    "The request to link {remote} with {circle} has been canceled remotely" : "Begäran att länka {remote} med {circle} har avbrutits av extern part",
+    "The request to link {circle} with {remote} has been accepted" : "Begäran att länka {circle} med {remote} har accepterats",
+    "You dismissed the request to link {remote} with {circle}" : "Du avfärdade begäran att länka {remote} med {circle}",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} avfärdade begäran att länka {remote} med {circle}",
+    "You canceled the request to link {circle} with {remote}" : "Du avbröt begäran att länka {circle} med {remote}",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} avbröt begäran att länka {circle} med {remote}",
+    "You accepted the request to link {remote} with {circle}" : "Du accepterade begäran att länka {remote} med {circle}",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} accepterade begäran att länka {remote} med {circle}",
+    "A link between {circle} and {remote} is now up and running" : "En länk mellan {circle} och {remote} är nu uppe och fungerande",
+    "The link between {circle} and {remote} has been shutdown remotely" : "Länken mellan {circle} och {remote} har blivit avstängt av extern part",
+    "You closed the link between {circle} and {remote}" : "Du stängde länken mellan {circle} och {remote}",
+    "{author} closed the link between {circle} and {remote}" : "{author} stängde länken mellan {circle} och {remote}",
+    "{member} cancelled his request to join {circle}" : "{member} avbröt sin begäran att gå med i {circle}",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "Vid händelser i en <strong>Cirkel</strong> där du är medlem",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "Någon viktig händelse i en <strong>Cirkel</strong> du modererar",
+    "On global events happening in any <strong>Circle</strong>" : "Vid globala händelser som händer i någon <strong>Cirkel</strong>",
+    "Join Request" : "Anslutningsbegäran",
+    "Password Protected" : "Lösenordsskyddad",
+    "Circle Invite" : "Cirkel-inbjudan",
+    "Email Address" : "E-postadress",
+    "Initialisation Nextcloud" : "Initialisering Nextcloud",
+    "Initialisation Circles App" : "Initialisering Cirkel-appen",
+    "Circle not found" : "Cirkel kunde inte hittas",
+    "Circle not found " : "Cirkel kunde inte hittas",
+    "This account is already a member of the circle" : "Detta konto är redan medlem av denna cirkel",
+    "Federated link not found" : "Federerad länk hittades inte",
+    "The circle is not federated" : "Cirkeln är inte federerad",
+    "You cannot join this circle" : "Du kan inte gå med i denna cirkel",
+    "This member is the owner of the circle" : "Medlemmen är ägare av cirkeln",
+    "%s (Circle owned by %s)" : "1%s (Cirkel ägs av 1%s)",
+    "Personal Circle" : "Personlig cirkel",
     "You need a specify a type of circle" : "Du behöver specificera en cirkeltyp",
     "A circle with that name exists" : "En cirkel med det namnet finns",
     "This member is not the owner of the circle" : "Medlemmen är inte ägaren av cirkeln",
@@ -167,21 +191,7 @@ OC.L10N.register(
     "Email format is not valid" : "E-postformat är inte giltigt",
     "This contact is not available" : "Denna kontakt är inte tillgänglig",
     "You have no permission to create a new circle" : "Du har inte behörighet att skapa en ny cirkel",
-    "%s shared a file with \"%s\"." : "%s delade en fil med \"%s\".",
-    "%s shared a file with you." : "%s delade en fil med dig.",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s delade innehåll med dig.\nDu borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s delade innehåll med dig. Du borde redan ha fått ett separat e-postmeddelande med en länk för åtkomst.",
-    "Password to access content shared with you by %1$s" : "Lösenord för tillgång till innehåll delat med dig av 1%1$s",
-    "Password to access content" : "Lösenord för att komma åt innehåll",
     "This item is already shared with this circle" : "Detta objektet delas redan med denna cirkeln.",
-    "Bring cloud-users closer together." : "För moln-användare närmare varandra.",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirklar låter användare att skapa deras egna grupper av användare/kollegor/vänner.\nDessa grupper av användare (eller \"cirklar\") kan användas av alla andra appar vid delning.",
-    "No files in here" : "Inga filer här",
-    "No entries found in this folder" : "Inga objekt funna i denna mapp",
-    "Name" : "Namn",
-    "Size" : "Storlek",
-    "Modified" : "Ändrad",
-    "Initialisation Nextcloud" : "Initialisering Nextcloud",
-    "Initialisation Circles App" : "Initialisering Cirkel-appen"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "Cirklar låter användare att skapa deras egna grupper av användare/kollegor/vänner.\nDessa grupper av användare (eller \"cirklar\") kan användas av alla andra appar vid delning."
 },
 "nplurals=2; plural=(n != 1);");
