@@ -1,38 +1,8 @@
 OC.L10N.register(
     "circles",
     {
-    "Circles" : "圈子",
-    "Circles' files" : "圈子的文件",
-    "Select circles to filter by" : "选择圈子来筛选",
-    "No circles found" : "未找到任何圈子",
-    "Please select circles to filter by" : "请选择圈子来筛选",
-    "No files found for the selected circles" : "该圈子下没有任何文件",
-    "You created the circle {circle}" : "您创建了圈子 {circle}",
-    "{author} created the circle {circle}" : "{author} 创建了圈子 {circle}",
     "You deleted {circle}" : "您删除了 {circle}",
     "{author} deleted {circle}" : "{author} 已删除 {circle}",
-    "You linked {group} to {circle}" : "您已将 {group} 链接到 {circle}",
-    "{group} has been linked to {circle} by {author}" : "{author} 已将 {group} 连接到 {circle}",
-    "You unlinked {group} from {circle}" : "您已将 {group} 从 {circle} 中断开",
-    "{group} has been unlinked from {circle} by {author}" : "{author} 已将 {group} 从 {circle} 中断开",
-    "You changed the level of the linked group {group} in {circle} to %1$s" : "您已将 {circle} 中的组  {group} 的级别修改为 %1$s",
-    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} 已将 {circle} 中的组 {group} 的级别修改为 %1$s",
-    "You sent a request to link {circle} with {remote}" : "您发送了一个请求，将 {circle} 与 {remote} 链接",
-    "{author} sent a request to link {circle} with {remote}" : "{author} 发送了一个请求，将 {circle} 与 {remote} 链接",
-    "{remote} requested a link with {circle}" : "{remote} 要求与 {circle} 链接",
-    "The request to link {circle} with {remote} has been rejected" : "将 {circle} 与 {remote} 链接的请求已被拒绝",
-    "The request to link {remote} with {circle} has been canceled remotely" : "将 {remote} 与 {circle} 链接的请求已被远程取消",
-    "The request to link {circle} with {remote} has been accepted" : "{circle} 与 {remote} 链接的请求已被接受",
-    "You dismissed the request to link {remote} with {circle}" : "您已将 {remote} 与 {circle} 链接的请求撤销",
-    "{author} dismissed the request to link {remote} with {circle}" : "{author} 驳回了将 {remote} 与 {circle} 链接的请求",
-    "You canceled the request to link {circle} with {remote}" : "您取消了将 {circle} 与 {remote} 链接的请求",
-    "{author} canceled the request to link {circle} with {remote}" : "{author} 取消了将 {circle} 与 {remote} 链接的请求",
-    "You accepted the request to link {remote} with {circle}" : "接受了 {remote} 与 {circle} 链接的请求",
-    "{author} accepted the request to link {remote} with {circle}" : "{author} 接受了 {remote} 与 {circle} 链接的请求",
-    "A link between {circle} and {remote} is now up and running" : "{circle} 和 {remote} 之间的链接现已启动并运行",
-    "The link between {circle} and {remote} has been shutdown remotely" : "{circle} 和 {remote} 之间的链接已被远程关闭",
-    "You closed the link between {circle} and {remote}" : "您关闭了 {circle} 和 {remote} 之间的链接",
-    "{author} closed the link between {circle} and {remote}" : "{author} 关闭了 {circle} 和 {remote} 之间的链接",
     "You joined {circle}" : "您已经加入了 {circle}",
     "{member} joined {circle}" : "{member} 加入了 {circle}",
     "You accepted the invitation to join {circle}" : "您接受邀请加入 {circle}",
@@ -50,7 +20,6 @@ OC.L10N.register(
     "You declined the invitation to join {circle}" : "您拒绝了加入 {circle} 的邀请",
     "{member} declined an invitation to join {circle}" : "{member} 拒绝加入 {circle}",
     "You cancelled your request to join {circle}" : "您取消了加入 {circle} 的请求",
-    "{member} cancelled his request to join {circle}" : "{member} 取消了他加入 {circle} 的请求",
     "You removed {member} from {circle}" : "您已从 {circle} 删除 {member}",
     "You have been removed from {circle} by {author}" : "您已被 {author} 移出 {circle}",
     "{member} has been removed from {circle} by {author}" : "{member} 已被 {author} 从 {circle} 移除",
@@ -72,9 +41,6 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} 发送了加入 {circle} 的请求",
     "You are the new owner of {circle}" : "您是 {circle} 的新拥有者",
     "{member} is the new owner of {circle}" : "{member} 是 {circle} 的新拥有者",
-    "On events happening in a <strong>Circle</strong> of which you are a member" : "当出现发生在一个您是其中一员的<strong>圈子</strong>的事件时",
-    "Any important event in a <strong>Circle</strong> you are moderating" : "您正在<strong>圈子</strong>中主持的任何重要事件",
-    "On global events happening in any <strong>Circle</strong>" : "当出现发生在任意<strong>圈子</strong>中的全局事件时",
     "Shared to Circles" : "共享圈子的文件",
     "Single" : "单个",
     "Personal" : "个人",
@@ -82,20 +48,18 @@ OC.L10N.register(
     "Visible" : "可见的",
     "Open" : "打开",
     "Invite" : "邀请",
-    "Join Request" : "加入邀请",
     "Friends" : "好友",
-    "Password Protected" : "受密码保护",
+    "Password protected" : "受密码保护",
     "No Owner" : "无所有人",
     "Hidden" : "隐藏的",
     "Backend" : "后端",
     "Local" : "本地",
     "Root" : "根路径",
-    "Circle Invite" : "Circle 邀请",
     "Federated" : "联合云",
     "Mount point" : "挂载点",
     "Nextcloud Account" : "Nextcloud 账号",
     "Nextcloud Group" : "NextCloud 群组",
-    "Email Address" : "电子邮件地址",
+    "Email address" : "电子邮件地址",
     "Contact" : "联系",
     "Circle" : "圈子",
     "Nextcloud App" : "NextCloud 应用",
@@ -127,23 +91,15 @@ OC.L10N.register(
     "Building Local Database" : "正在构建本地数据库",
     "Testing Basic Circle Creation" : "正在测试基础 Circle 创建",
     "Adding local users and moderators" : "添加本地用户和管理员",
-    "Circle not found" : "查找不到圈子",
-    "Circle not found " : "找不到圈子",
-    "This member does not exist" : "此成员不存在",
-    "This account is already a member of the circle" : "这个账号已经是圈子的成员了",
-    "Federated link not found" : "未找到联合云链接",
     "This feature is not available for personal circles" : "此功能不适用于个人圈子",
-    "The circle is not federated" : "圈子没有联合",
-    "You cannot join this circle" : "您不能加入此圈子",
     "This member is not a moderator" : "此成员不是管理员",
     "Insufficient privileges" : "权限不足",
-    "This member is the owner of the circle" : "此成员是圈子的所有者",
+    "This member does not exist" : "此成员不存在",
     "Level cannot be changed for this type of member" : "对于该类型的成员，级别不能被更改",
     "You are already a member of this circle" : "您已经是此圈子的成员",
     "You have been blocked from this circle" : "您被限制加入此圈子",
     "The account is already a member of this circle" : "账号已经是这个圈子的成员了",
     "The account has already been invited into this circle" : "账号已经被邀请进入这个圈子了",
-    "%s (Circle owned by %s)" : "%s（圈子所有者为%s）",
     "You are now a member of the Circle \"%2$s\"" : "您现在是\"%2$s\" 圈子的一员了",
     "You have been invited by %1$s into the Circle \"%2$s\"" : "%1$s 已邀请您加入圈子 \"%2$s\"",
     "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s发送了一条加入\"%2$s\" 圈子的请求",
@@ -151,8 +107,68 @@ OC.L10N.register(
     "Refuse" : "拒绝",
     "Leave the circle" : "离开圈子",
     "%s" : "%s",
-    "Personal Circle" : "个人圈子",
     "%s owned by %s" : "%s 所有者为 %s",
+    "%s shared a file with \"%s\"." : "%s 和 \"%s\"分享了一个文件",
+    "%s shared a file with you." : "%s 和你分享了一个文件",
+    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s和你分享了一些内容。\n你应该已经收到了一封带访问链接的邮件。\n",
+    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s 和你分享了一些内容。你应该已经收到了一封带访问链接的邮件",
+    "Password to access content shared with you by %1$s" : "用于获取%1$s分享给您内容的密码",
+    "Password to access content" : "内容访问密码",
+    "Bring cloud-users closer together." : "把云端用户连接到一起。",
+    "No files in here" : "此处没有文件",
+    "No entries found in this folder" : "此文件夹中无项目",
+    "Name" : "名称",
+    "Size" : "大小",
+    "Modified" : "修改日期",
+    "Circles" : "圈子",
+    "Circles' files" : "圈子的文件",
+    "Select circles to filter by" : "选择圈子来筛选",
+    "No circles found" : "未找到任何圈子",
+    "Please select circles to filter by" : "请选择圈子来筛选",
+    "No files found for the selected circles" : "该圈子下没有任何文件",
+    "You created the circle {circle}" : "您创建了圈子 {circle}",
+    "{author} created the circle {circle}" : "{author} 创建了圈子 {circle}",
+    "You linked {group} to {circle}" : "您已将 {group} 链接到 {circle}",
+    "{group} has been linked to {circle} by {author}" : "{author} 已将 {group} 连接到 {circle}",
+    "You unlinked {group} from {circle}" : "您已将 {group} 从 {circle} 中断开",
+    "{group} has been unlinked from {circle} by {author}" : "{author} 已将 {group} 从 {circle} 中断开",
+    "You changed the level of the linked group {group} in {circle} to %1$s" : "您已将 {circle} 中的组  {group} 的级别修改为 %1$s",
+    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} 已将 {circle} 中的组 {group} 的级别修改为 %1$s",
+    "You sent a request to link {circle} with {remote}" : "您发送了一个请求，将 {circle} 与 {remote} 链接",
+    "{author} sent a request to link {circle} with {remote}" : "{author} 发送了一个请求，将 {circle} 与 {remote} 链接",
+    "{remote} requested a link with {circle}" : "{remote} 要求与 {circle} 链接",
+    "The request to link {circle} with {remote} has been rejected" : "将 {circle} 与 {remote} 链接的请求已被拒绝",
+    "The request to link {remote} with {circle} has been canceled remotely" : "将 {remote} 与 {circle} 链接的请求已被远程取消",
+    "The request to link {circle} with {remote} has been accepted" : "{circle} 与 {remote} 链接的请求已被接受",
+    "You dismissed the request to link {remote} with {circle}" : "您已将 {remote} 与 {circle} 链接的请求撤销",
+    "{author} dismissed the request to link {remote} with {circle}" : "{author} 驳回了将 {remote} 与 {circle} 链接的请求",
+    "You canceled the request to link {circle} with {remote}" : "您取消了将 {circle} 与 {remote} 链接的请求",
+    "{author} canceled the request to link {circle} with {remote}" : "{author} 取消了将 {circle} 与 {remote} 链接的请求",
+    "You accepted the request to link {remote} with {circle}" : "接受了 {remote} 与 {circle} 链接的请求",
+    "{author} accepted the request to link {remote} with {circle}" : "{author} 接受了 {remote} 与 {circle} 链接的请求",
+    "A link between {circle} and {remote} is now up and running" : "{circle} 和 {remote} 之间的链接现已启动并运行",
+    "The link between {circle} and {remote} has been shutdown remotely" : "{circle} 和 {remote} 之间的链接已被远程关闭",
+    "You closed the link between {circle} and {remote}" : "您关闭了 {circle} 和 {remote} 之间的链接",
+    "{author} closed the link between {circle} and {remote}" : "{author} 关闭了 {circle} 和 {remote} 之间的链接",
+    "{member} cancelled his request to join {circle}" : "{member} 取消了他加入 {circle} 的请求",
+    "On events happening in a <strong>Circle</strong> of which you are a member" : "当出现发生在一个您是其中一员的<strong>圈子</strong>的事件时",
+    "Any important event in a <strong>Circle</strong> you are moderating" : "您正在<strong>圈子</strong>中主持的任何重要事件",
+    "On global events happening in any <strong>Circle</strong>" : "当出现发生在任意<strong>圈子</strong>中的全局事件时",
+    "Join Request" : "加入邀请",
+    "Password Protected" : "受密码保护",
+    "Circle Invite" : "Circle 邀请",
+    "Email Address" : "电子邮件地址",
+    "Initialisation Nextcloud" : "初始化 Nextcloud",
+    "Initialisation Circles App" : "初始化 Circles 应用",
+    "Circle not found" : "查找不到圈子",
+    "Circle not found " : "找不到圈子",
+    "This account is already a member of the circle" : "这个账号已经是圈子的成员了",
+    "Federated link not found" : "未找到联合云链接",
+    "The circle is not federated" : "圈子没有联合",
+    "You cannot join this circle" : "您不能加入此圈子",
+    "This member is the owner of the circle" : "此成员是圈子的所有者",
+    "%s (Circle owned by %s)" : "%s（圈子所有者为%s）",
+    "Personal Circle" : "个人圈子",
     "You need a specify a type of circle" : "您需要指定一种类型的圈子",
     "A circle with that name exists" : "存在具有该名称的圈子",
     "This member is not the owner of the circle" : "此成员不是圈子的所有者",
@@ -167,23 +183,7 @@ OC.L10N.register(
     "Email format is not valid" : "电子邮件格式无效",
     "This contact is not available" : "此联系人不可用",
     "You have no permission to create a new circle" : "您没有权限创建新的圈子",
-    "%s shared a file with \"%s\"." : "%s 和 \"%s\"分享了一个文件",
-    "%s shared a file with you." : "%s 和你分享了一个文件",
-    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s和你分享了一些内容。\n你应该已经收到了一封带访问链接的邮件。\n",
-    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s 和你分享了一些内容。你应该已经收到了一封带访问链接的邮件",
-    "Password to access content shared with you by %1$s" : "用于获取%1$s分享给您内容的密码",
-    "Password to access content" : "内容访问密码",
     "This item is already shared with this circle" : "这个项目已经分享给这个圈子了",
-    "Bring cloud-users closer together." : "把云端用户连接到一起。",
-    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "圈子允许人们与他人/同事/朋友创建他们自己的小组。\n这些小组的成员（或“圈子”）可以被其它APP用来分享。",
-    "No files in here" : "此处没有文件",
-    "No entries found in this folder" : "此文件夹中无项目",
-    "Name" : "名称",
-    "Size" : "大小",
-    "Modified" : "修改日期",
-    "Initialisation Nextcloud" : "初始化 Nextcloud",
-    "Initialisation Circles App" : "初始化 Circles 应用",
-    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "您的管理员至少允许一种类型的圈子，否则您不能使用“圈子”应用程序",
-    "Could not find share" : "查找不到共享"
+    "Circles allows people to create their own groups of people/colleagues/friends.\nThose groups of people (or \"circles\") can then be used by any other app for sharing purpose." : "圈子允许人们与他人/同事/朋友创建他们自己的小组。\n这些小组的成员（或“圈子”）可以被其它APP用来分享。"
 },
 "nplurals=1; plural=0;");
