@@ -9,12 +9,14 @@ OC.L10N.register(
     "%1$s commented on %2$s" : "%1$s كتب تعليق على %2$s",
     "{author} commented on {file}" : "{author} علّق على {file}",
     "<strong>Comments</strong> for files" : "<strong>تعليقات</strong> على الملفات",
-    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "تمت الإشارة إليك في \"{file}\" في تعليق لمستخدم. لكن هذا المستخدم تم حذف حسابه بعدها",
+    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "تمت الإشارة إليك في \"{file}\"، في تعليقٍ من قِبَل حسابٍ تمّ حذفه سلفاً",
     "{user} mentioned you in a comment on \"{file}\"" : "أشار إليك {user} في تعليق على {file}",
     "Files app plugin to add comments to files" : "المكوِّن الإضافي لتطبيق الملفات لإضافة تعليقات إلى الملفات",
     "Edit comment" : "تعديل التعليق",
     "Delete comment" : "حذف التعليق",
     "Cancel edit" : "إلغاء التعديل",
+    "New comment" : "ملاحظة جديدة",
+    "Write a comment …" : "أكتُب ملاحظةً ...",
     "Post comment" : "أضف تعليق",
     "@ for mentions, : for emoji, / for smart picker" : "@ للإشارات،    : للإيموجي،    / للاقط الذكي",
     "Could not reload comments" : "تعذّرت إعادة تحميل الملاحظات",
@@ -29,6 +31,7 @@ OC.L10N.register(
     "Comment deleted" : "التعليق حُذف",
     "An error occurred while trying to delete the comment" : "حدث خطأ أثناء محاولة حذف التعليق",
     "An error occurred while trying to create the comment" : "حدث خطأ أثناء محاولة إنشاء التعليق",
+    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "تمت الإشارة إليك في \"{file}\" في تعليق لمستخدم. لكن هذا المستخدم تم حذف حسابه بعدها",
     "_%n unread comment_::_%n unread comments_" : ["%n تعليق غير مقروء","%n تعليق غير مقروء","تعليقان غير مقروءة","%n تعليقات غير مقروء","%n تعليق غير مقروء","%n تعليق غير مقروء"]
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
