@@ -9,12 +9,14 @@ OC.L10N.register(
     "%1$s commented on %2$s" : "%1$s коментарисао на %2$s",
     "{author} commented on {file}" : "{author} коментарисао на {file}",
     "<strong>Comments</strong> for files" : "<strong>Коментари</strong> на фајлове",
-    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Поменути сте за „{file}”, у коментару корисника које је од тада обрисан",
+    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "Поменути сте за „{file}”, у коментару налога који је касније обрисан",
     "{user} mentioned you in a comment on \"{file}\"" : "{user} вас је поменуо у коментару за „{file}",
     "Files app plugin to add comments to files" : "Додатак апликацији за фајлове да додајете коментаре на фајлове",
     "Edit comment" : "Измени коментар",
     "Delete comment" : "Обриши коментар",
     "Cancel edit" : "Поништи измену",
+    "New comment" : "Нови коментар",
+    "Write a comment …" : "Напишите коментар…",
     "Post comment" : "Објави коментар",
     "@ for mentions, : for emoji, / for smart picker" : "@ за помињања, : за емођи, / за паметни бирач",
     "Could not reload comments" : "Коментари не могу поново да се учитају",
@@ -29,6 +31,7 @@ OC.L10N.register(
     "Comment deleted" : "Коментар обрисан",
     "An error occurred while trying to delete the comment" : "Грешка приликом покушаја брисања коментара",
     "An error occurred while trying to create the comment" : "Грешка приликом покушаја креирања коментара",
+    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "Поменути сте за „{file}”, у коментару корисника које је од тада обрисан",
     "_%n unread comment_::_%n unread comments_" : ["%nнепрочитани коментар","%nнепрочитана коментара ","%n непрочитаних коментара"]
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
