@@ -9,13 +9,14 @@ OC.L10N.register(
     "%1$s commented on %2$s" : "%1$s 评论了 %2$s",
     "{author} commented on {file}" : "{author} 对 {file} 的评论",
     "<strong>Comments</strong> for files" : "文件的<strong>评论</strong>",
-    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "用户在“ {file}”中的评论中提到了你，此评论已被删除",
     "{user} mentioned you in a comment on \"{file}\"" : "{user} 在 “{file}” 的评论中提到了你",
     "Files app plugin to add comments to files" : "文件应用插件可向文件添加评论",
     "Edit comment" : "编辑评论",
     "Delete comment" : "删除评论",
     "Cancel edit" : "取消编辑",
+    "New comment" : "新评论",
     "Post comment" : "发表评论",
+    "@ for mentions, : for emoji, / for smart picker" : "使用“@”提及，“:”输入表情符号，“/”唤起智能选择",
     "Could not reload comments" : "无法重载评论",
     "No comments yet, start the conversation!" : "还没有评论，开始对话吧！",
     "No more messages" : "没有更多消息",
@@ -28,7 +29,7 @@ OC.L10N.register(
     "Comment deleted" : "评论已删除",
     "An error occurred while trying to delete the comment" : "删除评论时出错",
     "An error occurred while trying to create the comment" : "创建评论时出错",
-    "%1$s commented" : "%1$s 已评论",
+    "You were mentioned on \"{file}\", in a comment by a user that has since been deleted" : "用户在“ {file}”中的评论中提到了你，此评论已被删除",
     "_%n unread comment_::_%n unread comments_" : ["%n 条未读评论"]
 },
 "nplurals=1; plural=0;");
