@@ -21,11 +21,6 @@ OC.L10N.register(
     "Good evening, {name}" : "Good evening, {name}",
     "Hello" : "Hello",
     "Hello, {name}" : "Hello, {name}",
-    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking.",
-    "Change background image" : "Change background image",
-    "Pick from Files" : "Pick from Files",
-    "Default images" : "Default images",
-    "Plain background" : "Plain background",
-    "Insert from {productName}" : "Insert from {productName}"
+    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking."
 },
 "nplurals=1; plural=0;");
