@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Dashboard" : "儀表板",
     "Dashboard app" : "儀表板應用程式",
-    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "開始您新的一天\n\nNextcloud 儀表板是您一天的起點，為您提供您即將到來的約會概覽、緊急電子郵件、聊天訊息、到來的工單、最新的推文以及更多！使用者可以新增他們喜愛的小工具與變更他們喜愛的背景。",
+    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! People can add the widgets they like and change the background to their liking." : "開始您新的一天\n\nNextcloud 儀表板是您一天的起點，為您提供您即將到來的約會概覽、緊急電子郵件、聊天訊息、到來的工單、最新的推文以及更多！使用者可以新增他們喜愛的小工具與變更他們喜愛的背景。",
     "\"{title} icon\"" : "「{title} 圖示」",
     "Customize" : "自訂",
     "Edit widgets" : "編輯小工具",
@@ -24,10 +24,6 @@ OC.L10N.register(
     "Hello" : "嗨",
     "Hello, {name}" : "嗨，{name}",
     "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an\noverview of your upcoming appointments, urgent emails, chat messages,\nincoming tickets, latest tweets and much more! Users can add the widgets\nthey like and change the background to their liking." : "開始您新的一天\n\nNextcloud 儀表板是您一天的起點，為您提供\n您即將到來的約會概覽、緊急電子郵件、聊天訊息、\n到來的工單、最新的推文以及更多！使用者可以新增\n他們喜愛的小工具與變更他們喜愛的背景。",
-    "Change background image" : "變更背景圖片",
-    "Pick from Files" : "從檔案選取",
-    "Default images" : "預設圖片",
-    "Plain background" : "簡單背景",
-    "Insert from {productName}" : "插入自 {productName}"
+    "Start your day informed\n\nThe Nextcloud Dashboard is your starting point of the day, giving you an overview of your upcoming appointments, urgent emails, chat messages, incoming tickets, latest tweets and much more! Users can add the widgets they like and change the background to their liking." : "開始您新的一天\n\nNextcloud 儀表板是您一天的起點，為您提供您即將到來的約會概覽、緊急電子郵件、聊天訊息、到來的工單、最新的推文以及更多！使用者可以新增他們喜愛的小工具與變更他們喜愛的背景。"
 },
 "nplurals=1; plural=0;");
