@@ -6,6 +6,7 @@ declare(strict_types=1);
  * @copyright Copyright (c) 2021 Julien Veyssier <eneiluj@posteo.net>
  *
  * @author Julien Veyssier <eneiluj@posteo.net>
+ * @author Richard Steinmetz <richard@steinmetz.cloud>
  *
  * @license GNU AGPL version 3 or any later version
  *
@@ -32,6 +33,7 @@ use OCP\Dashboard\IButtonWidget;
 use OCP\Dashboard\IIconWidget;
 use OCP\Dashboard\IOptionWidget;
 use OCP\Dashboard\IManager;
+use OCP\Dashboard\IReloadableWidget;
 use OCP\Dashboard\IWidget;
 use OCP\Dashboard\Model\WidgetButton;
 use OCP\Dashboard\Model\WidgetOptions;
@@ -39,7 +41,9 @@ use OCP\IConfig;
 use OCP\IRequest;
 
 use OCP\Dashboard\IAPIWidget;
+use OCP\Dashboard\IAPIWidgetV2;
 use OCP\Dashboard\Model\WidgetItem;
+use OCP\Dashboard\Model\WidgetItems;
 
 class DashboardApiController extends OCSController {
 
@@ -68,6 +72,24 @@ class DashboardApiController extends OCSController {
 	 * Example request with Curl:
 	 * curl -u user:passwd http://my.nc/ocs/v2.php/apps/dashboard/api/v1/widget-items -H Content-Type:application/json -X GET -d '{"sinceIds":{"github_notifications":"2021-03-22T15:01:10Z"}}'
 	 *
+	 * @param string[] $widgetIds Limit widgets to given ids
+	 * @return IWidget[]
+	 */
+	private function getShownWidgets(array $widgetIds): array {
+		if (empty($widgetIds)) {
+			$systemDefault = $this->config->getAppValue('dashboard', 'layout', 'recommendations,spreed,mail,calendar');
+			$widgetIds = explode(',', $this->config->getUserValue($this->userId, 'dashboard', 'layout', $systemDefault));
+		}
+
+		return array_filter(
+			$this->dashboardManager->getWidgets(),
+			static function (IWidget $widget) use ($widgetIds) {
+				return in_array($widget->getId(), $widgetIds);
+			},
+		);
+	}
+
+	/**
 	 * @param array $sinceIds Array indexed by widget Ids, contains date/id from which we want the new items
 	 * @param int $limit Limit number of result items per widget
 	 * @param string[] $widgets Limit results to specific widgets
@@ -76,18 +98,11 @@ class DashboardApiController extends OCSController {
 	 * @NoCSRFRequired
 	 */
 	public function getWidgetItems(array $sinceIds = [], int $limit = 7, array $widgets = []): DataResponse {
-		$showWidgets = $widgets;
 		$items = [];
-
-		if (empty($showWidgets)) {
-			$systemDefault = $this->config->getAppValue('dashboard', 'layout', 'recommendations,spreed,mail,calendar');
-			$showWidgets = explode(',', $this->config->getUserValue($this->userId, 'dashboard', 'layout', $systemDefault));
-		}
-
-		$widgets = $this->dashboardManager->getWidgets();
+		$widgets = $this->getShownWidgets($widgets);
 		foreach ($widgets as $widget) {
-			if ($widget instanceof IAPIWidget && in_array($widget->getId(), $showWidgets)) {
-				$items[$widget->getId()] = array_map(function (WidgetItem $item) {
+			if ($widget instanceof IAPIWidget) {
+				$items[$widget->getId()] = array_map(static function (WidgetItem $item) {
 					return $item->jsonSerialize();
 				}, $widget->getItems($this->userId, $sinceIds[$widget->getId()] ?? null, $limit));
 			}
@@ -102,6 +117,33 @@ class DashboardApiController extends OCSController {
 	 *
 	 * @NoAdminRequired
 	 * @NoCSRFRequired
+	 *
+	 * Get the items for the widgets
+	 *
+	 * @param array<string, string> $sinceIds Array indexed by widget Ids, contains date/id from which we want the new items
+	 * @param int $limit Limit number of result items per widget
+	 * @param string[] $widgets Limit results to specific widgets
+	 * @return DataResponse
+	 */
+	public function getWidgetItemsV2(array $sinceIds = [], int $limit = 7, array $widgets = []): DataResponse {
+		$items = [];
+		$widgets = $this->getShownWidgets($widgets);
+		foreach ($widgets as $widget) {
+			if ($widget instanceof IAPIWidgetV2) {
+				$items[$widget->getId()] = $widget
+					->getItemsV2($this->userId, $sinceIds[$widget->getId()] ?? null, $limit)
+					->jsonSerialize();
+			}
+		}
+
+		return new DataResponse($items);
+	}
+
+	/**
+	 * Get the widgets
+	 *
+	 * @NoAdminRequired
+	 * @NoCSRFRequired
 	 */
 	public function getWidgets(): DataResponse {
 		$widgets = $this->dashboardManager->getWidgets();
@@ -116,6 +158,8 @@ class DashboardApiController extends OCSController {
 				'icon_url' => ($widget instanceof IIconWidget) ? $widget->getIconUrl() : '',
 				'widget_url' => $widget->getUrl(),
 				'item_icons_round' => $options->withRoundItemIcons(),
+				'item_api_versions' => [],
+				'reload_interval' => 0,
 			];
 			if ($widget instanceof IButtonWidget) {
 				$data += [
@@ -128,6 +172,15 @@ class DashboardApiController extends OCSController {
 					}, $widget->getWidgetButtons($this->userId)),
 				];
 			}
+			if ($widget instanceof IReloadableWidget) {
+				$data['reload_interval'] = $widget->getReloadInterval();
+			}
+			if ($widget instanceof IAPIWidget) {
+				$data['item_api_versions'][] = 1;
+			}
+			if ($widget instanceof IAPIWidgetV2) {
+				$data['item_api_versions'][] = 2;
+			}
 			return $data;
 		}, $widgets);
 
