@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Calendari",
-    "To-dos" : "Tasques pendents",
+    "Tasks" : "Tasques",
     "Personal" : "Personal",
     "{actor} created calendar {calendar}" : "{actor} ha creat el calendari {calendar}",
     "You created calendar {calendar}" : "Heu creat el calendari {calendar}",
@@ -93,7 +93,6 @@ OC.L10N.register(
     "Decline" : "Rebutja",
     "More options …" : "Més opcions…",
     "More options at %s" : "Més opcions a %s",
-    "In a meeting" : "En una reunió",
     "Contacts" : "Contactes",
     "{actor} created address book {addressbook}" : "{actor} ha creat la llibreta d'adreces {addressbook}",
     "You created address book {addressbook}" : "Heu creat la llibreta d'adreces {addressbook}",
@@ -144,14 +143,13 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Configura un compte CalDAV",
     "Configures a CardDAV account" : "Configura un compte CardDAV",
     "Events" : "Esdeveniments",
-    "Tasks" : "Tasques",
     "Untitled task" : "Tasca sense títol",
     "Completed on %s" : "Completada el %s",
     "Due on %s by %s" : "Venç el %s a les %s",
     "Due on %s" : "Venç el %s",
     "DAV system address book" : "Llibreta d'adreces del sistema DAV",
     "No outstanding DAV system address book sync." : "No hi ha cap sincronització pendent de la llibreta d'adreces del sistema DAV",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling occ dav:sync-system-addressbook." : "La sincronització de la llibreta d'adreces del sistema DAV encara no s'ha executat perquè la instància té més de 1000 usuaris o a causa d'un error. Executeu-la manualment amb «occ dav:sync-system-addressbook».",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "La sincronització de la llibreta d'adreces del sistema DAV encara no s'ha executat perquè la instància té més de 1000 usuaris o a causa d'un error. Executeu-la manualment amb «occ dav:sync-system-addressbook».",
     "Migrated calendar (%1$s)" : "Calendari migrat (%1$s)",
     "Calendars including events, details and attendees" : "Calendaris amb esdeveniments, detalls i assistents",
     "Contacts and groups" : "Contactes i grups",
@@ -163,13 +161,16 @@ OC.L10N.register(
     "Long absence Message" : "Missatge d'absència llarga",
     "Save" : "Desa",
     "Disable absence" : "Inhabilita l'absència",
+    "Absence saved" : "S'ha desat l'absència",
     "Failed to save your absence settings" : "No s'han pogut desar els paràmetres de l'absència",
+    "Absence cleared" : "S'ha esborrat l'absència",
     "Failed to clear your absence settings" : "No s'han pogut esborrar els paràmetres de l'absència",
     "Time zone:" : "Fus horari:",
     "to" : "a",
     "Delete slot" : "Suprimeix la franja",
     "No working hours set" : "No s'ha definit cap horari laboral",
     "Add slot" : "Afegeix una franja",
+    "Weekdays" : "Dies de la setmana",
     "Monday" : "Dilluns",
     "Tuesday" : "Dimarts",
     "Wednesday" : "Dimecres",
@@ -184,7 +185,7 @@ OC.L10N.register(
     "Saved availability" : "S'ha desat la disponibilitat",
     "Failed to save availability" : "No s'ha pogut desar la disponibilitat",
     "Availability" : "Disponibilitat",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Si configureu el vostre horari laboral, la resta d'usuaris veuran quan sou fora de l'oficina quan planifiquin una reunió.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si configureu el vostre horari laboral, la resta de persones veuran quan sou fora de l'oficina quan planifiquin una reunió.",
     "Absence" : "Absència",
     "Configure your next absence period." : "Configureu el pròxim període d'absència.",
     "Calendar server" : "Servidor de calendari",
@@ -204,6 +205,7 @@ OC.L10N.register(
     "Are you accepting the invitation?" : "Accepteu la invitació?",
     "Tentative" : "Provisional",
     "Your attendance was updated successfully." : "S'ha actualitzat correctament l'assistència.",
-    "%1$s has responded your invitation" : "%1$s ha respost a la vostra invitació"
+    "To-dos" : "Tasques pendents",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Si configureu el vostre horari laboral, la resta d'usuaris veuran quan sou fora de l'oficina quan planifiquin una reunió."
 },
 "nplurals=2; plural=(n != 1);");
