@@ -2,6 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Ημερολόγιο",
+    "Tasks" : "Εργασίες",
     "Personal" : "Προσωπικά",
     "{actor} created calendar {calendar}" : "{actor} δημιουργήθηκε το ημερολόγιο {calendar}",
     "You created calendar {calendar}" : "Δημιουργήσατε ημερολόγιο {ημερολόγιο}",
@@ -64,7 +65,6 @@ OC.L10N.register(
     "Decline" : "Απόρριψη",
     "More options …" : "Περισσότερες επιλογές...",
     "More options at %s" : "Περισσότερες επιλογές στο %s",
-    "In a meeting" : "Σε συνάντηση",
     "Contacts" : "Επαφές",
     "You created contact {card} in address book {addressbook}" : "Δημιουργήσατε την επαφή {card} στο βιβλίο διευθύνσεων {addressbook}",
     "You deleted contact {card} from address book {addressbook}" : "Διαγράψατε την επαφή {card} από το βιβλίο διευθύνσεων {addressbook}",
@@ -76,7 +76,6 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Ρυθμίσεις λογαριασμού CalDAV",
     "Configures a CardDAV account" : "Ρυθμίσεις λογαριασμού CardDAV",
     "Events" : "Συμβάντα",
-    "Tasks" : "Εργασίες",
     "Untitled task" : "Εργασία χωρίς όνομα",
     "Completed on %s" : "Ολοκληρώθηκε %s",
     "Contacts and groups" : "Επαφές και ομάδες",
@@ -98,7 +97,6 @@ OC.L10N.register(
     "Failed to load availability" : "Αποτυχία φόρτωσης της διαθεσιμότητας",
     "Failed to save availability" : "Αποτυχία αποθήκευσης της διαθεσιμότητας",
     "Availability" : "Διαθεσιμότητα",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Εάν διαμορφώσετε τις ώρες εργασίας σας, οι άλλοι χρήστες θα βλέπουν πότε είστε εκτός γραφείου όταν κάνουν κράτηση για μια συνάντηση.",
     "Calendar server" : "Διακομιστής ημερολογίου",
     "Send invitations to attendees" : "Αποστολή προσκλήσεων στους συμμετέχοντες.",
     "Automatically generate a birthday calendar" : "Δημιουργία ημερολογίου γενεθλίων αυτόματα",
@@ -115,6 +113,7 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Παρακαλώ επικοινωνήστε απ' ευθείας με τον διοργανωτή.",
     "Are you accepting the invitation?" : "Αποδέχεστε την πρόσκληση;",
     "Tentative" : "Δοκιμαστικό",
-    "Your attendance was updated successfully." : "Η παρουσία σας ενημερώθηκε με επιτυχία."
+    "Your attendance was updated successfully." : "Η παρουσία σας ενημερώθηκε με επιτυχία.",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Εάν διαμορφώσετε τις ώρες εργασίας σας, οι άλλοι χρήστες θα βλέπουν πότε είστε εκτός γραφείου όταν κάνουν κράτηση για μια συνάντηση."
 },
 "nplurals=2; plural=(n != 1);");
