@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Agenda",
-    "To-dos" : "Pense-bêtes",
+    "Tasks" : "Tâches",
     "Personal" : "Personnel",
     "{actor} created calendar {calendar}" : "{actor} a créé l'agenda {calendar}",
     "You created calendar {calendar}" : "Vous avez créé l'agenda {calendar}",
@@ -143,7 +143,6 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Configure un compte CalDAV",
     "Configures a CardDAV account" : "Configure un compte CardDAV",
     "Events" : "Évènements",
-    "Tasks" : "Tâches",
     "Untitled task" : "Tâche sans titre",
     "Completed on %s" : "Terminé le %s",
     "Due on %s by %s" : "Echéance le %s pour %s",
@@ -171,6 +170,7 @@ OC.L10N.register(
     "Delete slot" : "Supprimer le créneau",
     "No working hours set" : "Heures de travail non définies",
     "Add slot" : "Ajouter un créneau",
+    "Weekdays" : "Jours de la semaine",
     "Monday" : "Lundi",
     "Tuesday" : "Mardi",
     "Wednesday" : "Mercredi",
@@ -185,7 +185,7 @@ OC.L10N.register(
     "Saved availability" : "Disponibilités sauvegardées",
     "Failed to save availability" : "Impossible de sauvegarder les disponibilités",
     "Availability" : "Disponibilités",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Si vous configurez vos heures de travail, les autres utilisateurs verront si vous êtes disponible quand ils planifient une réunion.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si vous configurez vos heures de travail, les autres personnes verront si vous êtes disponible quand ils planifient une réunion.",
     "Absence" : "Absence",
     "Configure your next absence period." : "Configurez votre prochaine période d'absence.",
     "Calendar server" : "Serveur de calendrier",
@@ -204,6 +204,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Merci de contacter l'organisateur directement.",
     "Are you accepting the invitation?" : "Acceptez-vous l'invitation ?",
     "Tentative" : "Provisoire",
-    "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès."
+    "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès.",
+    "To-dos" : "Pense-bêtes",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Si vous configurez vos heures de travail, les autres utilisateurs verront si vous êtes disponible quand ils planifient une réunion."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
