@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Calendario",
-    "To-dos" : "Da fare",
+    "Tasks" : "Attività",
     "Personal" : "Personale",
     "{actor} created calendar {calendar}" : "{actor} ha creato il calendario {calendar}",
     "You created calendar {calendar}" : "Hai creato il calendario {calendar}",
@@ -93,7 +93,6 @@ OC.L10N.register(
     "Decline" : "Rifiuta",
     "More options …" : "Altre opzioni...",
     "More options at %s" : "Altre opzioni alle %s",
-    "In a meeting" : "In una riunione",
     "Contacts" : "Contatti",
     "{actor} created address book {addressbook}" : "{actor} ha creato la rubrica {addressbook}",
     "You created address book {addressbook}" : "Hai creato la rubrica {addressbook}",
@@ -114,8 +113,8 @@ OC.L10N.register(
     "{actor} unshared address book {addressbook} from group {group}" : "{actor} ha eliminato la condivisone della rubrica {addressbook} con il gruppo {group}",
     "{actor} created contact {card} in address book {addressbook}" : "{actor} ha creato il contatto {card} nella rubrica {addressbook}",
     "You created contact {card} in address book {addressbook}" : "Hai creato il contatto {card} nella rubrica {addressbook}",
-    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} ha cancellato il contatto {card} nella rubrica {addressbook}",
-    "You deleted contact {card} from address book {addressbook}" : "Hai cancellato il contatto {card} nella rubrica {addressbook}",
+    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} ha eliminato il contatto {card} nella rubrica {addressbook}",
+    "You deleted contact {card} from address book {addressbook}" : "Hai eliminato il contatto {card} nella rubrica {addressbook}",
     "{actor} updated contact {card} in address book {addressbook}" : "{actor} ha aggiornato il contatto {card} nella rubrica {addressbook}",
     "You updated contact {card} in address book {addressbook}" : "Hai aggiornato il contatto {card} nella rubrica {addressbook}",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Un <strong>contatto</strong> o <strong>rubrica</strong> sono stati modificati ",
@@ -124,16 +123,16 @@ OC.L10N.register(
     "File is not updatable: %1$s" : "Il file non è aggiornabile: %1$s",
     "Could not write to final file, canceled by hook" : "Impossibile scrivere nel file finale, annullato da hook",
     "Could not write file contents" : "Impossibile scrivere il contenuto del file",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
+    "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
     "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Errore durante la copia del file nella destinazione (copiato: %1$s, dimensione prevista del file: %2$s)",
     "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Dimensione prevista del file %1$s, letto (dal client Nextcloud) e scritto (nell'archivio Nextcloud) %2$s. Potrebbe trattarsi di un problema di rete sul lato d'invio o di un problema di scrittura nell'archivio sul lato server.",
     "Could not rename part file to final file, canceled by hook" : "Impossibile rinominare il file di parte in file finale, annullato da hook",
     "Could not rename part file to final file" : "Impossibile rinominare il file di parte in file finale",
     "Failed to check file size: %1$s" : "Verifica della dimensione del file non riuscito: %1$s",
     "Could not open file" : "Impossibile aprire il file",
-    "Encryption not ready: %1$s" : "Crittografia non pronta: %1$s",
+    "Encryption not ready: %1$s" : "Cifratura non pronta: %1$s",
     "Failed to open file: %1$s" : "Apertura del file non riuscito: %1$s",
-    "Failed to unlink: %1$s" : "Scollegamento fallito: %1$s",
+    "Failed to unlink: %1$s" : "Scollegamento non riuscito: %1$s",
     "Invalid chunk name" : "Nome non valido per lo spezzone",
     "Could not rename part file assembled from chunks" : "Non è possibile rinominare il file assemblato da più spezzoni",
     "Failed to write file contents: %1$s" : "Scrittura del contenuto del file non riuscita: %1$s",
@@ -144,7 +143,6 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Configura un account CalDAV",
     "Configures a CardDAV account" : "Configura un account CardDAV",
     "Events" : "Eventi",
-    "Tasks" : "Attività",
     "Untitled task" : "Attività senza titolo",
     "Completed on %s" : "Completata il %s",
     "Due on %s by %s" : "Scade il %s per %s",
@@ -186,7 +184,6 @@ OC.L10N.register(
     "Saved availability" : "Disponibilità salvata",
     "Failed to save availability" : "Salvataggio disponibilità non riuscito",
     "Availability" : "Disponibilità",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Se imposti il tuo orario di lavoro, gli altri utenti potranno vedere quando non sei in ufficio per organizzare una riunione.",
     "Absence" : "Assenza",
     "Configure your next absence period." : "Configura il tuo prossimo periodo di assenza.",
     "Calendar server" : "Server di calendari",
@@ -205,6 +202,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Contatta direttamente l'amministratore.",
     "Are you accepting the invitation?" : "Accetti l'invito?",
     "Tentative" : "Provvisorio",
-    "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente."
+    "Your attendance was updated successfully." : "La tua partecipazione è stata aggiornata correttamente.",
+    "To-dos" : "Da fare",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Se imposti il tuo orario di lavoro, gli altri utenti potranno vedere quando non sei in ufficio per organizzare una riunione."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
