@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "カレンダー",
-    "To-dos" : "To-dos",
+    "Tasks" : "タスク",
     "Personal" : "個人",
     "{actor} created calendar {calendar}" : "{actor}はカレンダー {calendar} を作成しました",
     "You created calendar {calendar}" : "カレンダー {calendar} を作成しました",
@@ -143,19 +143,29 @@ OC.L10N.register(
     "Configures a CalDAV account" : "CalDAVアカウントを設定します",
     "Configures a CardDAV account" : "CardDAVアカウントを設定します",
     "Events" : "イベント",
-    "Tasks" : "タスク",
     "Untitled task" : "タイトルなしタスク",
     "Completed on %s" : "%sに完了",
     "Due on %s by %s" : "期限日%s が%sにより設定",
     "Due on %s" : "期限日：%s",
+    "DAV system address book" : "DAVシステムアドレス帳",
+    "No outstanding DAV system address book sync." : "DAVシステムアドレス帳の同期が完了していません。",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAVシステムのアドレス帳同期は、インスタンスに1000人以上のユーザーがいるか、エラーが発生したためまだ実行されていません。手動で実行するには、\"occ dav:sync-system-addressbook\"を呼び出してください。",
     "Migrated calendar (%1$s)" : "カレンダーを移行しました (%1$s)",
     "Calendars including events, details and attendees" : "カレンダーには、イベント、イベントの詳細及び出席者が含まれます",
     "Contacts and groups" : "連絡先とグループ",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAVエンドポイント",
-    "Availability" : "応対可能日時",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "勤務時間を設定すると、他のユーザが会議を予約する際に、あなたがいつ不在であるかがわかります。",
-    "Time zone:" : "時間帯：",
+    "First day" : "初日",
+    "Last day (inclusive)" : "最終日（含む）",
+    "Short absence status" : "短い不在のステータス",
+    "Long absence Message" : "長期不在のメッセージ",
+    "Save" : "保存",
+    "Disable absence" : "不在を無効にする",
+    "Absence saved" : "不在を保存しました",
+    "Failed to save your absence settings" : "不在設定の保存に失敗しました",
+    "Absence cleared" : "不在を削除しました",
+    "Failed to clear your absence settings" : "不在設定の解除に失敗しました",
+    "Time zone:" : "タイムゾーン：",
     "to" : "宛先",
     "Delete slot" : "スロットを削除",
     "No working hours set" : "勤務時間未設定",
@@ -167,11 +177,15 @@ OC.L10N.register(
     "Friday" : "金曜日",
     "Saturday" : "土曜日",
     "Sunday" : "日曜日",
+    "Pick a start time for {dayName}" : "{dayName} 開始時間を指定してください",
+    "Pick a end time for {dayName}" : "{dayName} の終了時間を指定してください",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "利用時間外は自動的にユーザーステータスを\"非通知\" に設定し、すべての通知をミュートします。",
-    "Save" : "保存",
     "Failed to load availability" : "可用性の読み込みに失敗",
     "Saved availability" : "可用性を保存しました",
     "Failed to save availability" : "可用性を保存しました",
+    "Availability" : "応対可能日時",
+    "Absence" : "不在",
+    "Configure your next absence period." : "次の不在期間を設定します。",
     "Calendar server" : "カレンダーサーバー",
     "Send invitations to attendees" : "参加者に招待状を送信する",
     "Automatically generate a birthday calendar" : "自動的に誕生日カレンダーを生成する",
@@ -189,6 +203,7 @@ OC.L10N.register(
     "Are you accepting the invitation?" : "招待を受け入れていますか？",
     "Tentative" : "暫定的",
     "Your attendance was updated successfully." : "出席は正常に更新されました。",
-    "%1$s has responded your invitation" : "%1$s はあなたの招待に応じた"
+    "To-dos" : "To-dos",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "勤務時間を設定すると、他のユーザが会議を予約する際に、あなたがいつ不在であるかがわかります。"
 },
 "nplurals=1; plural=0;");
