@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Календар",
-    "To-dos" : "За работење",
+    "Tasks" : "Задачи",
     "Personal" : "Лично",
     "{actor} created calendar {calendar}" : "{actor} креираше календар {calendar}",
     "You created calendar {calendar}" : "Креиравте календар {calendar}",
@@ -61,7 +61,7 @@ OC.L10N.register(
     "Where:" : "Каде: ",
     "Description:" : "Опис:",
     "_%n year_::_%n years_" : ["една година","%n години"],
-    "_%n month_::_%n months_" : ["еден месец","%n месеци"],
+    "_%n month_::_%n months_" : ["%n месец","%n месеци"],
     "_%n day_::_%n days_" : ["еден ден","%n дена"],
     "_%n hour_::_%n hours_" : ["еден час","%n часа"],
     "_%n minute_::_%n minutes_" : ["една минута","%n минути"],
@@ -76,6 +76,7 @@ OC.L10N.register(
     "\"%1$s\" has been canceled" : "\"%1$s\" е отакажана",
     "Re: %1$s" : "Одг: %1$s",
     "%1$s has accepted your invitation" : "%1$s ја прифати вашата покана",
+    "%1$s has tentatively accepted your invitation" : "%1$s привремено ја прифати нафаша покана",
     "%1$s has declined your invitation" : "%1$s ја одби вашата покана",
     "%1$s has responded to your invitation" : "%1$s одговори на вашата покана",
     "Invitation updated: %1$s" : "Поканата е ажурирана: %1$s",
@@ -92,7 +93,6 @@ OC.L10N.register(
     "Decline" : "Одбиј",
     "More options …" : "Повеќе опции ...",
     "More options at %s" : "Повеќе опции на %s",
-    "In a meeting" : "На состанок",
     "Contacts" : "Контакти",
     "{actor} created address book {addressbook}" : "{actor} креираше адресар {addressbook}",
     "You created address book {addressbook}" : "Креиравте адресар {addressbook}",
@@ -109,8 +109,12 @@ OC.L10N.register(
     "{actor} unshared address book {addressbook} from themselves" : "{actor} не го споделува адресар {addressbook} со себе",
     "You shared address book {addressbook} with group {group}" : "Споделивте адресар {addressbook} со група {group}",
     "{actor} shared address book {addressbook} with group {group}" : "{actor} сподели адресар {addressbook} со група {group}",
+    "You unshared address book {addressbook} from group {group}" : "Остранивте од споделување адресар {addressbook} со група{group}",
+    "{actor} unshared address book {addressbook} from group {group}" : "{actor} острани од споделување адресар {addressbook} од група {group}",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong>Контракт</strong> или <strong>адресар</strong> е променет",
     "Accounts" : "Сметки",
+    "System address book which holds all accounts" : "Системски адресар кој ги содржи сите сметки",
+    "File is not updatable: %1$s" : "Датотека што не се ажурира: %1$s",
     "_%n byte_::_%n bytes_" : ["%n бајт","%n бајти"],
     "Could not open file" : "Неможе да се отвори датотеката",
     "Failed to open file: %1$s" : "Неуспешно отварање на датотека: %1$s",
@@ -121,22 +125,31 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Конфигурирај CalDAV сметка",
     "Configures a CardDAV account" : "Конфигурирај CardDAV сметка",
     "Events" : "Настани",
-    "Tasks" : "Задачи",
     "Untitled task" : "Неименувана задача",
     "Completed on %s" : "Завршена на %s",
     "Due on %s by %s" : "Истекува на %s од %s",
     "Due on %s" : "Истекува на %s",
     "Migrated calendar (%1$s)" : "мигриран календар (%1$s)",
+    "Calendars including events, details and attendees" : "Календари вклучувајќи настани, детали и присутни",
     "Contacts and groups" : "Контакти и групи",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAV крајна точка",
     "First day" : "Прв ден",
+    "Last day (inclusive)" : "Последен ден (вклучително)",
+    "Short absence status" : "Статус на кратко отсуство",
+    "Long absence Message" : "Порака за долго отсуство",
     "Save" : "Зачувај",
+    "Disable absence" : "Оневозможи отсуство",
+    "Absence saved" : "Отсуството е зачувано",
+    "Failed to save your absence settings" : "Неуспешно зачувување на поставките за отсуство",
+    "Absence cleared" : "Отсуството е избришано",
+    "Failed to clear your absence settings" : "Неуспешно бришење на поставките за отсуство",
     "Time zone:" : "Временска зона:",
     "to" : "до",
     "Delete slot" : "Избриши слот",
     "No working hours set" : "Не се поставени работни часови",
     "Add slot" : "Додади слот",
+    "Weekdays" : "Работни денови",
     "Monday" : "Понеделник",
     "Tuesday" : "Вторник",
     "Wednesday" : "Среда",
@@ -144,12 +157,16 @@ OC.L10N.register(
     "Friday" : "Петок",
     "Saturday" : "Сабота",
     "Sunday" : "Недела",
+    "Pick a start time for {dayName}" : "Избери почетно време за {dayName}",
+    "Pick a end time for {dayName}" : "Избери крајно време за {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматско поставување на статус во \"Не вознемирувај\" недостапен за да ги занемите сите известувања.",
     "Failed to load availability" : "Неуспешно вчитување на достапноста",
     "Saved availability" : "Достапноста е зачувана",
     "Failed to save availability" : "Неуспешно зачувување на достапноста",
     "Availability" : "Достапност",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ако ги поставите работните часови, другите корисници ќе можат да видат кога сте слободни за да можат да закажат состанок.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ако ги поставите работните часови, другите корисници ќе можат да видат кога сте слободни за да можат да закажат состанок.",
+    "Absence" : "Отсуство",
+    "Configure your next absence period." : "Поставете го вашиот следен период на отсуство.",
     "Calendar server" : "Календар сервер",
     "Send invitations to attendees" : "Испрати покани на учесниците",
     "Automatically generate a birthday calendar" : "Автоматско генерирање на календар со родендени",
@@ -157,6 +174,8 @@ OC.L10N.register(
     "Hence they will not be available immediately after enabling but will show up after some time." : "Оттука, тие нема да бидат достапни веднаш по овозможувањето, но ќе се појават по некое време.",
     "Send notifications for events" : "Испрати известувања за настани",
     "Notifications are sent via background jobs, so these must occur often enough." : "Известувањата ќе бидат испраќани преку задачите што се извршуваат во позадина, така што тие треба да се случуваат доволно често.",
+    "Send reminder notifications to calendar sharees as well" : "Испратете известувања за потсетници и до споделувањата на календарот",
+    "Reminders are always sent to organizers and attendees." : "Секогаш се испраќаат потсетници до организаторите и до присутните.",
     "Enable notifications for events via push" : "Овозможи известувања за настани преку push",
     "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Исто така инсталирајте ја {calendarappstoreopen}Календар апликацијата{linkclose}, или {calendardocopen}поврзете го вашиот компјутер & мобилен за синхронизација ↗{linkclose}.",
     "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Бидете сигурни дека правилно се поставени {emailopen}параметрите за Е-пошта{linkclose}.",
@@ -164,6 +183,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Контактирајте го организаторот директно.",
     "Are you accepting the invitation?" : "Дали ја прифаќате поканата?",
     "Tentative" : "Прелиминарно",
-    "Your attendance was updated successfully." : "Вашето присуство е успешно ажурирано."
+    "Your attendance was updated successfully." : "Вашето присуство е успешно ажурирано.",
+    "To-dos" : "За работење",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ако ги поставите работните часови, другите корисници ќе можат да видат кога сте слободни за да можат да закажат состанок."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
