@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Kalender",
-    "To-dos" : "Gjøremål",
+    "Tasks" : "Oppgaver",
     "Personal" : "Personlig",
     "{actor} created calendar {calendar}" : "{actor} opprettet kalenderen {calendar}",
     "You created calendar {calendar}" : "Du opprettet kalenderen {calendar}",
@@ -75,7 +75,12 @@ OC.L10N.register(
     "Cancelled: %1$s" : "Kansellerte: %1$s",
     "\"%1$s\" has been canceled" : "\"%1$s\" har blitt kansellert",
     "Re: %1$s" : "Sv: %1$s",
+    "%1$s has accepted your invitation" : "%1$s har godtatt invitasjonen din",
+    "%1$s has tentatively accepted your invitation" : "%1$s har foreløpig godtatt invitasjonen din",
+    "%1$s has declined your invitation" : "%1$s har avvist invitasjonen din",
     "%1$s has responded to your invitation" : "%1$s har svart på invitasjonen din",
+    "Invitation updated: %1$s" : "Invitasjon oppdatert: %1$s",
+    "%1$s updated the event \"%2$s\"" : "%1$s oppdaterte hendelsen \"%2$s\"",
     "Invitation: %1$s" : "Invitasjon: %1$s",
     "%1$s would like to invite you to \"%2$s\"" : "%1$s vil invitere deg til \"%2$s\"",
     "Organizer:" : "Arrangør:",
@@ -113,6 +118,8 @@ OC.L10N.register(
     "{actor} updated contact {card} in address book {addressbook}" : "{actor} oppdaterte kontakten {card} i adresseboken {addressbook}",
     "You updated contact {card} in address book {addressbook}" : "Du oppdaterte kontakten {card} i adresseboken {addressbook}",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "En <strong>kontakt</strong> eller <strong>adressebok</strong> ble endret",
+    "Accounts" : "Kontoer",
+    "System address book which holds all accounts" : "Systemadressebok som inneholder alle kontoer",
     "File is not updatable: %1$s" : "Filen kan ikke oppdateres: %1$s",
     "Could not write to final file, canceled by hook" : "Kunne ikke skrive til den endelige filen, kansellert av hook",
     "Could not write file contents" : "Kunne ikke skrive filinnhold",
@@ -136,22 +143,34 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Konfigurerer en CalDAV konto",
     "Configures a CardDAV account" : "Konfigurerer en CardDAV konto",
     "Events" : "Hendelser",
-    "Tasks" : "Oppgaver",
     "Untitled task" : "Oppgave uten tittel",
     "Completed on %s" : "Ferdig på %s",
     "Due on %s by %s" : "Forfaller på %s ved %s",
     "Due on %s" : "Forfaller på %s",
+    "DAV system address book" : "DAV-systemadressebok",
+    "No outstanding DAV system address book sync." : "Ingen utestående DAV-systemadressebok synkronisering.",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemadresseboksynkroniseringen har ikke kjørt enda fordi forekomsten har mer enn 1000 brukere, eller fordi det oppstod en feil. Kjør den manuelt ved å kalle \"occ dav: sync-system-addressbook\".",
     "Migrated calendar (%1$s)" : "Migrerte kalenderen (%1$s)",
     "Calendars including events, details and attendees" : "Kalendere inkludert hendelser, detaljer og deltakere",
     "Contacts and groups" : "Kontakter og grupper",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAV endepunkt",
+    "First day" : "Første dag",
+    "Last day (inclusive)" : "Siste dag (inklusive)",
+    "Short absence status" : "Kort fraværsstatus",
+    "Long absence Message" : "Lang fraværsmelding",
     "Save" : "Lagre",
+    "Disable absence" : "Deaktiver fravær",
+    "Absence saved" : "Fravær lagret",
+    "Failed to save your absence settings" : "Lagring av dine fraværsinnstillinger feilet",
+    "Absence cleared" : "Fravær fjernet",
+    "Failed to clear your absence settings" : "Fjerning av dine fraværsinnstillinger feilet",
     "Time zone:" : "Tidssone:",
     "to" : "til",
     "Delete slot" : "Slett tidsluke",
     "No working hours set" : "Ingen arbeidstid satt",
     "Add slot" : "Legg til tidsrom",
+    "Weekdays" : "Ukedager",
     "Monday" : "Mandag",
     "Tuesday" : "Tirsdag",
     "Wednesday" : "Onsdag",
@@ -159,12 +178,16 @@ OC.L10N.register(
     "Friday" : "Fredag",
     "Saturday" : "Lørdag",
     "Sunday" : "Søndag",
+    "Pick a start time for {dayName}" : "Velg et starttidspunkt for {dayName}",
+    "Pick a end time for {dayName}" : "Velg et sluttidspunkt for {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Sett brukerstatus automatisk til «Ikke forstyrr» utenfor arbeidstid for å dempe alle varsler.",
     "Failed to load availability" : "Feilet med laste inn arbeidstid",
     "Saved availability" : "Lagret arbeidstid",
     "Failed to save availability" : "Feilet ved lagring av arbeidstid",
     "Availability" : "Arbeidstid",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Hvis du konfigurerer arbeidstiden din, vil andre brukere se når du ikke er på kontoret når de bestiller et møte.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Hvis du konfigurerer arbeidstiden din, vil andre personer se når du ikke er på kontoret når de bestiller et møte.",
+    "Absence" : "Fravær",
+    "Configure your next absence period." : "Konfigurer din neste fraværsperiode.",
     "Calendar server" : "Kalenderserver",
     "Send invitations to attendees" : "Send invitasjoner til deltakere",
     "Automatically generate a birthday calendar" : "Lag fødelsdagskalender automatisk",
@@ -181,6 +204,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Ta kontakt med arrangøren direkte.",
     "Are you accepting the invitation?" : "Aksepterer du invitasjonen?",
     "Tentative" : "Foreløpig",
-    "Your attendance was updated successfully." : "Deltakelsen din ble oppdatert."
+    "Your attendance was updated successfully." : "Deltakelsen din ble oppdatert.",
+    "To-dos" : "Gjøremål",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Hvis du konfigurerer arbeidstiden din, vil andre brukere se når du ikke er på kontoret når de bestiller et møte."
 },
 "nplurals=2; plural=(n != 1);");
