@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Agenda",
-    "To-dos" : "Taken",
+    "Tasks" : "Taken",
     "Personal" : "Persoonlijk",
     "{actor} created calendar {calendar}" : "{actor} creëerde agenda {calendar}",
     "You created calendar {calendar}" : "Jij creëerde agenda {calendar}",
@@ -32,6 +32,7 @@ OC.L10N.register(
     "You deleted event {event} from calendar {calendar}" : "Je verwijderde afspraak {event} uit agenda {calendar}",
     "{actor} updated event {event} in calendar {calendar}" : "{actor} heeft afspraak {event} in agenda {calendar} bijgewerkt",
     "You updated event {event} in calendar {calendar}" : "Je hebt afspraak {event} in agenda {calendar} bijgewerkt",
+    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Je hebt evenement {event} verplaatst van agenda {sourceCalendar} naar agenda {targetCalendar}",
     "{actor} restored event {event} of calendar {calendar}" : "{actor} herstelde afspraak {event} in agenda {calendar}",
     "You restored event {event} of calendar {calendar}" : "Je herstelde afspraak {event} in agenda {calendar}",
     "Busy" : "Bezig",
@@ -43,9 +44,11 @@ OC.L10N.register(
     "You updated to-do {todo} in list {calendar}" : "Jij paste de taak {todo} in de lijst {calendar} aan",
     "{actor} solved to-do {todo} in list {calendar}" : "{actor} voltooide de taak {todo} in de lijst {calendar}",
     "You solved to-do {todo} in list {calendar}" : "Jij voltooide de taak {todo} in de lijst {calendar}",
+    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} heropende taak {todo} in lijst {calendar}",
     "Calendar, contacts and tasks" : "Agenda, contactpersonen en taken",
     "A <strong>calendar</strong> was modified" : "Een <strong>agenda</strong> is aangepast",
     "A calendar <strong>event</strong> was modified" : "Een agenda <strong>gebeurtenis</strong> is aangepast",
+    "A calendar <strong>to-do</strong> was modified" : "Een agenda <strong>to-do</strong> was aangepast",
     "Contact birthdays" : "Verjaardagen",
     "Death of %s" : "Sterfdatum van %s",
     "Untitled calendar" : "Naamloze calender",
@@ -66,7 +69,12 @@ OC.L10N.register(
     "Where: %s" : "Waar: %s",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Cancelled: %1$s" : "Geannuleerd: %1$s",
+    "\"%1$s\" has been canceled" : "\"%1$s\" is geannuleerd",
     "Re: %1$s" : "Re: %1$s",
+    "%1$s has accepted your invitation" : "%1$s heeft uw uitnodiging aanvaard",
+    "%1$s has declined your invitation" : "%1$s heeft uw uitnodiging afgewezen",
+    "%1$s has responded to your invitation" : "%1$s heeft gereageerd op uw uitnodiging",
+    "Invitation updated: %1$s" : "Uitnodiging bijgewerkt: %1$s",
     "Invitation: %1$s" : "Uitnodiging: %1$s",
     "Organizer:" : "Organisator:",
     "Attendees:" : "Deelnemers:",
@@ -103,6 +111,7 @@ OC.L10N.register(
     "{actor} updated contact {card} in address book {addressbook}" : "{actor} wijzigde contact {card} in adresboek {addressbook}",
     "You updated contact {card} in address book {addressbook}" : "Je wijzigde contact {card} in adresboek {addressbook}",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Een <strong>contact</strong> uit adresboek </strong> is gewijzigd",
+    "Accounts" : "Accounts",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Verwachte bestandsgrootte van %1$s maar gelezen (van Nextcloud-client) en geschreven (naar Nextcloud-opslag) %2$s. Dit kan een netwerkprobleem zijn aan de verzendende kant of een probleem met het schrijven naar de opslag aan de serverkant.",
     "Could not rename part file to final file, canceled by hook" : "Kon bestandsdeel niet hernoemen naar definitief bestand, geannuleerd door hook",
@@ -122,7 +131,6 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Configureert een CalDAV account",
     "Configures a CardDAV account" : "Configureert een CardDAV account",
     "Events" : "Evenementen",
-    "Tasks" : "Taken",
     "Untitled task" : "Taak zonder titel",
     "Completed on %s" : "Voltooid op %s",
     "Due on %s by %s" : "Verwacht op %s door %s",
@@ -146,7 +154,8 @@ OC.L10N.register(
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Stel de gebruikersstatus automatisch in op \"Niet storen\" buiten de beschikbaarheid om alle meldingen te dempen.",
     "Failed to load availability" : "Kon beschikbaarheid niet laden",
     "Availability" : "Beschikbaarheid",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Als je je werkuren instelt kunnen andere gebruikers zien wanneer je niet beschikbaar bent als ze een meeting willen plannen.",
+    "Absence" : "Afwezigheid",
+    "Configure your next absence period." : "Configureer uw volgende afwezigheidsperiode.",
     "Calendar server" : "Agendaserver",
     "Send invitations to attendees" : "Verzend uitnodigingen naar deelnemers",
     "Automatically generate a birthday calendar" : "Genereer verjaardagskalender automatisch",
@@ -161,6 +170,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Neem rechtstreeks contact op met de organisator.",
     "Are you accepting the invitation?" : "Neem je de uitnodiging aan?",
     "Tentative" : "Onder voorbehoud",
-    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt."
+    "Your attendance was updated successfully." : "Je deelname is succesvol bijgewerkt.",
+    "To-dos" : "Taken",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Als je je werkuren instelt kunnen andere gebruikers zien wanneer je niet beschikbaar bent als ze een meeting willen plannen."
 },
 "nplurals=2; plural=(n != 1);");
