@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Календарь",
-    "To-dos" : "Задачи",
+    "Tasks" : "Задачи",
     "Personal" : "Личное",
     "{actor} created calendar {calendar}" : "{actor} создал(а) календарь «{calendar}»",
     "You created calendar {calendar}" : "Вы создали календарь «{calendar}»",
@@ -143,18 +143,28 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Настройка аккаунта CalDAV",
     "Configures a CardDAV account" : "Настройка аккаунта CardDAV",
     "Events" : "События",
-    "Tasks" : "Задачи",
     "Untitled task" : "Задача без названия",
     "Completed on %s" : "Завершено %s",
     "Due on %s by %s" : "До %s %s",
     "Due on %s" : "До %s",
+    "DAV system address book" : "Системная адресная книга DAV",
+    "No outstanding DAV system address book sync." : "Синхронизация системной адресной книги DAV выполнена.",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Синхронизация системной адресной книги DAV ещё не запущена, поскольку в этом экземпляре более 1000 пользователей или произошла ошибка. Перезапустите синхронизацию вручную используя команду «occ dav:sync-system-addressbook».",
     "Migrated calendar (%1$s)" : "Перенос календаря (%1$s)",
     "Calendars including events, details and attendees" : "Календари, в том числе события, подробные сведения и участники",
     "Contacts and groups" : "Контакты и группы",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "точка подключения WebDAV",
     "First day" : "Первый день",
+    "Last day (inclusive)" : "Последний день (включительно)",
+    "Short absence status" : "Краткий статус отсутствия",
+    "Long absence Message" : "Длинное сообщение об отсутствии",
     "Save" : "Сохранить",
+    "Disable absence" : "Отключить отсутствие",
+    "Absence saved" : "Состояние отсутствия сохранено",
+    "Failed to save your absence settings" : "Не удалось сохранить параметры отсутствия",
+    "Absence cleared" : "Состояние отсутствия удалено",
+    "Failed to clear your absence settings" : "Не удалось удалить параметры отсутствия",
     "Time zone:" : "Часовой пояс:",
     "to" : "по",
     "Delete slot" : "Удалить интервал",
@@ -167,12 +177,16 @@ OC.L10N.register(
     "Friday" : "Пятница",
     "Saturday" : "Суббота",
     "Sunday" : "Воскресенье",
+    "Pick a start time for {dayName}" : "Выберите время начала в {dayName}",
+    "Pick a end time for {dayName}" : "Выберите время окончания в {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматически изменять статус на «Не беспокоить» вне интервала доступности для отключения уведомлений.",
     "Failed to load availability" : "Не удалось получить сведения о доступности",
     "Saved availability" : "Сведения о доступности сохранены",
     "Failed to save availability" : "Не удалось сохранить сведения о доступности",
-    "Availability" : "Доступность",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Если вы настроите свое рабочее время, другие пользователи будут видеть, когда вас нет в офисе, когда они планируют встречу.",
+    "Availability" : "Рабочее время",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Если вы настроите свой расписание работы, другие пользователи при планировании встреч смогут видеть, когда вас нет в офисе.",
+    "Absence" : "Отсутствие",
+    "Configure your next absence period." : "Укажите интервал вашего следующего отсутствия.",
     "Calendar server" : "Сервер календаря",
     "Send invitations to attendees" : "Отправить приглашения",
     "Automatically generate a birthday calendar" : "Создавать календарь дней рождения автоматически",
@@ -189,6 +203,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Обратитесь к организатору напрямую.",
     "Are you accepting the invitation?" : "Принять приглашение?",
     "Tentative" : "Под вопросом",
-    "Your attendance was updated successfully." : "Статус участия обновлён."
+    "Your attendance was updated successfully." : "Статус участия обновлён.",
+    "To-dos" : "Задачи",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Если вы настроите свое рабочее время, другие пользователи будут видеть, когда вас нет в офисе, когда они планируют встречу."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
