@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Календар",
-    "To-dos" : "Обавезе",
+    "Tasks" : "Задаци",
     "Personal" : "Лично",
     "{actor} created calendar {calendar}" : "{actor} направи календар {calendar}",
     "You created calendar {calendar}" : "Направили сте календар {calendar}",
@@ -93,7 +93,6 @@ OC.L10N.register(
     "Decline" : "Одбиј",
     "More options …" : "Још опција…",
     "More options at %s" : "Још опција на %s",
-    "In a meeting" : "На састанку",
     "Contacts" : "Контакти",
     "{actor} created address book {addressbook}" : "{actor} је креирао адресар {addressbook}",
     "You created address book {addressbook}" : "Креирали сте адресар {addressbook}",
@@ -144,7 +143,6 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Подешава CalDAV налог",
     "Configures a CardDAV account" : "Подешава CardDAV налог",
     "Events" : "Догађаји",
-    "Tasks" : "Задаци",
     "Untitled task" : "Неименовани задатак",
     "Completed on %s" : "Завршено %s",
     "Due on %s by %s" : "Рок је %s од стране %s",
@@ -172,6 +170,7 @@ OC.L10N.register(
     "Delete slot" : "Обриши прорез",
     "No working hours set" : "Нису подешени радни сати",
     "Add slot" : "Додај термин",
+    "Weekdays" : "Дани у недељи",
     "Monday" : "Понедељак",
     "Tuesday" : "Уторак",
     "Wednesday" : "Среда",
@@ -186,7 +185,7 @@ OC.L10N.register(
     "Saved availability" : "Доступност је сачувана",
     "Failed to save availability" : "Није успело снимање доступности ",
     "Availability" : "Доступност",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ако подесите своје радне сате, када буду заказивали састанак, остали корисници ће видети када сте ван канцеларије.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Ако подесите своје радне сате, када буду заказивали састанак, други људи ће видети када сте ван канцеларије.",
     "Absence" : "Одсутност",
     "Configure your next absence period." : "Конфигуришите свој наредни период одсутности.",
     "Calendar server" : "Календар сервера",
@@ -205,6 +204,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Контактирајте директно организатора.",
     "Are you accepting the invitation?" : "Да ли прихватате позивницу?",
     "Tentative" : "Условна потврда",
-    "Your attendance was updated successfully." : "Ваше присуство је успешно ажурирано."
+    "Your attendance was updated successfully." : "Ваше присуство је успешно ажурирано.",
+    "To-dos" : "Обавезе",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ако подесите своје радне сате, када буду заказивали састанак, остали корисници ће видети када сте ван канцеларије."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
