@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "日曆",
-    "To-dos" : "待辦事項",
+    "Tasks" : "任務",
     "Personal" : "個人",
     "{actor} created calendar {calendar}" : "{actor} 建立了日曆 {calendar}",
     "You created calendar {calendar}" : "您建立了日曆 {calendar}",
@@ -93,7 +93,6 @@ OC.L10N.register(
     "Decline" : "拒絕",
     "More options …" : "更多選項 ...",
     "More options at %s" : "%s有更多選項",
-    "In a meeting" : "會議中",
     "Contacts" : "聯絡人",
     "{actor} created address book {addressbook}" : "{actor} 創建了通訊錄 {addressbook} ",
     "You created address book {addressbook}" : "您創建了通訊錄 {addressbook} ",
@@ -144,7 +143,6 @@ OC.L10N.register(
     "Configures a CalDAV account" : "設定一個 CalDAV 帳號",
     "Configures a CardDAV account" : "設定一個 CardDAV 帳號",
     "Events" : "活動",
-    "Tasks" : "任務",
     "Untitled task" : "無標題任務",
     "Completed on %s" : "完成於 %s",
     "Due on %s by %s" : "完成日期為 %s %s",
@@ -172,6 +170,7 @@ OC.L10N.register(
     "Delete slot" : "刪除欄位",
     "No working hours set" : "尚未設置工作時間",
     "Add slot" : "新增欄位",
+    "Weekdays" : "平日",
     "Monday" : "星期一",
     "Tuesday" : "星期二",
     "Wednesday" : "星期三",
@@ -186,7 +185,7 @@ OC.L10N.register(
     "Saved availability" : "已保存空閒時間",
     "Failed to save availability" : "未能保存空閒時間",
     "Availability" : "空閒時間",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他用戶在預約會議時就會知道您何時不在辦公室。",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他人仕在預約會議時就會知道您何時不在辦公室。",
     "Absence" : "缺席",
     "Configure your next absence period." : "設定您的下一個缺席時段。",
     "Calendar server" : "日曆伺服器",
@@ -205,6 +204,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "請直接聯繫絡主辦人",
     "Are you accepting the invitation?" : "接受邀請嗎？",
     "Tentative" : "暫定",
-    "Your attendance was updated successfully." : "您的參與狀況成功更新"
+    "Your attendance was updated successfully." : "您的參與狀況成功更新",
+    "To-dos" : "待辦事項",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他用戶在預約會議時就會知道您何時不在辦公室。"
 },
 "nplurals=1; plural=0;");
