@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "日曆",
-    "To-dos" : "待辦事項",
+    "Tasks" : "工作項目",
     "Personal" : "個人",
     "{actor} created calendar {calendar}" : "{actor} 建立了日曆 {calendar}",
     "You created calendar {calendar}" : "您建立了日曆 {calendar}",
@@ -143,26 +143,34 @@ OC.L10N.register(
     "Configures a CalDAV account" : "設定一個 CalDAV 帳號",
     "Configures a CardDAV account" : "設定一個 CardDAV 帳號",
     "Events" : "活動",
-    "Tasks" : "工作項目",
     "Untitled task" : "未命名工作項目",
     "Completed on %s" : "完成於 %s",
     "Due on %s by %s" : "到期於 %s 由 %s",
     "Due on %s" : "到期於 %s",
-    "Checking for DAV system address book" : "正在檢查 DAV 系統通訊錄",
+    "DAV system address book" : "DAV 系統通訊錄",
     "No outstanding DAV system address book sync." : "沒有未完成的 DAV 系統通訊錄同步。",
-    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling occ dav:sync-system-addressbook." : "DAV 系統通訊錄同步尚未執行，因為您的站台有超過 1000 個使用者，或是因為發生錯誤。請透過呼叫 occ dav:sync-system-addressbook 手動執行。",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV 系統通訊錄同步尚未執行，因為您的站台有超過 1000 個使用者，或是因為遇到錯誤。請透過呼叫「occ dav:sync-system-addressbook」手動執行。",
     "Migrated calendar (%1$s)" : "已導入的行事曆 (%1$s)",
     "Calendars including events, details and attendees" : "行事曆，包含事件、詳細資訊及參與者",
     "Contacts and groups" : "聯絡人與群組",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAV 端點",
-    "Availability" : "可用性",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。",
+    "First day" : "第一天",
+    "Last day (inclusive)" : "最後一天（含）",
+    "Short absence status" : "短暫缺席狀態",
+    "Long absence Message" : "長期缺席訊息",
+    "Save" : "儲存",
+    "Disable absence" : "停用缺席",
+    "Absence saved" : "缺席時段已儲存",
+    "Failed to save your absence settings" : "儲存您的缺席設定失敗",
+    "Absence cleared" : "缺席時段已清除",
+    "Failed to clear your absence settings" : "清除您的缺席設定失敗",
     "Time zone:" : "時區：",
     "to" : "到",
     "Delete slot" : "刪除欄位",
     "No working hours set" : "未設定工作時間",
     "Add slot" : "新增欄位",
+    "Weekdays" : "週間",
     "Monday" : "週一",
     "Tuesday" : "週二",
     "Wednesday" : "週三",
@@ -170,11 +178,16 @@ OC.L10N.register(
     "Friday" : "週五",
     "Saturday" : "週六",
     "Sunday" : "週日",
+    "Pick a start time for {dayName}" : "為 {dayName} 挑選開始時間",
+    "Pick a end time for {dayName}" : "為 {dayName} 挑選結束時間",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "在忙碌時，自動將使用者狀態設定為「請勿打擾」以靜音所有通知。",
-    "Save" : "儲存",
     "Failed to load availability" : "載入可用性失敗",
     "Saved availability" : "已儲存可用性",
     "Failed to save availability" : "儲存可用性失敗",
+    "Availability" : "可用性",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。",
+    "Absence" : "缺席",
+    "Configure your next absence period." : "設定您的下一個缺席時段。",
     "Calendar server" : "日曆伺服器",
     "Send invitations to attendees" : "發送邀請函給參加者",
     "Automatically generate a birthday calendar" : "自動生成生日日曆",
@@ -192,6 +205,7 @@ OC.L10N.register(
     "Are you accepting the invitation?" : "您接受邀請嗎？",
     "Tentative" : "暫定",
     "Your attendance was updated successfully." : "您的參與狀態成功更新。",
-    "%1$s has responded your invitation" : "%1$s 已回應您的邀請"
+    "To-dos" : "待辦事項",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "若您設定了您的工作時間，其他使用者在預約會議時就會知道您何時不在辦公室。"
 },
 "nplurals=1; plural=0;");
