@@ -29,6 +29,7 @@
 namespace OCA\DAV\DAV\Sharing;
 
 use OCA\DAV\Connector\Sabre\Principal;
+use OCP\AppFramework\Db\TTransactional;
 use OCP\Cache\CappedMemoryCache;
 use OCP\IDBConnection;
 use OCP\IGroupManager;
@@ -36,6 +37,8 @@ use OCP\IUserManager;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 
 class Backend {
+	use TTransactional;
+
 	private IDBConnection $db;
 	private IUserManager $userManager;
 	private IGroupManager $groupManager;
@@ -63,18 +66,20 @@ class Backend {
 	 */
 	public function updateShares(IShareable $shareable, array $add, array $remove): void {
 		$this->shareCache->clear();
-		foreach ($add as $element) {
-			$principal = $this->principalBackend->findByUri($element['href'], '');
-			if ($principal !== '') {
-				$this->shareWith($shareable, $element);
+		$this->atomic(function () use ($shareable, $add, $remove) {
+			foreach ($add as $element) {
+				$principal = $this->principalBackend->findByUri($element['href'], '');
+				if ($principal !== '') {
+					$this->shareWith($shareable, $element);
+				}
 			}
-		}
-		foreach ($remove as $element) {
-			$principal = $this->principalBackend->findByUri($element, '');
-			if ($principal !== '') {
-				$this->unshare($shareable, $element);
+			foreach ($remove as $element) {
+				$principal = $this->principalBackend->findByUri($element, '');
+				if ($principal !== '') {
+					$this->unshare($shareable, $element);
+				}
 			}
-		}
+		}, $this->db);
 	}
 
 	/**
@@ -201,13 +206,13 @@ class Backend {
 			];
 		}
 
-		$this->shareCache->set((string) $resourceId, $shares);
+		$this->shareCache->set((string)$resourceId, $shares);
 		return $shares;
 	}
 
 	public function preloadShares(array $resourceIds): void {
 		$resourceIds = array_filter($resourceIds, function(int $resourceId) {
-			return !isset($this->shareCache[(string) $resourceId]);
+			return !isset($this->shareCache[$resourceId]);
 		});
 		if (count($resourceIds) === 0) {
 			return;
@@ -235,7 +240,7 @@ class Backend {
 		}
 
 		foreach ($resourceIds as $resourceId) {
-			$this->shareCache->set((string) $resourceId, $sharesByResource[$resourceId]);
+			$this->shareCache->set($resourceId, $sharesByResource[$resourceId]);
 		}
 	}
 
