@@ -45,8 +45,6 @@ OC.L10N.register(
     "Enable password recovery:" : "Activează recuperarea parolei:",
     "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Activarea acestei opțiuni îți va permite să redobândești accesul la fișierele tale criptate în cazul pierderii parolei",
     "Enabled" : "Activat",
-    "Disabled" : "Dezactivat",
-    "The share will expire on %s." : "Partajarea va expira în data de %s.",
-    "Cheers!" : "Noroc!"
+    "Disabled" : "Dezactivat"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
