@@ -13,8 +13,6 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitud de elemento compartido Federado enviada, recibiras una invitación. Verifica tus notificaciones.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No fue posible establecer el elemento compartido, parece que el servidor es obsoleto (Nextcloud <=9).",
     "It is not allowed to send federated group shares from this server." : "No está permitido enviar comparticiones de grupos federados desde este servidor.",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "La compartición de %1$s falló, porque este elemento ya está compartido con el usuario %2$s",
-    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
     "Federated shares require read permissions" : "Las comparticiones federadas requieren permisos de lectura",
     "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "La compartición de %1$s falló, no se pudo encontrar %2$s, tal vez el servidor no está disponible actualmente o utiliza un certificado autofirmado.",
@@ -28,13 +26,6 @@ OC.L10N.register(
     "Sharing" : "Compartiendo",
     "Federated file sharing" : "Compartir  elementos",
     "Provide federated file sharing across servers" : "Proporciona compartición de archivos federada entre servidores",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Ajusta cómo las personas pueden compartir entre servidores. Esto incluye comparticiones entre usuarios en este servidor si están utilizando compartición federada.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permite a los usuarios de este servidor enviar comparticiones a otros servidores (esta opción también permite el acceso WebDAV a comparticiones públicas)",
-    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
-    "Allow users on this server to send shares to groups on other servers" : "Permite a los usuarios de este servidor enviar comparticiones a grupos en otros servidores",
-    "Allow users on this server to receive group shares from other servers" : "Permite a los usuarios de este servidor recibir comparticiones de grupos de otros servidores",
-    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
-    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública",
     "Unable to update federated files sharing config" : "No se pudo actualizar la configuración de compartición federada de archivos",
     "Federated Cloud" : "Nube Federada",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "¡Puedes compartir con cualquier persona que utilice un servidor Nextcloud u otros servidores y servicios compatibles con Open Cloud Mesh (OCM)! Simplemente ingresa su ID de Nube Federada en el diálogo de compartición. Se ve como person@cloud.example.com",
@@ -51,6 +42,15 @@ OC.L10N.register(
     "Cloud ID copied to the clipboard" : "ID de Nube copiado al portapapeles",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Clipboard is not available" : "El portapapeles no está disponible",
-    "Copied!" : "¡Copiado!"
+    "Copied!" : "¡Copiado!",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "La compartición de %1$s falló, porque este elemento ya está compartido con el usuario %2$s",
+    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Ajusta cómo las personas pueden compartir entre servidores. Esto incluye comparticiones entre usuarios en este servidor si están utilizando compartición federada.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permite a los usuarios de este servidor enviar comparticiones a otros servidores (esta opción también permite el acceso WebDAV a comparticiones públicas)",
+    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
+    "Allow users on this server to send shares to groups on other servers" : "Permite a los usuarios de este servidor enviar comparticiones a grupos en otros servidores",
+    "Allow users on this server to receive group shares from other servers" : "Permite a los usuarios de este servidor recibir comparticiones de grupos de otros servidores",
+    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
+    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
