@@ -12,7 +12,6 @@ OC.L10N.register(
     "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitud de elemento compartido Federado enviada, recibiras una invitación. Verifica tus notificaciones.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No fue posible establecer el elemento compartido, parece que el servidor es obsoleto (Nextcloud <=9).",
-    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
     "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
     "Could not find share" : "No fue posible encontrar el elemento compartido",
     "Federated sharing" : "Elementos compartidos",
@@ -24,9 +23,6 @@ OC.L10N.register(
     "Sharing" : "Compartiendo",
     "Federated file sharing" : "Compartir  elementos",
     "Provide federated file sharing across servers" : "Provee el compartir archivos federados entre servidores",
-    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
-    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
-    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública",
     "Federated Cloud" : "Nube Federada",
     "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
     "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
@@ -37,6 +33,10 @@ OC.L10N.register(
     "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Clipboard is not available" : "El portapapeles no está disponible",
-    "Copied!" : "¡Copiado!"
+    "Copied!" : "¡Copiado!",
+    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
+    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
+    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
+    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
