@@ -13,8 +13,8 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Demande de partage fédéré envoyée, vous allez recevoir une invitation. Vérifiez vos notifications.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Impossible d'établir un partage fédére, il semble que le serveur avec lequel fédérer est trop vieux (Nextcloud <=9)",
     "It is not allowed to send federated group shares from this server." : "Il n'est pas autorisé d'envoyer des partages à des groupes fédérés depuis ce serveur.",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Le partage de %1$s a échoué, parce que cet élément est déjà partagé avec l'utilisateur %2$s",
-    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
+    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Impossible de partager %1$s car il est déjà partagé avec le compte %2$s",
+    "Not allowed to create a federated share to the same account" : "Non autorisé à créer un partage fédéré vers le même compte",
     "Federated shares require read permissions" : "Les partages fédérés nécessitent des permissions de lecture.",
     "File is already shared with %s" : "Le fichier est déjà partagé avec %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Le partage de %1$s a échoué, impossible de trouver %2$s, le serveur est peut-être momentanément injoignable ou utilise un certificat auto-signé.",
@@ -28,13 +28,13 @@ OC.L10N.register(
     "Sharing" : "Partage",
     "Federated file sharing" : "Partage de fichiers fédéré",
     "Provide federated file sharing across servers" : "Fourni un partage de fichiers fédéré entre plusieurs serveurs",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Configurer comment les utilisateurs peuvent faire des partages entre serveurs. Cela inclut aussi les partages entre utilisateurs de ce serveur s'ils utilisent des partages fédérés.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs (cette option permet aussi l'accès WebDAV aux partages publics)",
-    "Allow users on this server to receive shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages d'autres serveurs",
-    "Allow users on this server to send shares to groups on other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages à des groupes sur d'autres serveurs",
-    "Allow users on this server to receive group shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages de groupe depuis d'autres serveurs",
-    "Search global and public address book for users" : "Rechercher dans le carnet d'adresse global et public pour les utilisateurs",
-    "Allow users to publish their data to a global and public address book" : "Autoriser les utilisateurs à publier leurs données dans un carnet d'adresse global et public",
+    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Configurer comment les utilisateurs peuvent faire des partages entre serveurs. Cela inclut aussi les partages entre personnes de ce serveur s'ils utilisent des partages fédérés.",
+    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Autoriser les personnes de ce serveur à envoyer des partages vers d'autres serveurs (cette option permet aussi l'accès WebDAV aux partages publics)",
+    "Allow people on this server to receive shares from other servers" : "Autoriser les personnes de ce serveur à recevoir des partages d'autres serveurs",
+    "Allow people on this server to send shares to groups on other servers" : "Autoriser les personnes de ce serveur à envoyer des partages à des groupes sur d'autres serveurs",
+    "Allow people on this server to receive group shares from other servers" : "Autoriser les personnes de ce serveur à recevoir des partages de groupe d'autres serveurs",
+    "Search global and public address book for people" : "Rechercher dans le carnet d'adresses global et public pour les personnes",
+    "Allow people to publish their data to a global and public address book" : "Autoriser les personnes à publier leurs données dans un carnet d'adresses global et public",
     "Unable to update federated files sharing config" : "Impossible de mettre à jour la configuration du partage fédéré de fichiers ",
     "Federated Cloud" : "Cloud Fédéré",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Vous pouvez partager avec quiconque utilise un serveur Nextcloud ou un serveur ou service compatible Open Cloud Mesh (OCM). Renseignez simplement son ID de Cloud Fédéré sur une instance fédérée dans la boîte de dialogue de partage. Cela ressemble à utilisateur@cloud.exemple.com.",
@@ -52,13 +52,14 @@ OC.L10N.register(
     "Copy to clipboard" : "Copier dans le presse-papiers",
     "Clipboard is not available" : "Le presse-papiers n'est pas disponible",
     "Copied!" : "Copié !",
-    "Copy" : "Copier",
-    "Not supported!" : "Non supporté!",
-    "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
-    "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Vous avez reçu \"%3$s\" en tant que partage distant de%4$s(%1$s) (par le biais de%5$s (%2$s))",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Vous avez reçu \"%3$s\" en tant que partage distant de %4$s (%1$s)",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Partagez avec moi grâce à mon ID de Cloud Fédéré #Nextcloud %s",
-    "Open documentation" : "Voir la documentation"
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Le partage de %1$s a échoué, parce que cet élément est déjà partagé avec l'utilisateur %2$s",
+    "Not allowed to create a federated share with the same user" : "Non autorisé à créer un partage fédéré avec le même utilisateur",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Configurer comment les utilisateurs peuvent faire des partages entre serveurs. Cela inclut aussi les partages entre utilisateurs de ce serveur s'ils utilisent des partages fédérés.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Autoriser les utilisateurs de ce serveur à envoyer des partages vers d'autres serveurs (cette option permet aussi l'accès WebDAV aux partages publics)",
+    "Allow users on this server to receive shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages d'autres serveurs",
+    "Allow users on this server to send shares to groups on other servers" : "Autoriser les utilisateurs de ce serveur à envoyer des partages à des groupes sur d'autres serveurs",
+    "Allow users on this server to receive group shares from other servers" : "Autoriser les utilisateurs de ce serveur à recevoir des partages de groupe depuis d'autres serveurs",
+    "Search global and public address book for users" : "Rechercher dans le carnet d'adresse global et public pour les utilisateurs",
+    "Allow users to publish their data to a global and public address book" : "Autoriser les utilisateurs à publier leurs données dans un carnet d'adresse global et public"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
