@@ -13,8 +13,6 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Enviouse a solicitude dunha compartición federada, Vde. recibirá unha notificación. Comprobe as súas notificacións.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Non foi posíbel estabelecer unha compartición federada, semella que o servidor  federar é antigo de máis (Nextcloud <= 9).",
     "It is not allowed to send federated group shares from this server." : "Non está permitido enviar unha compartición de grupos federados  dende este servidor.",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Fallou a compartición de %1$s por mor de que este elemento xa foi compartido co usuario %2$s",
-    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
     "Federated shares require read permissions" : "As comparticións federadas precisan permisos de lectura",
     "File is already shared with %s" : "O ficheiro xa está a ser compartido con %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Produciuse un fallo ao compartir %1$s Non foi posíbel atopar %2$s, quizais haxa un problema de conexión co servidor  ou emprega un certificado autoasinado.",
@@ -28,13 +26,6 @@ OC.L10N.register(
     "Sharing" : "Compartindo",
     "Federated file sharing" : "Compartición federada de ficheiros",
     "Provide federated file sharing across servers" : "Fornece a compartición federada de ficheiros entre servidores",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Axuste a forma como as persoas poden compartir entre servidores. Isto inclúe tamén as comparticións entre usuarios deste servidor se están a usar a compartición federada.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitirlle aos usuarios deste servidor enviar comparticións a outros servidores (esta opción tamén permite o acceso de WebDAV a comparticións públicas)",
-    "Allow users on this server to receive shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións doutros servidores",
-    "Allow users on this server to send shares to groups on other servers" : "Permitirlle aos usuarios deste servidor enviar comparticións a grupos noutros servidores",
-    "Allow users on this server to receive group shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións de grupos dende outros servidores",
-    "Search global and public address book for users" : "Buscar usuarios nos cadernos de enderezos globais e públicos",
-    "Allow users to publish their data to a global and public address book" : "Permitirlle aos usuarios publicar os seus datos nun caderno de  enderezos global e público",
     "Unable to update federated files sharing config" : "Non é posíbel actualizar a configuración de uso compartido de ficheiros federados",
     "Federated Cloud" : "Nube federada",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Pode compartir con calquera persoa que empregue servidores Nextcloud, ou outro servidor ou  servizo compatíbel co Open Cloud Mesh (OCM)! Simplemente, introduza o seu ID de nube federada no diálogo de compartir. É algo como persona@cloud.example.com",
@@ -52,8 +43,14 @@ OC.L10N.register(
     "Copy to clipboard" : "Copiar no portapapeis.",
     "Clipboard is not available" : "O portapapeis non está dispoñíbel",
     "Copied!" : "Copiado!",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Vde. recibiu «%3$s» como un elemento compartido remoto de %4$s (%1$s) (de parte de %5$s (%2$s))",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Vde. recibiu «%3$s» como un elemento compartido remoto de %4$s (%1$s)",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Comparte comigo a través do meu ID da nube federada de #Nextcloud , vexa %s"
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Fallou a compartición de %1$s por mor de que este elemento xa foi compartido co usuario %2$s",
+    "Not allowed to create a federated share with the same user" : "Non está permitido crear unha compartición federada co mesmo usuario",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Axuste a forma como as persoas poden compartir entre servidores. Isto inclúe tamén as comparticións entre usuarios deste servidor se están a usar a compartición federada.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Permitirlle aos usuarios deste servidor enviar comparticións a outros servidores (esta opción tamén permite o acceso de WebDAV a comparticións públicas)",
+    "Allow users on this server to receive shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións doutros servidores",
+    "Allow users on this server to send shares to groups on other servers" : "Permitirlle aos usuarios deste servidor enviar comparticións a grupos noutros servidores",
+    "Allow users on this server to receive group shares from other servers" : "Permitirlle aos usuarios deste servidor recibir comparticións de grupos dende outros servidores",
+    "Search global and public address book for users" : "Buscar usuarios nos cadernos de enderezos globais e públicos",
+    "Allow users to publish their data to a global and public address book" : "Permitirlle aos usuarios publicar os seus datos nun caderno de  enderezos global e público"
 },
 "nplurals=2; plural=(n != 1);");
