@@ -13,8 +13,6 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Föderált megosztási kérés elküldve, kapni fog egy meghívót. Ellenőrizze az értesítéseit.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "A föderált megosztás nem hozható létre, úgy tűnik, hogy a föderálandó kiszolgáló túl régi. (Nextcloud <= 9).",
     "It is not allowed to send federated group shares from this server." : "Nem küldhet föderált csoportmegosztást erről a kiszolgálóról.",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "A(z) %1$s megosztása sikertelen, mert már meg van osztva %2$s felhasználóval",
-    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet föderált megosztást létrehozni",
     "Federated shares require read permissions" : "A föderált megosztásokhoz olvasási jogosultság szükséges",
     "File is already shared with %s" : "A fájl már meg van osztva vele: %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "A(z) %1$s megosztása sikertelen, a(z) %2$s nem található, talán a kiszolgáló jelenleg nem érhető el vagy önaláírt tanúsítványt használ.",
@@ -28,13 +26,6 @@ OC.L10N.register(
     "Sharing" : "Megosztás",
     "Federated file sharing" : "Föderált fájlmegosztás",
     "Provide federated file sharing across servers" : "Föderált fájlmegosztás biztosítása a kiszolgálók között",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Állítsa be, hogy az emberek hogyan oszthatnak meg kiszolgálók között. Ebbe beleértendők a kiszolgálón lévő felhasználók közti megosztások és a föderált megosztások is.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Engedélyezze a kiszolgálón lévő felhasználóknak, hogy megosztásokat küldjenek más kiszolgálóknak (ez a lehetőség lehetővé teszi a nyilvános megosztások WebDAV hozzáférését is)",
-    "Allow users on this server to receive shares from other servers" : "Engedélyezze ezen kiszolgáló felhasználóinak, hogy megosztásokat fogadjanak más kiszolgálóktól",
-    "Allow users on this server to send shares to groups on other servers" : "Engedélyezze ezen kiszolgáló felhasználóinak, hogy megosztásokat küldjenek más kiszolgálók csoportjainak",
-    "Allow users on this server to receive group shares from other servers" : "Engedélyezi ezen kiszolgáló felhasználóinak, hogy csoportmegosztásokat fogadjanak más kiszolgálóktól",
-    "Search global and public address book for users" : "Felhasználók keresése a globális és a nyilvános címjegyzékben",
-    "Allow users to publish their data to a global and public address book" : "A felhasználók közzétehetik az adataikat a globális és nyilvános címjegyzékben",
     "Unable to update federated files sharing config" : "A föderált fájlmegosztási konfiguráció nem frissíthető",
     "Federated Cloud" : "Föderált felhő",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Bármelyik Nextcloud-kiszolgálót vagy egyéb Open Cloud Mesh-kompatibilis (OCM) kiszolgálót és szolgáltatást használó felhasználóval megoszthatja adatait. Csak tegye a föderált felhőazonosítóját a megosztási párbeszédablakba. Hasonlóan néz ki: person@cloud.example.com",
@@ -52,13 +43,14 @@ OC.L10N.register(
     "Copy to clipboard" : "Másolás a vágólapra",
     "Clipboard is not available" : "A vágólap nem érhető el",
     "Copied!" : "Másolva!",
-    "Copy" : "Másolás",
-    "Not supported!" : "Nem támogatott!",
-    "Press ⌘-C to copy." : "A másoláshoz nyomjon ⌘-C-t.",
-    "Press Ctrl-C to copy." : "A másoláshoz nyomjon Ctrl-C-t.",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "A(z) „%3$s” fogadva távoli megosztásként innen: %4$s (%1$s) (%5$s nevében (%2$s))",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Kapott egy távoli megosztást: „%3$s”, innen: %4$s (%1$s)",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Ossza meg velem a #Nextcloud föderált felhőazonosítóm segítségével, lásd %s",
-    "Open documentation" : "Dokumentáció megnyitása"
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "A(z) %1$s megosztása sikertelen, mert már meg van osztva %2$s felhasználóval",
+    "Not allowed to create a federated share with the same user" : "Azonos felhasználóval nem lehet föderált megosztást létrehozni",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Állítsa be, hogy az emberek hogyan oszthatnak meg kiszolgálók között. Ebbe beleértendők a kiszolgálón lévő felhasználók közti megosztások és a föderált megosztások is.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Engedélyezze a kiszolgálón lévő felhasználóknak, hogy megosztásokat küldjenek más kiszolgálóknak (ez a lehetőség lehetővé teszi a nyilvános megosztások WebDAV hozzáférését is)",
+    "Allow users on this server to receive shares from other servers" : "Engedélyezze ezen kiszolgáló felhasználóinak, hogy megosztásokat fogadjanak más kiszolgálóktól",
+    "Allow users on this server to send shares to groups on other servers" : "Engedélyezze ezen kiszolgáló felhasználóinak, hogy megosztásokat küldjenek más kiszolgálók csoportjainak",
+    "Allow users on this server to receive group shares from other servers" : "Engedélyezi ezen kiszolgáló felhasználóinak, hogy csoportmegosztásokat fogadjanak más kiszolgálóktól",
+    "Search global and public address book for users" : "Felhasználók keresése a globális és a nyilvános címjegyzékben",
+    "Allow users to publish their data to a global and public address book" : "A felhasználók közzétehetik az adataikat a globális és nyilvános címjegyzékben"
 },
 "nplurals=2; plural=(n != 1);");
