@@ -13,8 +13,6 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Испратено е барање за федерално споделување, ќе добиете покана. Проверете ги известувањата.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Неможе да се воспостави федерално споделување, изгледа дека Федералноиот сервер има премногу стара верзија (<= 9).",
     "It is not allowed to send federated group shares from this server." : "Не е овозможено да испратите федерално групно споделување од овој сервер.",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Споделувањето на %1$s е неуспешно, бидејќи истото веќе е споделено со корисникот %2$s",
-    "Not allowed to create a federated share with the same user" : "Не е овозможено да креирате федерално споделување со ист корисник",
     "Federated shares require read permissions" : "Федералното споделување бара дозволи за читање",
     "File is already shared with %s" : "Датотеката е веќе споделена со %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Споделувањето на %1$s е неуспешно, неможе да се пронајде %2$s, можеби серверот моментално не е достапен или користи недоверлив сертификат.",
@@ -28,13 +26,6 @@ OC.L10N.register(
     "Sharing" : "Споделување",
     "Federated file sharing" : "Федерално споделување на датотеки",
     "Provide federated file sharing across servers" : "Обезбедете федерално споделување на датотеки помеѓу сервери",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Прилагодете како луѓето можат да споделуваат помеѓу серверите. Ова ги вклучува споделувањата помеѓу корисниците на овој сервер, како и доколку користат федерално споделување.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволи им на корисниците на овој сервер да испраќаат споделувања со други сервери (оваа можност истотака дозволува WebDAV пристап до јавни споделувања)",
-    "Allow users on this server to receive shares from other servers" : "Дозволи им на корисниците на овој сервер да примаат споделувања од други сервери",
-    "Allow users on this server to send shares to groups on other servers" : "Дозволи им на корисниците на овој сервер да испраќаат споделувања со групи на други сервери",
-    "Allow users on this server to receive group shares from other servers" : "Дозволи им на корисниците на овој сервер да примаат споделувања од групи од други сервери",
-    "Search global and public address book for users" : "Пребарајте го глобалниот и јавниот именик на корисници",
-    "Allow users to publish their data to a global and public address book" : "Дозволи им на корисниците да објавуваат информации во глобалниот и јавниот именик ",
     "Unable to update federated files sharing config" : "Неможе да се ажурираат параметрите за федерално споделување",
     "Federated Cloud" : "Федерален клауд",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Можете да споделувате со секој што користи Nextcloud сервер или друг вид на Open Cloud Mesh (OCM) компатибилен сервер или сервис! Само внесете го федералниот ID во полето за споделување. Треба да изгледа korisnik@cloud.primer.com",
@@ -51,6 +42,15 @@ OC.L10N.register(
     "Cloud ID copied to the clipboard" : "Cloud ID е копиран во клипборд",
     "Copy to clipboard" : "Копирај во клипборд",
     "Clipboard is not available" : "Клипбордот не е достапен",
-    "Copied!" : "Копирано!"
+    "Copied!" : "Копирано!",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Споделувањето на %1$s е неуспешно, бидејќи истото веќе е споделено со корисникот %2$s",
+    "Not allowed to create a federated share with the same user" : "Не е овозможено да креирате федерално споделување со ист корисник",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Прилагодете како луѓето можат да споделуваат помеѓу серверите. Ова ги вклучува споделувањата помеѓу корисниците на овој сервер, како и доколку користат федерално споделување.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Дозволи им на корисниците на овој сервер да испраќаат споделувања со други сервери (оваа можност истотака дозволува WebDAV пристап до јавни споделувања)",
+    "Allow users on this server to receive shares from other servers" : "Дозволи им на корисниците на овој сервер да примаат споделувања од други сервери",
+    "Allow users on this server to send shares to groups on other servers" : "Дозволи им на корисниците на овој сервер да испраќаат споделувања со групи на други сервери",
+    "Allow users on this server to receive group shares from other servers" : "Дозволи им на корисниците на овој сервер да примаат споделувања од групи од други сервери",
+    "Search global and public address book for users" : "Пребарајте го глобалниот и јавниот именик на корисници",
+    "Allow users to publish their data to a global and public address book" : "Дозволи им на корисниците да објавуваат информации во глобалниот и јавниот именик "
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
