@@ -13,8 +13,6 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "De gefedereerde share aanvraag is verzonden, je ontvangt een uitnodiging. Controleer je meldingen.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Kon geen gefedereerde share tot stand brengen, waarschijnlijk was de federatieserver te oud (Nextcloud <=9).",
     "It is not allowed to send federated group shares from this server." : "Het is niet toegestaan om gefedereerde groepsshares vanaf deze server te versturen.",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Delen van %1$s is mislukt omdat het object al wordt gedeeld met gebruiker %2$s",
-    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
     "Federated shares require read permissions" : "Gefedereerde shares vereisen leesmachtiging",
     "File is already shared with %s" : "Bestand is al gedeeld met %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Delen van %1$s mislukt, kon %2$s niet vinden, misschien is de server niet bereikbaar of je gebruikt een zelf-ondertekend certificaat.",
@@ -28,13 +26,6 @@ OC.L10N.register(
     "Sharing" : "Delen",
     "Federated file sharing" : "Gefedereerd delen",
     "Provide federated file sharing across servers" : "Voorzien in gefedereerd delen van bestanden over verschillende servers",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Pas aan hoe mensen kunnen delen tussen servers. Dit omvat ook shares tussen gebruikers op deze server als ze federatief delen gebruiken.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Sta gebruikers toe om op deze server shares naar andere servers te sturen (deze optie staat ook WebDAV toegang toe tot openbare shares).",
-    "Allow users on this server to receive shares from other servers" : "Toestaan dat gebruikers op deze server shares ontvangen van andere servers",
-    "Allow users on this server to send shares to groups on other servers" : "Sta gebruikers op deze server toe om shares naar groepen op andere servers te delen",
-    "Allow users on this server to receive group shares from other servers" : "Sta gebruikers op deze server toe om shares van groepen op andere servers te ontvangen",
-    "Search global and public address book for users" : "Doorzoeken van openbare adresboeken voor gebruikers",
-    "Allow users to publish their data to a global and public address book" : "Publiek maken van data met een openbaar adresboek toestaan",
     "Federated Cloud" : "Gefedereerde Cloud",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Je kunt met iedereen delen die Nextcloud, ownCloud of een ander Open Cloud Mesh (OCM) compatible server of services gebruikt! Gebruik simpelweg hun gefedereerde Cloud ID in de deel-dialoog. Het ziet eruit als iemand@cloud.voorbeeld.com",
     "Your Federated Cloud ID:" : "Je gefedereerde Cloud ID:",
@@ -48,8 +39,14 @@ OC.L10N.register(
     "Share with me through my #Nextcloud Federated Cloud ID" : "Deel met mij via mijn #Nextcloud gefedereerde Cloud ID",
     "Copy to clipboard" : "Kopiëren naar het klembord",
     "Copied!" : "Gekopieerd!",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Je ontving  \"%3$s\" als een externe deellink van %4$s (%1$s) (namens %5$s (%2$s))",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Je ontving \"%3$s\" als een externe deellink van %4$s (%1$s)",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Deel met mij via mijn #Nextcloud gefedereerde Cloud ID, zie %s"
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Delen van %1$s is mislukt omdat het object al wordt gedeeld met gebruiker %2$s",
+    "Not allowed to create a federated share with the same user" : "Het is niet toegestaan om een gefedereerde share met dezelfde gebruikersserver te maken",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Pas aan hoe mensen kunnen delen tussen servers. Dit omvat ook shares tussen gebruikers op deze server als ze federatief delen gebruiken.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Sta gebruikers toe om op deze server shares naar andere servers te sturen (deze optie staat ook WebDAV toegang toe tot openbare shares).",
+    "Allow users on this server to receive shares from other servers" : "Toestaan dat gebruikers op deze server shares ontvangen van andere servers",
+    "Allow users on this server to send shares to groups on other servers" : "Sta gebruikers op deze server toe om shares naar groepen op andere servers te delen",
+    "Allow users on this server to receive group shares from other servers" : "Sta gebruikers op deze server toe om shares van groepen op andere servers te ontvangen",
+    "Search global and public address book for users" : "Doorzoeken van openbare adresboeken voor gebruikers",
+    "Allow users to publish their data to a global and public address book" : "Publiek maken van data met een openbaar adresboek toestaan"
 },
 "nplurals=2; plural=(n != 1);");
