@@ -13,8 +13,7 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Запрос межсерверного общего доступа оправлен, вы получите приглашение. Проверьте свои уведомления.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Не удалось установить межсерверный общий доступ, на другом сервере установлена устаревшая версия Nextcloud (версия 9.x или более ранняя).",
     "It is not allowed to send federated group shares from this server." : "Не допускается предоставление межсерверного общего доступа группам пользователей.",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Не удалось предоставить доступ к %1$s, так как этот ресурс уже доступен пользователю %2$s",
-    "Not allowed to create a federated share with the same user" : "Не допускается создание межсерверного общего ресурса с тем же пользователем",
+    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "Не удалось предоставить доступ к %1$s, так как этот ресурс уже доступен пользователю %2$s",
     "Federated shares require read permissions" : "Для федеративных ресурсов требуются разрешения на чтение",
     "File is already shared with %s" : "Доступ к файлу уже предоставлен %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Не удалось предоставить доступ к «%1$s», не удалось найти %2$s. Возможно, сервер недоступен или использует самоподписанный сертификат.",
@@ -28,13 +27,13 @@ OC.L10N.register(
     "Sharing" : "Общий доступ",
     "Federated file sharing" : "Межсерверный обмен файлами",
     "Provide federated file sharing across servers" : "Приложение позволяет использовать межсерверный обмен файлами",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Настройте, как люди могут делиться между серверами. Сюда входят и общие ресурсы между пользователями на этом сервере, если они используют федеративное совместное использование.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Разрешить пользователям на этом сервере отправлять общие ресурсы на другие серверы (этот параметр также разрешает доступ WebDAV к общим папкам)",
-    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям получать общие ресурсы с других серверов",
-    "Allow users on this server to send shares to groups on other servers" : "Разрешить предоставлять общий доступ для групп пользователей других серверов",
-    "Allow users on this server to receive group shares from other servers" : "Разрешить принимать общий доступ, предоставляемый с другого сервера группе пользователей",
-    "Search global and public address book for users" : "Искать пользователей в глобальной и открытой адресной книге",
-    "Allow users to publish their data to a global and public address book" : "Разрешить пользователям публиковать свои данные в глобальной и общедоступной адресной книге",
+    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Настройте, как пользователи могут публиковать ресурсы между разными серверами. Сюда входят и общие ресурсы между пользователями на этом сервере, если они используют федеративное совместное использование.",
+    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Разрешить пользователям на этом сервере публиковать общие ресурсы на других серверах (этот параметр также разрешает доступ WebDAV к общим папкам)",
+    "Allow people on this server to receive shares from other servers" : "Разрешить пользователям этого сервера принимать общие ресурсы с других серверов",
+    "Allow people on this server to send shares to groups on other servers" : "Разрешить пользователям этого сервера предоставлять общий доступ  группам пользователей других серверов",
+    "Allow people on this server to receive group shares from other servers" : "Разрешить пользователям этого сервера принимать общие ресурсы с других серверов, опубликованные для групп пользователей",
+    "Search global and public address book for people" : "Искать пользователей в глобальной и открытой адресной книге",
+    "Allow people to publish their data to a global and public address book" : "Разрешить пользователям этого сервера публиковать свои данные в глобальной и общедоступной адресной книге",
     "Unable to update federated files sharing config" : "Невозможно обновить конфигурацию общего доступа к федеративным файлам",
     "Federated Cloud" : "Федерация облачных хранилищ",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Вы можете предоставить общий доступ любому пользователю Nextcloud или других серверов и сервисов, совместимых с Open Cloud Mesh (OCM)! Просто введите его идентификатор федеративного облачного хранилища в диалоге предоставления общего доступа. Идентификатор указывается в виде «person@cloud.example.com».",
@@ -52,8 +51,14 @@ OC.L10N.register(
     "Copy to clipboard" : "Копировать в буфер",
     "Clipboard is not available" : "Буфер обмена недоступен",
     "Copied!" : "Скопировано!",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "Вам предоставлен общий доступ к ресурсу «%3$s»  расположенному на сервере %4$s (%1$s) (от лица %5$s (%2$s))",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "Вам предоставлен доступ к «%3$s» в качестве удалённого ресурса из %4$s (%1$s)",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Поделитесь со мной через мой #Nextcloud ID в федерации облачных хранилищ, смотрите %s"
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Не удалось предоставить доступ к %1$s, так как этот ресурс уже доступен пользователю %2$s",
+    "Not allowed to create a federated share with the same user" : "Не допускается создание межсерверного общего ресурса с тем же пользователем",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Настройте, как люди могут делиться между серверами. Сюда входят и общие ресурсы между пользователями на этом сервере, если они используют федеративное совместное использование.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Разрешить пользователям на этом сервере отправлять общие ресурсы на другие серверы (этот параметр также разрешает доступ WebDAV к общим папкам)",
+    "Allow users on this server to receive shares from other servers" : "Разрешить пользователям получать общие ресурсы с других серверов",
+    "Allow users on this server to send shares to groups on other servers" : "Разрешить предоставлять общий доступ для групп пользователей других серверов",
+    "Allow users on this server to receive group shares from other servers" : "Разрешить принимать общий доступ, предоставляемый с другого сервера группе пользователей",
+    "Search global and public address book for users" : "Искать пользователей в глобальной и открытой адресной книге",
+    "Allow users to publish their data to a global and public address book" : "Разрешить пользователям публиковать свои данные в глобальной и общедоступной адресной книге"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
