@@ -13,8 +13,6 @@ OC.L10N.register(
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Požiadavka na združené zdieľanie bola odoslaná, obdržíte pozvánku. Skontrolujte oznámenia.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Nepodarilo sa nadviazať združené zdieľanie, pravdepodobne je verzia servera s ktorým chcete zdieľať príliš zastaraná (Nextcloud <= 9).",
     "It is not allowed to send federated group shares from this server." : "Z tohto servera nie je povolené odosielať združené sprístupnenia.",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Zdieľanie %1$s zlyhalo, táto položka už je zdieľaná s užívateľom %2$s ",
-    "Not allowed to create a federated share with the same user" : "Nie je možné vytvoriť združené sprístupnenie so sebou samým",
     "Federated shares require read permissions" : "Združené zdieľanie vyžaduje práva na čítanie",
     "File is already shared with %s" : "Súbor je už sprístupnený používateľovi %s",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Zdieľanie %1$s s zlyhalo, nepodarilo sa nájsť %2$s, možno je server momentálne nedostupný alebo používa certifikát s vlastným podpisom.",
@@ -28,13 +26,6 @@ OC.L10N.register(
     "Sharing" : "Sprístupnenie",
     "Federated file sharing" : "Združené sprístupňovanie súborov",
     "Provide federated file sharing across servers" : "Poskytnúť združené sprístupňovanie súborov naprieč servermi",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Upravte ako ľudia môžu zdieľať medzi servermi. Toto zahŕňa zdieľania medzi užívateľmi na tomto serveri ako aj používanie združeného zdieľania.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Povoliť používateľom z tohto servera sprístupňovať obsah na iných serveroch (to umožňuje WebDAV prístup k verejným zdieľaniam)",
-    "Allow users on this server to receive shares from other servers" : "Povoliť používateľom z tohto servera sprístupňovanie obsahu z iných serverov",
-    "Allow users on this server to send shares to groups on other servers" : "Povoliť používateľom na tomto serveri odosielať sprístupnenia skupinám na iné servery",
-    "Allow users on this server to receive group shares from other servers" : "Povoliť používateľom na tomto serveri prijímať sprístupnenia pre skupiny z iných serverov",
-    "Search global and public address book for users" : "Vyhľadávať používateľov v globálnom a verejnom adresári kontaktov",
-    "Allow users to publish their data to a global and public address book" : "Povoliť používateľom publikovanie ich dát do globálneho a verejného adresára",
     "Unable to update federated files sharing config" : "Nedá sa aktualizovať konfigurácia zdieľania združených súborov",
     "Federated Cloud" : "Združený cloud",
     "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Môžete zdieľať s kýmkoľvek, kto používa server Nextcloud alebo iné kompatibilné servery a služby Open Cloud Mesh (OCM)! Jednoducho vložte ich identifikátor združeného cloudu v dialógovom okne zdieľania. Má podobu osoba@cloud.priklad.com",
@@ -52,8 +43,14 @@ OC.L10N.register(
     "Copy to clipboard" : "Skopírovať do schránky",
     "Clipboard is not available" : "Schránka nie je prístupná",
     "Copied!" : "Skopírované!",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s) (on behalf of %5$s (%2$s))" : "\"%3$s\" ste dostali ako vzdialenú zdieľanú položku od %4$s (%1$s) (v mene %5$s (%2$s))",
-    "You received \"%3$s\" as a remote share from %4$s (%1$s)" : "\"%3$s\" ste dostali ako vzdialený zdieľaný súbor od %4$s (%1$s)",
-    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Sprístupnite mi obsah prostredníctvom môjho #identifikátora združeného identifikátora cloudu Nextcloud, viac na %s"
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Zdieľanie %1$s zlyhalo, táto položka už je zdieľaná s užívateľom %2$s ",
+    "Not allowed to create a federated share with the same user" : "Nie je možné vytvoriť združené sprístupnenie so sebou samým",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Upravte ako ľudia môžu zdieľať medzi servermi. Toto zahŕňa zdieľania medzi užívateľmi na tomto serveri ako aj používanie združeného zdieľania.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Povoliť používateľom z tohto servera sprístupňovať obsah na iných serveroch (to umožňuje WebDAV prístup k verejným zdieľaniam)",
+    "Allow users on this server to receive shares from other servers" : "Povoliť používateľom z tohto servera sprístupňovanie obsahu z iných serverov",
+    "Allow users on this server to send shares to groups on other servers" : "Povoliť používateľom na tomto serveri odosielať sprístupnenia skupinám na iné servery",
+    "Allow users on this server to receive group shares from other servers" : "Povoliť používateľom na tomto serveri prijímať sprístupnenia pre skupiny z iných serverov",
+    "Search global and public address book for users" : "Vyhľadávať používateľov v globálnom a verejnom adresári kontaktov",
+    "Allow users to publish their data to a global and public address book" : "Povoliť používateľom publikovanie ich dát do globálneho a verejného adresára"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
