@@ -6,15 +6,15 @@ OC.L10N.register(
     "Remote share password" : "Uzak paylaşım parolası",
     "Cancel" : "İptal",
     "Add remote share" : "Uzak paylaşım ekle",
-    "Invalid Federated Cloud ID" : "Birleşik bulut kodu geçersiz",
+    "Invalid Federated Cloud ID" : "Birleşik bulut kimliği geçersiz",
     "Server to server sharing is not enabled on this server" : "Bu sunucuda sunucudan sunucuya paylaşım etkin değil",
     "Couldn't establish a federated share." : "Birleşik bir paylaşım oluşturulamadı.",
     "Couldn't establish a federated share, maybe the password was wrong." : "Birleşik bir paylaşım oluşturulamadı. Parola yanlış olabilir.",
     "Federated Share request sent, you will receive an invitation. Check your notifications." : "Birleşik paylaşım isteği gönderildi. Bir çağrı alacaksınız. Bildirimlerinizi denetleyin.",
     "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Birleşik bir paylaşım oluşturulamadı. Birleşik çalışılacak sunucunun sürümü çok eski gibi görünüyor (Nextcloud <= 9).",
     "It is not allowed to send federated group shares from this server." : "Bu sunucudan birleşik grup paylaşımları gönderilemez",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "%1$s ögesi %2$s kullanıcısı ile zaten paylaşılmış olduğundan paylaşılamadı",
-    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşik paylaşım oluşturulamaz",
+    "Sharing %1$s failed, because this item is already shared with the account %2$s" : "%1$s paylaşılamadı. Bu öge zaten %2$s hesabı ile paylaşılmış",
+    "Not allowed to create a federated share to the same account" : "Aynı hesap ile bir birleşik paylaşım oluşturulamaz",
     "Federated shares require read permissions" : "Birleşik paylaşımlar için okuma izinleri gereklidir",
     "File is already shared with %s" : "Dosya %s ile zaten paylaşılmış",
     "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "%1$s paylaşılamadı. %2$s bulunamadı. Sunucuya erişilemiyor ya da sunucu kendinden imzalı bir güvenlik sertifikası kullanıyor olabilir.",
@@ -28,17 +28,17 @@ OC.L10N.register(
     "Sharing" : "Paylaşım",
     "Federated file sharing" : "Birleşik dosya paylaşımı",
     "Provide federated file sharing across servers" : "Sunucular arasında birleşik dosya paylaşımı yapılmasını sağlar",
-    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Kullanıcıların sunucular arasındaki paylaşım yöntemini ayarlayın. Bu yöntem, bu sunucuda bulunan ve birleşik paylaşım kullanan kullanıcılar arasındaki paylaşımları da belirler.",
-    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Bu sunucudaki kullanıcılar diğer sunuculara paylaşım gönderebilsin (herkese açık paylaşımlara WebDAV erişimi de sağlar)",
-    "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardan paylaşım alabilsin",
-    "Allow users on this server to send shares to groups on other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki gruplara paylaşım gönderebilsin",
-    "Allow users on this server to receive group shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki grup paylaşımlarını alabilsin",
-    "Search global and public address book for users" : "Genel ve herkese açık adres defterindeki kullanıcılar aranabilsin",
-    "Allow users to publish their data to a global and public address book" : "Kullanıcıların bilgilerini genel ve herkese açık bir adres defterinde paylaşabilsin",
+    "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Kişilerin sunucular arasındaki paylaşım yöntemini ayarlayın. Bu yöntem, bu sunucuda bulunan ve birleşik paylaşım kullanan kişiler arasındaki paylaşımları da belirler.",
+    "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Bu sunucudaki kişiler diğer sunuculara paylaşım gönderebilsin (herkese açık paylaşımlara WebDAV erişimi de sağlar)",
+    "Allow people on this server to receive shares from other servers" : "Bu sunucudaki kişiler diğer sunuculardan paylaşım alabilsin",
+    "Allow people on this server to send shares to groups on other servers" : "Bu sunucudaki kişiler diğer sunuculardaki gruplara paylaşım gönderebilsin",
+    "Allow people on this server to receive group shares from other servers" : "Bu sunucudaki kişiler diğer sunuculardaki grup paylaşımlarını alabilsin",
+    "Search global and public address book for people" : "Genel ve herkese açık adres defterindeki kişiler aranabilsin",
+    "Allow people to publish their data to a global and public address book" : "Kişiler bilgilerini genel ve herkese açık bir adres defterinde paylaşabilsin",
     "Unable to update federated files sharing config" : "Birleşik dosya paylaşımı yapılandırması güncellenemedi",
     "Federated Cloud" : "Birleşik bulut",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud ya da Open Cloud Mesh (OCM) ile uyumlu sunucu ve hizmetler ile paylaşım yapılabilir. Paylaşım penceresine person@cloud.example.com gibi Birleşik Bulut Kodunu yazmanız yeterlidir.",
-    "Your Federated Cloud ID:" : "Birleşik bulut kodunuz:",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Nextcloud ya da Open Cloud Mesh (OCM) ile uyumlu sunucu ve hizmetler ile paylaşım yapılabilir. Paylaşım penceresine person@cloud.example.com gibi birleşik bulut kimliğini yazmanız yeterlidir.",
+    "Your Federated Cloud ID:" : "Birleşik bulut kimliğiniz:",
     "Share it so your friends can share files with you:" : "Paylaşın, böylece arkadaşlarınız da sizinle dosya paylaşabilir:",
     "Facebook" : "Facebook",
     "Twitter" : "Twitter",
@@ -46,11 +46,20 @@ OC.L10N.register(
     "Add to your website" : "Sitenize ekleyin",
     "Share with me via Nextcloud" : "Benimle Nextcloud üzerinden paylaşın",
     "HTML Code:" : "HTML kodu:",
-    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "#Nextcloud Birleşik Bulut Kodum ile paylaş,  {url} adresine bakın",
-    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud birleşik bulut kodum üzerinden benimle paylaş",
-    "Cloud ID copied to the clipboard" : "Bulut kodu panoya kopyalandı",
+    "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "#Nextcloud birleşik bulut kimliğim ile paylaş,  {url} adresine bakın",
+    "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud birleşik bulut kimliğim üzerinden benimle paylaş",
+    "Cloud ID copied to the clipboard" : "Bulut kimliği panoya kopyalandı",
     "Copy to clipboard" : "Panoya kopyala",
     "Clipboard is not available" : "Pano kullanılamıyor",
-    "Copied!" : "Kopyalandı!"
+    "Copied!" : "Kopyalandı!",
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "%1$s ögesi %2$s kullanıcısı ile zaten paylaşılmış olduğundan paylaşılamadı",
+    "Not allowed to create a federated share with the same user" : "Aynı kullanıcı ile bir birleşik paylaşım oluşturulamaz",
+    "Adjust how people can share between servers. This includes shares between users on this server as well if they are using federated sharing." : "Kullanıcıların sunucular arasındaki paylaşım yöntemini ayarlayın. Bu yöntem, bu sunucuda bulunan ve birleşik paylaşım kullanan kullanıcılar arasındaki paylaşımları da belirler.",
+    "Allow users on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Bu sunucudaki kullanıcılar diğer sunuculara paylaşım gönderebilsin (herkese açık paylaşımlara WebDAV erişimi de sağlar)",
+    "Allow users on this server to receive shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardan paylaşım alabilsin",
+    "Allow users on this server to send shares to groups on other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki gruplara paylaşım gönderebilsin",
+    "Allow users on this server to receive group shares from other servers" : "Bu sunucudaki kullanıcılar diğer sunuculardaki grup paylaşımlarını alabilsin",
+    "Search global and public address book for users" : "Genel ve herkese açık adres defterindeki kullanıcılar aranabilsin",
+    "Allow users to publish their data to a global and public address book" : "Kullanıcıların bilgilerini genel ve herkese açık bir adres defterinde paylaşabilsin"
 },
 "nplurals=2; plural=(n > 1);");
