@@ -5,13 +5,13 @@ OC.L10N.register(
     "Server is already in the list of trusted servers." : "Serwer znajduje się już na liście zaufanych serwerów.",
     "No server to federate with found" : "Nie znaleziono federacyjnego serwera",
     "Could not add server" : "Nie można dodać serwera",
-    "Federation" : "Federacja",
-    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu użytkownika.",
-    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu użytkownika. Na przykład zostanie to użyte do automatycznego uzupełniania dla zewnętrznych użytkowników przy udostępnianiu federacyjnym.",
     "Trusted servers" : "Zaufane serwery",
-    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu użytkownika. Na przykład zostanie to użyte do automatycznego uzupełniania dla zewnętrznych użytkowników przy udostępnianiu federacyjnym. Nie jest konieczne dodawanie serwera jako serwera zaufanego w celu utworzenia udostępnienia federacyjnego.",
+    "Federation" : "Federacja",
     "+ Add trusted server" : "+ Dodaj zaufany serwer",
     "Trusted server" : "Zaufany serwer",
-    "Add" : "Dodaj"
+    "Add" : "Dodaj",
+    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu użytkownika.",
+    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu użytkownika. Na przykład zostanie to użyte do automatycznego uzupełniania dla zewnętrznych użytkowników przy udostępnianiu federacyjnym.",
+    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federacja umożliwia łączenie się z innymi zaufanymi serwerami w celu wymiany katalogu użytkownika. Na przykład zostanie to użyte do automatycznego uzupełniania dla zewnętrznych użytkowników przy udostępnianiu federacyjnym. Nie jest konieczne dodawanie serwera jako serwera zaufanego w celu utworzenia udostępnienia federacyjnego."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
