@@ -37,10 +37,10 @@ OC.L10N.register(
     "Set reminder" : "ضبط التذكير",
     "Edit locally" : "تعديل محليًا",
     "Open" : "افتح",
-    "Delete file" : "احذف الملف",
-    "Delete folder" : "حذف المجلد",
-    "Disconnect storage" : "قطع اتصال التخزين",
-    "Leave this share" : "مغادرة هذه المشاركة",
+    "_Delete file_::_Delete files_" : ["حذف ملفات","حذف ملف","حذف ملفات","حذف ملفات","حذف ملفات","حذف ملفات"],
+    "_Delete folder_::_Delete folders_" : ["حذف 0 مجلد","حذف مجلد واحد","حذف مجلدين","حذف مجلدات","حذف مجلدات","حذف مجلدات"],
+    "_Disconnect storage_::_Disconnect storages_" : ["فصل 0 وحدة تخزين","فصل وحدة تخزين واحدة","فصل وحدتيْ تخزين","فصل وحدات تخزين","فصل وحدات تخزين","فصل وحدات تخزين"],
+    "_Leave this share_::_Leave these shares_" : ["مغادرة 0 مشاركة","مغادرة هذه المشاركة","مغادرة هاتين المشاركتين","مغادرة هذه المشاركات","مغادرة هذه المشاركات","مغادرة هذه المشاركات"],
     "Could not load info for file \"{file}\"" : "لم يستطع تحميل معلومات الملف \"{file}\"",
     "Files" : "الملفات",
     "Details" : "التفاصيل",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "مساحة التخزين الخاصة بك شبه ممتلئة ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["تطابق \"{filter}\"","تطابق  \"{filter}\" ","تطابقان \"{filter}\"","تطابقات \"{filter}\"","تطابقات \"{filter}\"","تطابقات \"{filter}\""],
     "View in folder" : "اعرض في المجلد",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "تم نسخ الرابط المباشر (تعمل فقط بالنسبة للمستخدمين الذين يملكون تخويلاً بالوصول إلى هذا الملف أو المجلد)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "تم نسخ الرابط المباشر (يعمل فقط للأشخاص الذين لديهم حق الوصول إلى هذا الملف/المجلد)",
     "Path" : "المسار",
     "_%n byte_::_%n bytes_" : ["بايت","بايت","بايت","بايت","بايت","%n بايت"],
     "Favorited" : "المفضلة",
     "Favorite" : "المفضلة",
-    "Copy direct link (only works for users who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للمستخدمين الذين يمكنهم الوصول الى هذا الملف/المجلد)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للأشخاص الذين لديهم حق الوصول إلى هذا الملف/المجلد)",
     "New folder" : "مجلد جديد",
     "Create new folder" : "إنشاء مجلدا جديد",
     "Upload file" : "رفع ملف",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "استعادة من قبل {user}",
     "Renamed by {user}" : "اعادة تسمية من قبل {user}",
     "Moved by {user}" : "نقل من قبل {user}",
-    "\"remote user\"" : "\"مستخدم عن بعد\"",
+    "\"remote account\"" : "\"حساب قصِي remote account\"",
     "You created {file}" : "أنشأتَ {file}",
     "You created an encrypted file in {file}" : "أنت انشأت ملف مشفر في {file}",
     "{user} created {file}" : "{user} انشاء ملف {file}",
@@ -175,7 +175,8 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "إسحَب و أفلِت الملفات هنا لرفعها",
     "Your have used your space quota and cannot upload files anymore" : "لقد استنفذت حصتك التخزينية و لم يعد بإمكانك رفع أي ملفات بعدُ",
     "You don’t have permission to upload or create files here" : "لا تملك الصلاحية لرفع او انشاء ملف هنا ",
-    "Upload successful" : "تمّ الرفع بنجاحٍ",
+    "Some files could not be uploaded" : "بعض الملفات لم يمكن رفعها",
+    "Files uploaded successfully" : "تمّ رفع الملفات بنجاحٍ",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" الأمر نُفّذ بنجاح",
     "\"{displayName}\" action failed" : "\"{dispalyName}\" الأمر أخفق عند التنفيذ",
     "Toggle selection for file \"{displayName}\"" : "تبديل الاختيار للملف \"{displayName}\"",
@@ -194,8 +195,6 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "تعذر إعادة تسمية \"{oldName}\"، لم يعد موجودًا",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "الاسم \"{newName}\" مُستعمَلٌ سلفاً في المجلّد\"{dir}\". إختَر اسماً آخر رجاءً.",
     "Could not rename \"{oldName}\"" : "تعذرت إعادة تسمية \"{oldName}\"",
-    "Could not copy {file}. {message}" : "تعذّر نسخ {file}. {message}",
-    "Could not move {file}. {message}" : "تعذّر نقل {file}. {message}",
     "Total rows summary" : "ملخص مجموع الأسطر",
     "Toggle selection for all files and folders" : "تبديل الاختيار لكل الملفات و المجلدات",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" فشل في بعض العناصر",
@@ -209,6 +208,8 @@ OC.L10N.register(
     "{relative}% used" : "{relative}% مستخدمة",
     "Could not refresh storage stats" : "تعذر تحديث حالة التخزين",
     "Your storage is full, files can not be updated or synced anymore!" : "مساحتك التخزينية ممتلئة, لا يمكن تحديث ملفاتك أو مزامنتها بعد الآن !",
+    "Create" : "إنشاء",
+    "A file or folder with that name already exists." : "ملف أو مجلد بنفس هذا الاسم موجود سلفاً",
     "Transfer ownership of a file or folder" : "تحويل ملكية ملف أو مجلد",
     "Choose file or folder to transfer" : "اختر ملف او مجلد لنقل الملكية",
     "Change" : "تغير",
@@ -223,7 +224,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "اختر ملف أو مجلد للربط معه",
     "Choose file" : "إختَر ملفاً",
     "Choose {file}" : "إختَر {file}",
-    "Add" : "أضِف",
     "Loading current folder" : "تحميل المجلد الحالي",
     "No files in here" : "لا يوجد ملفات هنا ",
     "Upload some content or sync with your devices!" : "ارفع بعض المحتوي او زامن مع اجهزتك !",
@@ -240,8 +240,9 @@ OC.L10N.register(
     "Open the files app settings" : "إفتح إعدادات تطبيق الملفات",
     "Files settings" : "إعدادات الملفات",
     "File cannot be accessed" : "الملف لم يمكن الوصول إليه",
-    "You might not have have permissions to view it, ask the sender to share it" : "يمكن ألاّ تكون لديك صلاحية لعرضه، أطلب من المُرسل إن يشاركه معك",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "إمّا أن الملف غير موجود أو أنك لا تمتلك الصلاحية لعرضه. أُطلُب من المُرسل أن يتشاركه معك.",
     "Sort favorites first" : "فرز المفضلات أولا",
+    "Sort folders before files" : "فرز المجلدات قبل الملفات",
     "Show hidden files" : "عرض الملفات المخفية",
     "Crop image previews" : "اقتصاص صورة العروض",
     "Enable the grid view" : "تمكين المنظور الصندوقي",
@@ -256,33 +257,41 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "لم نستطع تغير الحالة المفضلة للملف",
     "Error while loading the file data" : "خطأ اثناء تحميل بيانات الملف",
     "Pick a template for {name}" : "اختر قالبا لـ {name}",
-    "Create" : "إنشاء",
     "Create a new file with the selected template" : "إنشاء ملف جديد بإستخدام القالب المحدد",
     "Creating file" : "إنشاء ملف",
     "Blank" : "فارغ",
     "Unable to create new file from template" : "تعذر إنشاء الملف الجديد من القالب",
-    "Delete and unshare" : "إحذِف و الغٍ المشاركات ",
-    "Unshare" : "إلغاء المُشارَكة",
     "Delete permanently" : "حذف بشكل دائم",
+    "Delete and unshare" : "إحذِف و الغٍ المشاركات ",
+    "You are about to delete {count} items." : "أنت على وشك حذف {count} عنصر.",
+    "Confirm deletion" : "أكِّد على الحذف",
+    "Cancel" : "الغاء",
+    "Deletion cancelled" : "تمّ إلغاء الحذف",
     "Destination is not a folder" : "المَقصَد ليس مُجلّداً",
     "This file/folder is already in that directory" : "هذا الملف/المجلد موجود سلفاً في ذلك المجلد",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "لا يمكنك نقل ملف/مجلد إلى نفسه أو إلى مجلد فرعي منه",
     "(copy)" : "(نسخ)",
     "(copy %n)" : "(نسخ %n)",
+    "Move cancelled" : "تمّ إلغاء النقل",
     "A file or folder with that name already exists in this folder" : "ملف أو مجلد بنفس ذاك الاسم موجود سلفاً في هذا المجلد",
-    "The files is locked" : "الملفات مقفله",
     "The file does not exist anymore" : "الملف لم يعد موجوداً",
     "Choose destination" : "إختَر المَقصِد",
     "Copy to {target}" : "أُنسُخ إلى {target}",
     "Move to {target}" : "أُنقُل إلى {target}",
     "Cancelled move or copy operation" : ".عملية النسخ أو النقل تمّ إلغاؤها",
+    "Move or copy operation failed" : "عملية النسخ أو النقل أخفقت",
     "Open folder {displayName}" : "إفتح المجلد {displayName}",
     "Open in Files" : "إفتَح في \"الملفات\"",
     "Open details" : "افتح التفاصيل",
+    "An error occurred while uploading. Please try again later." : "حدث خطأ أثناء الرفع. يُرجى المحاولة مرة أخرى في وقت لاحق.",
+    "Could not copy {file}. {message}" : "تعذّر نسخ {file}. {message}",
+    "Could not move {file}. {message}" : "تعذّر نقل {file}. {message}",
+    "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
+    "Filename" : "اسم الملف",
+    "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
     "Create new templates folder" : "إنشيْ مجلد جديد للقوالب",
     "Templates" : "القوالب",
-    "Unable to initialize the templates directory" : "تعذر تهيئة دليل القوالب",
-    "Created new folder \"{name}\"" : "تمّ إنشاء مجلد جديد باسم \"{name}\"",
+    "New template folder" : "مجلد القوالب الجديد",
     "One of the dropped files could not be processed" : "أحد الملفات المُفلَتة لا يمكن معالجته",
     "Uploading \"{filename}\" failed" : "فشل في تحديث \"{filename}\" ",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} مجلد","{folderCount} مجلد","{folderCount} مجلدان","{folderCount} مجلد","{folderCount} مجلدات","{folderCount} مجلدات"],
@@ -295,20 +304,27 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "الملفات والمجلدات التي حددتها كامفضلة سوف تظهر هنا ",
     "All files" : "كل الملفات",
     "List of your files and folders." : "قائمة بملفاتك و مجلداتك",
+    "Personal Files" : "ملفات شخصية",
+    "List of your files and folders that are not shared." : "قائمة بالملفات و المجلدات التي لم تتم مشاركتها.",
+    "No personal files found" : "لا توجد أي ملفات شخصية",
+    "Files that are not shared will show up here." : "الملفات التي لم تتم مشاركتها ستُعرض هنا",
     "List of recently modified files and folders." : "قائمة بالملفات و المجلدات التي تمّ تعديلها مؤخراً.",
     "No recently modified files" : "لا توجد أيّ ملفات تمّ تعديلها مؤخراً",
     "Files and folders you recently modified will show up here." : "الملفات و المجلدات التي تمّ تعديلها مؤخراً ستظهر هنا.",
-    "Toggle %1$s sublist" : "تبديل %1$s قائمة فرعية",
     "No entries found in this folder" : "لا يوجد مدخلات في هذا المجلد ",
     "Select all" : "تحديد الكل ",
     "Upload too large" : "حجم الترفيع أعلى من المسموح",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "حجم الملفات التي تريد ترفيعها أعلى من المسموح على الخادم.",
     "Text file" : "ملف نصي",
     "New text file.txt" : "ملف نصي جديد fille.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "تم نسخ الرابط المباشر (تعمل فقط بالنسبة للمستخدمين الذين يملكون تخويلاً بالوصول إلى هذا الملف أو المجلد)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "نسخ الرابط المباشر (يعمل فقط للمستخدمين الذين يمكنهم الوصول الى هذا الملف/المجلد)",
     "You can only favorite a single file or folder at a time" : "يمكنك فقط تفضيل ملف أو مجلد واحد في المرة الواحدة",
+    "\"remote user\"" : "\"مستخدم عن بعد\"",
     "Search users" : "ابحث عن مستخدمين",
-    "Cancel" : "الغاء",
+    "You might not have have permissions to view it, ask the sender to share it" : "يمكن ألاّ تكون لديك صلاحية لعرضه، أطلب من المُرسل إن يشاركه معك",
     "Set up templates folder" : "إعداد مجلد القوالب",
+    "Toggle %1$s sublist" : "تبديل %1$s قائمة فرعية",
     "Toggle grid view" : "تفعيل/تعطيل القائمة",
     "Deleted files" : "الملفات المحذوفة",
     "Shares" : "التي قمتَ بمشاركتها",
@@ -327,6 +343,8 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "لم يمكن عرض هذه القائمة بالكامل بسبب إشكالية في الأداء. سيتم عرض الملفات عندما تمر عليها في القائمة",
     "Search for an account" : "البحث عن حساب",
     "Choose" : "إختَر",
-    "No files or folders have been deleted yet" : "لم يتم حذف أي ملفات أو مجلدات بعدُ"
+    "No files or folders have been deleted yet" : "لم يتم حذف أي ملفات أو مجلدات بعدُ",
+    "Add" : "أضِف",
+    "The files is locked" : "الملفات مقفله"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
