@@ -34,10 +34,7 @@ OC.L10N.register(
     "Choose target folder" : "Избор на папка",
     "Edit locally" : "Локално редактиране",
     "Open" : "Отвори",
-    "Delete file" : "Изтриване на файл",
-    "Delete folder" : "Изтриване на папка",
-    "Disconnect storage" : "Извади хранилището",
-    "Leave this share" : "Напускане на споделянето",
+    "_Delete file_::_Delete files_" : ["Изтриване на файлове","Изтриване на файлове"],
     "Could not load info for file \"{file}\"" : "Информацията за файла \"{file}\" не може да бъде заредена",
     "Files" : "Файлове",
     "Details" : "Подробности",
@@ -98,12 +95,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Вашето хранилище е почти запълнено ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["съвпада с \"{filter}\"","съвпада с \"{filter}\""],
     "View in folder" : "Преглед в папката",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Беше копирана директна връзка (ще работи само за потребители с достъп до този файл/папка)",
     "Path" : "Път",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байта"],
     "Favorited" : "Отбелязано в любими",
     "Favorite" : "Любими",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Копирай директната връзка (ще работи само за потребители с достъп до файла/папката)",
     "New folder" : "Нова папка",
     "Create new folder" : "Създай нова папка",
     "Upload file" : "Качи файл",
@@ -124,7 +119,6 @@ OC.L10N.register(
     "Restored by {user}" : "Възстановен от {user}",
     "Renamed by {user}" : "Преименуван от {user}",
     "Moved by {user}" : "Преместен от {user}",
-    "\"remote user\"" : "\"отдалечен потребител\"",
     "You created {file}" : "Създадохте {file}",
     "You created an encrypted file in {file}" : "Създадохте криптиран файл в {file}",
     "{user} created {file}" : "{user} създаде {file}",
@@ -168,16 +162,14 @@ OC.L10N.register(
     "File Management" : "Управление на файлове",
     "Reload current directory" : "Презареждане на текущата директория",
     "Go to the \"{dir}\" directory" : "Отидете в директорията \"{dir}\"",
+    "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
     "\"{displayName}\" action executed successfully" : "Действието „{displayName}“ е изпълнено успешно",
     "\"{displayName}\" action failed" : "Действието „{displayName}“ е неуспешно",
-    "Select the row for {displayName}" : "Избиране на реда за {displayName}",
     "File name" : "Име на файл",
     "Folder name" : "Име на папка",
     "Download file {name}" : "Изтегляне на файл {name}",
     "Name cannot be empty" : "Името не може да бъде празно",
     "Total rows summary" : "Обобщение на общия брой редове",
-    "Select all" : "Избери всички",
-    "Unselect all" : "Отмяна на избора на всички",
     "\"{displayName}\" failed on some elements " : "„{displayName}“ не успя да се изпълни за някои елементи ",
     "\"{displayName}\" batch action executed successfully" : " Пакетното действие „{displayName}“ е изпълнено успешно",
     "File not found" : "Файлът не е намерен",
@@ -185,6 +177,8 @@ OC.L10N.register(
     "{usedQuotaByte} used" : "{usedQuotaByte} използвано",
     "{relative}% used" : "{relative}% използвано",
     "Could not refresh storage stats" : "Статистиката за хранилище не можа да се обнови",
+    "Your storage is full, files can not be updated or synced anymore!" : "Хранилището е запълнено. Поради това качването и синхронизирането на файлове е невъзможно!",
+    "Create" : "Създаване",
     "Transfer ownership of a file or folder" : "Прехвърляне на собственост на файл или папка",
     "Choose file or folder to transfer" : "Избор на файл или папка за прехвърляне",
     "Change" : "Промени",
@@ -209,7 +203,6 @@ OC.L10N.register(
     "Open the files app settings" : "Отваряне на настройките на приложението за файлове",
     "Files settings" : "Настройки на файловете",
     "File cannot be accessed" : "Файлът не е достъпен",
-    "You might not have have permissions to view it, ask the sender to share it" : "Може да нямате права да го видите, помолете подателя да го сподели",
     "Show hidden files" : "Показвай и скрити файлове",
     "Crop image previews" : "Изрязване на визуализациите на изображение",
     "Additional settings" : "Допълнителни настройки",
@@ -222,34 +215,34 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Не може да се промени състоянието за предпочитане на файла",
     "Error while loading the file data" : "Грешка при зареждането на файловете.",
     "Pick a template for {name}" : "Избор на шаблон за {name}",
-    "Create" : "Създаване",
     "Create a new file with the selected template" : "Създаване на нов файл с избрания шаблон",
     "Creating file" : "Създаване на файл ",
     "Blank" : "Празен",
     "Unable to create new file from template" : "Не може да се създаде нов файл от шаблон",
     "Delete permanently" : "Изтрий завинаги",
+    "Cancel" : "Отказ",
     "Open details" : "Отваряне на подробности",
+    "Filename" : "Име на файла",
+    "Unable to initialize the templates directory" : "Неуспешно инициализиране на директорията с шаблони",
     "Create new templates folder" : "Създаване на нова папка за шаблони",
     "Templates" : "Шаблони",
-    "Unable to initialize the templates directory" : "Неуспешно инициализиране на директорията с шаблони",
     "No favorites yet" : "Няма любими",
     "Files and folders you mark as favorite will show up here" : "Файловете и папките които маркирате като любими ще се показват тук",
     "All files" : "Всички файлове",
-    "Toggle %1$s sublist" : "Превключване на %1$s подсписък ",
     "No entries found in this folder" : "Няма намерени записи в тази папка",
+    "Select all" : "Избери всички",
     "Upload too large" : "Прекалено голям файл за качване",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитвате да качите са по-големи от позволеното на сървъра.",
     "Text file" : "Текстов файл",
     "New text file.txt" : "Текстов файл.txt",
-    "Storage invalid" : "Невалидно хранилище",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Беше копирана директна връзка (ще работи само за потребители с достъп до този файл/папка)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Копирай директната връзка (ще работи само за потребители с достъп до файла/папката)",
     "You can only favorite a single file or folder at a time" : "Можете да предпочетете само един файл или папка наведнъж",
-    "Unlimited" : "Неограничено",
+    "\"remote user\"" : "\"отдалечен потребител\"",
     "Search users" : "Търсене за потребители",
-    "Cancel" : "Отказ",
+    "You might not have have permissions to view it, ask the sender to share it" : "Може да нямате права да го видите, помолете подателя да го сподели",
     "Set up templates folder" : "Настройка на папка за шаблони",
-    "%s used" : "%s използвани",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s от %2$s използвани",
+    "Toggle %1$s sublist" : "Превключване на %1$s подсписък ",
     "Toggle grid view" : "Превключи решетъчния изглед",
     "Deleted files" : "Изтрити файлове",
     "Shares" : "Споделени",
@@ -257,13 +250,16 @@ OC.L10N.register(
     "Shared with you" : "Споделени с вас",
     "Deleted shares" : "Изтрити",
     "Pending shares" : "Чакащи споделяния",
+    "Select the row for {displayName}" : "Избиране на реда за {displayName}",
     "Open folder {name}" : "Отваряне на папка {name}",
+    "Unselect all" : "Отмяна на избора на всички",
     "ascending" : "възходящо",
     "descending" : "низходящо",
     "Sort list by {column} ({direction})" : "Сортиране на списъка по  {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Този списък не е напълно рендиран поради причини, свързани с производителността. Файловете ще бъдат рендирани, докато навигирате из списъка.",
     "Search for an account" : "Търсене на профил",
     "Choose" : "Изберете",
-    "No files or folders have been deleted yet" : "Все още няма изтрити файлове или папки"
+    "No files or folders have been deleted yet" : "Все още няма изтрити файлове или папки",
+    "Add" : "Добавяне"
 },
 "nplurals=2; plural=(n != 1);");
