@@ -29,10 +29,6 @@ OC.L10N.register(
     "Copy" : "Eilañ",
     "Choose target folder" : "Dibab an teuliad moned",
     "Open" : "Digeriñ",
-    "Delete file" : "Dilemel ar restr",
-    "Delete folder" : "Dilemel an teuliad",
-    "Disconnect storage" : "Digevreañ ar skor stokañ-mañ",
-    "Leave this share" : "Laoskel ar rannadenn",
     "Could not load info for file \"{file}\"" : "Dibosupl eo kargañ titouroù ar restr \"{file}\"",
     "Files" : "Restroù",
     "Details" : "Munudoù",
@@ -82,7 +78,6 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["okted","okted","okted","okted","%n okted"],
     "Favorited" : "Lakaet evel pennroll",
     "Favorite" : "Pennrollañ",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Eilañ al liamm eeun (nemet evit an implijourien aotreet da dizhout ar restr-mañ pe an teuliad-mañ)",
     "New folder" : "Teuliad nevez",
     "Create new folder" : "Krouiñ un teuliad nevez",
     "Upload file" : "Pellgas ur restr",
@@ -103,7 +98,6 @@ OC.L10N.register(
     "Restored by {user}" : "Adsavet gant {user}",
     "Renamed by {user}" : "Adanvet gant {user}",
     "Moved by {user}" : "Dilec'hiet gant {user}",
-    "\"remote user\"" : "\"pell-implijer\"",
     "You created {file}" : "Krouet ho peus {file}",
     "You created an encrypted file in {file}" : "Ur restr sifret ho peus krouet e {file}",
     "{user} created {file}" : "{user} en.he deus krouet {file}",
@@ -142,6 +136,7 @@ OC.L10N.register(
     "You don’t have permission to upload or create files here" : "N'och ket aotreet kas pe krouiñ restroù amañ",
     "Folder name" : "Anv teuliad",
     "Your storage is full, files can not be updated or synced anymore!" : "Leun eo ho skor stokañ. Ne c'hall ket ar restroù bezañ na nevezet na kempredet ken !",
+    "Create" : "Krouiñ",
     "Transfer ownership of a file or folder" : "Treuzkas perc'henniezh ur restr pe un teuliad",
     "Choose file or folder to transfer" : "Dibabit ur restr pe un teuliad da dreuzkas",
     "Change" : "Cheñch",
@@ -162,9 +157,9 @@ OC.L10N.register(
     "Use this address to access your Files via WebDAV" : "Implijit ar chomlec'h-mañ evit tizhout ho restroù dre WebDAV",
     "Unable to change the favourite state of the file" : "Dibosupl eo cheñch stad pennroll ar restr",
     "Error while loading the file data" : "Ur fazi zo bet en ur gargañ roadennoùar restr",
-    "Create" : "Krouiñ",
-    "Unshare" : "Na eskemm ken",
     "Delete permanently" : "Lamet da viken",
+    "Cancel" : "Arrest",
+    "Filename" : "Anv restr",
     "No favorites yet" : "Pennroll ebet evit ar poent",
     "Files and folders you mark as favorite will show up here" : "Ar restroù ha teuliadoù ouzhpennet en ho pennrolloù a vo diskwelet amañ",
     "All files" : "An holl restroù",
@@ -174,9 +169,10 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Ar restroù a glaskit pellgas a ya dreist d'ar vent vrasañ aotreet gant ar servijer mañ.",
     "Text file" : "Restr testenn",
     "New text file.txt" : "Restr testenn nevez rest.txt",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Eilañ al liamm eeun (nemet evit an implijourien aotreet da dizhout ar restr-mañ pe an teuliad-mañ)",
     "You can only favorite a single file or folder at a time" : "Ne c'hallit ouzhpennañ nemet ur pennroll teuliad pe restr en un taol.",
+    "\"remote user\"" : "\"pell-implijer\"",
     "Search users" : "Klask implijourien",
-    "Cancel" : "Arrest",
     "Toggle grid view" : "Gweredekat/Diweredekat an diskwel roued",
     "Deleted files" : "Restroù dilemet",
     "Shares" : "Rannañ",
