@@ -37,10 +37,7 @@ OC.L10N.register(
     "Set reminder" : "Προσθήκη υπενθύμισης",
     "Edit locally" : "Επεξεργασία τοπικά",
     "Open" : "Άνοιγμα",
-    "Delete file" : "Διαγραφή αρχείου",
-    "Delete folder" : "Διαγραφή φακέλου",
-    "Disconnect storage" : "Αποσύνδεση αποθηκευτικού χώρου",
-    "Leave this share" : "Αποχωρήστε από αυτήν την κοινή χρήση",
+    "_Delete file_::_Delete files_" : ["Διαγραφή αρχείου","Διαγραφή αρχείων"],
     "Could not load info for file \"{file}\"" : "Αδυναμία φόρτωσης πληροφοριών για το αρχείο \"{file}\"",
     "Files" : "Αρχεία",
     "Details" : "Λεπτομέρειες",
@@ -101,12 +98,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός σας χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Ταιριάζει \"{filter}\"","Ταιριάζουν \"{filter}\""],
     "View in folder" : "Προβολή στον φάκελο",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Ο άμεσος σύνδεσμος αντιγράφηκε (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση σε αυτό το αρχείο/φάκελο)",
     "Path" : "Διαδρομή",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Αγαπημένα",
     "Favorite" : "Αγαπημένο",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση στο αρχείο/φάκελο)",
     "New folder" : "Νέος φάκελος",
     "Create new folder" : "Δημιουργία νέου φακέλου",
     "Upload file" : "Μεταφόρτωση αρχείου",
@@ -127,7 +122,6 @@ OC.L10N.register(
     "Restored by {user}" : "Επαναφέρθηκε από τον {user}",
     "Renamed by {user}" : "Μετονομάστηκε από τον {user}",
     "Moved by {user}" : "Μετακινήθηκε από τον {user}",
-    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
     "You created {file}" : "Δημιουργήσατε το {file}",
     "You created an encrypted file in {file}" : "Δημιουργήσατε ένα κρυπτογραφημένο αρχείο στο {file}",
     "{user} created {file}" : "Ο/η {user} δημιούργησε {file}",
@@ -171,15 +165,38 @@ OC.L10N.register(
     "File Management" : "Διαχείριση αρχείων",
     "Reload current directory" : "Επαναφόρτωση τρέχοντος καταλόγου",
     "Go to the \"{dir}\" directory" : "Μετάβαση στον κατάλογο \"{dir}\"",
+    "Drag and drop files here to upload" : "Σύρετε και αφήστε αρχεία εδώ για να τα μεταφορτώσετε",
+    "Your have used your space quota and cannot upload files anymore" : "Έχετε χρησιμοποιήσει το όριο χώρου σας και δεν μπορείτε να μεταφορτώσετε αρχεία πλέον",
+    "You don’t have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
+    "\"{displayName}\" action executed successfully" : "Η ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
+    "\"{displayName}\" action failed" : "Η ενέργεια του \"{displayName}\" απέτυχε",
     "Rename file" : "Μετονομασία αρχείου",
     "File name" : "Όνομα αρχείου",
     "Folder name" : "Όνομα φακέλου",
+    "This node is unavailable" : "Αυτός ο κόμβος δεν είναι διαθέσιμος",
     "Download file {name}" : "Λήψη αρχείου {name}",
+    "\"{name}\" is not an allowed filetype." : "Το \"{name}\" δεν είναι ένας επιτρεπόμενος τύπος αρχείου.",
+    "{newName} already exists." : "Το {newName} υπάρχει ήδη.",
+    "\"{char}\" is not allowed inside a file name." : "\"{char}\" δεν επιτρέπεται μέσα σε όνομα αρχείου.",
     "Name cannot be empty" : "Το όνομα δεν μπορεί να είναι κενό",
-    "A long time ago" : "Πριν αρκετό καιρό",
-    "Select all" : "Επιλογή όλων",
-    "Unselect all" : "Αποεπιλογή όλων",
+    "Another entry with the same name already exists" : "Υπάρχει ήδη μια άλλη καταχώρηση με το ίδιο όνομα",
+    "Renamed \"{oldName}\" to \"{newName}\"" : "Μετονομασία του \"{oldName}\" σε \"{newName}\"",
+    "Could not rename \"{oldName}\", it does not exist any more" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\", δεν υπάρχει πλέον",
+    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Το όνομα \"{newName}\" χρησιμοποιείται ήδη στον φάκελο \"{dir}\". Παρακαλώ επιλέξτε ένα διαφορετικό όνομα.",
+    "Could not rename \"{oldName}\"" : "Δεν ήταν δυνατή η μετονομασία του \"{oldName}\"",
+    "Total rows summary" : "Συνολική σύνοψη γραμμών",
+    "\"{displayName}\" failed on some elements " : "\"{displayName}\" απέτυχε σε ορισμένα στοιχεία",
+    "\"{displayName}\" batch action executed successfully" : "Η μαζική ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
+    "List of files and folders." : "Λίστα αρχείων και φακέλων.",
+    "Column headers with buttons are sortable." : "Οι επικεφαλίδες στηλών με κουμπιά είναι ταξινομήσιμες.",
+    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Η λίστα αυτή δεν εμφανίζεται πλήρως για λόγους απόδοσης. Τα αρχεία θα εμφανίζονται καθώς πλοηγείστε στη λίστα.",
     "File not found" : "Δε βρέθηκε το αρχείο",
+    "Storage informations" : "Πληροφορίες αποθήκευσης",
+    "{usedQuotaByte} used" : "{usedQuotaByte} χρησιμοποιείται",
+    "{relative}% used" : "{relative}% χρησιμοποιείται",
+    "Could not refresh storage stats" : "Δεν ήταν δυνατή η ανανέωση των στατιστικών αποθήκευσης",
+    "Your storage is full, files can not be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι γεμάτος, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πια!",
+    "Create" : "Δημιουργία",
     "Transfer ownership of a file or folder" : "Μεταβίβαση κυριότητας αρχείου ή φακέλου",
     "Choose file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
     "Change" : "Αλλαγή",
@@ -192,6 +209,8 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Αποστολή αίτησης μεταβίβασης κυριότητας",
     "Cannot transfer ownership of a file or folder you do not own" : "Δεν είναι δυνατή η μεταβίβαση της κυριότητας ενός αρχείου ή φακέλου που δε σας ανήκει",
     "Select file or folder to link to" : "Επιλέξτε αρχείο ή φάκελο για σύνδεση",
+    "Choose file" : "Επιλέξτε αρχείο",
+    "Choose {file}" : "Επιλέξτε {file}",
     "Loading current folder" : "Φόρτωση τρέχοντος φακέλου",
     "No files in here" : "Δεν υπάρχουν αρχεία εδώ",
     "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
@@ -201,52 +220,78 @@ OC.L10N.register(
     "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
     "Shared" : "Κοινόχρηστα",
     "Switch to list view" : "Αλλαγή σε προβολή λίστας",
+    "Switch to grid view" : "Εναλλαγή σε προβολή πλέγματος",
+    "Error during upload: {message}" : "Σφάλμα κατά τη μεταφόρτωση: {message}",
+    "Unknown error during upload" : "Άγνωστο σφάλμα κατά τη μεταφόρτωση",
     "Open the files app settings" : "Ανοίξτε τις ρυθμίσεις της εφαρμογής αρχείων",
     "Files settings" : "Ρυθμίσεις αρχείων",
     "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
-    "You might not have have permissions to view it, ask the sender to share it" : "Μπορεί να μην έχετε δικαίωμα για να το δείτε. Ζητήστε από τον αποστολέα να το μοιραστεί",
+    "Sort favorites first" : "Ταξινόμηση των αγαπημένων πρώτα",
     "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
     "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
+    "Enable the grid view" : "Ενεργοποίηση της προβολής πλέγματος",
     "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
     "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
     "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνση για πρόσβαση στα Αρχεία σας μέσω WebDAV",
+    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Εάν έχετε ενεργοποιήσει το 2FA, πρέπει να δημιουργήσετε και να χρησιμοποιήσετε έναν νέο κωδικό πρόσβασης εφαρμογής κάνοντας κλικ εδώ.",
     "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
     "WebDAV URL copied to clipboard" : "Ο σύνδεσμος WebDAV αντιγράφηκε στο πρόχειρο",
     "Unable to change the favourite state of the file" : "Αδυναμία αλλαγής αγαπημένης κατάστασης αρχείου",
     "Error while loading the file data" : "Σφάλμα κατά την φόρτωση αρχείου δεδομένων",
     "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για {name}",
-    "Create" : "Δημιουργία",
     "Create a new file with the selected template" : "Δημιουργήστε ένα νέο αρχείο με το επιλεγμένο πρότυπο",
     "Creating file" : "Δημιουργία αρχείου",
     "Blank" : "Κενό",
     "Unable to create new file from template" : "Δεν είναι δυνατή η δημιουργία νέου αρχείου από το πρότυπο",
     "Delete permanently" : "Διαγραφή οριστικά",
+    "Cancel" : "Ακύρωση",
+    "Destination is not a folder" : "Ο προορισμός δεν είναι φάκελος",
+    "This file/folder is already in that directory" : "Αυτό το αρχείο/φάκελος βρίσκεται ήδη σε αυτόν τον κατάλογο",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Δεν μπορείτε να μετακινήσετε ένα αρχείο/φάκελο στον εαυτό του ή σε έναν υποφάκελο του ίδιου του φακέλου.",
+    "A file or folder with that name already exists in this folder" : "Ένα αρχείο ή ένας φάκελος με αυτό το όνομα υπάρχει ήδη σε αυτόν το φάκελο",
+    "The file does not exist anymore" : "Το αρχείο δεν υπάρχει πλέον",
+    "Choose destination" : "Επιλέξτε προορισμό",
     "Copy to {target}" : "Αντιγραφή σε {target}",
     "Move to {target}" : "Μετακίνηση σε {target}",
+    "Cancelled move or copy operation" : "Ακυρώθηκε η λειτουργία μετακίνησης ή αντιγραφής",
     "Open folder {displayName}" : "Άνοιγμα φακέλου {displayName}",
+    "Open in Files" : "Άνοιγμα στα Αρχεία",
     "Open details" : "Άνοιγμα λεπτομερειών",
+    "Could not copy {file}. {message}" : "Δεν ήταν δυνατή η αντιγραφή του {file}. {message}",
+    "Could not move {file}. {message}" : "Δεν ήταν δυνατή η μετακίνηση του {file}. {message}",
+    "Created new folder \"{name}\"" : "Δημιουργήθηκε νέος φάκελος \"{name}\"",
+    "Filename" : "Όνομα αρχείου",
+    "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
     "Create new templates folder" : "Δημιουργία νέου φακέλου προτύπων",
     "Templates" : "Πρότυπα",
-    "Unable to initialize the templates directory" : "Δεν είναι δυνατή η προετοιμασία του καταλόγου προτύπων",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} φάκελος","{folderCount} φακέλοι"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} αρχείο","{fileCount} αρχεία"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 αρχείο και {folderCount} φάκελος","1 αρχείο και {folderCount} φακέλοι"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} αρχείο και 1 φάκελος","{fileCount} αρχεία και 1 φάκελος"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} αρχεία και {folderCount} φακέλοι",
+    "List of favorites files and folders." : "Λίστα αγαπημένων αρχείων και φακέλων.",
     "No favorites yet" : "Κανένα αγαπημένο ακόμα",
     "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα θα εμφανιστούν εδώ",
     "All files" : "Όλα τα αρχεία",
-    "Toggle %1$s sublist" : "Εναλλαγή %1$s σε υπολίστα",
+    "List of your files and folders." : "Λίστα των αρχείων και φακέλων σας.",
+    "List of recently modified files and folders." : "Λίστα των πρόσφατα τροποποιημένων αρχείων και φακέλων.",
+    "No recently modified files" : "Δεν υπάρχουν πρόσφατα τροποποιημένα αρχεία",
+    "Files and folders you recently modified will show up here." : "Εδώ θα εμφανίζονται τα αρχεία και οι φάκελοι που τροποποιήσατε πρόσφατα.",
     "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
+    "Select all" : "Επιλογή όλων",
     "Upload too large" : "Πολύ μεγάλο αρχείο προς μεταφόρτωση",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να μεταφορτώσετε υπερβαίνουν το μέγιστο μέγεθος μεταφόρτωσης αρχείων σε αυτόν τον διακομιστή.",
     "Text file" : "Αρχείο κειμένου",
     "New text file.txt" : "Νέο αρχείο file.txt",
-    "Storage invalid" : "Μη έγκυρος αποθηκευτικός χώρος",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Ο άμεσος σύνδεσμος αντιγράφηκε (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση σε αυτό το αρχείο/φάκελο)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για χρήστες που έχουν πρόσβαση στο αρχείο/φάκελο)",
     "You can only favorite a single file or folder at a time" : "Προσθήκη στα αγαπημένα ενός αρχείου ή φακέλου κάθε φορά",
-    "Unlimited" : "Απεριόριστο",
+    "\"remote user\"" : "\"απομακρυσμένος χρήστης\"",
     "Search users" : "Αναζήτηση χρηστών",
-    "Cancel" : "Ακύρωση",
+    "You might not have have permissions to view it, ask the sender to share it" : "Μπορεί να μην έχετε δικαίωμα για να το δείτε. Ζητήστε από τον αποστολέα να το μοιραστεί",
     "Set up templates folder" : "Ρύθμιση φακέλου προτύπων",
-    "%s used" : "%s σε χρήση",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "χρησιμοποιούνται %1$s από %2$s",
+    "Toggle %1$s sublist" : "Εναλλαγή %1$s σε υπολίστα",
     "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
     "Deleted files" : "Διαγραμμένα αρχεία",
     "Shares" : "Κοινόχρηστα",
@@ -256,12 +301,17 @@ OC.L10N.register(
     "Pending shares" : "Κοινή χρήση σε εκκρεμότητα",
     "This file has the tag {tag}" : "Αυτό το αρχείο έχει την ετικέτα {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Αυτό το αρχείο έχει τις ετικέτες {firstTags} και {lastTag}",
+    "Select the row for {displayName}" : "Επιλέξτε τη γραμμή για τον/την {displayName}",
     "Open folder {name}" : "Άνοιγμα φακέλου {name}",
+    "Unselect all" : "Αποεπιλογή όλων",
     "ascending" : "αύξουσα",
     "descending" : "φθίνουσα",
     "Sort list by {column} ({direction})" : "Ταξινόμηση λίστας ανά {column} ({direction})",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Η λίστα αυτή δεν εμφανίζεται πλήρως για λόγους απόδοσης. Τα αρχεία θα εμφανίζονται καθώς πλοηγείστε στη λίστα.",
     "Search for an account" : "Αναζήτηση για λογαριασμό",
     "Choose" : "Επιλογή",
-    "No files or folders have been deleted yet" : "Κανένα αρχείο ή φάκελος δεν έχει διαγραφεί ακόμα"
+    "No files or folders have been deleted yet" : "Κανένα αρχείο ή φάκελος δεν έχει διαγραφεί ακόμα",
+    "Add" : "Προσθήκη",
+    "The files is locked" : "Το αρχείο είναι κλειδωμένο"
 },
 "nplurals=2; plural=(n != 1);");
