@@ -34,19 +34,19 @@ OC.L10N.register(
     "Move" : "Mover",
     "Copy" : "Copiar",
     "Choose target folder" : "Elegir carpeta de destino",
-    "Set reminder" : "Enviar recordatorio",
+    "Set reminder" : "Establecer recordatorio",
     "Edit locally" : "Editar localmente",
     "Open" : "Abrir",
-    "Delete file" : "Eliminar archivo",
-    "Delete folder" : "Eliminar carpeta",
-    "Disconnect storage" : "Desconectar almacenamiento",
-    "Leave this share" : "Dejar de compartir",
+    "_Delete file_::_Delete files_" : ["Eliminar archivo","Eliminar archivos","Eliminar archivos"],
+    "_Delete folder_::_Delete folders_" : ["Eliminar carpeta","Eliminar carpetas","Eliminar carpetas"],
+    "_Disconnect storage_::_Disconnect storages_" : ["Desconectar almacenamiento","Desconectar almacenamientos","Desconectar almacenamientos"],
+    "_Leave this share_::_Leave these shares_" : ["Abandonar este recurso compartido","Abandonar estos recursos compartidos","Abandonar estos recursos compartidos"],
     "Could not load info for file \"{file}\"" : "No se ha podido cargar información para el archivo \"{file}\"",
     "Files" : "Archivos",
     "Details" : "Detalles",
     "Please select tag(s) to add to the selection" : "Seleccione la(s) etiqueta(s) para añadir a la selección",
     "Apply tag(s) to selection" : "Aplicar etiqueta(s) a la selección",
-    "Select directory \"{dirName}\"" : "Seleccione el directorio \"{dirName}\"",
+    "Select directory \"{dirName}\"" : "Seleccione la carpeta \"{dirName}\"",
     "Select file \"{fileName}\"" : "Seleccione el archivo \"{fileName}\"",
     "Pending" : "Pendiente",
     "Unable to determine date" : "No se ha podido determinar la fecha",
@@ -79,7 +79,7 @@ OC.L10N.register(
     "_%n file_::_%n files_" : ["%n archivo","%n archivos","%n archivos"],
     "{dirs} and {files}" : "{dirs} y {files}",
     "_including %n hidden_::_including %n hidden_" : ["incluyendo %n oculto","incluyendo %n ocultos","incluyendo %n ocultos"],
-    "You do not have permission to upload or create files here" : "No tienes permiso para subir o crear archivos aquí",
+    "You do not have permission to upload or create files here" : "No tiene permiso para subir o crear archivos aquí",
     "_Uploading %n file_::_Uploading %n files_" : ["Subiendo %n archivo","Subiendo %n archivos","Subiendo %n archivos"],
     "New" : "Nuevo",
     "New file/folder menu" : "Menú de carpeta/archivo nuevo",
@@ -101,14 +101,14 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coinciden \"{filter}\"","coincide \"{filter}\"","coincide \"{filter}\""],
     "View in folder" : "Ver en carpeta",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Favorited" : "Agregado a favoritos",
     "Favorite" : "Favorito",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "New folder" : "Nueva carpeta",
-    "Create new folder" : "Crear nueva carpeta",
+    "Create new folder" : "Crear carpeta nueva",
     "Upload file" : "Subir archivo",
     "Recent" : "Reciente",
     "Not favorited" : "Quitado como favorito",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Restaurado por {user}",
     "Renamed by {user}" : "Renombrado por {user}",
     "Moved by {user}" : "Movido por {user}",
-    "\"remote user\"" : "\"usuario remoto\"",
+    "\"remote account\"" : "\"cuenta remota\"",
     "You created {file}" : "Ha creado {file}",
     "You created an encrypted file in {file}" : "Has creado un archivo cifrado en {file}",
     "{user} created {file}" : "{user} ha creado {file}",
@@ -169,45 +169,47 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Se ha completado la transferencia de propiedad de {path} a {user}.",
     "in %s" : "en %s",
     "File Management" : "Gestión de archivos",
-    "Reload current directory" : "Recargar directorio actual",
-    "Go to the \"{dir}\" directory" : "Ir al directorio \"{dir}\"",
+    "Current directory path" : "Dirección de la carpeta actual",
+    "Reload current directory" : "Recargar carpeta actual",
+    "Go to the \"{dir}\" directory" : "Ir a la carpeta \"{dir}\"",
     "Drag and drop files here to upload" : "Arrastre y suelte archivos aquí para subirlos",
-    "Upload successful" : "Subida exitosa",
+    "Your have used your space quota and cannot upload files anymore" : "Ha utilizado su cuota de espacio y ya no puede subir más archivos",
+    "You don’t have permission to upload or create files here" : "No tiene permisos para subir o crear archivos aquí",
+    "Some files could not be uploaded" : "No se pudieron subir algunos archivos",
+    "Files uploaded successfully" : "Se subieron los archivos exitosamente",
     "\"{displayName}\" action executed successfully" : "la acción \"{displayName}\" se ejecutó exitósamente",
     "\"{displayName}\" action failed" : "la acción \"{displayName}\" falló",
-    "Select the row for {displayName}" : "Seleccione la fila para {displayName}",
+    "Toggle selection for file \"{displayName}\"" : "Alternar selección para archivo \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Alternar selección para la carpeta \"{displayName}\"",
     "Rename file" : "Renombrar archivo",
     "File name" : "Nombre del archivo",
     "Folder name" : "Nombre de la carpeta",
     "This node is unavailable" : "Este nodo no está disponible",
     "Download file {name}" : "Descargar archivo {name}",
-    "\"{name}\" is not an allowed filetype." : "\" {name}\" no es un tipo de archivo permitido.",
+    "\"{name}\" is not an allowed filetype." : "\"{name}\" no es un tipo de archivo permitido.",
     "{newName} already exists." : "{newName} ya existe.",
     "\"{char}\" is not allowed inside a file name." : "\"{char}\" no está permitido dentro del nombre de un archivo.",
     "Name cannot be empty" : "El nombre no puede estar vacío",
     "Another entry with the same name already exists" : "Ya existe otra entrada con el mismo nombre",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Renombrado \"{oldName}\" a \"{newName}\"",
-    "Could not rename \"{oldName}\", it does not exist any more" : "No se ha podido renombrar \"{oldName}\", ya no existe.",
+    "Could not rename \"{oldName}\", it does not exist any more" : "No se ha podido renombrar \"{oldName}\", ya no existe",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "El nombre \"{newName}\" ya está en uso en la carpeta \"{dir}\". Por favor, escoja un nombre diferente.",
     "Could not rename \"{oldName}\"" : "No se ha podido renombrar \"{oldName}\"",
-    "Could not copy {file}. {message}" : "No se pudo copiar {file}. {message}",
-    "Could not move {file}. {message}" : "No se pudo mover {file}. {message}",
     "Total rows summary" : "Resumen de filas totales",
-    "Select all" : "Seleccionar todo",
-    "Unselect all" : "Desmarrcar todos",
+    "Toggle selection for all files and folders" : "Seleccionar/deseleccionar todos los archivos y carpetas",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" fallo en algunos elementos",
     "\"{displayName}\" batch action executed successfully" : "la acción en lotes \"{displayName}\" se ejecutó exitósamente",
-    "Sort list by {column}" : "Ordenar lista por {column}",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} y {summaryFolder}",
     "List of files and folders." : "Lista de archivos y carpetas.",
+    "Column headers with buttons are sortable." : "Las columnas con botones en la cabecera son ordenables.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
     "File not found" : "No se ha encontrado el archivo",
-    "_{count} file_::_{count} files_" : ["{count} archivo","{count} archivos","{count} archivos"],
-    "_{count} folder_::_{count} folders_" : ["{count} carpeta","{count} carpetas","{count} carpetas"],
     "Storage informations" : "Informaciones de almacenamiento",
     "{usedQuotaByte} used" : "{usedQuotaByte} utilizados",
     "{relative}% used" : "{relative}% utilizado",
     "Could not refresh storage stats" : "No fue posible refrescar las estadísticas de almacenamiento",
+    "Your storage is full, files can not be updated or synced anymore!" : "Su almacenamiento está lleno, ¡Ya no se pueden subir ni sincronizarse más archivos!",
+    "Create" : "Crear",
+    "A file or folder with that name already exists." : "Un archivo o carpeta con ese nombre ya existe.",
     "Transfer ownership of a file or folder" : "Transferir la propiedad de un archivo o carpeta",
     "Choose file or folder to transfer" : "Elegir archivo o carpeta para transferir",
     "Change" : "Cambiar",
@@ -218,8 +220,10 @@ OC.L10N.register(
     "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
     "Unknown error" : "Error desconocido",
     "Ownership transfer request sent" : "Enviada la solicitud de transferencia de propiedad",
-    "Cannot transfer ownership of a file or folder you do not own" : "No puedes transferir la propiedad de un archivo o directorio del cual no eres propietario",
+    "Cannot transfer ownership of a file or folder you do not own" : "No puede transferir la propiedad de un archivo o carpeta de la cual no es propietario",
     "Select file or folder to link to" : "Selecciona archivo o carpeta a enlazar",
+    "Choose file" : "Elegir archivo",
+    "Choose {file}" : "Seleccionar {file}",
     "Loading current folder" : "Cargando carpeta actual",
     "No files in here" : "Aquí no hay archivos",
     "Upload some content or sync with your devices!" : "¡Suba contenidos o sincronice sus dispositivos!",
@@ -230,16 +234,21 @@ OC.L10N.register(
     "Shared" : "Compartido",
     "Switch to list view" : "Cambiar a vista de lista",
     "Switch to grid view" : "Cambiar a vista de cuadrícula",
+    "Error during upload: {message}" : "Error durante la subida: {message}",
+    "Error during upload, status code {status}" : "Error durante la subida, código de estado {status}",
+    "Unknown error during upload" : "Error desconocido durante la subida",
     "Open the files app settings" : "Abrir la configuración de la app Archivos",
     "Files settings" : "Configuración de archivos",
     "File cannot be accessed" : "El archivo no puede ser accesado",
-    "You might not have have permissions to view it, ask the sender to share it" : "Puede que no tenga permisos para verlo, solicite al remitente que lo comparta",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "El archivo no fue encontrado o no tiene permisos para verlo. Solicite al remitente que lo comparta.",
     "Sort favorites first" : "Ordenar los favoritos primero",
+    "Sort folders before files" : "Ordenar carpetas antes que archivos",
     "Show hidden files" : "Mostrar archivos ocultos",
     "Crop image previews" : "Recortar la previsualización de las imágenes",
     "Enable the grid view" : "Habilitar vista de cuadrícula",
-    "Additional settings" : "Configuración adicional",
+    "Additional settings" : "Ajustes adicionales",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
     "Copy to clipboard" : "Copiar al portapapeles",
     "Use this address to access your Files via WebDAV" : "Use esta dirección para acceder a tus archivos vía WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Si ha habilitado 2FA, debe crear y utilizar una nueva contraseña de aplicación haciendo clic aquí.",
@@ -248,29 +257,43 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "No se ha podido cambiar el estado de favorito del fichero",
     "Error while loading the file data" : "Error al cargar los datos del archivo",
     "Pick a template for {name}" : "Elija una plantilla para {name}",
-    "Create" : "Crear",
     "Create a new file with the selected template" : "Crear un nuevo archivo con la plantilla seleccionada",
     "Creating file" : "Creando el archivo",
     "Blank" : "Vacío",
     "Unable to create new file from template" : "No se ha podido crear un nuevo archivo desde la plantilla",
-    "Delete permanently" : "Eliminar de forma definitiva",
+    "Delete permanently" : "Eliminar de forma permanente",
+    "Delete and unshare" : "Eliminar y dejar de compartir",
+    "You are about to delete {count} items." : "Está a punto de eliminar {count} ítems.",
+    "Confirm deletion" : "Confirmar eliminación",
+    "Cancel" : "Cancelar",
+    "Deletion cancelled" : "Eliminación cancelada",
     "Destination is not a folder" : "El destino no es una carpeta",
     "This file/folder is already in that directory" : "Este archivo/carpeta ya está en ese directorio",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "No puede mover un archivo/carpeta a sí mismo o a una sub-carpeta de sí mismo",
+    "(copy)" : "(copiar)",
+    "(copy %n)" : "(copiar %n)",
+    "Move cancelled" : "Se canceló la movida",
     "A file or folder with that name already exists in this folder" : "Un archivo o carpeta con ese nombre ya existe en esta carpeta",
-    "The files is locked" : "El archivo está bloqueado",
     "The file does not exist anymore" : "El archivo ya no existe",
-    "Chose destination" : "Seleccione el destino",
+    "Choose destination" : "Elegir destino",
     "Copy to {target}" : "Copiar a {target}",
     "Move to {target}" : "Mover a {target}",
     "Cancelled move or copy operation" : "Se canceló la operación de mover o copiar",
+    "Move or copy operation failed" : "La operación de mover o copiar falló",
     "Open folder {displayName}" : "Abrir carpeta {displayName}",
     "Open in Files" : "Abrir en Archivos",
     "Open details" : "Abrir detalles",
+    "An error occurred while uploading. Please try again later." : "Ocurrió un error mientras se hacía la subida. Por favor, inténtelo de nuevo más tarde.",
+    "Could not copy {file}. {message}" : "No se pudo copiar {file}. {message}",
+    "Could not move {file}. {message}" : "No se pudo mover {file}. {message}",
+    "Created new folder \"{name}\"" : "Se creó la carpeta nueva \"{name}\"",
+    "Filename" : "Nombre de archivo",
+    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
     "Create new templates folder" : "Crear nueva carpeta de plantillas",
     "Templates" : "Plantillas",
-    "Unable to initialize the templates directory" : "No se ha podido iniciar la carpeta de plantillas",
-    "Created new folder \"{name}\"" : "Se creó la carpeta nueva \"{name}\"",
+    "New template folder" : "Nueva carpeta de plantillas",
+    "One of the dropped files could not be processed" : "Uno de los archivos arrastrados no puede ser procesado",
+    "Uploading \"{filename}\" failed" : "La subida de \"{filename}\" falló",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} carpeta","{folderCount} carpetas","{folderCount} carpetas"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} archivo","{fileCount} archivos","{fileCount} archivos"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 archivo y {folderCount} carpeta","1 archivo y {folderCount} carpetas","1 archivo y {folderCount} carpetas"],
@@ -281,24 +304,27 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Aquí aparecerán los archivos y carpetas que has marcado como favoritos",
     "All files" : "Todos los archivos",
     "List of your files and folders." : "Lista de sus archivos y carpetas.",
+    "Personal Files" : "Archivos Personales",
+    "List of your files and folders that are not shared." : "Lista de sus archivos y carpetas que no están compartidos.",
+    "No personal files found" : "No se encontraron archivos personales",
+    "Files that are not shared will show up here." : "Los archivos y carpetas que no ha compartido aparecerán aquí.",
     "List of recently modified files and folders." : "Lista de archivos y carpetas modificados recientemente.",
     "No recently modified files" : "No hay archivos modificados recientemente.",
     "Files and folders you recently modified will show up here." : "Los archivos y carpetas que ha modificado recientemente aparecerán aquí.",
-    "Toggle %1$s sublist" : "Alternar %1$s sublista",
     "No entries found in this folder" : "No hay entradas en esta carpeta",
+    "Select all" : "Seleccionar todo",
     "Upload too large" : "Subida demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que está intentando subir sobrepasan el tamaño máximo permitido en este servidor.",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo archivo.txt",
-    "Storage invalid" : "Almacenamiento no válido",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "El enlace directo fue copiado (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un solo archivo o carpeta cada vez",
-    "Unlimited" : "Ilimitado",
+    "\"remote user\"" : "\"usuario remoto\"",
     "Search users" : "Buscar usuarios",
-    "Cancel" : "Cancelar",
+    "You might not have have permissions to view it, ask the sender to share it" : "Puede que no tenga permisos para verlo, solicite al remitente que lo comparta",
     "Set up templates folder" : "Configura una carpeta para plantillas",
-    "%s used" : "usado %s",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s de %2$s usados",
+    "Toggle %1$s sublist" : "Alternar %1$s sublista",
     "Toggle grid view" : "Alternar vista de cuadrícula",
     "Deleted files" : "Archivos eliminados",
     "Shares" : "Archivos compartidos",
@@ -308,13 +334,17 @@ OC.L10N.register(
     "Pending shares" : "Recursos compartidos pendientes",
     "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}",
+    "Select the row for {displayName}" : "Seleccione la fila para {displayName}",
     "Open folder {name}" : "Abrir carpeta {name}",
+    "Unselect all" : "Desmarcar todos",
     "ascending" : "ascendente",
     "descending" : "descendente",
     "Sort list by {column} ({direction})" : "Ordenar lista por {column} ({direction})",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista no se renderiza completa por razones de rendimiento. Los archivos serán renderizados mientras ud. navegue por la lista.",
+    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navega por la lista.",
     "Search for an account" : "Buscar una cuenta",
-    "Choose" : "Selecciona",
-    "No files or folders have been deleted yet" : "No se han borrado archivos o carpetas todavía"
+    "Choose" : "Seleccione",
+    "No files or folders have been deleted yet" : "No se han borrado archivos o carpetas todavía",
+    "Add" : "Añadir",
+    "The files is locked" : "El archivo está bloqueado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
