@@ -34,10 +34,7 @@ OC.L10N.register(
     "Choose target folder" : "Selecciona la carpeta de destino.",
     "Edit locally" : "Editar localmente.",
     "Open" : "Abrir",
-    "Delete file" : "Borrar archivo",
-    "Delete folder" : "Borrar carpeta",
-    "Disconnect storage" : "Desconectar almacenamiento",
-    "Leave this share" : "Salir de esta compartición.",
+    "_Delete file_::_Delete files_" : ["Eliminar archivo","Eliminar archivos","Eliminar archivos"],
     "Could not load info for file \"{file}\"" : "No fue posible cargar información para el archivo \"{file}\"",
     "Files" : "Archivos",
     "Details" : "Detalles",
@@ -98,12 +95,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Tu almacenamiento está casi lleno ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide con \"{filter}\".","coincide con \"{filter}\".","coincide con \"{filter}\"."],
     "View in folder" : "Ver en la carpeta",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Se ha copiado el enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta).",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes","%n bytes"],
     "Favorited" : "Marcado como favorito",
     "Favorite" : "Favorito",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "New folder" : "Carpeta nueva",
     "Create new folder" : "Crear nueva carpeta",
     "Upload file" : "Cargar archivo",
@@ -124,7 +119,6 @@ OC.L10N.register(
     "Restored by {user}" : "Restaurado por {user}",
     "Renamed by {user}" : "Renombrado por {user}",
     "Moved by {user}" : "Movido por {user}",
-    "\"remote user\"" : "\"usuario remoto\"",
     "You created {file}" : "Creaste {file}",
     "You created an encrypted file in {file}" : "Creaste un archivo encriptado en {file}",
     "{user} created {file}" : "{user} creó {file}",
@@ -168,9 +162,9 @@ OC.L10N.register(
     "File Management" : "Gestión de archivos.",
     "Reload current directory" : "Recargar directorio actual.",
     "Go to the \"{dir}\" directory" : "Ir al directorio \"{dir}\".",
+    "You don’t have permission to upload or create files here" : "No cuentas con los permisos para cargar o crear archivos aquí",
     "\"{displayName}\" action executed successfully" : "La acción \"{displayName}\" se ejecutó correctamente.",
     "\"{displayName}\" action failed" : "La acción \"{displayName}\" falló.",
-    "Select the row for {displayName}" : "Seleccionar la fila para {displayName}.",
     "Rename file" : "Renombrar archivo.",
     "File name" : "Nombre de archivo.",
     "Folder name" : "Nombre de la carpeta",
@@ -183,8 +177,6 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "No se pudo cambiar el nombre de \"{oldName}\", ya no existe.",
     "Could not rename \"{oldName}\"" : "No se pudo cambiar el nombre de \"{oldName}\".",
     "Total rows summary" : "Resumen total de filas.",
-    "Select all" : "Seleccionar todo",
-    "Unselect all" : "Desmarcar todo.",
     "\"{displayName}\" failed on some elements " : "La acción \"{displayName}\" falló en algunos elementos.",
     "\"{displayName}\" batch action executed successfully" : "La acción en lote \"{displayName}\" se ejecutó correctamente.",
     "List of files and folders." : "Lista de archivos y carpetas. ",
@@ -192,6 +184,8 @@ OC.L10N.register(
     "{usedQuotaByte} used" : "{usedQuotaByte} usados.",
     "{relative}% used" : "{relative}% usados.",
     "Could not refresh storage stats" : "No se pudo actualizar las estadísticas de almacenamiento.",
+    "Your storage is full, files can not be updated or synced anymore!" : "Tu espacio está lleno. ¡Los archivos ya no se pueden actualizar o sincronizar!",
+    "Create" : "Crear",
     "Transfer ownership of a file or folder" : "Transferir propiedad de un archivo o carpeta.",
     "Choose file or folder to transfer" : "Selecciona un archivo o carpeta para transferir.",
     "Change" : "Cambiar",
@@ -215,7 +209,6 @@ OC.L10N.register(
     "Open the files app settings" : "Abrir la configuración de la aplicación de archivos.",
     "Files settings" : "Configuración de archivos.",
     "File cannot be accessed" : "No se puede acceder al archivo.",
-    "You might not have have permissions to view it, ask the sender to share it" : "Puede que no tengas permisos para verlo. Pide al remitente que lo comparta contigo.",
     "Sort favorites first" : "Ordenar primero los favoritos.",
     "Show hidden files" : "Mostrar archivos ocultos",
     "Crop image previews" : "Recortar vistas previas de imágenes.",
@@ -229,36 +222,36 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "No se puede cambiar el estado de favorito del archivo.",
     "Error while loading the file data" : "Error al cargar los datos del archivo.",
     "Pick a template for {name}" : "Selecciona una plantilla para {name}.",
-    "Create" : "Crear",
     "Create a new file with the selected template" : "Crea un archivo nuevo con la plantilla seleccionada.",
     "Creating file" : "Creando archivo.",
     "Blank" : "En blanco",
     "Unable to create new file from template" : "No se pudo crear un nuevo archivo a partir de la plantilla.",
     "Delete permanently" : "Borrar permanentemente",
+    "Cancel" : "Cancelar",
     "Open folder {displayName}" : "Abrir carpeta {displayName}.",
     "Open details" : "Abrir detalles.",
+    "Filename" : "Nombre de archivo",
+    "Unable to initialize the templates directory" : "No se pudo inicializar el directorio de plantillas.",
     "Create new templates folder" : "Crear nueva carpeta de plantillas.",
     "Templates" : "Plantillas",
-    "Unable to initialize the templates directory" : "No se pudo inicializar el directorio de plantillas.",
     "List of favorites files and folders." : "Lista de archivos y carpetas favoritos.",
     "No favorites yet" : "Aún no hay favoritos",
     "Files and folders you mark as favorite will show up here" : "Los archivos y carpetas que marques como favoritos se mostrarán aquí. ",
     "All files" : "Todos los archivos",
-    "Toggle %1$s sublist" : "Alternar sublista de %1$s.",
     "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
+    "Select all" : "Seleccionar todo",
     "Upload too large" : "La carga es demasido grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Los archivos que estás intentando cargar sobrepasan el tamaño máximo permitido para la carga de archivos en este servidor.",
     "Text file" : "Archivo de texto",
     "New text file.txt" : "Nuevo ArchivoDeTexto.txt",
-    "Storage invalid" : "El almacenamiento es inválido",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Se ha copiado el enlace directo (solo funciona para usuarios que tienen acceso a este archivo/carpeta).",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar liga directa (sólo funciona para usuarios que tienen acceso a este archivo/carpeta)",
     "You can only favorite a single file or folder at a time" : "Solo puedes marcar como favorito un archivo o carpeta a la vez.",
-    "Unlimited" : "Ilimitado",
+    "\"remote user\"" : "\"usuario remoto\"",
     "Search users" : "Buscar usuarios.",
-    "Cancel" : "Cancelar",
+    "You might not have have permissions to view it, ask the sender to share it" : "Puede que no tengas permisos para verlo. Pide al remitente que lo comparta contigo.",
     "Set up templates folder" : "Configurar carpeta de plantillas.",
-    "%s used" : "%s usado",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s de %2$s usados",
+    "Toggle %1$s sublist" : "Alternar sublista de %1$s.",
     "Toggle grid view" : "Alternar vista en cuadrícula.",
     "Deleted files" : "Papelera",
     "Shares" : "Elementos compartidos",
@@ -268,13 +261,16 @@ OC.L10N.register(
     "Pending shares" : "Comparticiones pendientes",
     "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}.",
     "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}.",
+    "Select the row for {displayName}" : "Seleccionar la fila para {displayName}.",
     "Open folder {name}" : "Abrir carpeta {name}",
+    "Unselect all" : "Desmarcar todo.",
     "ascending" : "ascendente",
     "descending" : "descendente",
     "Sort list by {column} ({direction})" : "Ordenar lista por {column} ({direction}).",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista no se muestra completamente por motivos de rendimiento. Los archivos se mostrarán a medida que navegas por la lista.",
     "Search for an account" : "Buscar una cuenta",
     "Choose" : "Seleccionar",
-    "No files or folders have been deleted yet" : "No se han eliminado archivos o carpetas todavía."
+    "No files or folders have been deleted yet" : "No se han eliminado archivos o carpetas todavía.",
+    "Add" : "Guardar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
