@@ -33,10 +33,6 @@ OC.L10N.register(
     "Choose target folder" : "Vali sihtkaust",
     "Edit locally" : "Muuda lokaalselt",
     "Open" : "Ava",
-    "Delete file" : "Kustuta fail",
-    "Delete folder" : "Kustuta kaust",
-    "Disconnect storage" : "Ühenda andmehoidla lahti",
-    "Leave this share" : "Lahku jaoskaustast",
     "Could not load info for file \"{file}\"" : "Faili \"{file}\" info laadimine ebaõnnestus",
     "Files" : "Failid",
     "Details" : "Üksikasjad",
@@ -91,7 +87,6 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bait","%n baiti"],
     "Favorited" : "Lemmikud",
     "Favorite" : "Lemmik",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopeeri otselink (töötab ainult nende kasutajate jaoks, kelle on ligipääs sellele failile/kaustale)",
     "New folder" : "Uus kaust",
     "Create new folder" : "Loo uus kaust",
     "Upload file" : "Laadi fail üles",
@@ -112,7 +107,6 @@ OC.L10N.register(
     "Restored by {user}" : "Taastatud kasutaja {user} poolt",
     "Renamed by {user}" : "Ümber nimetatud kasutaja {user} poolt",
     "Moved by {user}" : "Liigutatud kasutaja {user} poolt",
-    "\"remote user\"" : "\"kaugkasutaja\"",
     "You created {file}" : "Sa lõid faili {file}",
     "You created an encrypted file in {file}" : "Sa lõid krüpteeritud faili {file}",
     "{user} created {file}" : "Kasutaja {user} lõi faili {file}",
@@ -148,13 +142,14 @@ OC.L10N.register(
     "File Management" : "Failihaldus",
     "Reload current directory" : "Värskenda jooksvat kataloogi",
     "Go to the \"{dir}\" directory" : "Mine kataloogi \"{dir}\"",
+    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
     "Folder name" : "Kausta nimi",
     "Download file {name}" : "Laadi fail {name} alla",
-    "Select all" : "Vali kõik",
     "File not found" : "Faili ei leitud",
     "{usedQuotaByte} used" : "{usedQuotaByte} kasutusel",
     "{relative}% used" : "{relative}% kasutusel",
     "Your storage is full, files can not be updated or synced anymore!" : "Sinu andmemaht on täis! Faile ei uuendata ega sünkroniseerita!",
+    "Create" : "Loo",
     "Change" : "Muuda",
     "New owner" : "Uus omanik",
     "Unknown error" : "Tundmatu viga",
@@ -165,7 +160,6 @@ OC.L10N.register(
     "Go back" : "Mine tagasi",
     "Shared by link" : "Jagatud lingiga",
     "Shared" : "Jagatud",
-    "You don’t have permission to upload or create files here" : "Sul puuduvad õigused siia failide üleslaadimiseks või tekitamiseks",
     "Files settings" : "Failide seaded",
     "File cannot be accessed" : "Failile ligipääs puudub",
     "Show hidden files" : "Näita peidetud faile",
@@ -174,25 +168,28 @@ OC.L10N.register(
     "Copy to clipboard" : "Kopeeri lõikepuhvrisse",
     "Use this address to access your Files via WebDAV" : "Oma failidele WebDAV kaudu ligipääsemiseks kasuta seda aadressi",
     "WebDAV URL copied to clipboard" : "WebDAV URL kopeeritud lõikepuhvrisse",
-    "Create" : "Loo",
     "Blank" : "Tühi",
     "Unable to create new file from template" : "Faili loomine mallist ebaõnnestus",
     "Delete permanently" : "Kustuta jäädavalt",
+    "Cancel" : "Loobu",
     "Open folder {displayName}" : "Ava kaust {displayName}",
+    "Filename" : "Faili nimi",
+    "Unable to initialize the templates directory" : "Mallide kausta loomine ebaõnnestus",
     "Create new templates folder" : "Loo uus mallide kaust",
     "Templates" : "Mallid",
-    "Unable to initialize the templates directory" : "Mallide kausta loomine ebaõnnestus",
     "No favorites yet" : "Lemmikuid veel pole",
     "Files and folders you mark as favorite will show up here" : "Siin kuvatakse faile ja kaustasid, mille oled märkinud lemmikuteks",
     "All files" : "Kõik failid",
     "No entries found in this folder" : "Selles kaustast ei leitud kirjeid",
+    "Select all" : "Vali kõik",
     "Upload too large" : "Üleslaadimine on liiga suur",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Failid, mida sa proovid üles laadida, ületavad serveri poolt üleslaaditavatele failidele määratud maksimaalse suuruse.",
     "Text file" : "Tekstifail",
     "New text file.txt" : "Uus tekstifail.txt",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopeeri otselink (töötab ainult nende kasutajate jaoks, kelle on ligipääs sellele failile/kaustale)",
     "You can only favorite a single file or folder at a time" : "Korraga saab lemmikuks märkida ainult ühe faili või kausta",
+    "\"remote user\"" : "\"kaugkasutaja\"",
     "Search users" : "Otsi kasutajaid",
-    "Cancel" : "Loobu",
     "Set up templates folder" : "Seadista mallide kaust",
     "Deleted files" : "Kustutatud failid",
     "Shares" : "Jagamisi",
