@@ -37,10 +37,7 @@ OC.L10N.register(
     "Set reminder" : "Set reminder",
     "Edit locally" : "ویرایش محلی",
     "Open" : "باز کردن",
-    "Delete file" : "حذف پرونده",
-    "Delete folder" : "حذف پوشه",
-    "Disconnect storage" : "فضای ذخیره را جدا کنید",
-    "Leave this share" : "ترک این اشتراک",
+    "_Delete file_::_Delete files_" : ["Delete file","Delete files"],
     "Could not load info for file \"{file}\"" : "بارگیری اطلاعات برای پرونده امکان پذیر نیست \"{file}\"",
     "Files" : "پرونده‌ها",
     "Details" : "جزئیات",
@@ -101,12 +98,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "فضای ذخیره‌سازی شما تقریباً پر است ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["مطابقت با \"{filter}\"","مطابقت با \"{filter}\""],
     "View in folder" : "مشاهده در پوشه",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "پیوند مستقیم کپی شد (فقط برای کاربرانی که به این فایل/پوشه دسترسی دارند کار می کند)",
     "Path" : "مسیر",
     "_%n byte_::_%n bytes_" : ["%n بایت","%n بایت"],
     "Favorited" : "برگزیده شده",
     "Favorite" : "برگزیده",
-    "Copy direct link (only works for users who have access to this file/folder)" : "کپی لینک مستقیم (فقط برای کاربرانی که به این فایل/پوشه دسترسی دارند کار می کند)",
     "New folder" : "پوشه جدید",
     "Create new folder" : "ساختن پوشه جدید",
     "Upload file" : "بارگذاری پرونده",
@@ -127,7 +122,6 @@ OC.L10N.register(
     "Restored by {user}" : "بازیابی شده توسط {user}",
     "Renamed by {user}" : "تغییر نام توسط {user}",
     "Moved by {user}" : "منتقل شده توسط {user}",
-    "\"remote user\"" : "\"کاربران از راه‌ دور\"",
     "You created {file}" : "شما {file} را ایجاد کردید",
     "You created an encrypted file in {file}" : "شما یک فایل رمزگذاری شده در {file} ایجاد کردید",
     "{user} created {file}" : "{user} {file} را ایجاد کرد",
@@ -173,7 +167,6 @@ OC.L10N.register(
     "Go to the \"{dir}\" directory" : "به دایرکتوری \"{dir}\" بروید",
     "Drag and drop files here to upload" : "برای بارگذاری، فایل‌ها را بکشید و اینجا بیاندازید",
     "You don’t have permission to upload or create files here" : "شما دسترسی مجاز برای آپلود یا ایجاد فایل در اینجا را ندارید",
-    "Upload successful" : "بارگذاری موفق",
     "\"{displayName}\" action executed successfully" : "عملکرد \"{displayName}\" با موفقیت اجرا شد",
     "\"{displayName}\" action failed" : "اقدام \"{displayName}\" ناموفق بود",
     "Rename file" : "تغییر نام فایل",
@@ -201,6 +194,7 @@ OC.L10N.register(
     "{relative}% used" : "{نسبی}% استفاده شده است",
     "Could not refresh storage stats" : "نمی‌توان آمار ذخیره‌سازی را بازخوانی کرد",
     "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
+    "Create" : "ساخت",
     "Transfer ownership of a file or folder" : "انتقال مالکیت یک فایل یا پوشه",
     "Choose file or folder to transfer" : "فایل یا پوشه را برای انتقال انتخاب کنید",
     "Change" : "تغییر",
@@ -226,7 +220,6 @@ OC.L10N.register(
     "Open the files app settings" : "تنظیمات برنامه فایل ها را باز کنید",
     "Files settings" : "تنظیمات پرونده‌ها",
     "File cannot be accessed" : "فایل قابل دسترسی نیست",
-    "You might not have have permissions to view it, ask the sender to share it" : "ممکن است مجوز مشاهده آن را نداشته باشید، از فرستنده بخواهید آن را به اشتراک بگذارد",
     "Sort favorites first" : "ابتدا موارد دلخواه را مرتب کنید",
     "Show hidden files" : "نمایش پرونده‌های مخفی",
     "Crop image previews" : "پیش نمایش تصویر برش",
@@ -240,21 +233,21 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "امکان تغییر حالت دلخواه فایل وجود ندارد",
     "Error while loading the file data" : "خطا هنگام بارگیری داده های فایل",
     "Pick a template for {name}" : "یک الگو برای {name} انتخاب کنید",
-    "Create" : "ساخت",
     "Create a new file with the selected template" : "یک فایل جدید با الگوی انتخاب شده ایجاد کنید",
     "Creating file" : "ایجاد فایل",
     "Blank" : "جای خالی",
     "Unable to create new file from template" : "امکان ایجاد فایل جدید از الگو وجود ندارد",
-    "Unshare" : "لغو اشتراک‌گذاری",
     "Delete permanently" : "حذف قطعی",
+    "Cancel" : "لغو",
     "Copy to {target}" : "رونوشت به {target}",
     "Move to {target}" : "جابجایی به {target}",
     "Open folder {displayName}" : "باز کردن پوشه {displayName}",
     "Open in Files" : "در فایل باز کنید",
     "Open details" : "باز کردن جزئیات",
+    "Filename" : "نام پرونده",
+    "Unable to initialize the templates directory" : "راه اندازی دایرکتوری الگوها ممکن نیست",
     "Create new templates folder" : "پوشه قالب های جدید ایجاد کنید",
     "Templates" : "قالب‌ها",
-    "Unable to initialize the templates directory" : "راه اندازی دایرکتوری الگوها ممکن نیست",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} پوشه","{folderCount} پوشه"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} پرونده","{fileCount} پرونده"],
     "List of favorites files and folders." : "لیست فایل ها و پوشه های مورد علاقه",
@@ -264,17 +257,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "فهرست فایل‌ها و پوشه‌هایی که اخیراً اصلاح شده‌اند.",
     "No recently modified files" : "هیچ فایلی که اخیراً اصلاح شده است",
     "Files and folders you recently modified will show up here." : "فایل‌ها و پوشه‌هایی که اخیراً تغییر داده‌اید در اینجا نمایش داده می‌شوند.",
-    "Toggle %1$s sublist" : "تغییر%1$s فهرست فرعی",
     "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
     "Select all" : "انتخاب همه",
     "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
     "Text file" : "فایل متنی",
     "New text file.txt" : "پروندهٔ متنی جدید با پسوند txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "پیوند مستقیم کپی شد (فقط برای کاربرانی که به این فایل/پوشه دسترسی دارند کار می کند)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "کپی لینک مستقیم (فقط برای کاربرانی که به این فایل/پوشه دسترسی دارند کار می کند)",
     "You can only favorite a single file or folder at a time" : "در هر زمان فقط می توانید یک فایل یا پوشه را مورد علاقه خود قرار دهید",
+    "\"remote user\"" : "\"کاربران از راه‌ دور\"",
     "Search users" : "جستجوی کاربران",
-    "Cancel" : "لغو",
+    "You might not have have permissions to view it, ask the sender to share it" : "ممکن است مجوز مشاهده آن را نداشته باشید، از فرستنده بخواهید آن را به اشتراک بگذارد",
     "Set up templates folder" : "پوشه قالب ها را تنظیم کنید",
+    "Toggle %1$s sublist" : "تغییر%1$s فهرست فرعی",
     "Toggle grid view" : "نمای شبکه را تغییر دهید",
     "Deleted files" : "پرونده‌های حذف شده",
     "Shares" : "اشتراک گذاری ها",
