@@ -37,10 +37,7 @@ OC.L10N.register(
     "Set reminder" : "Definir un lembrete",
     "Edit locally" : "Editar localmente",
     "Open" : "Abrir",
-    "Delete file" : "Eliminar ficheiro",
-    "Delete folder" : "Eliminar cartafol",
-    "Disconnect storage" : "Desconectar o almacenamento",
-    "Leave this share" : "Deixar esta compartición",
+    "_Delete file_::_Delete files_" : ["Eliminar ficheiro","Eliminar ficheiros"],
     "Could not load info for file \"{file}\"" : "Non foi posíbel cargar información para o ficheiro «{file}»",
     "Files" : "Ficheiros",
     "Details" : "Detalles",
@@ -101,12 +98,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "O seu espazo de almacenamento está case cheo ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["coincide con «{filter}»","coinciden con «{filter}»"],
     "View in folder" : "Ver no cartafol",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Foi copiada a ligazón directa (só funciona para os usuarios que teñen acceso a este ficheiro/cartafol)",
     "Path" : "Ruta",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Marcado como favorito",
     "Favorite" : "Favorito",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar a ligazón directa (só funciona para usuarios con acceso a este ficheiro/cartafol)",
     "New folder" : "Novo cartafol",
     "Create new folder" : "Crear un cartafol novo",
     "Upload file" : "Enviar ficheiro",
@@ -127,7 +122,6 @@ OC.L10N.register(
     "Restored by {user}" : "Restaurado por {user}",
     "Renamed by {user}" : "Renomeado por {user}",
     "Moved by {user}" : "Movido por {user}",
-    "\"remote user\"" : "«usuario remoto»",
     "You created {file}" : "{file} foi creado por Vde.",
     "You created an encrypted file in {file}" : "Vde. creo un ficheiro cifrado en {file}",
     "{user} created {file}" : "{user} creou {file}",
@@ -172,10 +166,10 @@ OC.L10N.register(
     "Reload current directory" : "Recargar o directorio actual",
     "Go to the \"{dir}\" directory" : "Vaia ao directorio «{dir}».",
     "Drag and drop files here to upload" : "Arrastre e solte os ficheiros aquí para envialos",
-    "Upload successful" : "Envío satisfactorio",
+    "Your have used your space quota and cannot upload files anymore" : "Vde. usou a súa cota de espazo e xa non pode enviar ningún ficheiro más",
+    "You don’t have permission to upload or create files here" : "Non ten permiso para enviar ou crear ficheiros aquí.",
     "\"{displayName}\" action executed successfully" : "A acción «{displayName}» executouse correctamente",
     "\"{displayName}\" action failed" : "A acción «{displayName}» fallou",
-    "Select the row for {displayName}" : "Seleccione a fila para {displayName}",
     "Rename file" : "Renomear o ficheiro",
     "File name" : "Nome de ficheiro",
     "Folder name" : "Nome do cartafol",
@@ -190,24 +184,19 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Non foi posíbel renomear «{oldName}», xa non existe",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "O nome «{newName}» xa se utiliza no cartafol «{dir}». Escolla un nome diferente.",
     "Could not rename \"{oldName}\"" : "Non foi posíbel renomear «{oldName}»",
-    "Could not copy {file}. {message}" : "Non foi posíbel copiar {file}. {mensaxe}",
-    "Could not move {file}. {message}" : "Non foi posíbel mover {file}. {mensaxe}",
     "Total rows summary" : "Resumo total de filas",
-    "Select all" : "Seleccionar todo",
-    "Unselect all" : "Desmarcar todo",
     "\"{displayName}\" failed on some elements " : "Produciuse un fallo nalgúns elementos de «{displayName}» ",
     "\"{displayName}\" batch action executed successfully" : "A acción por lotes «{displayName}» executouse correctamente",
-    "Sort list by {column}" : "Ordenar a lista por {column}",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} e {summaryFolder}",
     "List of files and folders." : "Lista de ficheiros e cartafoles",
+    "Column headers with buttons are sortable." : "As cabeceiras das columnas con botóns pódense ordenar.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Esta lista non se representa de xeito completo por mor do rendemento. Os ficheiros represéntanse mentres se despraza pola lista.",
     "File not found" : "Ficheiro non atopado",
-    "_{count} file_::_{count} files_" : ["{count} ficheiro","{count} ficheiros"],
-    "_{count} folder_::_{count} folders_" : ["{count} cartafol","{count} cartafoles"],
     "Storage informations" : "Información de almacenamento",
     "{usedQuotaByte} used" : "{usedQuotaByte} usado",
     "{relative}% used" : "{relative}% usado",
     "Could not refresh storage stats" : "Non foi posíbel  actualizar as estatísticas de almacenamento",
+    "Your storage is full, files can not be updated or synced anymore!" : "O seu espazo de almacenamento está cheo, xa non se poden actualizar nin sincronizar os ficheiros.",
+    "Create" : "Crear",
     "Transfer ownership of a file or folder" : "Transferencia da propiedade dun ficheiro ou cartafol",
     "Choose file or folder to transfer" : "Escolla o ficheiro ou cartafol para transferir",
     "Change" : "Cambiar",
@@ -220,6 +209,8 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Enviouse solicitude de transferencia da propiedade",
     "Cannot transfer ownership of a file or folder you do not own" : "Non é posíbel transferir a propiedade dun ficheiro ou cartafol do que non es o propietario",
     "Select file or folder to link to" : "Seleccione o ficheiro ou cartafol ao que ligar",
+    "Choose file" : "Escoller o ficheiro",
+    "Choose {file}" : "Escoller  {file}",
     "Loading current folder" : "Cargando o cartafol actual",
     "No files in here" : "Aquí non hai ficheiros",
     "Upload some content or sync with your devices!" : "Envíe algún contido ou sincronice cos seus dispositivos!",
@@ -230,16 +221,18 @@ OC.L10N.register(
     "Shared" : "Compartido",
     "Switch to list view" : "Cambiar á vista de lista",
     "Switch to grid view" : "Cambiar á vista de grade",
+    "Error during upload: {message}" : "Produciuse un erro durante o envío: {message}",
+    "Unknown error during upload" : "Produciuse un erro descoñecido durante o envío",
     "Open the files app settings" : "Abrir os axustes da aplicación de ficheiros",
     "Files settings" : "Axustes de Ficheiros",
     "File cannot be accessed" : "Non é posíbel acceder ao ficheiro",
-    "You might not have have permissions to view it, ask the sender to share it" : "É posíbel que non teña permisos para velo, pídalle ao remitente que o comparta",
     "Sort favorites first" : "Ordene antes os favoritos",
     "Show hidden files" : "Amosar os ficheiros agochados",
     "Crop image previews" : "Recortar a vista previa das imaxes",
     "Enable the grid view" : "Activar á vista de grade",
     "Additional settings" : "Axustes adicionais",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "URL de WebDAV",
     "Copy to clipboard" : "Copiar no portapapeis.",
     "Use this address to access your Files via WebDAV" : "Empregue este enderezo para acceder ao seu Ficheiros mediante WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Se activou A2F, debe crear e utilizar un novo contrasinal de aplicación premendo aquí.",
@@ -248,29 +241,33 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Non é posíbel cambiar o estado favorito do ficheiro",
     "Error while loading the file data" : "Produciuse un erro ao cargar os datos do ficheiro",
     "Pick a template for {name}" : "Escolla un modelo para {name}",
-    "Create" : "Crear",
     "Create a new file with the selected template" : "Crear un novo ficheiro co modelo seleccionado",
     "Creating file" : "Creando o ficheiro",
     "Blank" : "Baleiro",
     "Unable to create new file from template" : "Non é posíbel crear un novo ficheiro a partir do modelo",
     "Delete permanently" : "Eliminar definitivamente",
+    "Confirm deletion" : "Confirmar a eliminación",
+    "Cancel" : "Cancelar",
     "Destination is not a folder" : "O destino non é un cartafol",
     "This file/folder is already in that directory" : "Este ficheiro/cartafol xa está nese directorio",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non é posíbel mover un ficheiro/cartafol sobre si mesmo ou a un subcartafol de si mesmo",
     "A file or folder with that name already exists in this folder" : "Neste cartafol xa existe un ficheiro ou cartafol con ese nome",
-    "The files is locked" : "Os ficheiros están bloqueados",
     "The file does not exist anymore" : "O ficheiro xa non existe",
-    "Chose destination" : "Escoller o destino",
     "Copy to {target}" : "Copiar en {target}",
     "Move to {target}" : "Mover a {target}",
     "Cancelled move or copy operation" : "Foi cancelada a operación de movemento ou copia",
     "Open folder {displayName}" : "Abrir o cartafol  {displayName}",
     "Open in Files" : "Abrir en Ficheiros",
     "Open details" : "Abrir detalles",
+    "Could not copy {file}. {message}" : "Non foi posíbel copiar {file}. {mensaxe}",
+    "Could not move {file}. {message}" : "Non foi posíbel mover {file}. {mensaxe}",
+    "Created new folder \"{name}\"" : "Creouse un novo cartafol «{name}»",
+    "Filename" : "Nome de ficheiro",
+    "Unable to initialize the templates directory" : "Non é posíbel iniciar o directorio de modelos",
     "Create new templates folder" : "Crear un novo cartafol de modelos",
     "Templates" : "Modelos",
-    "Unable to initialize the templates directory" : "Non é posíbel iniciar o directorio de modelos",
-    "Created new folder \"{name}\"" : "Creouse un novo cartafol «{name}»",
+    "One of the dropped files could not be processed" : "Non foi posíbel procesar un dos ficheiros arrastrados",
+    "Uploading \"{filename}\" failed" : "Produciuse un fallo ao cargar «{filename}».",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartafol","{folderCount} cartafoles"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ficheiro","{fileCount} ficheiros"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ficheiro e {folderCount} cartafol","1 ficheiro e {folderCount} cartafoles"],
@@ -284,21 +281,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Lista de ficheiros e cartafoles modificados recentemente.",
     "No recently modified files" : "Non hai ficheiros modificados recentemente",
     "Files and folders you recently modified will show up here." : "Os ficheiros e cartafoles que modificou recentemente amosaranse aquí.",
-    "Toggle %1$s sublist" : "Alternar %1$s sublista",
     "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
+    "Select all" : "Seleccionar todo",
     "Upload too large" : "Envío grande de máis",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Os ficheiros que tenta enviar exceden do tamaño máximo permitido neste servidor",
     "Text file" : "Ficheiro de texto",
     "New text file.txt" : "Novo ficheiro de texto.txt",
-    "Storage invalid" : "Almacenamento incorrecto",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Foi copiada a ligazón directa (só funciona para os usuarios que teñen acceso a este ficheiro/cartafol)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copiar a ligazón directa (só funciona para usuarios con acceso a este ficheiro/cartafol)",
     "You can only favorite a single file or folder at a time" : "Só pode marcar como favorito un único ficheiro ou cartafol por vez",
-    "Unlimited" : "Sen límites",
+    "\"remote user\"" : "«usuario remoto»",
     "Search users" : "Buscar usuarios",
-    "Cancel" : "Cancelar",
+    "You might not have have permissions to view it, ask the sender to share it" : "É posíbel que non teña permisos para velo, pídalle ao remitente que o comparta",
     "Set up templates folder" : "Estabelecer un cartafol de modelos",
-    "%s used" : "%s utilizado",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s de %2$s utilizado",
+    "Toggle %1$s sublist" : "Alternar %1$s sublista",
     "Toggle grid view" : "Alternar a vista como grade",
     "Deleted files" : "Ficheiros eliminados",
     "Shares" : "Comparticións",
@@ -308,13 +304,17 @@ OC.L10N.register(
     "Pending shares" : "Comparticións pendentes",
     "This file has the tag {tag}" : "Este ficheiro ten a etiqueta {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Este ficheiro ten as etiquetas {firstTags} e {lastTag}",
+    "Select the row for {displayName}" : "Seleccione a fila para {displayName}",
     "Open folder {name}" : "Abrir o cartafol {name}",
+    "Unselect all" : "Desmarcar todo",
     "ascending" : "ascendente",
     "descending" : "descendente",
     "Sort list by {column} ({direction})" : "Ordenar a lista por {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Esta lista non se representa de xeito completo por mor do rendemento. Os ficheiros represéntanse se despraza pola lista.",
     "Search for an account" : "Buscar por unha conta",
     "Choose" : "Escoller",
-    "No files or folders have been deleted yet" : "Aínda non se eliminou ningún ficheiro nin cartafol"
+    "No files or folders have been deleted yet" : "Aínda non se eliminou ningún ficheiro nin cartafol",
+    "Add" : "Engadir",
+    "The files is locked" : "Os ficheiros están bloqueados"
 },
 "nplurals=2; plural=(n != 1);");
