@@ -30,10 +30,6 @@ OC.L10N.register(
     "Copy" : "Kopiraj",
     "Choose target folder" : "Odaberi ciljnu mapu",
     "Open" : "Otvori",
-    "Delete file" : "Izbriši datoteku",
-    "Delete folder" : "Izbriši mapu",
-    "Disconnect storage" : "Odspoji pohranu",
-    "Leave this share" : "Napustite ovo dijeljenje",
     "Could not load info for file \"{file}\"" : "Nije moguće učitati podatke za datoteku „{file}”",
     "Files" : "Datoteke",
     "Details" : "Pojedinosti",
@@ -90,7 +86,6 @@ OC.L10N.register(
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajtova","%n bajtova"],
     "Favorited" : "Favorit",
     "Favorite" : "Favorit",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj izravnu poveznicu (samo za korisnike koji smiju pristupiti ovoj datoteci/mapi)",
     "New folder" : "Nova mapa",
     "Create new folder" : "Stvori novu mapu",
     "Upload file" : "Otpremi datoteku",
@@ -111,7 +106,6 @@ OC.L10N.register(
     "Restored by {user}" : "Vratio {user}",
     "Renamed by {user}" : "Preimenovao {user}",
     "Moved by {user}" : "Premjestio {user}",
-    "\"remote user\"" : "„udaljeni korisnik”",
     "You created {file}" : "Stvorili ste {file}",
     "You created an encrypted file in {file}" : "Stvorili ste šifriranu datoteku u {file}",
     "{user} created {file}" : "{user} je stvorio {file}",
@@ -153,11 +147,13 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Prijenos vlasništva {path} od {user} je završen.",
     "in %s" : "za %s",
     "File Management" : "Upravljanje datotekama",
+    "You don’t have permission to upload or create files here" : "Ovdje ne smijete otpremati ili stvarati datoteke",
     "File name" : "Naziv datoteke",
     "Folder name" : "Naziv mape",
     "Name cannot be empty" : "Naziv ne može biti prazan",
-    "Select all" : "Odaberi sve",
     "File not found" : "Datoteka nije pronađena",
+    "Your storage is full, files can not be updated or synced anymore!" : "Vaša je pohrana puna, datoteke više nije moguće ažurirati ni sinkronizirati!",
+    "Create" : "Stvori",
     "Transfer ownership of a file or folder" : "Prenesi vlasništvo nad datotekom ili mapom",
     "Choose file or folder to transfer" : "Odaberite datoteku ili mapu za prijenos",
     "Change" : "Promijeni",
@@ -184,32 +180,31 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Nije moguće promijeniti status favorita datoteke",
     "Error while loading the file data" : "Pogreška pri učitavanju podataka iz datoteke",
     "Pick a template for {name}" : "Odaberite predložak za {name}",
-    "Create" : "Stvori",
     "Create a new file with the selected template" : "Stvorite novu datoteku s odabranim predloškom",
     "Creating file" : "Stvaranje datoteke",
     "Blank" : "Prazno",
     "Unable to create new file from template" : "Nije moguće stvoriti novu datoteku iz predloška",
     "Delete permanently" : "Trajno izbrišite",
+    "Cancel" : "Odustani",
     "Open details" : "Otvori pojedinosti",
-    "Templates" : "Predlošci",
+    "Filename" : "Naziv datoteke",
     "Unable to initialize the templates directory" : "Nije moguće inicijalizirati direktorij predložaka",
+    "Templates" : "Predlošci",
     "No favorites yet" : "Još nema favorita",
     "Files and folders you mark as favorite will show up here" : "Ovdje će se prikazati datoteke i mape koje označite kao favorite",
     "All files" : "Sve datoteke",
-    "Toggle %1$s sublist" : "Uključivanje/isključivanje potpopisa %1$s",
     "No entries found in this folder" : "U ovoj mapi nisu pronađeni nikakvi zapisi",
+    "Select all" : "Odaberi sve",
     "Upload too large" : "Otprema je prevelika",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke koje pokušavate otpremiti premašuju maksimalnu veličinu za otpremu datoteka na ovom poslužitelju.",
     "Text file" : "Tekstna datoteka",
     "New text file.txt" : "Nova tekstna datoteka.txt",
-    "Storage invalid" : "Neispravna pohrana",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj izravnu poveznicu (samo za korisnike koji smiju pristupiti ovoj datoteci/mapi)",
     "You can only favorite a single file or folder at a time" : "Istovremeno možete označiti samo jednu datoteku ili mapu kao favorita",
-    "Unlimited" : "Neograničeno",
+    "\"remote user\"" : "„udaljeni korisnik”",
     "Search users" : "Pretraži korisnike",
-    "Cancel" : "Odustani",
     "Set up templates folder" : "Postavi mapu predložaka",
-    "%s used" : "Iskorišteno %s",
-    "%1$s of %2$s used" : "Iskorišteno %1$s od %2$s",
+    "Toggle %1$s sublist" : "Uključivanje/isključivanje potpopisa %1$s",
     "Toggle grid view" : "Uključi/isključi prikaz rešetke",
     "Deleted files" : "Izbrisane datoteke",
     "Shares" : "Dijeljenja",
@@ -217,6 +212,7 @@ OC.L10N.register(
     "Shared with you" : "Podijeljeno s vama",
     "Deleted shares" : "Izbrisana dijeljenja",
     "Pending shares" : "Dijeljenja na čekanju",
-    "Choose" : "Odaberite"
+    "Choose" : "Odaberite",
+    "Add" : "Dodaj"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
