@@ -34,10 +34,6 @@ OC.L10N.register(
     "Choose target folder" : "Pilih folder target",
     "Edit locally" : "Sunting secara lokal",
     "Open" : "Buka",
-    "Delete file" : "Hapus berkas",
-    "Delete folder" : "Hapus folder",
-    "Disconnect storage" : "Memutuskan penyimpaan",
-    "Leave this share" : "Tinggalkan pembagian ini",
     "Could not load info for file \"{file}\"" : "Tidak dapat menampilkan info berkas \"{file}\"",
     "Files" : "Berkas",
     "Details" : "Rincian",
@@ -65,7 +61,7 @@ OC.L10N.register(
     "Could not create file \"{file}\"" : "Tidak dapat membuat berkas \"{file}\"",
     "Could not create file \"{file}\" because it already exists" : "Tidak dapat membuat berkas \"{file}\" karena sudah ada",
     "Could not create folder \"{dir}\" because it already exists" : "Tidak dapat membuat folder \"{dir}\" karena sudah ada",
-    "Could not fetch file details \"{file}\"" : "Tidak dapat melihat detail \"{file}\"",
+    "Could not fetch file details \"{file}\"" : "Tidak dapat memperoleh detail berkas \"{file}\"",
     "Error deleting file \"{fileName}\"." : "Terjadi kesalahan saat menghapus berkas \"{fileName}\".",
     "No search results in other folders for {tag}{filter}{endtag}" : "Hasil pencarian tidak ditemukan di folder lainnya untuk '{tag}{filter}{endtag}'",
     "Enter more than two characters to search in other folders" : "Masukkan lebih dari dua karakter untuk mencari di folder lain",
@@ -98,12 +94,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Penyimpanan Anda hampir penuh ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["cocok dengan \"{filter}\""],
     "View in folder" : "Lihat dalam folder",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Tautan langsung disalin (hanya bisa untuk pengguna yang memiliki akses ke berkas/folder ini)",
     "Path" : "Jalur",
     "_%n byte_::_%n bytes_" : ["%n byte"],
     "Favorited" : "Difavoritkan",
     "Favorite" : "Favorit",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Salin tautan langsung (hanya berlaku bagi pengguna yang telah memiliki akses ke berkas/folder ini)",
     "New folder" : "Folder baru",
     "Create new folder" : "Buat direktori baru",
     "Upload file" : "Unggah berkas",
@@ -124,7 +118,6 @@ OC.L10N.register(
     "Restored by {user}" : "Dipulihkan oleh {user}",
     "Renamed by {user}" : "Diganti nama oleh {user}",
     "Moved by {user}" : "Dipindahkan oleh {user}",
-    "\"remote user\"" : "\"remote user\"",
     "You created {file}" : "Anda membuat {file}",
     "You created an encrypted file in {file}" : "Anda membuat berkas terenkripsi pada {file}",
     "{user} created {file}" : "{user} membuat {file}",
@@ -166,13 +159,15 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Transfer kepemilikan pada {path} dari {user} selesai.",
     "in %s" : "dalam %s",
     "File Management" : "Pengelolaan Berkas",
+    "You don’t have permission to upload or create files here" : "Anda tidak memiliki akses untuk mengunggah atau membuat berkas di sini",
     "Folder name" : "Nama folder",
-    "Select all" : "Pilih Semua",
     "File not found" : "Berkas tidak ditemukan",
     "Storage informations" : "Informasi penyimpanan",
     "{usedQuotaByte} used" : "{usedQuotaByte} digunakan",
     "{relative}% used" : "{relative}% digunakan",
     "Could not refresh storage stats" : "Tidak dapat memuat ulang statistik penyimpanan",
+    "Your storage is full, files can not be updated or synced anymore!" : "Ruang penyimpanan Anda penuh, berkas tidak dapat diperbarui atau disinkronkan lagi!",
+    "Create" : "Buat",
     "Transfer ownership of a file or folder" : "Transfer kepemilikan dari berkas atau folder",
     "Choose file or folder to transfer" : "Pilih berkas atau folder untuk transfer",
     "Change" : "Ubah",
@@ -193,7 +188,6 @@ OC.L10N.register(
     "Open the files app settings" : "Buka setelan aplikasi berkas",
     "Files settings" : "Setelan berkas",
     "File cannot be accessed" : "Berkas tidak dapat diakses",
-    "You might not have have permissions to view it, ask the sender to share it" : "Anda mungkin tidak memiliki izin untuk menampilkan ini, tanyakan pengirim untuk membagikannya",
     "Show hidden files" : "Lihat berkas tersembunyi",
     "Crop image previews" : "Pangkas pratinjau gambar",
     "Additional settings" : "Setelan tambahan",
@@ -206,32 +200,32 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Gagal mengubah status favorit berkas",
     "Error while loading the file data" : "Galat pemuatan data berkas",
     "Pick a template for {name}" : "Pilih templat untuk {name}",
-    "Create" : "Buat",
     "Create a new file with the selected template" : "Buat sebuah berkas baru dengan templat yang dipilih",
     "Creating file" : "Membuat berkas",
     "Blank" : "Kosong",
     "Unable to create new file from template" : "Tidak dapat membuat berkas baru dari templat",
     "Delete permanently" : "Hapus secara permanen",
-    "Templates" : "Templat",
+    "Cancel" : "Membatalkan",
+    "Filename" : "Nama berkas",
     "Unable to initialize the templates directory" : "Tidak dapat membuat direktori templat",
+    "Templates" : "Templat",
     "No favorites yet" : "Belum memiliki favorit",
     "Files and folders you mark as favorite will show up here" : "Berkas dan folder yang Anda tandai sebagai favorit akan ditampilkan di sini.",
     "All files" : "Semua berkas",
-    "Toggle %1$s sublist" : "Alih %1$s subdaftar",
     "No entries found in this folder" : "Tidak ada entri yang ditemukan dalam folder ini",
+    "Select all" : "Pilih Semua",
     "Upload too large" : "Yang diunggah terlalu besar",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Berkas yang dicoba untuk diunggah melebihi ukuran maksimum pengunggahan berkas di server ini.",
     "Text file" : "Berkas teks",
     "New text file.txt" : "Teks baru file.txt",
-    "Storage invalid" : "Penyimpanan tidak sah",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Tautan langsung disalin (hanya bisa untuk pengguna yang memiliki akses ke berkas/folder ini)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Salin tautan langsung (hanya berlaku bagi pengguna yang telah memiliki akses ke berkas/folder ini)",
     "You can only favorite a single file or folder at a time" : "Anda hanya dapat memfavoritkan satu berkas atau folder dalam satu waktu",
-    "Unlimited" : "Tak terbatas",
+    "\"remote user\"" : "\"remote user\"",
     "Search users" : "Cari pengguna",
-    "Cancel" : "Membatalkan",
+    "You might not have have permissions to view it, ask the sender to share it" : "Anda mungkin tidak memiliki izin untuk menampilkan ini, tanyakan pengirim untuk membagikannya",
     "Set up templates folder" : "Siapkan folder templat",
-    "%s used" : "%s digunakan",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "%1$s dari %2$s sudah digunakan",
+    "Toggle %1$s sublist" : "Alih %1$s subdaftar",
     "Toggle grid view" : "Alihkan tampilan jala-jala",
     "Deleted files" : "Berkas terhapus",
     "Shares" : "Dibagikan",
@@ -239,6 +233,8 @@ OC.L10N.register(
     "Shared with you" : "Shared with you",
     "Deleted shares" : "Berbagi terhapus",
     "Pending shares" : "Berbagi tertunda",
-    "Choose" : "Pilih"
+    "Unselect all" : "Batalkan semua pemilihan",
+    "Choose" : "Pilih",
+    "Add" : "Tambah"
 },
 "nplurals=1; plural=0;");
