@@ -37,10 +37,6 @@ OC.L10N.register(
     "Set reminder" : "Setja áminningu",
     "Edit locally" : "Breyta staðvært",
     "Open" : "Opna",
-    "Delete file" : "Eyða skrá",
-    "Delete folder" : "Eyða möppu",
-    "Disconnect storage" : "Aftengja geymslu",
-    "Leave this share" : "Leave this share",
     "Could not load info for file \"{file}\"" : "Gat ekki lesið upplýsingar um skrána \"{file}\"",
     "Files" : "Skráaforrit",
     "Details" : "Nánar",
@@ -101,12 +97,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Geymsluplássið þitt er næstum fullt ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["samsvarar \"{filter}\"","samsvara \"{filter}\""],
     "View in folder" : "Skoða í möppu",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Beinn tengill var afritaður (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
     "Path" : "Slóð",
     "_%n byte_::_%n bytes_" : ["%n bæti","%n bæti"],
     "Favorited" : "Sett í eftirlæti",
     "Favorite" : "Eftirlæti",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Afrita beinan tengil (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
     "New folder" : "Ný mappa",
     "Create new folder" : "Búa til nýja möppu",
     "Upload file" : "Senda inn skrá",
@@ -127,7 +121,6 @@ OC.L10N.register(
     "Restored by {user}" : "Endurheimt af {user}",
     "Renamed by {user}" : "Endurnefnt af {user}",
     "Moved by {user}" : "Fært af {user}",
-    "\"remote user\"" : "\"fjartengdur notandi\"",
     "You created {file}" : "Þú bjóst til {file}",
     "You created an encrypted file in {file}" : "Þú bjóst til dulritaða skrá í {file}",
     "{user} created {file}" : "{user} bjó til {file}",
@@ -172,10 +165,10 @@ OC.L10N.register(
     "Reload current directory" : "Endurhlaða núverandi möppu",
     "Go to the \"{dir}\" directory" : "Fara í heimamöppu",
     "Drag and drop files here to upload" : "Dragðu og slepptu hér skrám til að senda inn",
-    "Upload successful" : "Innsending tókst",
+    "Your have used your space quota and cannot upload files anymore" : "Þú hefur fullnýtt geymslukvótann þinn og getur ekki lengur sent inn skrár",
+    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
     "\"{displayName}\" action executed successfully" : "Tókst að framkvæma \"{displayName}\" aðgerð",
     "\"{displayName}\" action failed" : "\"{displayName}\" aðgerð mistókst",
-    "Select the row for {displayName}" : "Veldu röðina fyrir {displayName}",
     "Rename file" : "Endurnefna skrá",
     "File name" : "Skráarheiti",
     "Folder name" : "Nafn möppu",
@@ -190,25 +183,19 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Gat ekki endurnefnt \"{oldName}\", það er ekki lengur til staðar",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Heitið \"{newName}\" er nú þegar notað í \"{dir}\" möppunni. Veldu eitthvað annað nafn.",
     "Could not rename \"{oldName}\"" : "Tókst ekki að endurnefna \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Gat ekki afritað {file}. {message}",
-    "Could not move {file}. {message}" : "Gat ekki fært {file}. {message}",
     "Total rows summary" : "Samantek á fjölda raða",
-    "Select all" : "Velja allt",
-    "Unselect all" : "Afvelja allt",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" aðgerð mistókst á einhverjum atriðum",
     "\"{displayName}\" batch action executed successfully" : "Tókst að framkvæma \"{displayName}\" magnvinnsluaðgerð",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} og {summaryFolder}",
     "List of files and folders." : "Listi yfir skrár og möppur.",
     "Column headers with buttons are sortable." : "Dálkfyrirsagnir með hnöppum eru raðanlegar",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Skrárnar munu birtast eftir því sem farið er í gegnum listann.",
     "File not found" : "Skrá finnst ekki",
-    "_{count} file_::_{count} files_" : ["{count} skrá","{count} skrár"],
-    "_{count} folder_::_{count} folders_" : ["{count} mappa","{count} möppur"],
     "Storage informations" : "Upplýsingar um geymslurými",
     "{usedQuotaByte} used" : "{usedQuotaByte} notað",
     "{relative}% used" : "{relative}% notað",
     "Could not refresh storage stats" : "Gat ekki uppfært tölfræði fyrir geymslurými",
     "Your storage is full, files can not be updated or synced anymore!" : "Geymsluplássið þitt er fullt, ekki er lengur hægt að uppfæra eða samstilla skrár!",
+    "Create" : "Búa til",
     "Transfer ownership of a file or folder" : "Millifæra eignarhald skráar eða möppu",
     "Choose file or folder to transfer" : "Veldu skrá eða möppu til að millifæra",
     "Change" : "Breyta",
@@ -223,7 +210,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Veldu skrá eða möppu til að tengja í",
     "Choose file" : "Veldu skrá",
     "Choose {file}" : "Veldu {file}",
-    "Add" : "Bæta við",
     "Loading current folder" : "Hleð inn núverandi möppu",
     "No files in here" : "Engar skrár hér",
     "Upload some content or sync with your devices!" : "Sendu inn eitthvað efni eða samstilltu við tækin þín!",
@@ -234,14 +220,11 @@ OC.L10N.register(
     "Shared" : "Sameiginlegt",
     "Switch to list view" : "Skipta yfir í listasýn",
     "Switch to grid view" : "Skipta yfir í reitasýn",
-    "Your have used your space quota and cannot upload files anymore" : "Þú hefur fullnýtt geymslukvótann þinn og getur ekki lengur sent inn skrár",
-    "You don’t have permission to upload or create files here" : "Þú hefur ekki heimild til að hlaða inn eða búa til skjöl hér",
     "Error during upload: {message}" : "Villa við innsendingu: {message}",
     "Unknown error during upload" : "Óþekkt villa við innsendingu",
     "Open the files app settings" : "Opna stillingar skráaforritsins",
     "Files settings" : "Stillingar skráaforritsins",
     "File cannot be accessed" : "Skráin er ekki aðgengileg",
-    "You might not have have permissions to view it, ask the sender to share it" : "Þú hefur mögulega ekki heimildir til að skoða hana, biddu sendandann um að deila henni",
     "Sort favorites first" : "Raða eftirlætum fremst",
     "Show hidden files" : "Sýna faldar skrár",
     "Crop image previews" : "Skera utan af forskoðun mynda",
@@ -257,29 +240,30 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Get ekki breytt stöðu sem eftirlæti á skránni",
     "Error while loading the file data" : "Villa við að hlaða inn skráagögnum",
     "Pick a template for {name}" : "Veldu sniðmát fyrir {name}",
-    "Create" : "Búa til",
     "Create a new file with the selected template" : "Búa til nýja skrá úr völdu sniðmáti",
     "Creating file" : "Bý til skrá",
     "Blank" : "Tóm",
     "Unable to create new file from template" : "Tekst ekki að búa til nýja skrá út frá sniðmáti",
     "Delete permanently" : "Eyða varanlega",
+    "Cancel" : "Hætta við",
     "Destination is not a folder" : "Áfangastaðurinn er ekki mappa",
     "This file/folder is already in that directory" : "Þessi skrá/mappa er þegar í þessari möppu",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Þú getur ekki flutt skrá/möppu inn í sjálfa sig eða inni í undirmöppu af sjálfri sér",
     "A file or folder with that name already exists in this folder" : "Skrá eða mappa með þessu heiti er þegar til staðar í þessari möppu",
-    "The files is locked" : "Skráin er læst",
     "The file does not exist anymore" : "Skráin  er ekki lengur til",
-    "Chose destination" : "Veldu áfangastað",
     "Copy to {target}" : "Afrita í {target}",
     "Move to {target}" : "Færa í {target}",
     "Cancelled move or copy operation" : "Hætti við aðgerð við að færa eða afrita",
     "Open folder {displayName}" : "Opna möppu {displayName}",
     "Open in Files" : "Opna í skráaforritinu",
     "Open details" : "Opna nánari upplýsingar",
+    "Could not copy {file}. {message}" : "Gat ekki afritað {file}. {message}",
+    "Could not move {file}. {message}" : "Gat ekki fært {file}. {message}",
+    "Created new folder \"{name}\"" : "Bjó til nýja möppu \"{name}\"",
+    "Filename" : "Skráarheiti",
+    "Unable to initialize the templates directory" : "Tókst ekki að frumstilla sniðmátamöppuna",
     "Create new templates folder" : "Búa til nýja sniðmátamöppu",
     "Templates" : "Sniðmát",
-    "Unable to initialize the templates directory" : "Tókst ekki að frumstilla sniðmátamöppuna",
-    "Created new folder \"{name}\"" : "Bjó til nýja möppu \"{name}\"",
     "One of the dropped files could not be processed" : "Ekki var hægt að vinna með eina af slepptu skránum",
     "Uploading \"{filename}\" failed" : "Innsending \"{filename}\" mistókst",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mappa","{folderCount} möppur"],
@@ -295,16 +279,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Listi yfir nýlega breyttar skrár og möppur.",
     "No recently modified files" : "Engar nýlega breyttar skrár",
     "Files and folders you recently modified will show up here." : "Skrár og möppur sem þú breyttir nýlega birtast hér.",
-    "Toggle %1$s sublist" : "Víxla %1$s undirlistanum af/á",
     "No entries found in this folder" : "Engar skrár fundust í þessari möppu",
+    "Select all" : "Velja allt",
     "Upload too large" : "Innsend skrá er of stór",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Skrárnar sem þú ert að senda inn eru stærri en hámarks innsendingarstærð á þessum netþjóni.",
     "Text file" : "Textaskrá",
     "New text file.txt" : "Ný textaskrá.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Beinn tengill var afritaður (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Afrita beinan tengil (virkar bara fyrir notendur sem eiga aðgang að þessari skrá/möppu)",
     "You can only favorite a single file or folder at a time" : "Þú getur aðeins bætt einni skrá eða möppu í einu í eftilæti",
+    "\"remote user\"" : "\"fjartengdur notandi\"",
     "Search users" : "Leita að notendum",
-    "Cancel" : "Hætta við",
+    "You might not have have permissions to view it, ask the sender to share it" : "Þú hefur mögulega ekki heimildir til að skoða hana, biddu sendandann um að deila henni",
     "Set up templates folder" : "Setja upp sniðmátamöppu",
+    "Toggle %1$s sublist" : "Víxla %1$s undirlistanum af/á",
     "Toggle grid view" : "Víxla reitasýn af/á",
     "Deleted files" : "Eyddar skrár",
     "Shares" : "Sameignir",
@@ -314,13 +302,17 @@ OC.L10N.register(
     "Pending shares" : "Sameignir í bið",
     "This file has the tag {tag}" : "Þessi skrá er með merkið {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Þessi skrá er með merkin {firstTags} og {lastTag}",
+    "Select the row for {displayName}" : "Veldu röðina fyrir {displayName}",
     "Open folder {name}" : "Opna möppu {name}",
+    "Unselect all" : "Afvelja allt",
     "ascending" : "hækkandi",
     "descending" : "lækkandi",
     "Sort list by {column} ({direction})" : "Raða lista eftir {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Skrárnar munu birtast eftir því sem farið er í gegnum listann.",
     "Search for an account" : "Leita að notandaaðgangi",
     "Choose" : "Velja",
-    "No files or folders have been deleted yet" : "Engum skrám eða möppum hefur enn verið eytt"
+    "No files or folders have been deleted yet" : "Engum skrám eða möppum hefur enn verið eytt",
+    "Add" : "Bæta við",
+    "The files is locked" : "Skráin er læst"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
