@@ -37,10 +37,6 @@ OC.L10N.register(
     "Set reminder" : "Imposta promemoria",
     "Edit locally" : "Modifica localmente",
     "Open" : "Apri",
-    "Delete file" : "Elimina file",
-    "Delete folder" : "Elimina cartella",
-    "Disconnect storage" : "Disconnetti archiviazione",
-    "Leave this share" : "Abbandona questa condivisione",
     "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
     "Files" : "File",
     "Details" : "Dettagli",
@@ -101,12 +97,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["verifica \"{filter}\"","verificano \"{filter}\"","verificano \"{filter}\""],
     "View in folder" : "Visualizza nella cartella",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
     "Path" : "Percorso",
     "_%n byte_::_%n bytes_" : ["%n byte","%n byte","%n byte"],
     "Favorited" : "Preferiti",
     "Favorite" : "Preferito",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
     "New folder" : "Nuova cartella",
     "Create new folder" : "Crea una nuova cartella",
     "Upload file" : "Carica file",
@@ -127,7 +121,6 @@ OC.L10N.register(
     "Restored by {user}" : "Ripristinata da {user}",
     "Renamed by {user}" : "Rinominata da {user}",
     "Moved by {user}" : "Spostata da {user}",
-    "\"remote user\"" : "\"utente remoto\"",
     "You created {file}" : "Hai creato {file}",
     "You created an encrypted file in {file}" : "Hai creato un file cifrato in {file}",
     "{user} created {file}" : "{user} ha creato {file}",
@@ -175,7 +168,6 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Trascina i file qui per caricarli",
     "Your have used your space quota and cannot upload files anymore" : "Hai esaurito la tua quota di spazio e non puoi più caricare file",
     "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
-    "Upload successful" : "Caricamento effettuato",
     "\"{displayName}\" action executed successfully" : "L'azione \"{displayName}\" è stata eseguita correttamente",
     "\"{displayName}\" action failed" : "L'azione \"{displayName}\" non è riuscita",
     "Rename file" : "Rinomina file",
@@ -192,8 +184,6 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Impossibile rinominare \"{oldName}\", non esiste più",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{newName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
     "Could not rename \"{oldName}\"" : "Impossibile rinominare \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Impossibile copiare {file}. {message}",
-    "Could not move {file}. {message}" : "Impossibile spostare {file}. {message}",
     "Total rows summary" : "Riepilogo totale delle righe",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" non è riuscita su alcuni elementi",
     "\"{displayName}\" batch action executed successfully" : "L'azione batch \"{displayName}\" è stata eseguita correttamente",
@@ -206,6 +196,7 @@ OC.L10N.register(
     "{relative}% used" : "{relative}% usato",
     "Could not refresh storage stats" : "Impossibile aggiornare le statistiche di archiviazione",
     "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
+    "Create" : "Crea",
     "Transfer ownership of a file or folder" : " Trasferisci la proprietà di un file o di una cartella",
     "Choose file or folder to transfer" : "Scegli file o cartella da trasferire",
     "Change" : "Modifica",
@@ -220,7 +211,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Seleziona un file o una cartella da collegare",
     "Choose file" : "Scegli file",
     "Choose {file}" : "Scegli {file}",
-    "Add" : "Aggiungi",
     "Loading current folder" : "Sto caricando la cartella corrente",
     "No files in here" : "Qui non c'è alcun file",
     "Upload some content or sync with your devices!" : "Carica dei contenuti o sincronizza con i tuoi dispositivi!",
@@ -237,7 +227,6 @@ OC.L10N.register(
     "Open the files app settings" : "Apri le impostazioni dell'applicazione File",
     "Files settings" : "Impostazioni File",
     "File cannot be accessed" : "Il file non possono essere acceduti",
-    "You might not have have permissions to view it, ask the sender to share it" : "Potresti non avere i permessi per visualizzarlo, chiedi al mittente di condividerlo",
     "Sort favorites first" : "Ordina prima i preferiti",
     "Show hidden files" : "Mostra i file nascosti",
     "Crop image previews" : "Ritaglia le anteprime delle immagini",
@@ -253,21 +242,19 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Impossibile cambiare lo stato di preferito del file",
     "Error while loading the file data" : "Errore durante il caricamento del file di dati",
     "Pick a template for {name}" : "Scegli un modello per {name}",
-    "Create" : "Crea",
     "Create a new file with the selected template" : "Crea un nuovo file con il modello selezionato",
     "Creating file" : "Creazione del file",
     "Blank" : "Vuoto",
     "Unable to create new file from template" : "Impossibile creare un nuovo file dal modello",
-    "Delete and unshare" : "Elimina e annulla la condivisione",
-    "Unshare" : "Rimuovi condivisione",
     "Delete permanently" : "Elimina permanentemente",
+    "Delete and unshare" : "Elimina e annulla la condivisione",
+    "Cancel" : "Annulla",
     "Destination is not a folder" : "La destinazione non è una cartella",
     "This file/folder is already in that directory" : "Questo file/cartella è già in quella cartella",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Non puoi spostare un file/cartella in se stesso o in una sottocartella di se stesso",
     "(copy)" : "(copia)",
     "(copy %n)" : "(copia %n)",
     "A file or folder with that name already exists in this folder" : "Esiste già un file o una cartella con quel nome in questa cartella",
-    "The files is locked" : "Il file è bloccato",
     "The file does not exist anymore" : "Il file non esiste più",
     "Choose destination" : "Scegli la destinazione",
     "Copy to {target}" : "Copia in {target}",
@@ -276,10 +263,13 @@ OC.L10N.register(
     "Open folder {displayName}" : "Apri la cartella {displayName}",
     "Open in Files" : "Apri in File",
     "Open details" : "Apri i dettagli",
+    "Could not copy {file}. {message}" : "Impossibile copiare {file}. {message}",
+    "Could not move {file}. {message}" : "Impossibile spostare {file}. {message}",
+    "Created new folder \"{name}\"" : "Crea una nuova cartella \"{name}\"",
+    "Filename" : "Nome file",
+    "Unable to initialize the templates directory" : "Impossibile inizializzare la cartella dei modelli",
     "Create new templates folder" : "Crea una nuova cartella dei modelli",
     "Templates" : "Modelli",
-    "Unable to initialize the templates directory" : "Impossibile inizializzare la cartella dei modelli",
-    "Created new folder \"{name}\"" : "Crea una nuova cartella \"{name}\"",
     "One of the dropped files could not be processed" : "Impossibile elaborare uno dei file eliminati",
     "Uploading \"{filename}\" failed" : "Caricamento di \"{filename}\" fallito",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} cartella","{folderCount} cartelle","{folderCount} cartelle"],
@@ -295,17 +285,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Lista di file e cartelle modificati di recente.",
     "No recently modified files" : "Nessun file modificato di recente",
     "Files and folders you recently modified will show up here." : "I file e le cartelle che hai modificato di recente saranno mostrati qui.",
-    "Toggle %1$s sublist" : "Passa alla sottolista %1$s",
     "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
     "Select all" : "Seleziona tutto",
     "Upload too large" : "Caricamento troppo grande",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
     "Text file" : "File di testo",
     "New text file.txt" : "Nuovo file di testo.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Il collegamento diretto è stato copiato (funziona solo per gli utenti che hanno accesso a questo file o cartella)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copia collegamento diretto (funziona solo per utenti che hanno accesso a questo file/cartella)",
     "You can only favorite a single file or folder at a time" : "Puoi aggiungere ai preferiti un singolo file o cartella alla volta",
+    "\"remote user\"" : "\"utente remoto\"",
     "Search users" : "Cerca utenti",
-    "Cancel" : "Annulla",
+    "You might not have have permissions to view it, ask the sender to share it" : "Potresti non avere i permessi per visualizzarlo, chiedi al mittente di condividerlo",
     "Set up templates folder" : "Configura la cartella dei modelli",
+    "Toggle %1$s sublist" : "Passa alla sottolista %1$s",
     "Toggle grid view" : "Commuta la vista a griglia",
     "Deleted files" : "File eliminati",
     "Shares" : "Condivisioni",
@@ -324,6 +317,8 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Questo elenco non è stata mostrato completamente per ragioni di prestazioni. I file saranno mostrati durante la navigazione dell'elenco.",
     "Search for an account" : "Cerca un account",
     "Choose" : "Scegli",
-    "No files or folders have been deleted yet" : "Nessun file o cartella è stato ancora eliminato"
+    "No files or folders have been deleted yet" : "Nessun file o cartella è stato ancora eliminato",
+    "Add" : "Aggiungi",
+    "The files is locked" : "Il file è bloccato"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
