@@ -37,10 +37,10 @@ OC.L10N.register(
     "Set reminder" : "リマインダーを設定",
     "Edit locally" : "ローカルで編集",
     "Open" : "開く",
-    "Delete file" : "ファイルを削除",
-    "Delete folder" : "フォルダーを削除",
-    "Disconnect storage" : "ストレージを切断する",
-    "Leave this share" : "この共有から抜ける",
+    "_Delete file_::_Delete files_" : ["ファイルの削除"],
+    "_Delete folder_::_Delete folders_" : ["フォルダを削除"],
+    "_Disconnect storage_::_Disconnect storages_" : ["ストレージを切断する"],
+    "_Leave this share_::_Leave these shares_" : ["これらの共有から抜ける"],
     "Could not load info for file \"{file}\"" : "\"{file}\" ファイルの情報を読み込めませんでした",
     "Files" : "ファイル",
     "Details" : "詳細",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "ストレージがほぼいっぱい ({usedSpacePercent}％) です　",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : [" \"{filter}\" にマッチ"],
     "View in folder" : "フォルダー内で表示",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "直接リンクがコピーされました（ただしこのファイルやフォルダにアクセスできる人だけが使用可能です）",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "ダイレクトリンクがコピーされました（このファイルやフォルダにアクセスできる人にのみ機能します）",
     "Path" : "Path",
     "_%n byte_::_%n bytes_" : ["%n バイト"],
     "Favorited" : "お気に入り済",
     "Favorite" : "お気に入り",
-    "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダにアクセスできる人にのみ機能します)",
     "New folder" : "新しいフォルダー",
     "Create new folder" : "新しいフォルダーを作成",
     "Upload file" : "ファイルをアップロード",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "{user} が復元しました",
     "Renamed by {user}" : "{user} が作成しました",
     "Moved by {user}" : "{user} が移動しました",
-    "\"remote user\"" : "\"リモートユーザー\"",
+    "\"remote account\"" : "\"リモートアカウント\"",
     "You created {file}" : "{file} を作成しました",
     "You created an encrypted file in {file}" : "{file} で暗号化ファイルを作成しました",
     "{user} created {file}" : "{user} が {file} を作成しました",
@@ -169,13 +169,18 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{user} からの {path} の所有権転送が完了しました。",
     "in %s" : "%s で",
     "File Management" : "ファイル管理",
+    "Current directory path" : "現在のディレクトリパス",
     "Reload current directory" : "カレントディレクトリの再読み込み",
     "Go to the \"{dir}\" directory" : "\"{dir}\" ディレクトリに移動する",
     "Drag and drop files here to upload" : "ここにファイルをドラッグ＆ドロップしてアップロードする",
-    "Upload successful" : "アップロード成功",
+    "Your have used your space quota and cannot upload files anymore" : "あなたのクォータ容量を使い果たし、ファイルをアップロードできなくなりました。",
+    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
+    "Some files could not be uploaded" : "いくつかのファイルがアップロードできませんでした",
+    "Files uploaded successfully" : "ファイルが正常にアップロードされました",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" アクションは正常に実行された",
     "\"{displayName}\" action failed" : "\"{displayName}\" アクションは失敗しました",
-    "Select the row for {displayName}" : "{displayName} の行を選択する",
+    "Toggle selection for file \"{displayName}\"" : "ファイル \"{displayName}\" の選択を切り替える",
+    "Toggle selection for folder \"{displayName}\"" : "フォルダ \"{displayName}\" の選択を切り替える",
     "Rename file" : "ファイル名の変更",
     "File name" : "ファイル名",
     "Folder name" : "フォルダー名",
@@ -190,24 +195,21 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\" の名前を変更できませんでした、それは既に存在しません。",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" という名前は \"{dir}\" フォルダですでに使用されています。別の名前を選択してください。",
     "Could not rename \"{oldName}\"" : "\"{oldName}\" の名前を変更できませんでした。",
-    "Could not copy {file}. {message}" : "{file} をコピーできませんでした。 {message}",
-    "Could not move {file}. {message}" : "{file} を移動できませんでした。 {message}",
     "Total rows summary" : "総行数のサマリー",
-    "Select all" : "すべて選択",
-    "Unselect all" : "すべて選択解除",
+    "Toggle selection for all files and folders" : "すべてのファイルとフォルダの選択を切り替える",
     "\"{displayName}\" failed on some elements " : "いくつかの要素で \"{displayName}\" が失敗しました。",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" バッチアクションが正常に実行されました。",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} と {summaryFolder}",
     "List of files and folders." : "ファイルとフォルダの一覧。",
+    "Column headers with buttons are sortable." : "ボタン付きの列ヘッダはソート可能です。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
     "File not found" : "ファイルが見つかりません",
-    "_{count} file_::_{count} files_" : ["{count} ファイル"],
-    "_{count} folder_::_{count} folders_" : ["{count} フォルダ"],
     "Storage informations" : "ストレージ情報",
     "{usedQuotaByte} used" : "{usedQuotaByte} 使用されています",
     "{relative}% used" : "{relative}% 使用されています",
     "Could not refresh storage stats" : "ストレージの状態を更新できませんでした",
     "Your storage is full, files can not be updated or synced anymore!" : "ストレージは一杯です。ファイルの更新と同期はできません！",
+    "Create" : "作成",
+    "A file or folder with that name already exists." : "その名前のファイルまたはフォルダーは既に存在しています。",
     "Transfer ownership of a file or folder" : "ファイルまたはフォルダーの所有権を譲渡する",
     "Choose file or folder to transfer" : "譲渡するファイルまたはフォルダーを選択してください",
     "Change" : "変更",
@@ -220,8 +222,8 @@ OC.L10N.register(
     "Ownership transfer request sent" : "所有権転送のリクエストを送信しました",
     "Cannot transfer ownership of a file or folder you do not own" : "所有していないファイルまたはフォルダーの所有権を譲渡することはできません",
     "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
+    "Choose file" : "ファイルを選択",
     "Choose {file}" : "{file}を選択",
-    "Add" : "追加",
     "Loading current folder" : "現在のフォルダの読み込み中",
     "No files in here" : "ファイルがありません",
     "Upload some content or sync with your devices!" : "何かコンテンツをアップロードするか、デバイスからファイルを同期してください。",
@@ -232,17 +234,21 @@ OC.L10N.register(
     "Shared" : "共有中",
     "Switch to list view" : "リスト表示へ切り替え",
     "Switch to grid view" : "グリッド表示へ切り替え",
-    "You don’t have permission to upload or create files here" : "ここにファイルをアップロードまたは作成する権限がありません",
+    "Error during upload: {message}" : "アップロード中にエラーが発生しました: {message}",
+    "Error during upload, status code {status}" : "アップロード中のエラー、ステータスコード {status}",
+    "Unknown error during upload" : "不明なエラーがアップロード中に発生しました",
     "Open the files app settings" : "ファイルアプリの設定を開く",
     "Files settings" : "ファイルの設定",
     "File cannot be accessed" : "ファイルにアクセスできません",
-    "You might not have have permissions to view it, ask the sender to share it" : "閲覧権限がない可能性があるため、送信者に共有を依頼してください",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "ファイルが見つからないか、あなたがそれを表示する権限を持っていない可能性があります。送信者に共有するように依頼してください。",
     "Sort favorites first" : "お気に入りを最初に並べる",
+    "Sort folders before files" : "ファイルよりもフォルダを先に並べ替えます",
     "Show hidden files" : "隠しファイルを表示",
     "Crop image previews" : "プレビュー画像を切り抜く",
     "Enable the grid view" : "グリッド表示を有効にする",
     "Additional settings" : "追加設定",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
     "Copy to clipboard" : "クリップボードにコピー",
     "Use this address to access your Files via WebDAV" : "このアドレスを使用すれば、WebDAV経由でファイルにアクセスできます",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2FAを有効にしている場合は、ここをクリックして新しいアプリのパスワードを作成し、使用する必要があります。",
@@ -251,29 +257,42 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "ファイルのお気に入りの状態を変更できません",
     "Error while loading the file data" : "ファイルデータの読み込み中にエラーが発生しました",
     "Pick a template for {name}" : "{name} のテンプレートを選択してください",
-    "Create" : "作成",
     "Create a new file with the selected template" : "選択したテンプレートを使用して新しいファイルを作成します",
     "Creating file" : "ファイル作成",
     "Blank" : "ブランク",
     "Unable to create new file from template" : "テンプレートから新しいファイルを作成できません",
-    "Delete permanently" : "永久に削除",
+    "Delete permanently" : "完全に削除する",
+    "Delete and unshare" : "削除して共有を解除",
+    "You are about to delete {count} items." : "あなたは {count} 個のアイテムを削除しようとしています。",
+    "Confirm deletion" : "削除の確認",
+    "Cancel" : "キャンセル",
+    "Deletion cancelled" : "削除はキャンセルされました",
     "Destination is not a folder" : "宛先がフォルダではありません",
     "This file/folder is already in that directory" : "このファイル/フォルダはすでにそのディレクトリにあります",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "ファイル/フォルダをそれ自身の上に移動したり、それ自身のサブフォルダに移動したりすることはできません。",
+    "(copy)" : "(copy)",
+    "(copy %n)" : "(copy %n)",
     "A file or folder with that name already exists in this folder" : "その名前のファイルまたはフォルダが、このフォルダに既に存在します",
-    "The files is locked" : "ファイルはロックされています",
     "The file does not exist anymore" : "ファイルはもう存在しません",
-    "Chose destination" : "目的地を選ぶ",
+    "Choose destination" : "移動先を選択",
     "Copy to {target}" : "{target} にコピー",
     "Move to {target}" : "{target} に移動",
     "Cancelled move or copy operation" : "キャンセルされた移動またはコピー操作",
+    "Move or copy operation failed" : "移動またはコピー操作は失敗しました",
     "Open folder {displayName}" : "フォルダ {displayName} を開く",
     "Open in Files" : "ファイルアプリで開く",
     "Open details" : "詳細を開く",
+    "An error occurred while uploading. Please try again later." : "アップロード中にエラーが発生しました。後でもう一度お試しください。",
+    "Could not copy {file}. {message}" : "{file} をコピーできませんでした。 {message}",
+    "Could not move {file}. {message}" : "{file} を移動できませんでした。 {message}",
+    "Created new folder \"{name}\"" : "新規フォルダ \"{name}\" を作成しました",
+    "Filename" : "ファイル名",
+    "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
     "Create new templates folder" : "新しいテンプレートフォルダーを作成",
     "Templates" : "テンプレート",
-    "Unable to initialize the templates directory" : "テンプレートディレクトリを初期化できませんでした",
-    "Created new folder \"{name}\"" : "新規フォルダ \"{name}\" を作成した",
+    "New template folder" : "新しいテンプレートフォルダ",
+    "One of the dropped files could not be processed" : "ドロップされたファイルの1つが処理できませんでした",
+    "Uploading \"{filename}\" failed" : "\"{filename}\" のアップロードに失敗しました",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} フォルダ"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} ファイル"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 ファイルと {folderCount} フォルダ"],
@@ -284,19 +303,27 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "お気に入りに登録されたファイルやフォルダーは、ここに表示されます。",
     "All files" : "すべてのファイル",
     "List of your files and folders." : "ファイルやフォルダーの一覧",
+    "Personal Files" : "個人ファイル",
+    "List of your files and folders that are not shared." : "共有されていないファイルやフォルダの一覧。",
+    "No personal files found" : "個人ファイルは見つかりませんでした",
+    "Files that are not shared will show up here." : "共有されていないファイルは、ここに表示されます。",
     "List of recently modified files and folders." : "最近変更されたファイルとフォルダーのリスト",
     "No recently modified files" : "最近更新されたファイルはありません",
     "Files and folders you recently modified will show up here." : "最近変更したファイルやフォルダーがここに表示されます。",
-    "Toggle %1$s sublist" : "サブリスト %1$s を切り替え",
     "No entries found in this folder" : "このフォルダーにはエントリーがありません",
+    "Select all" : "すべて選択",
     "Upload too large" : "アップロードには大きすぎます。",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "アップロードしようとしているファイルは、このサーバーのファイルアップロード時の最大サイズを超えています。",
     "Text file" : "テキストファイル",
     "New text file.txt" : "新規のテキストファイル作成",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "直接リンクがコピーされました（ただしこのファイルやフォルダにアクセスできる人だけが使用可能です）",
+    "Copy direct link (only works for users who have access to this file/folder)" : "ダイレクトリンクをコピー (このファイル/フォルダーにアクセスできるユーザーのみ)",
     "You can only favorite a single file or folder at a time" : "お気に入りに追加できるファイルまたはフォルダーは一度に1つまでです",
+    "\"remote user\"" : "\"リモートユーザー\"",
     "Search users" : "ユーザーを検索",
-    "Cancel" : "キャンセル",
+    "You might not have have permissions to view it, ask the sender to share it" : "閲覧権限がない可能性があるため、送信者に共有を依頼してください",
     "Set up templates folder" : "テンプレートフォルダーを設定",
+    "Toggle %1$s sublist" : "サブリスト %1$s を切り替え",
     "Toggle grid view" : "グリッド表示の切り替え",
     "Deleted files" : "ゴミ箱",
     "Shares" : "共有",
@@ -306,13 +333,17 @@ OC.L10N.register(
     "Pending shares" : "保留中の共有",
     "This file has the tag {tag}" : "このファイルには {tag} タグがあります。",
     "This file has the tags {firstTags} and {lastTag}" : "このファイルには {firstTags} と {lastTag} というタグがあります",
+    "Select the row for {displayName}" : "{displayName} の行を選択する",
     "Open folder {name}" : "フォルダ {name} を開く",
+    "Unselect all" : "すべて選択解除",
     "ascending" : "昇順",
     "descending" : "降順",
     "Sort list by {column} ({direction})" : "{column} ({direction}) でリストを並べ替える",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "このリストはパフォーマンスの都合上、すべてレンダリングされているわけではありません。リスト内を移動すると、ファイルが次々と表示されていきます。",
     "Search for an account" : "アカウントを検索",
     "Choose" : "選択",
-    "No files or folders have been deleted yet" : "まだ削除されたファイルやフォルダはありません"
+    "No files or folders have been deleted yet" : "まだ削除されたファイルやフォルダはありません",
+    "Add" : "追加",
+    "The files is locked" : "ファイルはロックされています"
 },
 "nplurals=1; plural=0;");
