@@ -37,10 +37,6 @@ OC.L10N.register(
     "Set reminder" : "Set reminder",
     "Edit locally" : "Edit locally",
     "Open" : "Open",
-    "Delete file" : "Delete file",
-    "Delete folder" : "Delete folder",
-    "Disconnect storage" : "Disconnect storage",
-    "Leave this share" : "Leave this share",
     "Could not load info for file \"{file}\"" : "Could not load info for file \"{file}\"",
     "Files" : "ფაილები",
     "Details" : "Details",
@@ -101,12 +97,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Your storage is almost full ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matches \"{filter}\"","match \"{filter}\""],
     "View in folder" : "View in folder",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Direct link was copied (only works for users who have access to this file/folder)",
     "Path" : "Path",
     "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
     "Favorited" : "Favorited",
     "Favorite" : "Favorite",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
     "New folder" : "New folder",
     "Create new folder" : "Create new folder",
     "Upload file" : "Upload file",
@@ -127,7 +121,6 @@ OC.L10N.register(
     "Restored by {user}" : "Restored by {user}",
     "Renamed by {user}" : "Renamed by {user}",
     "Moved by {user}" : "Moved by {user}",
-    "\"remote user\"" : "\"remote user\"",
     "You created {file}" : "You created {file}",
     "You created an encrypted file in {file}" : "You created an encrypted file in {file}",
     "{user} created {file}" : "{user} created {file}",
@@ -175,7 +168,6 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Drag and drop files here to upload",
     "Your have used your space quota and cannot upload files anymore" : "Your have used your space quota and cannot upload files anymore",
     "You don’t have permission to upload or create files here" : "You don’t have permission to upload or create files here",
-    "Upload successful" : "Upload successful",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" action executed successfully",
     "\"{displayName}\" action failed" : "\"{displayName}\" action failed",
     "Rename file" : "Rename file",
@@ -192,8 +184,6 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Could not rename \"{oldName}\", it does not exist any more",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name.",
     "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Could not copy {file}. {message}",
-    "Could not move {file}. {message}" : "Could not move {file}. {message}",
     "Total rows summary" : "Total rows summary",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" failed on some elements ",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" batch action executed successfully",
@@ -206,6 +196,7 @@ OC.L10N.register(
     "{relative}% used" : "{relative}% used",
     "Could not refresh storage stats" : "Could not refresh storage stats",
     "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
+    "Create" : "Create",
     "Transfer ownership of a file or folder" : "Transfer ownership of a file or folder",
     "Choose file or folder to transfer" : "Choose file or folder to transfer",
     "Change" : "Change",
@@ -220,7 +211,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Select file or folder to link to",
     "Choose file" : "Choose file",
     "Choose {file}" : "Choose {file}",
-    "Add" : "Add",
     "Loading current folder" : "Loading current folder",
     "No files in here" : "No files in here",
     "Upload some content or sync with your devices!" : "Upload some content or sync with your devices!",
@@ -236,7 +226,6 @@ OC.L10N.register(
     "Open the files app settings" : "Open the files app settings",
     "Files settings" : "Files settings",
     "File cannot be accessed" : "File cannot be accessed",
-    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
     "Sort favorites first" : "Sort favorites first",
     "Show hidden files" : "Show hidden files",
     "Crop image previews" : "Crop image previews",
@@ -252,18 +241,16 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Unable to change the favourite state of the file",
     "Error while loading the file data" : "Error while loading the file data",
     "Pick a template for {name}" : "Pick a template for {name}",
-    "Create" : "Create",
     "Create a new file with the selected template" : "Create a new file with the selected template",
     "Creating file" : "Creating file",
     "Blank" : "Blank",
     "Unable to create new file from template" : "Unable to create new file from template",
-    "Unshare" : "Unshare",
     "Delete permanently" : "Delete permanently",
+    "Cancel" : "Cancel",
     "Destination is not a folder" : "Destination is not a folder",
     "This file/folder is already in that directory" : "This file/folder is already in that directory",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "You cannot move a file/folder onto itself or into a subfolder of itself",
     "A file or folder with that name already exists in this folder" : "A file or folder with that name already exists in this folder",
-    "The files is locked" : "The files is locked",
     "The file does not exist anymore" : "The file does not exist anymore",
     "Choose destination" : "Choose destination",
     "Copy to {target}" : "Copy to {target}",
@@ -272,10 +259,13 @@ OC.L10N.register(
     "Open folder {displayName}" : "Open folder {displayName}",
     "Open in Files" : "Open in Files",
     "Open details" : "Open details",
+    "Could not copy {file}. {message}" : "Could not copy {file}. {message}",
+    "Could not move {file}. {message}" : "Could not move {file}. {message}",
+    "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
+    "Filename" : "Filename",
+    "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
     "Create new templates folder" : "Create new templates folder",
     "Templates" : "Templates",
-    "Unable to initialize the templates directory" : "Unable to initialize the templates directory",
-    "Created new folder \"{name}\"" : "Created new folder \"{name}\"",
     "One of the dropped files could not be processed" : "One of the dropped files could not be processed",
     "Uploading \"{filename}\" failed" : "Uploading \"{filename}\" failed",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} folders"],
@@ -291,17 +281,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "List of recently modified files and folders.",
     "No recently modified files" : "No recently modified files",
     "Files and folders you recently modified will show up here." : "Files and folders you recently modified will show up here.",
-    "Toggle %1$s sublist" : "Toggle %1$s sublist",
     "No entries found in this folder" : "No entries found in this folder",
     "Select all" : "Select all",
     "Upload too large" : "Upload too large",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "The files you are trying to upload exceed the maximum size for file uploads on this server.",
     "Text file" : "Text file",
     "New text file.txt" : "New text file.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Direct link was copied (only works for users who have access to this file/folder)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Copy direct link (only works for users who have access to this file/folder)",
     "You can only favorite a single file or folder at a time" : "You can only favorite a single file or folder at a time",
+    "\"remote user\"" : "\"remote user\"",
     "Search users" : "Search users",
-    "Cancel" : "Cancel",
+    "You might not have have permissions to view it, ask the sender to share it" : "You might not have have permissions to view it, ask the sender to share it",
     "Set up templates folder" : "Set up templates folder",
+    "Toggle %1$s sublist" : "Toggle %1$s sublist",
     "Toggle grid view" : "Toggle grid view",
     "Deleted files" : "Deleted files",
     "Shares" : "Shares",
@@ -320,6 +313,8 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list.",
     "Search for an account" : "Search for an account",
     "Choose" : "Choose",
-    "No files or folders have been deleted yet" : "No files or folders have been deleted yet"
+    "No files or folders have been deleted yet" : "No files or folders have been deleted yet",
+    "Add" : "Add",
+    "The files is locked" : "The files is locked"
 },
 "nplurals=2; plural=(n!=1);");
