@@ -22,6 +22,7 @@ OC.L10N.register(
     "An unknown error has occurred" : "알 수 없는 에러 발생",
     "File could not be uploaded" : "파일을 업로드할 수 없음",
     "Uploading …" : "업로드 중…",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
     "Uploading … ({currentNumber}/{total})" : "업로드 중… ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize}/{totalSize}({bitrate})",
     "Uploading that item is not supported" : "이 항목의 업로드를 지원하지 않습니다.",
@@ -36,10 +37,10 @@ OC.L10N.register(
     "Set reminder" : "알림 설정",
     "Edit locally" : "로컬에서 편집",
     "Open" : "열기",
-    "Delete file" : "파일 삭제",
-    "Delete folder" : "폴더 삭제",
-    "Disconnect storage" : "저장소 연결 해제",
-    "Leave this share" : "이 공유에서 떠나기",
+    "_Delete file_::_Delete files_" : ["파일 삭제"],
+    "_Delete folder_::_Delete folders_" : ["폴더 삭제"],
+    "_Disconnect storage_::_Disconnect storages_" : ["저장소 연결 끊기"],
+    "_Leave this share_::_Leave these shares_" : ["이 공유에서 떠나기"],
     "Could not load info for file \"{file}\"" : "파일 \"{file}\"의 정보를 가져올 수 없음",
     "Files" : "파일",
     "Details" : "자세한 정보",
@@ -100,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "저장 공간이 거의 가득 찼습니다. ({usedSpacePercent}%)",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["'{filter}'와(과) 일치"],
     "View in folder" : "폴더에서 보기",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "직접 링크를 복사했습니다. (이 파일 및 폴더에 접근할 수 있는 사용자에게만 작동)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "직접 링크를 복사했습니다. (이 파일 및 폴더에 접근할 수 있는 사람에게만 작동)",
     "Path" : "경로",
     "_%n byte_::_%n bytes_" : ["%n 바이트"],
     "Favorited" : "즐겨찾기에 추가됨",
     "Favorite" : "즐겨찾기",
-    "Copy direct link (only works for users who have access to this file/folder)" : "직접 링크 복사(이 파일/폴더에 접근 권한이 있는 사람만)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "직접 링크 복사(이 파일/폴더에 접근 권한이 있는 사람만)",
     "New folder" : "새 폴더",
     "Create new folder" : "새 폴더 생성",
     "Upload file" : "파일 업로드",
@@ -126,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "{user} 님이 복원함",
     "Renamed by {user}" : "{user} 님이 이름을 변경함",
     "Moved by {user}" : "{user} 님이 이동함",
-    "\"remote user\"" : "\"원격 사용자\"",
+    "\"remote account\"" : "\"원격 계정\"",
     "You created {file}" : "{file}을(를) 만듦",
     "You created an encrypted file in {file}" : "{file}에 암호화된 파일을 생성했습니다.",
     "{user} created {file}" : "{user} 님이 {file}을(를) 만듦",
@@ -158,8 +159,8 @@ OC.L10N.register(
     "Upload (max. %s)" : "업로드(최대 %s)",
     "Accept" : "수락",
     "Reject" : "거절",
-    "Incoming ownership transfer from {user}" : "{user}(으)로부터 들어오는 중인 소유권 이전",
-    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path}을(를) 받아들이시겠습니까?\n\n참고: 전송 과정은 동의한 시점으로부터 최대 1시간 소요됩니다.",
+    "Incoming ownership transfer from {user}" : "{user}의 소유권 이전 요청",
+    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "{path}의 소유권을 받으시겠습니까?\n\n참고: 이전 과정은 동의한 시점으로부터 최대 1시간 소요됩니다.",
     "Ownership transfer failed" : "소유권 이전 실패",
     "Your ownership transfer of {path} to {user} failed." : "{user}을(를) 향한 {path}의 소유권 이전에 실패했습니다.",
     "The ownership transfer of {path} from {user} failed." : "{user}(으)로부터 {path}의 소유권을 받는 것에 실패했습니다.",
@@ -168,13 +169,18 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{user}(으)로부터 {path}의 소유권을 받았습니다.",
     "in %s" : "%s",
     "File Management" : "파일 관리",
+    "Current directory path" : "현재 디렉토리 경로",
     "Reload current directory" : "이 경로를 새로고침",
     "Go to the \"{dir}\" directory" : "\"{dir}\" 경로로 이동",
     "Drag and drop files here to upload" : "이곳에 파일을 드래그 앤 드롭해 업로드",
-    "Upload successful" : "업로드 성공",
+    "Your have used your space quota and cannot upload files anymore" : "저장소 할당량을 모두 사용하여 더 이상 파일을 업로드할 수 없습니다",
+    "You don’t have permission to upload or create files here" : "여기에 파일을 업로드하거나 만들 권한이 없습니다",
+    "Some files could not be uploaded" : "일부 파일을 업로드할 수 없었습니다.",
+    "Files uploaded successfully" : "파일을 성공적으로 업로드했습니다.",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" 작업을 성공적으로 실행함",
     "\"{displayName}\" action failed" : "\"{displayName}\" 작업을 실패함",
-    "Select the row for {displayName}" : "{displayName}을 위한 행을 선택",
+    "Toggle selection for file \"{displayName}\"" : "파일 \"{displayName}\" 선택/선택해제",
+    "Toggle selection for folder \"{displayName}\"" : "폴더 \"{displayName}\" 선택/선택해제",
     "Rename file" : "파일 이름 바꾸기",
     "File name" : "파일 이름",
     "Folder name" : "폴더 이름",
@@ -189,24 +195,21 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "\"{oldName}\"(이)가 더이상 존재하지 않아 이름을 바꿀 수 없습니다.",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "\"{newName}\" 이름이 \"{dir}\" 폴더에서 이미 사용 중입니다. 다른 이름을 고르세요.",
     "Could not rename \"{oldName}\"" : "\"{oldName}\"의 이름을 바꿀 수 없음",
-    "Could not copy {file}. {message}" : "{file}(을)를 복사할 수 없음. {message}",
-    "Could not move {file}. {message}" : "{file}(을)를 이동할 수 없음. {message}",
     "Total rows summary" : "총 행 요약",
-    "Select all" : "모두 선택",
-    "Unselect all" : "모두 선택 해제",
+    "Toggle selection for all files and folders" : "모든 파일 선택/선택해제",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" 이 일부 요소들에서 실패함",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" 일괄 작업을 성공적으로 실행함",
-    "Sort list by {column}" : "{column}(을)를 기준으로 목록 정렬",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile}(과)와 {summaryFolder}",
     "List of files and folders." : "파일과 폴더의 목록",
+    "Column headers with buttons are sortable." : "버튼이 있는 열 머리글은 정렬할 수 있습니다.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "성능 상의 이유로 목록을 전부 표시하지 않았습니다. 목록을 탐색하면 파일들이 표시됩니다.",
     "File not found" : "파일을 찾을 수 없음",
-    "_{count} file_::_{count} files_" : ["{count}개 파일"],
-    "_{count} folder_::_{count} folders_" : ["{count}개 폴더"],
     "Storage informations" : "저장소 정보",
     "{usedQuotaByte} used" : "{usedQuotaByte} 사용",
     "{relative}% used" : "{relative}% 사용",
     "Could not refresh storage stats" : "저장소 정보를 새로고칠 수 없음",
+    "Your storage is full, files can not be updated or synced anymore!" : "저장 공간이 가득 찼습니다. 파일을 업데이트하거나 동기화할 수 없습니다!",
+    "Create" : "생성",
+    "A file or folder with that name already exists." : "같은 이름을 사용하는 파일 또는 폴더가 이미 있습니다.",
     "Transfer ownership of a file or folder" : "파일이나 폴더의 소유권 이전",
     "Choose file or folder to transfer" : "이전할 파일이나 폴더 고르기",
     "Change" : "변경",
@@ -219,6 +222,8 @@ OC.L10N.register(
     "Ownership transfer request sent" : "소유권 이전 요청이 전송됨",
     "Cannot transfer ownership of a file or folder you do not own" : "내가 소유하지 않은 파일이나 폴더의 소유권을 이전할 수 없음",
     "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
+    "Choose file" : "파일 선택",
+    "Choose {file}" : "{file} 선택",
     "Loading current folder" : "현재 폴더를 불러오는 중",
     "No files in here" : "여기에 파일 없음",
     "Upload some content or sync with your devices!" : "파일을 업로드하거나 장치와 동기화하십시오!",
@@ -229,16 +234,21 @@ OC.L10N.register(
     "Shared" : "공유됨",
     "Switch to list view" : "목록 보기로 전환",
     "Switch to grid view" : "바둑판식 보기로 전환",
+    "Error during upload: {message}" : "업로드 오류: {message}",
+    "Error during upload, status code {status}" : "업로드 중 오류 발생, 상태 코드 {status}",
+    "Unknown error during upload" : "업로드 중 알 수 없는 오류 발생",
     "Open the files app settings" : "파일 앱 설정을 열기",
     "Files settings" : "파일 설정",
     "File cannot be accessed" : "파일에 접근할 수 없음",
-    "You might not have have permissions to view it, ask the sender to share it" : "이것을 볼 권한이 없는 것 같습니다, 보낸 이에게 공유를 요청하세요.",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "파일을 찾을 수 없거나 볼 권한이 없습니다. 보낸 이에게 공유를 요청하세요.",
     "Sort favorites first" : "즐겨찾기를 처음에 나열",
+    "Sort folders before files" : "폴더를 파일보다 먼저 정렬",
     "Show hidden files" : "숨김 파일 보이기",
     "Crop image previews" : "이미지 미리보기 확대",
     "Enable the grid view" : "바둑판식 보기 활성화",
     "Additional settings" : "고급 설정",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV URL",
     "Copy to clipboard" : "클립보드로 복사",
     "Use this address to access your Files via WebDAV" : "이 주소를 사용하여 WebDAV를 통해 내 파일에 접근하세요.",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "2단계 인증을 활성화했다면, 이곳을 클릭해 새로운 앱 암호를 만들어 사용해야 합니다.",
@@ -247,29 +257,43 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "파일의 즐겨찾기 상태를 변경할 수 없음",
     "Error while loading the file data" : "파일 데이터를 불러오는 중 오류 발생",
     "Pick a template for {name}" : "{name}을(를) 위한 템플릿 선택",
-    "Create" : "생성",
     "Create a new file with the selected template" : "선택한 템플릿으로 새 파일 만들기",
     "Creating file" : "파일 만들기",
     "Blank" : "여백",
     "Unable to create new file from template" : "템플릿으로 새 파일을 만들 수 없음",
     "Delete permanently" : "영구히 삭제",
+    "Delete and unshare" : "삭제 및 공유 해제",
+    "You are about to delete {count} items." : "{count}개 항목을 삭제합니다.",
+    "Confirm deletion" : "삭제 확인",
+    "Cancel" : "취소",
+    "Deletion cancelled" : "삭제가 취소됨",
     "Destination is not a folder" : "대상이 폴더가 아닙니다.",
     "This file/folder is already in that directory" : "이 파일/폴더가 이미 그 경로에 있습니다.",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "파일/폴더를 그 안이나 그 안의 폴더로 이동할 수 없습니다.",
+    "(copy)" : "(복사)",
+    "(copy %n)" : "(%n 복사)",
+    "Move cancelled" : "이동이 취소됨",
     "A file or folder with that name already exists in this folder" : "같은 이름을 사용하는 파일 또는 폴더가 이미 이 폴더에 있습니다.",
-    "The files is locked" : "이 파일은 잠겼습니다.",
     "The file does not exist anymore" : "파일이 더이상 존재하지 않습니다.",
-    "Chose destination" : "대상 선택",
+    "Choose destination" : "목적지 선택",
     "Copy to {target}" : "{target}에 복사",
     "Move to {target}" : "{target}에 이동",
     "Cancelled move or copy operation" : "이동 또는 복사 작업을 취소함",
+    "Move or copy operation failed" : "이동 또는 복사 작업에 실패함",
     "Open folder {displayName}" : "{displayName} 폴더 열기",
     "Open in Files" : "파일에서 열기",
     "Open details" : "자세한 정보 열기",
+    "An error occurred while uploading. Please try again later." : "업로드하는 중 오류가 발생했습니다. 잠시 후 다시 시도해 주세요.",
+    "Could not copy {file}. {message}" : "{file}(을)를 복사할 수 없음. {message}",
+    "Could not move {file}. {message}" : "{file}(을)를 이동할 수 없음. {message}",
+    "Created new folder \"{name}\"" : "\"{name}\" 폴더를 새로 만듦",
+    "Filename" : "파일 이름",
+    "Unable to initialize the templates directory" : "템플릿 디렉터리를 설정할 수 없음",
     "Create new templates folder" : "새로운 템플릿 폴더 만들기",
     "Templates" : "템플릿",
-    "Unable to initialize the templates directory" : "템플릿 디렉터리를 설정할 수 없음",
-    "Created new folder \"{name}\"" : "\"{name}\" 폴더를 새로 만듦",
+    "New template folder" : "새 템플릿 폴더",
+    "One of the dropped files could not be processed" : "드롭한 파일 중 하나를 처리할 수 없습니다",
+    "Uploading \"{filename}\" failed" : "\"{filename}\" 업로드가 실패함",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount}개 폴더"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount}개 파일"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1개 파일과 {folderCount}개 폴더"],
@@ -280,39 +304,47 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "즐겨찾기에 추가한 파일과 폴더가 여기에 나타납니다",
     "All files" : "모든 파일",
     "List of your files and folders." : "내 폴더와 파일의 목록",
+    "Personal Files" : "개인 파일",
+    "List of your files and folders that are not shared." : "공유되지 않는 파일과 폴더의 목록",
+    "No personal files found" : "개인 파일을 찾을 수 없음",
+    "Files that are not shared will show up here." : "공유되지 않는 파일이 이곳에 나타납니다.",
     "List of recently modified files and folders." : "최근에 수정된 파일과 폴더의 목록",
     "No recently modified files" : "최근에 수정된 파일 없음",
     "Files and folders you recently modified will show up here." : "최근에 수정한 파일과 폴더가 이곳에 표시됩니다.",
-    "Toggle %1$s sublist" : "%1$s 서브리스트 켜기/끄기",
     "No entries found in this folder" : "이 폴더에 항목 없음",
+    "Select all" : "모두 선택",
     "Upload too large" : "업로드한 파일이 너무 큼",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "이 파일이 서버에서 허용하는 최대 업로드 가능 용량보다 큽니다.",
     "Text file" : "텍스트 파일",
     "New text file.txt" : "새 텍스트 파일.txt",
-    "Storage invalid" : "저장소가 잘못됨",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "직접 링크를 복사했습니다. (이 파일 및 폴더에 접근할 수 있는 사용자에게만 작동)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "직접 링크 복사(이 파일/폴더에 접근 권한이 있는 사람만)",
     "You can only favorite a single file or folder at a time" : "한번에 한 파일 혹은 한 폴더만 즐겨찾기로 지정할 수 있습니다.",
-    "Unlimited" : "무제한",
+    "\"remote user\"" : "\"원격 사용자\"",
     "Search users" : "사용자 검색",
-    "Cancel" : "취소",
+    "You might not have have permissions to view it, ask the sender to share it" : "이것을 볼 권한이 없는 것 같습니다, 보낸 이에게 공유를 요청하세요.",
     "Set up templates folder" : "템플릿 폴더 설정",
-    "%s used" : "%s 사용함",
-    "%1$s of %2$s used" : "%2$s 중 %1$s 사용됨",
+    "Toggle %1$s sublist" : "%1$s 서브리스트 켜기/끄기",
     "Toggle grid view" : "바둑판식 보기 전환",
     "Deleted files" : "삭제된 파일",
     "Shares" : "공유",
     "Shared with others" : "다른 사람과 공유됨",
     "Shared with you" : "나와 공유됨",
     "Deleted shares" : "삭제된 공유",
-    "Pending shares" : "진행중인 공유",
+    "Pending shares" : "보류 중인 공유",
     "This file has the tag {tag}" : "이 파일에 {tag} 태그가 있음",
     "This file has the tags {firstTags} and {lastTag}" : "이 파일에 {firstTags}와 {lastTag} 태그가 있음",
+    "Select the row for {displayName}" : "{displayName}을 위한 행을 선택",
     "Open folder {name}" : "{name} 폴더 열기",
+    "Unselect all" : "모두 선택 해제",
     "ascending" : "오름차순",
     "descending" : "내림차순",
     "Sort list by {column} ({direction})" : "{column} ({direction})으로 목록 정렬",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "이 목록은 성능 상의 이유로 완전히 표시되지 않았습니다. 목록을 탐색하면 파일이 표시됩니다.",
     "Search for an account" : "계정 검색",
     "Choose" : "선택",
-    "No files or folders have been deleted yet" : "아직 삭제된 파일이나 폴더가 없습니다."
+    "No files or folders have been deleted yet" : "아직 삭제된 파일이나 폴더가 없습니다.",
+    "Add" : "추가",
+    "The files is locked" : "이 파일은 잠겼습니다."
 },
 "nplurals=1; plural=0;");
