@@ -36,10 +36,7 @@ OC.L10N.register(
     "Set reminder" : "Nustatyti priminimą",
     "Edit locally" : "Redaguoti lokaliai",
     "Open" : "Atverti",
-    "Delete file" : "Ištrinti failą",
-    "Delete folder" : "Ištrinti aplanką",
-    "Disconnect storage" : "Atjungti saugyklą",
-    "Leave this share" : "Palikti bendrinimą",
+    "_Delete file_::_Delete files_" : ["Ištrinti failą","Ištrinti failus","Ištrinti failus","Ištrinti failus"],
     "Could not load info for file \"{file}\"" : "Nepavyko įkelti informacijos failui „{file}“",
     "Files" : "Failai",
     "Details" : "Išsamiau",
@@ -93,12 +90,10 @@ OC.L10N.register(
     "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Išorinė saugykla \"{mountPoint}\" yra beveik pilna ({usedSpacePercent}%).",
     "Your storage is almost full ({usedSpacePercent}%)." : "Jūsų saugykla yra beveik pilna ({usedSpacePercent}%).",
     "View in folder" : "Rodyti aplanke",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Tiesioginė nuoroda buvo nukopijuota (veikia tik naudotojams, turintiems prieigą prie šio failo/aplanko)",
     "Path" : "Kelias",
     "_%n byte_::_%n bytes_" : ["%n baitas","%n baitai","%n baitų","%n baitų"],
     "Favorited" : "Pažymėtas mėgstamu",
     "Favorite" : "Mėgstamas",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopijuoti tiesioginę nuorodą (veiks tik naudotojams, turintiems prieigą prie šio failo/aplanko)",
     "New folder" : "Naujas aplankas",
     "Create new folder" : "Sukurti naują aplanką",
     "Upload file" : "Įkelti failą",
@@ -119,7 +114,6 @@ OC.L10N.register(
     "Restored by {user}" : "Atkūrė {user}",
     "Renamed by {user}" : "Pervadino {user}",
     "Moved by {user}" : "Perkėlė {user}",
-    "\"remote user\"" : "„nuotolinis naudotojas“",
     "You created {file}" : "Jūs sukūrėte {file}",
     "You created an encrypted file in {file}" : "Sukūrėte užšifruotą failą {file}",
     "{user} created {file}" : "{user} sukūrė {file}",
@@ -161,22 +155,18 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "{path} nuosavybės perdavimas iš naudotojo {user} užbaigtas.",
     "in %s" : "per %s",
     "File Management" : "Failų tvarkymas",
+    "You don’t have permission to upload or create files here" : "Jūs neturite leidimo čia įkelti arba kurti failus",
     "Rename file" : "Pervadinti failą",
     "File name" : "Failo pavadinimas",
     "Folder name" : "Aplanko pavadinimas",
     "Download file {name}" : "Atsisiųsti failą {name}",
     "{newName} already exists." : "{newName} jau yra.",
     "Name cannot be empty" : "Pavadinimas negali būti tuščias",
-    "A long time ago" : "Prieš ilgą laiką",
-    "Could not copy {file}. {message}" : "Nepavyko nukopijuoti {file}. {message}",
-    "Could not move {file}. {message}" : "Nepavyko perkelti {file}. {message}",
-    "Select all" : "Pažymėti viską",
     "List of files and folders." : "Failų ir aplankų sąrašas.",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} ir {summaryFolder}",
     "File not found" : "Failas nerastas",
-    "_{count} file_::_{count} files_" : ["{count} failas","{count} failai","{count} failų","{count} failas"],
-    "_{count} folder_::_{count} folders_" : ["{count} aplankas","{count} aplankai","{count} aplankų","{count} aplankas"],
     "Storage informations" : "Informacija apie saugyklą",
+    "Your storage is full, files can not be updated or synced anymore!" : "Jūsų saugykla pilna, failai daugiau nebegali būti atnaujinti arba sinchronizuojami!",
+    "Create" : "Sukurti",
     "Transfer ownership of a file or folder" : "Perduoti failo ar aplanko nuosavybę",
     "Choose file or folder to transfer" : "Pasirinkti norimą perduoti failą ar aplanką",
     "Change" : "Keisti",
@@ -205,30 +195,33 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Nepavyksta pakeisti failo Lankomiausiųjų būsenos",
     "Error while loading the file data" : "Klaida įkeliant failo duomenis",
     "Pick a template for {name}" : "Pasirinkite šabloną, skirtą {name}",
-    "Create" : "Sukurti",
     "Create a new file with the selected template" : "Sukurti naują failą naudojant pasirinktą šabloną",
     "Creating file" : "Sukuriamas failas",
     "Unable to create new file from template" : "Nepavyko sukurti naujo failo iš šablono",
     "Delete permanently" : "Ištrinti negrįžtamai",
+    "Cancel" : "Atsisakyti",
     "The file does not exist anymore" : "Failo daugiau nebėra",
-    "Templates" : "Šablonai",
+    "Copy to {target}" : "Kopijuoti į {target}",
+    "Move to {target}" : "Perkelti į {target}",
+    "Could not copy {file}. {message}" : "Nepavyko nukopijuoti {file}. {message}",
+    "Could not move {file}. {message}" : "Nepavyko perkelti {file}. {message}",
+    "Filename" : "Failo pavadinimas",
     "Unable to initialize the templates directory" : "Nepavyko inicijuoti šablonų katalogo",
+    "Templates" : "Šablonai",
     "No favorites yet" : "Kol kas nėra mėgstamų",
     "Files and folders you mark as favorite will show up here" : "Čia bus rodomi failai ir aplankai, kuriuos pažymėsite kaip mėgstamus",
     "All files" : "Visi failai",
     "No entries found in this folder" : "Nerasta įrašų šiame aplanke",
+    "Select all" : "Pažymėti viską",
     "Upload too large" : "Įkėlimui failas per didelis",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Bandomų įkelti failų dydis viršija maksimalų, šiame serveryje leidžiamų įkelti failų dydį.",
     "Text file" : "Tekstinis failas",
     "New text file.txt" : "Naujas tekstinis failas.txt",
-    "Storage invalid" : "Saugykla netinkama naudoti",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Tiesioginė nuoroda buvo nukopijuota (veikia tik naudotojams, turintiems prieigą prie šio failo/aplanko)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopijuoti tiesioginę nuorodą (veiks tik naudotojams, turintiems prieigą prie šio failo/aplanko)",
     "You can only favorite a single file or folder at a time" : "Vienu metu galite pažymėti mėgstamu tik vieną failą ar aplanką",
-    "Unlimited" : "Neribotai",
+    "\"remote user\"" : "„nuotolinis naudotojas“",
     "Search users" : "Ieškoti naudotojų",
-    "Cancel" : "Atsisakyti",
-    "%s used" : "%s panaudota",
-    "%s%%" : "%s%%",
-    "%1$s of %2$s used" : "naudojama %1$s iš %2$s",
     "Toggle grid view" : "Rodyti tinkleliu",
     "Deleted files" : "Ištrinti failai",
     "Shares" : "Viešiniai",
@@ -237,6 +230,7 @@ OC.L10N.register(
     "Deleted shares" : "Ištrinti viešiniai",
     "Pending shares" : "Laukiantys viešiniai",
     "This file has the tag {tag}" : "Šis failas turi žymą {tag}",
-    "Choose" : "Pasirinkite"
+    "Choose" : "Pasirinkite",
+    "Add" : "Pridėti"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
