@@ -37,10 +37,6 @@ OC.L10N.register(
     "Set reminder" : "Постави потсетник",
     "Edit locally" : "Уреди локално",
     "Open" : "Отвори",
-    "Delete file" : "Избриши датотека",
-    "Delete folder" : "Избриши папка",
-    "Disconnect storage" : "Исклучи складиште",
-    "Leave this share" : "Оставете го ова споделување",
     "Could not load info for file \"{file}\"" : "Неможе да се вчитаат информации за датотеката \"{file}\"",
     "Files" : "Датотеки",
     "Details" : "Детали:",
@@ -101,12 +97,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Вашето складиште е скоро исполнето ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["содржи '{filter}'","содржи '{filter}'"],
     "View in folder" : "Погледни во папката",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Копиран е директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
     "Path" : "Патека",
     "_%n byte_::_%n bytes_" : ["%n бајт","%n бајти"],
     "Favorited" : "Омилени",
     "Favorite" : "Омилени",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
     "New folder" : "Нова папка",
     "Create new folder" : "Креирај нова папка",
     "Upload file" : "Прикачи датотека",
@@ -127,7 +121,6 @@ OC.L10N.register(
     "Restored by {user}" : "Вратено од {user}",
     "Renamed by {user}" : "Преименувано од {user}",
     "Moved by {user}" : "Преместено од {user}",
-    "\"remote user\"" : "\"далечен корисник\"",
     "You created {file}" : "Креиравте {file}",
     "You created an encrypted file in {file}" : "Креиравте шифрирана датотека во {file}",
     "{user} created {file}" : "{user} креираше {file}",
@@ -169,11 +162,14 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Трансферот на сопственост на {path} од {user} е комплетиран.",
     "in %s" : "во %s",
     "File Management" : "Датотеки",
+    "Current directory path" : "Патека до оваа папка",
     "Reload current directory" : "Превчитај ја повторно моменталната папка",
     "Go to the \"{dir}\" directory" : "Оди до \"{dir}\" папката",
+    "Drag and drop files here to upload" : "Повлечи и испушти датотеки за прикачување",
+    "Your have used your space quota and cannot upload files anymore" : "Го имате искористено лимитот на просторот за прикачување и повеќе неможете да прикачувате датотеки",
+    "You don’t have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" акцијата е успешно извршена",
     "\"{displayName}\" action failed" : "\"{displayName}\" акцијата не успеа",
-    "Select the row for {displayName}" : "Избери ред за {displayName}",
     "Rename file" : "Преименувај датотека",
     "File name" : "Име на датотека",
     "Folder name" : "Име на папка",
@@ -181,6 +177,7 @@ OC.L10N.register(
     "Download file {name}" : "Преземи датотека {name}",
     "\"{name}\" is not an allowed filetype." : "\"{name}\" не е дозволен вид на датотека.",
     "{newName} already exists." : "{newName} веќе постои.",
+    "\"{char}\" is not allowed inside a file name." : "карактерот \"{char}\" не е дозволен во име на датотека.",
     "Name cannot be empty" : "Името неможе да биде празно",
     "Another entry with the same name already exists" : "Друг запис со исто име веќе постои",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Преименувано \"{oldName}\" во \"{newName}\"",
@@ -188,21 +185,18 @@ OC.L10N.register(
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{newName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
     "Could not rename \"{oldName}\"" : "Неможе да се преименува \"{oldName}\"",
     "Total rows summary" : "Резиме на вкупно редови",
-    "Select all" : "Избери се",
-    "Unselect all" : "Од-означи се",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" не успеа на некои елементи",
     "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" сериската акцијата е успешно извршена",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} и {summaryFolder}",
     "List of files and folders." : "Листа на датотеки и папки.",
+    "Column headers with buttons are sortable." : "Насловите на колоните со копчиња се сортираат.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Оваа листа не е целосно прикажана поради заштеда на перформанси. Датотеките ќе се прикажуваат додека се движите низ листата.",
     "File not found" : "Датотеката не е пронајдена",
-    "_{count} file_::_{count} files_" : ["{count} датотека","{count} датотеки"],
-    "_{count} folder_::_{count} folders_" : ["{count} папка","{count} папки"],
     "Storage informations" : "Информации за складиштето",
     "{usedQuotaByte} used" : "искористено {usedQuotaByte}",
     "{relative}% used" : "искористено {relative}% ",
     "Could not refresh storage stats" : "Неможе да се ажурира статистиката за складиштата",
     "Your storage is full, files can not be updated or synced anymore!" : "Вашето складиште е исполнето, датотеките веќе не можат да се ажирираат или синхронизираат!",
+    "Create" : "Креирај",
     "Transfer ownership of a file or folder" : "Трансфер на сопственост на датотека или папка",
     "Choose file or folder to transfer" : "Избери датотека или папка за трансфер",
     "Change" : "Измени",
@@ -215,8 +209,8 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Испратено барање за трансфер на сопственост",
     "Cannot transfer ownership of a file or folder you do not own" : "Неможете да направите трансвер на сопственот на папка која не е ваша",
     "Select file or folder to link to" : "Изберете датотека или папка за линк до",
+    "Choose file" : "Избери датотека",
     "Choose {file}" : "Избери {file}",
-    "Add" : "Додади",
     "Loading current folder" : "Вчитување на моменталната папка",
     "No files in here" : "Тука нема датотеки",
     "Upload some content or sync with your devices!" : "Прикачете некоја содржина или синхронизирајте со вашите уреди!",
@@ -225,16 +219,20 @@ OC.L10N.register(
     "Share" : "Сподели",
     "Shared by link" : "Споделено со линк",
     "Shared" : "Споделено",
-    "You don’t have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки",
+    "Switch to list view" : "Прикажи поглед во листа",
+    "Switch to grid view" : "Прикажи поглед во мрежа",
+    "Error during upload: {message}" : "Грешка при прикачување: {message}",
+    "Unknown error during upload" : "Непозната грешка при прикачување",
     "Open the files app settings" : "Отвори ги параметрите за датотеките",
     "Files settings" : "Параметри за датотеки",
     "File cannot be accessed" : "Неможе да се пристапи до датотеката",
-    "You might not have have permissions to view it, ask the sender to share it" : "Можеби немате дозвола за преглед, прашајте го испраќачот за споделувањето",
     "Sort favorites first" : "Прво омилените",
     "Show hidden files" : "Прикажи сокриени датотеки",
     "Crop image previews" : "Исечи ја сликата за преглед",
+    "Enable the grid view" : "Овозможи поглед во мрежа",
     "Additional settings" : "Дополнителни параметри",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "WebDAV адреса",
     "Copy to clipboard" : "Копирај во клипборд",
     "Use this address to access your Files via WebDAV" : "Користи ја оваа адреса за пристап до вашите датотеки преку WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако имате овозможено 2FA, мора да креирате и користите нова лозинка за апликација со кликнување овде.",
@@ -243,21 +241,38 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Неможе да се промени статусот на омимени на датотеката",
     "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
     "Pick a template for {name}" : "Избери шаблон за {name}",
-    "Create" : "Креирај",
     "Create a new file with the selected template" : "Креирај нова датотека со избраниот шаблон",
     "Creating file" : "Креирање на датотека",
     "Blank" : "Празно",
     "Unable to create new file from template" : "Неможе да се креира датотека од шаблон",
     "Delete permanently" : "Избриши",
+    "Cancel" : "Откажи",
+    "Destination is not a folder" : "Дестинацијата не е папка",
+    "This file/folder is already in that directory" : "Оваа папка/датотека се наоѓа веќе во таа папка",
+    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможете да преместите датотека/папка во себеси или во подпапка во себеси",
+    "A file or folder with that name already exists in this folder" : "Датотека или папка со тоа име веќе постои во оваа папка",
+    "The file does not exist anymore" : "Датотеката не постои",
+    "Choose destination" : "Избери дестинација",
     "Copy to {target}" : "Копирај во {target}",
     "Move to {target}" : "Премести во {target}",
+    "Cancelled move or copy operation" : "Откажана операција на копирање или преместување",
     "Open folder {displayName}" : "Отвори папка {displayName}",
     "Open in Files" : "Отвори во датотеките",
     "Open details" : "Отвори детали",
+    "Could not copy {file}. {message}" : "Неможе да се копира {file}. {message}",
+    "Could not move {file}. {message}" : "Неможе да се премести {file}. {message}",
+    "Created new folder \"{name}\"" : "Креирана нова папка \"{name}\"",
+    "Filename" : "Име на датотека",
+    "Unable to initialize the templates directory" : "Не може да се иницијализира папка за шаблони",
     "Create new templates folder" : "Креирај нова папка за шаблони",
     "Templates" : "Шаблони",
-    "Unable to initialize the templates directory" : "Не може да се иницијализира папка за шаблони",
-    "Created new folder \"{name}\"" : "Креирана нова папка \"{name}\"",
+    "One of the dropped files could not be processed" : "Една од испуштените датотеки неможе да се процесоира",
+    "Uploading \"{filename}\" failed" : "Неуспешно прикашување \"{filename}\"",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} датотека","{fileCount} датотеки"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 датотека и {folderCount} папки","1 датотека и {folderCount} папки"],
+    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} датотека и 1 папка","{fileCount} датотеки и 1 папка"],
+    "{fileCount} files and {folderCount} folders" : "{fileCount} датотеки и {folderCount} папки",
     "List of favorites files and folders." : "Листа на омилени датотеки и папки.",
     "No favorites yet" : "Сеуште нема фаворити",
     "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
@@ -266,16 +281,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Листа на скоро изменети датотеки и папки.",
     "No recently modified files" : "Нема скоро изменети датотеки",
     "Files and folders you recently modified will show up here." : "Датотеките и папките кои скоро ќе ги измените ќе се појават тука.",
-    "Toggle %1$s sublist" : "Вклучи %1$s подлисти",
     "No entries found in this folder" : "Нема ништо во оваа папка",
+    "Select all" : "Избери се",
     "Upload too large" : "Фајлот кој се вчитува е преголем",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
     "Text file" : "Текстуална датотека",
     "New text file.txt" : "Нова текстуална датотека file.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Копиран е директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
     "You can only favorite a single file or folder at a time" : "Можете да додавате само по една датотека или папка во фаворити одеднаш",
+    "\"remote user\"" : "\"далечен корисник\"",
     "Search users" : "Пребарувај корисници",
-    "Cancel" : "Откажи",
+    "You might not have have permissions to view it, ask the sender to share it" : "Можеби немате дозвола за преглед, прашајте го испраќачот за споделувањето",
     "Set up templates folder" : "Поставете папка за шаблони",
+    "Toggle %1$s sublist" : "Вклучи %1$s подлисти",
     "Toggle grid view" : "Промена во мрежа",
     "Deleted files" : "Избришани датотеки",
     "Shares" : "Споделувања",
@@ -285,13 +304,17 @@ OC.L10N.register(
     "Pending shares" : "Споделувања на чекање",
     "This file has the tag {tag}" : "Оваа датотека има ознака {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Оваа датотека има ознаки {firstTags} и {lastTag}",
+    "Select the row for {displayName}" : "Избери ред за {displayName}",
     "Open folder {name}" : "Отвори папка {name}",
+    "Unselect all" : "Од-означи се",
     "ascending" : "растечки",
     "descending" : "опаѓачки",
     "Sort list by {column} ({direction})" : "Подреди листа по {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Оваа листа не е целосно прикажана поради заштеда на перформанси. Датотеките ќе се прикажуваат додека се движите низ листата.",
     "Search for an account" : "Пребарај сметка",
     "Choose" : "Избери",
-    "No files or folders have been deleted yet" : "Нема датотеки или папки што се избришани"
+    "No files or folders have been deleted yet" : "Нема датотеки или папки што се избришани",
+    "Add" : "Додади",
+    "The files is locked" : "Датотекатите се заклучени"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
