@@ -37,10 +37,6 @@ OC.L10N.register(
     "Set reminder" : "Ustaw przypomnienie",
     "Edit locally" : "Edytuj lokalnie",
     "Open" : "Otwórz",
-    "Delete file" : "Usuń plik",
-    "Delete folder" : "Usuń katalog",
-    "Disconnect storage" : "Odłącz magazyn",
-    "Leave this share" : "Opuść udostępnienie",
     "Could not load info for file \"{file}\"" : "Nie można załadować informacji o pliku \"{file}\"",
     "Files" : "Pliki",
     "Details" : "Szczegóły",
@@ -101,12 +97,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Twój magazyn jest prawie pełny ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["pasuje do \"{filter}\"","pasują do \"{filter}\"","pasują do \"{filter}\"","pasują do \"{filter}\""],
     "View in folder" : "Zobacz w katalogu",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Bezpośredni link został skopiowany (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
     "Path" : "Ścieżka",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
     "Favorited" : "Ulubiony",
     "Favorite" : "Ulubiony",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
     "New folder" : "Nowy katalog",
     "Create new folder" : "Utwórz nowy katalog",
     "Upload file" : "Wyślij plik",
@@ -127,7 +121,6 @@ OC.L10N.register(
     "Restored by {user}" : "Przywrócone przez {user}",
     "Renamed by {user}" : "Zmienione przez {user}",
     "Moved by {user}" : "Przeniesione przez {user}",
-    "\"remote user\"" : "\"użytkownik zdalny\"",
     "You created {file}" : "Utworzy‭łeś {file}",
     "You created an encrypted file in {file}" : "Stworzyłeś zaszyfrowany plik w {file}",
     "{user} created {file}" : "{user} utworzy‭ł {file}",
@@ -172,10 +165,9 @@ OC.L10N.register(
     "Reload current directory" : "Przeładuj bieżący katalog",
     "Go to the \"{dir}\" directory" : "Przejdź do katalogu \"{dir}\"",
     "Drag and drop files here to upload" : "Przeciągnij i upuść pliki tutaj, aby je przesłać",
-    "Upload successful" : "Wysyłanie zakończone",
+    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
     "\"{displayName}\" action executed successfully" : "Akcja \"{displayName}\" została wykonana pomyślnie",
     "\"{displayName}\" action failed" : "Akcja \"{displayName}\" nie powiodła się",
-    "Select the row for {displayName}" : "Wybierz wiersz dla {displayName}",
     "Rename file" : "Zmień nazwę pliku",
     "File name" : "Nazwa pliku",
     "Folder name" : "Nazwa katalogu",
@@ -190,24 +182,18 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Nie można zmienić nazwy \"{oldName}\", już nie istnieje",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{newName}\" jest już używana w folderze \"{dir}\". Wybierz inną nazwę.",
     "Could not rename \"{oldName}\"" : "Nie można zmienić nazwy \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Nie można skopiować {file}. {message}",
-    "Could not move {file}. {message}" : "Nie można przenieść {file}. {message}",
     "Total rows summary" : "Podsumowanie wszystkich wierszy",
-    "Select all" : "Wybierz wszystko",
-    "Unselect all" : "Odznacz wszystko",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" nie powiodło się w przypadku niektórych elementów",
     "\"{displayName}\" batch action executed successfully" : "Akcja wsadowa \"{displayName}\" została wykonana pomyślnie",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} i {summaryFolder}.",
     "List of files and folders." : "Lista plików i katalogów.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
     "File not found" : "Nie odnaleziono pliku",
-    "_{count} file_::_{count} files_" : ["{count} plik","{count} pliki","{count} plików","{count} plików"],
-    "_{count} folder_::_{count} folders_" : ["{count} folder","{count} foldery","{count} folderów","{count} folderów"],
     "Storage informations" : "Informacje o przechowywaniu",
     "{usedQuotaByte} used" : "Wykorzystano {usedQuotaByte}",
     "{relative}% used" : "Wykorzystano {relative}%",
     "Could not refresh storage stats" : "Nie można odświeżyć statystyk przechowywania",
     "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Nie można już zaktualizować ani zsynchronizować plików!",
+    "Create" : "Utwórz",
     "Transfer ownership of a file or folder" : "Przenieś własność pliku lub katalogu",
     "Choose file or folder to transfer" : "Wybierz plik lub katalog do przeniesienia",
     "Change" : "Zmień",
@@ -221,7 +207,6 @@ OC.L10N.register(
     "Cannot transfer ownership of a file or folder you do not own" : "Nie można przenieść prawa własności do pliku lub katalogu, którego nie jesteś właścicielem",
     "Select file or folder to link to" : "Wybierz plik lub katalog do linku",
     "Choose {file}" : "Wybierz {file}",
-    "Add" : "Dodaj",
     "Loading current folder" : "Ładowanie bieżącego katalogu",
     "No files in here" : "Brak plików",
     "Upload some content or sync with your devices!" : "Wyślij lub zsynchronizuj pliki z urządzeniami.",
@@ -232,11 +217,9 @@ OC.L10N.register(
     "Shared" : "Udostępnione",
     "Switch to list view" : "Przełącz na widok listy",
     "Switch to grid view" : "Przełącz na widok siatki",
-    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wysyłania lub tworzenia plików w tym miejscu",
     "Open the files app settings" : "Otwórz ustawienia aplikacji plików",
     "Files settings" : "Ustawienia Plików",
     "File cannot be accessed" : "Nie można uzyskać dostępu do pliku",
-    "You might not have have permissions to view it, ask the sender to share it" : "Możesz nie mieć uprawnień, aby go wyświetlić, poproś nadawcę o udostępnienie",
     "Sort favorites first" : "Najpierw sortuj ulubione",
     "Show hidden files" : "Pokaż ukryte pliki",
     "Crop image previews" : "Przytnij podglądy obrazów",
@@ -251,29 +234,30 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Nie można zmienić ulubionego stanu pliku",
     "Error while loading the file data" : "Błąd podczas ładowania danych pliku",
     "Pick a template for {name}" : "Wybierz szablon dla {name}",
-    "Create" : "Utwórz",
     "Create a new file with the selected template" : "Utwórz nowy plik z wybranym szablonem",
     "Creating file" : "Tworzenie pliku",
     "Blank" : "Pusty",
     "Unable to create new file from template" : "Nie można utworzyć nowego pliku z szablonu",
     "Delete permanently" : "Usuń bezpowrotnie",
+    "Cancel" : "Anuluj",
     "Destination is not a folder" : "Miejsce docelowe nie jest katalogiem",
     "This file/folder is already in that directory" : "Ten plik/katalog znajduje się już w tym katalogu",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nie można przenieść pliku/katalogu do tego samego katalogu lub do własnego podkatalogu",
     "A file or folder with that name already exists in this folder" : "Plik lub katalog o tej nazwie już istnieje w tym katalogu",
-    "The files is locked" : "Pliki są zablokowane",
     "The file does not exist anymore" : "Plik już nie istnieje",
-    "Chose destination" : "Wybierz miejsce docelowe",
     "Copy to {target}" : "Skopiuj do {target}",
     "Move to {target}" : "Przenieś do {target}",
     "Cancelled move or copy operation" : "Anulowano operację przenoszenia lub kopiowania",
     "Open folder {displayName}" : "Otwórz katalog {displayName}",
     "Open in Files" : "Otwórz w Plikach",
     "Open details" : "Otwórz szczegóły",
+    "Could not copy {file}. {message}" : "Nie można skopiować {file}. {message}",
+    "Could not move {file}. {message}" : "Nie można przenieść {file}. {message}",
+    "Created new folder \"{name}\"" : "Utworzono nowy katalog \"{name}\"",
+    "Filename" : "Nazwa pliku",
+    "Unable to initialize the templates directory" : "Nie można zainicjować katalogu szablonów",
     "Create new templates folder" : "Stwórz nowy folder z szablonami",
     "Templates" : "Szablony",
-    "Unable to initialize the templates directory" : "Nie można zainicjować katalogu szablonów",
-    "Created new folder \"{name}\"" : "Utworzono nowy katalog \"{name}\"",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} katalog","{folderCount} katalogi","{folderCount} katalogów","{folderCount} katalogów"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} plik","{fileCount} pliki","{fileCount} plików","{fileCount} plików"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 plik i {folderCount} katalog","1 plik i {folderCount} katalogi","1 plik i {folderCount} katalogów","1 plik i {folderCount} katalogów"],
@@ -287,16 +271,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Lista ostatnio zmodyfikowanych plików i katalogów.",
     "No recently modified files" : "Brak ostatnio zmodyfikowanych plików",
     "Files and folders you recently modified will show up here." : "Tutaj pojawią się pliki i katalogi, które ostatnio zmodyfikowałeś.",
-    "Toggle %1$s sublist" : "Przełącz podlistę %1$s",
     "No entries found in this folder" : "Brak wpisów w tym katalogu",
+    "Select all" : "Wybierz wszystko",
     "Upload too large" : "Wysyłany plik jest za duży",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz wysłać, przekraczają maksymalną dopuszczalną wielkość.",
     "Text file" : "Plik tekstowy",
     "New text file.txt" : "Nowy plik tekstowy.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Bezpośredni link został skopiowany (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj bezpośredni link (działa tylko dla użytkowników, którzy mają dostęp do tego pliku/katalogu)",
     "You can only favorite a single file or folder at a time" : "Możesz dodać do ulubionych tylko pojedynczy plik lub katalog",
+    "\"remote user\"" : "\"użytkownik zdalny\"",
     "Search users" : "Wyszukaj użytkowników",
-    "Cancel" : "Anuluj",
+    "You might not have have permissions to view it, ask the sender to share it" : "Możesz nie mieć uprawnień, aby go wyświetlić, poproś nadawcę o udostępnienie",
     "Set up templates folder" : "Skonfiguruj katalog szablonów",
+    "Toggle %1$s sublist" : "Przełącz podlistę %1$s",
     "Toggle grid view" : "Przełącz widok siatki",
     "Deleted files" : "Usunięte pliki",
     "Shares" : "Udostępnione",
@@ -306,13 +294,17 @@ OC.L10N.register(
     "Pending shares" : "Oczekujące udostępnienia",
     "This file has the tag {tag}" : "Ten plik posiada etykietę {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Ten plik posiada etykiety {firstTags} i {lastTag}",
+    "Select the row for {displayName}" : "Wybierz wiersz dla {displayName}",
     "Open folder {name}" : "Otwórz katalog {name}",
+    "Unselect all" : "Odznacz wszystko",
     "ascending" : "rosnąco",
     "descending" : "malejąco",
     "Sort list by {column} ({direction})" : "Sortuj listę według {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ta lista nie jest w pełni renderowana ze względu na wydajność. Pliki będą renderowane podczas poruszania się po liście.",
     "Search for an account" : "Wyszukaj konto",
     "Choose" : "Wybierz",
-    "No files or folders have been deleted yet" : "Żadne pliki ani katalogi nie zostały jeszcze usunięte"
+    "No files or folders have been deleted yet" : "Żadne pliki ani katalogi nie zostały jeszcze usunięte",
+    "Add" : "Dodaj",
+    "The files is locked" : "Pliki są zablokowane"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
