@@ -37,10 +37,10 @@ OC.L10N.register(
     "Set reminder" : "Установить напоминание",
     "Edit locally" : "Редактировать локально",
     "Open" : "Открыть",
-    "Delete file" : "Удалить файл",
-    "Delete folder" : "Удалить каталог",
-    "Disconnect storage" : "Отсоединить хранилище",
-    "Leave this share" : "Отказаться от совместного доступа к этому ресурсу",
+    "_Delete file_::_Delete files_" : ["Удалить файл","Удалить файлы","Удалить файлы","Удалить файлы"],
+    "_Delete folder_::_Delete folders_" : ["Удалить папку","Удалить папки","Удалить папки","Удалить папки"],
+    "_Disconnect storage_::_Disconnect storages_" : ["Отключить хранилище","Отключить хранилища","Отключить хранилища","Отключить хранилища"],
+    "_Leave this share_::_Leave these shares_" : ["Отказаться от доступа к общему ресурсу","Отказаться от доступа к общим ресурсам","Отказаться от доступа к общим ресурсам","Отказаться от доступа к общим ресурсам"],
     "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
     "Files" : "Файлы",
     "Details" : "Подробно",
@@ -101,13 +101,13 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ваше хранилище почти заполнено (использовано {usedSpacePercent} %).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["соответствуют «{filter}»","соответствуют «{filter}»","соответствуют «{filter}»","соответствует «{filter}»"],
     "View in folder" : "Посмотреть в каталоге",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых есть доступ к этому файлу или папке. ",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых уже есть доступ к этому файлу или папке. ",
     "Path" : "Путь",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
     "Favorited" : "Избранное",
     "Favorite" : "Добавить в избранное",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Копировать прямую ссылку (работает только для пользователей с правами доступа к этому файлу или каталогу)",
-    "New folder" : "Новый каталог",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Копировать прямую ссылку (она сработает только для пользователей, у которых уже есть доступ к этому файлу или каталогу)",
+    "New folder" : "Новая папка",
     "Create new folder" : "Создать папку",
     "Upload file" : "Загрузить файл",
     "Recent" : "Недавно изменённые",
@@ -121,13 +121,13 @@ OC.L10N.register(
     "You removed {file} from your favorites" : "Вы удалили «{file}» из избранного",
     "Favorites" : "Избранные",
     "File changes" : "Изменения файлов",
-    "Created by {user}" : "Создано {user}",
-    "Changed by {user}" : "Изменено {user}",
-    "Deleted by {user}" : "Удалено {user}",
-    "Restored by {user}" : "Восстановлено {user}",
-    "Renamed by {user}" : "Переименовано {user}",
-    "Moved by {user}" : "Перемещено {user}",
-    "\"remote user\"" : "«пользователь с другого сервера»",
+    "Created by {user}" : "Создано пользователем {user}",
+    "Changed by {user}" : "Изменено пользователем {user}",
+    "Deleted by {user}" : "Удалено пользователем {user}",
+    "Restored by {user}" : "Восстановлено пользователем {user}",
+    "Renamed by {user}" : "Переименовано пользователем {user}",
+    "Moved by {user}" : "Перемещено пользователем {user}",
+    "\"remote account\"" : "«пользователь другого сервера»",
     "You created {file}" : "Вы создали «{file}»",
     "You created an encrypted file in {file}" : "Вы создали зашифрованный файл в «{file}»",
     "{user} created {file}" : "{user} создал(а) «{file}»",
@@ -169,13 +169,18 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Завершена передача владения «{path}» от пользователя {user}.",
     "in %s" : "в %s",
     "File Management" : "Управление файлами",
+    "Current directory path" : "Текущий путь к каталогу",
     "Reload current directory" : "Обновить текущий каталог",
     "Go to the \"{dir}\" directory" : "Перейти в каталог \"{dir}\"",
     "Drag and drop files here to upload" : "Перетаскивайте файлы сюда для загрузки",
-    "Upload successful" : "Загружено успешно",
+    "Your have used your space quota and cannot upload files anymore" : "Вы использовали всё доступное вам место и не можете больше загружать файлы",
+    "You don’t have permission to upload or create files here" : "У вас нет прав на создание или загрузку файлов в эту папку.",
+    "Some files could not be uploaded" : "Некоторые файлы не могут быть загружены",
+    "Files uploaded successfully" : "Файлы успешно обновлены",
     "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
     "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
-    "Select the row for {displayName}" : "Выбрать строку для {displayName}",
+    "Toggle selection for file \"{displayName}\"" : "Установить или снять выделение файла «{displayName}»",
+    "Toggle selection for folder \"{displayName}\"" : "Установить или снять выделение папки «{displayName}»",
     "Rename file" : "Переименовать файл",
     "File name" : "Имя файла",
     "Folder name" : "Имя папки",
@@ -190,24 +195,21 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Не удалось переименовать \"{oldName}\", его больше не существует",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{newName}\" уже используется в каталоге \"{dir}\". Выберите другое имя.",
     "Could not rename \"{oldName}\"" : "Не удалось переименовать «{oldName}»",
-    "Could not copy {file}. {message}" : "Ошибка копирования «{file}». {message}",
-    "Could not move {file}. {message}" : "Ошибка перемещения «{file}». {message}",
     "Total rows summary" : "Количество строк в общем",
-    "Select all" : "Выбрать всё",
-    "Unselect all" : "Отменить выделение для всех",
+    "Toggle selection for all files and folders" : "Установить или снять выделение всех файлов и папок",
     "\"{displayName}\" failed on some elements " : "«{displayName}» неудачно для некоторых элементов",
     "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} и {summaryFolder}",
     "List of files and folders." : "Список файлов и каталогов.",
+    "Column headers with buttons are sortable." : "Заголовки столбцов с кнопками можно сортировать.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
     "File not found" : "Файл не найден",
-    "_{count} file_::_{count} files_" : ["{count} файл","{count} файла","{count} файлов","{count} файлов"],
-    "_{count} folder_::_{count} folders_" : ["{count} папка","{count} папки","{count} папок","{count} папок"],
     "Storage informations" : "Сведения о хранилище",
     "{usedQuotaByte} used" : "Использовано {usedQuotaByte}",
     "{relative}% used" : "Использовано {relative}%",
     "Could not refresh storage stats" : "Не удалось обновить данные об использовании хранилища",
     "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище переполнено, файлы больше не могут быть обновлены или синхронизированы.",
+    "Create" : "Создать",
+    "A file or folder with that name already exists." : "Файл или папка с этим именем уже существуют.",
     "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
     "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
     "Change" : "Изменить",
@@ -220,8 +222,8 @@ OC.L10N.register(
     "Ownership transfer request sent" : "Запрос на передачу прав владения отправлен",
     "Cannot transfer ownership of a file or folder you do not own" : "Невозможно передать право владения на файл или каталог, которые вам не принадлежат",
     "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
+    "Choose file" : "Выберите файл",
     "Choose {file}" : "Выберан {file}",
-    "Add" : "Добавить",
     "Loading current folder" : "Загрузка текущей папки",
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
@@ -232,17 +234,21 @@ OC.L10N.register(
     "Shared" : "Опубликованное",
     "Switch to list view" : "Переключение в режим просмотра списка",
     "Switch to grid view" : "Переключиться на режим просмотра сеткой",
-    "You don’t have permission to upload or create files here" : "У вас нет прав на создание или загрузку файлов в эту папку.",
+    "Error during upload: {message}" : "Ошибка при загрузке: {message}",
+    "Error during upload, status code {status}" : "Ошибка при передаче на сервер. Сообщение об ошибке: {status}",
+    "Unknown error during upload" : "Неизвестная ошибка при загрузке",
     "Open the files app settings" : "Открыть параметры приложения «Файлы»",
     "Files settings" : "Настройки файлов",
     "File cannot be accessed" : "Не удалось получить доступ к файлу",
-    "You might not have have permissions to view it, ask the sender to share it" : "У вас отсутствуют права на просмотр файла, попросите предоставить их у владельца общего ресурса",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не удалось найти файл или у вас отсутствуют права на его просмотр.  Попросите отправителя предоставить вам доступ к этому файлу.",
     "Sort favorites first" : "Сначала избранное",
+    "Sort folders before files" : "Начинать список с папок",
     "Show hidden files" : "Показывать скрытые файлы",
     "Crop image previews" : "Обрезать пред. просмотр",
     "Enable the grid view" : "Включить режим просмотра сеткой",
     "Additional settings" : "Дополнительные параметры",
     "WebDAV" : "WebDAV",
+    "WebDAV URL" : "Ссылка WebDAV",
     "Copy to clipboard" : "Копировать в буфер",
     "Use this address to access your Files via WebDAV" : "Используйте этот адрес для подключения WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Если вы используете двухфакторную аутентификацию, то нажмите здесь чтобы создать пароль приложения.",
@@ -251,32 +257,45 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Не удалось изменить состояние «избранный» этого файла.",
     "Error while loading the file data" : "Не удалось загрузить данные файла",
     "Pick a template for {name}" : "Выбрать шаблон для {name}",
-    "Create" : "Создать",
     "Create a new file with the selected template" : "Создать файл на основе шаблона",
     "Creating file" : "Создание файла",
     "Blank" : "Пустой",
     "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
     "Delete permanently" : "Удалить навсегда",
+    "Delete and unshare" : "Удалить и закрыть общий доступ",
+    "You are about to delete {count} items." : "Подтвердите удаление {count} объекта (-ов).",
+    "Confirm deletion" : "Подтвердить удаление",
+    "Cancel" : "Отменить",
+    "Deletion cancelled" : "Удаление отменено",
     "Destination is not a folder" : "Указанное назначение не является папкой",
     "This file/folder is already in that directory" : "Файл или папка уже расположены в этой папке",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Папка или файл не могут быть перемещены во вложенную папку или в себя",
+    "(copy)" : "(копия)",
+    "(copy %n)" : "(копия %n)",
     "A file or folder with that name already exists in this folder" : "В этой папке уже есть файл или папка с этим именем",
-    "The files is locked" : "Файлы заблокированы",
     "The file does not exist anymore" : "Файл больше не существует",
-    "Chose destination" : "Выбор места назначения",
+    "Choose destination" : "Выберите место назначения",
     "Copy to {target}" : "Скопировать в «{target}»",
     "Move to {target}" : "Переместить в «{target}»",
     "Cancelled move or copy operation" : "Копирование или перемещение отменено",
+    "Move or copy operation failed" : "Ошибка перемещение или копирования",
     "Open folder {displayName}" : "Открыть каталог {displayName}",
     "Open in Files" : "Открыть в Файлах",
     "Open details" : "Открыть подробности",
+    "An error occurred while uploading. Please try again later." : "Ошибка во время передачи на сервер, попробуйте ещё раз.",
+    "Could not copy {file}. {message}" : "Ошибка копирования «{file}». {message}",
+    "Could not move {file}. {message}" : "Ошибка перемещения «{file}». {message}",
+    "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
+    "Filename" : "Имя файла",
+    "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
     "Create new templates folder" : "Создать новую папку шаблонов",
     "Templates" : "Шаблоны",
-    "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
-    "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{count} папка","{count} папки","{count} папок","{count} папки"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{count} файл","{count} файла","{count} файлов","{count} файла"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {count} папка","один файл и {count} папки","один файл и {count} папок","один файл и {count} папки"],
+    "New template folder" : "Новая папка шаблонов",
+    "One of the dropped files could not be processed" : "Один из перетащенных файлов не может быть обработан",
+    "Uploading \"{filename}\" failed" : "Загрузка \"{filename}\" не удалась",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{count} папка","{count} папки","{count} папок","{folderCount} папки"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{count} файл","{count} файла","{count} файлов","{fileCount} файла"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {count} папка","один файл и {count} папки","один файл и {count} папок","один файл и {folderCount} папки"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
     "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
     "List of favorites files and folders." : "Список избранных файлов и каталогов.",
@@ -284,19 +303,27 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
     "All files" : "Все файлы",
     "List of your files and folders." : "Список ваших файлов и каталогов.",
+    "Personal Files" : "Личные Файлы",
+    "List of your files and folders that are not shared." : "Список ваших неопубликованных файлов и папок.",
+    "No personal files found" : "Личные файлы не найдены",
+    "Files that are not shared will show up here." : "Файлы, которые не опубликованы, показаны здесь.",
     "List of recently modified files and folders." : "Список недавно измененных файлов и директорий.",
     "No recently modified files" : "Нет недавно измененных файлов",
     "Files and folders you recently modified will show up here." : "Здесь будут показаны недавно изменённые файлы и папки",
-    "Toggle %1$s sublist" : "Переключить %1$s подсписок",
     "No entries found in this folder" : "В этом каталоге ничего не найдено",
+    "Select all" : "Выбрать всё",
     "Upload too large" : "Файл слишком велик",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
     "Text file" : "Текстовый файл",
     "New text file.txt" : "Новый текстовый файл.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых есть доступ к этому файлу или папке. ",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Копировать прямую ссылку (работает только для пользователей с правами доступа к этому файлу или каталогу)",
     "You can only favorite a single file or folder at a time" : "Одновременно можно выбрать только один файл или папку",
+    "\"remote user\"" : "«пользователь с другого сервера»",
     "Search users" : "Поиск пользователей",
-    "Cancel" : "Отменить",
+    "You might not have have permissions to view it, ask the sender to share it" : "У вас отсутствуют права на просмотр файла, попросите предоставить их у владельца общего ресурса",
     "Set up templates folder" : "Указать папку шаблонов",
+    "Toggle %1$s sublist" : "Переключить %1$s подсписок",
     "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
     "Deleted files" : "Корзина",
     "Shares" : "Общие ресурсы",
@@ -306,13 +333,17 @@ OC.L10N.register(
     "Pending shares" : "Ожидающие общие ресурсы",
     "This file has the tag {tag}" : "Файлу назначана метка «{tag}»",
     "This file has the tags {firstTags} and {lastTag}" : "Файлу назначены метки «{firstTags}» и «{lastTag}»",
+    "Select the row for {displayName}" : "Выбрать строку для {displayName}",
     "Open folder {name}" : "Открыть папку {name}",
+    "Unselect all" : "Отменить выделение для всех",
     "ascending" : "восходящий",
     "descending" : "нисходящий",
     "Sort list by {column} ({direction})" : "Сортировать список по {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
     "Search for an account" : "Поиск по учетной записи",
     "Choose" : "Выберите",
-    "No files or folders have been deleted yet" : "Файлы или папки еще не удалены"
+    "No files or folders have been deleted yet" : "Файлы или папки еще не удалены",
+    "Add" : "Добавить",
+    "The files is locked" : "Файлы заблокированы"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
