@@ -37,10 +37,6 @@ OC.L10N.register(
     "Set reminder" : "Nastaviť pripomienku",
     "Edit locally" : "Editovať lokálne",
     "Open" : "Otvoriť",
-    "Delete file" : "Zmazať súbor",
-    "Delete folder" : "Zmazať priečinok",
-    "Disconnect storage" : "Odpojiť úložisko",
-    "Leave this share" : "Opustiť toto zdieľanie",
     "Could not load info for file \"{file}\"" : "Nebolo možné načítať informácie súboru \"{file}\"",
     "Files" : "Súbory",
     "Details" : "Podrobnosti",
@@ -101,12 +97,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["odpovedá \"{filter}\"","odpovedá \"{filter}\"","odpovedá \"{filter}\"","odpovedajú \"{filter}\""],
     "View in folder" : "Zobraziť v priečinku",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Priamy odkaz bol skopirovaný (funguje iba pre používateľov, ktorí majú prístup k danému súboru/adresáru)",
     "Path" : "Cesta",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov","%n bajtov"],
     "Favorited" : "Pridané k obľúbeným",
     "Favorite" : "Obľúbené",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopírovať priamy odkaz (funguje iba pre používateľov, ktorí majú prístup k tomuto súboru/priečinku)",
     "New folder" : "Nový priečinok",
     "Create new folder" : "Vytvoriť nový priečinok",
     "Upload file" : "Nahrať súbor",
@@ -127,7 +121,6 @@ OC.L10N.register(
     "Restored by {user}" : "Obnovené užívateľom {user}",
     "Renamed by {user}" : "Premenované užívateľom {user}",
     "Moved by {user}" : "Presunuté užívateľom {user}",
-    "\"remote user\"" : "\"vzdialený používateľ\"",
     "You created {file}" : "Vytvorili ste súbor {file}",
     "You created an encrypted file in {file}" : "Vytvorili ste zašifrovaný súbor  {file}",
     "{user} created {file}" : "{user} vytvoril súbor {file}",
@@ -174,7 +167,6 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Pre nahratie presuňte do tohto priestoru súbory ťahaním",
     "Your have used your space quota and cannot upload files anymore" : "Dosiahli ste limit vášho priestoru a už viac nemôžete nahrávať súbory",
     "You don’t have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvoriť súbory",
-    "Upload successful" : "Nahrávanie bolo úspešné",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\" akcia vykonaná úspešne",
     "\"{displayName}\" action failed" : "\"{displayName}\" akcia zlýhala",
     "Rename file" : "Premenovať súbor",
@@ -191,8 +183,6 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Nebolo možné premenovať  \"{oldName}\". Položka už neexistuje.",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{newName}\" sa už používa v priečinku \"{dir}\". Vyberte prosím iný názov.",
     "Could not rename \"{oldName}\"" : "Nebolo možné premenovať \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Nepodarilo sa skopírovať {file}. {message}",
-    "Could not move {file}. {message}" : "Nepodarilo sa presunúť {file}. {message}",
     "Total rows summary" : "Súčet všetkých riadkov",
     "\"{displayName}\" batch action executed successfully" : "Hromadná operácia \"{displayName}\" bola úspešne vykonaná",
     "List of files and folders." : "Zoznam súborov a priečinkov.",
@@ -204,6 +194,7 @@ OC.L10N.register(
     "{relative}% used" : "{relative}% použitých",
     "Could not refresh storage stats" : "Nebolo možné obnoviť úložiskové štatistiky",
     "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
+    "Create" : "Vytvoriť",
     "Transfer ownership of a file or folder" : "Prevod vlastníctva súboru alebo priečinka",
     "Choose file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
     "Change" : "Zmeniť",
@@ -217,7 +208,6 @@ OC.L10N.register(
     "Cannot transfer ownership of a file or folder you do not own" : "Nie je možné preniesť vlastníctvo súboru alebo priečinka, ktorý nevlastníte",
     "Select file or folder to link to" : "Vyberte súbor alebo priečinok na ktorý odkazovať",
     "Choose {file}" : "Vyberte {file}",
-    "Add" : "Pridať",
     "Loading current folder" : "Načítavanie súčasného priečinka",
     "No files in here" : "Nie sú tu žiadne súbory",
     "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte dáta so svojimi zariadeniami!",
@@ -233,7 +223,6 @@ OC.L10N.register(
     "Open the files app settings" : "Otvoriť nastavenia súborovej aplikácie",
     "Files settings" : "Nastavenia súborov",
     "File cannot be accessed" : "Súbor nie je možné sprístupniť",
-    "You might not have have permissions to view it, ask the sender to share it" : "Pravdopodobne nemáte prístup, požiadajte oň odosielateľa ",
     "Sort favorites first" : "Zoradiť od najobľúbenejších",
     "Show hidden files" : "Zobraziť skryté súbory",
     "Crop image previews" : "Orezať náhľady obrázkov",
@@ -249,18 +238,16 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Nie je možné zmeniť stav „obľúbené“ daného súboru",
     "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
     "Pick a template for {name}" : "Vyberte šablónu pre {name}",
-    "Create" : "Vytvoriť",
     "Create a new file with the selected template" : "Vytvoriť nový súbor pomocou vybranej šablóny",
     "Creating file" : "Vytvára sa súbor",
     "Blank" : "Prázdne",
     "Unable to create new file from template" : "Nemôžem vytvoriť nový súbor zo šablóny",
-    "Unshare" : "Zrušiť zdieľanie",
     "Delete permanently" : "Zmazať  natrvalo",
+    "Cancel" : "Zrušiť",
     "Destination is not a folder" : "Cieľ nie je priečinok",
     "This file/folder is already in that directory" : "Tento súbor/priečinok sa už v danom adresári nachádza",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nemôžete presunúť súbor/priečinok do seba alebo do jeho podpriečinka.",
     "A file or folder with that name already exists in this folder" : "Súbor alebo priečinok s týmto názvom už existuje v tomto priečinku",
-    "The files is locked" : "Súbory sú uzamknuté",
     "The file does not exist anymore" : "Súbor už neexistuje",
     "Copy to {target}" : "Kopírovať do {target}",
     "Move to {target}" : "Presunúť do {target}",
@@ -268,10 +255,13 @@ OC.L10N.register(
     "Open folder {displayName}" : "Otvoriť priečinok {displayName}",
     "Open in Files" : "Otvoriť v súboroch",
     "Open details" : "Otvoriť detaily",
+    "Could not copy {file}. {message}" : "Nepodarilo sa skopírovať {file}. {message}",
+    "Could not move {file}. {message}" : "Nepodarilo sa presunúť {file}. {message}",
+    "Created new folder \"{name}\"" : "Vytvorený nový priečinok \"{name}\"",
+    "Filename" : "Názov súboru",
+    "Unable to initialize the templates directory" : "Nemôžem inicializovať priečinok so šablónami",
     "Create new templates folder" : "Vytvoriť nový vzorový priečinok",
     "Templates" : "Šablóny",
-    "Unable to initialize the templates directory" : "Nemôžem inicializovať priečinok so šablónami",
-    "Created new folder \"{name}\"" : "Vytvorený nový priečinok \"{name}\"",
     "Uploading \"{filename}\" failed" : "Nahrávanie \"{filename}\" zlyhalo",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} priečinok","{folderCount} priečinky","{folderCount} priečinkov","{folderCount} priečinkov"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} súbor","{fileCount} súbory","{fileCount} súborov","{fileCount} súborov"],
@@ -286,17 +276,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Zoznam nedávno upravených súborov a priečinkov.",
     "No recently modified files" : "Žiadne nedávno upravené súbory",
     "Files and folders you recently modified will show up here." : "Súbory a priečinky, ktoré ste nedávno upravili sa zobrazia tu",
-    "Toggle %1$s sublist" : "Prepnúť %1$s podzoznam",
     "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
     "Select all" : "Vybrať všetko",
     "Upload too large" : "Nahrávanie je príliš veľké",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
     "Text file" : "Textový súbor",
     "New text file.txt" : "Nový text file.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Priamy odkaz bol skopirovaný (funguje iba pre používateľov, ktorí majú prístup k danému súboru/adresáru)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopírovať priamy odkaz (funguje iba pre používateľov, ktorí majú prístup k tomuto súboru/priečinku)",
     "You can only favorite a single file or folder at a time" : "Do obľúbených je možné zaradovať súbory a zložky len jednotlivo",
+    "\"remote user\"" : "\"vzdialený používateľ\"",
     "Search users" : "Hľadať používateľov",
-    "Cancel" : "Zrušiť",
+    "You might not have have permissions to view it, ask the sender to share it" : "Pravdopodobne nemáte prístup, požiadajte oň odosielateľa ",
     "Set up templates folder" : "Nastaviť priečinok pre šablóny",
+    "Toggle %1$s sublist" : "Prepnúť %1$s podzoznam",
     "Toggle grid view" : "Prepnúť zobrazenie mriežky",
     "Deleted files" : "Zmazané súbory",
     "Shares" : "Zdieľania",
@@ -315,6 +308,8 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzat zoznamom.",
     "Search for an account" : "Vyhľadať účet",
     "Choose" : "Vybrať",
-    "No files or folders have been deleted yet" : "Žiadne súbory alebo priečinky neboli ešte vymazané"
+    "No files or folders have been deleted yet" : "Žiadne súbory alebo priečinky neboli ešte vymazané",
+    "Add" : "Pridať",
+    "The files is locked" : "Súbory sú uzamknuté"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
