@@ -37,10 +37,7 @@ OC.L10N.register(
     "Set reminder" : "Nastavi opomnik",
     "Edit locally" : "Uredi krajevno",
     "Open" : "Odpri",
-    "Delete file" : "Izbriši datoteko",
-    "Delete folder" : "Izbriši mapo",
-    "Disconnect storage" : "Odklopi shrambo",
-    "Leave this share" : "Zapusti to mesto souporabe",
+    "_Delete file_::_Delete files_" : ["Izbriši datoteko","Izbriši datoteki","Izbriši datoteke","Izbriši datoteke"],
     "Could not load info for file \"{file}\"" : "Ni mogoče naložiti podatkov za datoteko »{file}«.",
     "Files" : "Datoteke",
     "Details" : "Podrobnosti",
@@ -101,12 +98,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Vaša shramba je skoraj do konca zasedena ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["se skladajo s filtrom »{filter}«","se skladajo s filtroma »{filter}«","se skladajo s filtri »{filter}«","se skladajo s filtri »{filter}«"],
     "View in folder" : "Pokaži v mapi",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
     "Path" : "Pot",
     "_%n byte_::_%n bytes_" : ["%n bajt","%n bajta","%n bajti","%n bajtov"],
     "Favorited" : "Označeno kot priljubljeno",
     "Favorite" : "Priljubljene",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
     "New folder" : "Nova mapa",
     "Create new folder" : "Ustvari novo mapo",
     "Upload file" : "Pošlji datoteko",
@@ -127,7 +122,6 @@ OC.L10N.register(
     "Restored by {user}" : "{user} obnovi predmet",
     "Renamed by {user}" : "{user} preimenuje predmet",
     "Moved by {user}" : "{user} premakne predmet",
-    "\"remote user\"" : "»Oddaljen uporabnik«",
     "You created {file}" : "Ustvarite datoteko ali mapo {file}",
     "You created an encrypted file in {file}" : "Ustvarite šifrirano datoteko v {file}",
     "{user} created {file}" : "{user} ustvari datoteko {file}",
@@ -172,10 +166,9 @@ OC.L10N.register(
     "Reload current directory" : "Ponovno naloži trenutno mapo",
     "Go to the \"{dir}\" directory" : "Pojdi v mapo »{dir}«",
     "Drag and drop files here to upload" : "Za pošiljanje potegnite in spustite datoteke na to mesto",
-    "Upload successful" : "Pošiljanje je uspešno končano",
+    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje in ustvarjanje datotek na tem mestu.",
     "\"{displayName}\" action executed successfully" : "Dejanje »{displayName}« je uspešno izvedeno",
     "\"{displayName}\" action failed" : "Dejanje »{displayName}« je spodletelo",
-    "Select the row for {displayName}" : "Izbor vrstice za {displayName}",
     "Rename file" : "Preimenuj datoteke",
     "File name" : "Ime datoteke",
     "Folder name" : "Ime mape",
@@ -190,24 +183,18 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Datoteke »{oldName}« ni mogoče preimenovati, ker ne obstaja več.",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ime »{newtName}« je v mapi »{dir}« že v uporabi. Izbrati je treba drugačno ime.",
     "Could not rename \"{oldName}\"" : "Datoteke »{oldName}« ni mogoče preimenovati",
-    "Could not copy {file}. {message}" : "Datoteke {file} ni mogoče kopirati. {message}",
-    "Could not move {file}. {message}" : "Datoteke {file} ni mogoče premakniti. {message}",
     "Total rows summary" : "Skupni povzetek vrstic",
-    "Select all" : "izberi vse",
-    "Unselect all" : "Odstrani izbor",
     "\"{displayName}\" failed on some elements " : "Dejanje »{displayName}« je pri nekaterih predmetih spodletelo",
     "\"{displayName}\" batch action executed successfully" : "Paketno dejanje »{displayName}« je uspešno izvedeno",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} in {summaryFolder}",
     "List of files and folders." : "Seznam datotek in map",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Seznam datotek ni v celoti izpisan zaradi zagotavljanja hitrosti in odzivnosti sistema. Predmeti se bodo dopolnjevali med brskanjem.",
     "File not found" : "Datoteke ni mogoče najti",
-    "_{count} file_::_{count} files_" : ["{count} datoteka","{count} datoteki","{count} datoteke","{count} datotek"],
-    "_{count} folder_::_{count} folders_" : ["{count} mapa","{count} mapi","{count} mape","{count} map"],
     "Storage informations" : "Podrobnosti shrambe",
     "{usedQuotaByte} used" : "Zasedeno {usedQuotaByte}",
     "{relative}% used" : "Zasedeno {relative} %",
     "Could not refresh storage stats" : "Ni mogoče osvežiti podatkov shrambe",
     "Your storage is full, files can not be updated or synced anymore!" : "Shramba je povsem napolnjena. Datotek ni več mogoče posodabljati in usklajevati!",
+    "Create" : "Ustvari",
     "Transfer ownership of a file or folder" : "Prenos lastništva datoteke ali mape",
     "Choose file or folder to transfer" : "Izbor datoteke ali mape za prenos",
     "Change" : "Spremeni",
@@ -221,7 +208,6 @@ OC.L10N.register(
     "Cannot transfer ownership of a file or folder you do not own" : "Ni mogoče prenesti lastništva datotek in map, katerih niste lastnik",
     "Select file or folder to link to" : "Izbor datoteke ali mape za povezavo",
     "Choose {file}" : "Izberite datoteko {file}",
-    "Add" : "Dodaj",
     "Loading current folder" : "Poteka nalaganje trenutne mape",
     "No files in here" : "V mapi ni datotek",
     "Upload some content or sync with your devices!" : "Uvozite vsebino, ali pa omogočite usklajevanje z napravami!",
@@ -232,11 +218,9 @@ OC.L10N.register(
     "Shared" : "V souporabi",
     "Switch to list view" : "Preklopi na seznamski pogled",
     "Switch to grid view" : "Preklopi na mrežni pogled",
-    "You don’t have permission to upload or create files here" : "Ni ustreznih dovoljenj za pošiljanje in ustvarjanje datotek na tem mestu.",
     "Open the files app settings" : "Odpri nastavitve programa Datoteke",
     "Files settings" : "Nastavitve datotek",
     "File cannot be accessed" : "Do datoteke dostop ni mogoč",
-    "You might not have have permissions to view it, ask the sender to share it" : "Morda ni ustreznih dovoljenj za ogled. Prosite pošiljatelja za prilagoditev.",
     "Sort favorites first" : "Razvrsti najprej priljubljene",
     "Show hidden files" : "Pokaži skrite datoteke",
     "Crop image previews" : "Obreži slike predogleda",
@@ -251,29 +235,30 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Ni mogoče spremeniti stanja priljubljenosti datoteke",
     "Error while loading the file data" : "Prišlo je do napake med nalaganjem podatkov računa",
     "Pick a template for {name}" : "Izbor predloge za {name}",
-    "Create" : "Ustvari",
     "Create a new file with the selected template" : "Ustvari novo datoteko z izbrano predlogo",
     "Creating file" : "Poteka ustvarjanje datoteke",
     "Blank" : "Prazno",
     "Unable to create new file from template" : "Nove datoteke iz predloge ni mogoče ustvariti",
     "Delete permanently" : "Trajno izbriši",
+    "Cancel" : "Prekliči",
     "Destination is not a folder" : "Ciljno mesto ni mapa",
     "This file/folder is already in that directory" : "Ta datoteka oziroma mapa je že v določeni mapi",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Mape ali datoteke ni mogoče premakniti samo vase oziroma v podmapo same sebe",
     "A file or folder with that name already exists in this folder" : "Datoteka oziroma mapa s tem imenom v tej mapi že obstaja",
-    "The files is locked" : "Datoteka je zaklenjena",
     "The file does not exist anymore" : "Datoteka ne obstaja več",
-    "Chose destination" : "Izbor ciljnega mesta",
     "Copy to {target}" : "Kopiraj na {target}",
     "Move to {target}" : "Premakni na {target}",
     "Cancelled move or copy operation" : "Opravilo kopiranje in premikanja je preklicano",
     "Open folder {displayName}" : "Odpri mapo {displayName}",
     "Open in Files" : "Open in Files",
     "Open details" : "Odpri podrobnosti",
+    "Could not copy {file}. {message}" : "Datoteke {file} ni mogoče kopirati. {message}",
+    "Could not move {file}. {message}" : "Datoteke {file} ni mogoče premakniti. {message}",
+    "Created new folder \"{name}\"" : "Ustvarjena je nova mapa »{name}«.",
+    "Filename" : "Ime datoteke",
+    "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
     "Create new templates folder" : "Ustvari novo začasno mapo",
     "Templates" : "Predloge",
-    "Unable to initialize the templates directory" : "Ni mogoče začeti mape predlog",
-    "Created new folder \"{name}\"" : "Ustvarjena je nova mapa »{name}«.",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapa","{folderCount} mapi","{folderCount} mape","{folderCount} map"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} datoteka","{fileCount} datoteki","{fileCount} datoteke","{fileCount} datotek"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 datoteka in {folderCount} mapa","1 datoteka in {folderCount} mapi","1 datoteka in {folderCount} mape","1 datoteka in {folderCount} map"],
@@ -287,16 +272,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Seznam nedavno spremenjenih datotek in map.",
     "No recently modified files" : "Ni nedavno spremenjenih datotek",
     "Files and folders you recently modified will show up here." : "Nedavno spremenjene datoteke ali mape, bodo zbrane na tem mestu.",
-    "Toggle %1$s sublist" : "Preklopi podseznam %1$s",
     "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
+    "Select all" : "izberi vse",
     "Upload too large" : "Prekoračena je omejitev dovoljene velikosti",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Datoteke, ki jih želite poslati, presegajo največjo dovoljeno velikost na strežniku.",
     "Text file" : "Besedilna datoteka",
     "New text file.txt" : "nova_datoteka.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Kopirana je neposredna povezava (za uporabnike, ki imajo dostop do datoteke ali mape)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiraj neposredno povezavo (za uporabnike, ki imajo dostop do datoteke ali mape)",
     "You can only favorite a single file or folder at a time" : "Kot priljubljeno je mogoče naenkrat označiti le eno datoteko ali mapo.",
+    "\"remote user\"" : "»Oddaljen uporabnik«",
     "Search users" : "Iskanje uporabnikov",
-    "Cancel" : "Prekliči",
+    "You might not have have permissions to view it, ask the sender to share it" : "Morda ni ustreznih dovoljenj za ogled. Prosite pošiljatelja za prilagoditev.",
     "Set up templates folder" : "Nastavitev mape predlog",
+    "Toggle %1$s sublist" : "Preklopi podseznam %1$s",
     "Toggle grid view" : "Preklopi mrežni pogled",
     "Deleted files" : "Izbrisane datoteke",
     "Shares" : "Souporaba",
@@ -306,13 +295,17 @@ OC.L10N.register(
     "Pending shares" : "Predmeti za souporabo na čakanju",
     "This file has the tag {tag}" : "Datoteka je označena z oznako {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Ta datoteka ima oznake {firstTags} in {lastTag}",
+    "Select the row for {displayName}" : "Izbor vrstice za {displayName}",
     "Open folder {name}" : "Odpri mapo {name}",
+    "Unselect all" : "Odstrani izbor",
     "ascending" : "naraščajoče",
     "descending" : "padajoče",
     "Sort list by {column} ({direction})" : "Razvrsti seznam po stolpcu {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Seznam datotek ni v celoti izpisan zaradi zagotavljanja hitrosti in odzivnosti sistema. Predmeti se bodo dopolnjevali ob brskanju.",
     "Search for an account" : "Poišči račun",
     "Choose" : "Izbor",
-    "No files or folders have been deleted yet" : "Ni še izbrisanih datotek in map"
+    "No files or folders have been deleted yet" : "Ni še izbrisanih datotek in map",
+    "Add" : "Dodaj",
+    "The files is locked" : "Datoteka je zaklenjena"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
