@@ -37,10 +37,10 @@ OC.L10N.register(
     "Set reminder" : "Постави подсетник",
     "Edit locally" : "Уреди локално",
     "Open" : "Отвори",
-    "Delete file" : "Обриши фајл",
-    "Delete folder" : "Обриши фасциклу",
-    "Disconnect storage" : "Искључи складиште",
-    "Leave this share" : "Напусти ово дељење",
+    "_Delete file_::_Delete files_" : ["Обриши фајл","Обриши фајлове","Обриши фајлове"],
+    "_Delete folder_::_Delete folders_" : ["Обрши фолдер","Обриши фолдере","Обриши фолдере"],
+    "_Disconnect storage_::_Disconnect storages_" : ["Искључи складиште","Искључи складишта","Искључи складишта"],
+    "_Leave this share_::_Leave these shares_" : ["Напусти ово дељење","Напусти ова дељења","Напусти ова дељења"],
     "Could not load info for file \"{file}\"" : "Не могу да учитам информације фајла „{file}“",
     "Files" : "Фајлови",
     "Details" : "Детаљи",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ваше складиште је скоро пуно ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["се подудара са „{filter}”","се подударају са „{filter}","се подудара са „{filter}"],
     "View in folder" : "Види у фасцикли",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Копиран је директан линк (функционише само за кориснике који имају приступ овом фајлу/фолдеру)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Копиран је директан линк (функционише само за особе који имају приступ овом фајлу/фолдеру)",
     "Path" : "Путања",
     "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајтова"],
     "Favorited" : "Омиљено",
     "Favorite" : "Омиљено",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директну везу (ради само за кориснике који имају приступ овом фајлу/фасциклу)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Копирај директни линк (ради само за особе које имају приступ овом фајлу/фолдеру)",
     "New folder" : "Нова фасцикла",
     "Create new folder" : "Направи нову фасциклу",
     "Upload file" : "Отпреми фајл",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Повратио {user}",
     "Renamed by {user}" : "Преименовао {user}",
     "Moved by {user}" : "Померио {user}",
-    "\"remote user\"" : "„удаљени корисник“",
+    "\"remote account\"" : "„удаљени налог”",
     "You created {file}" : "Направили сте {file}",
     "You created an encrypted file in {file}" : "Направили сте шифровани фајл {file}",
     "{user} created {file}" : "{user} је направио {file}",
@@ -169,13 +169,18 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Пренос власништва {path} на корисника {user} завршен.",
     "in %s" : "за %s",
     "File Management" : "Управљање фајловима",
+    "Current directory path" : "Путања текућег директоријума",
     "Reload current directory" : "Поново учитај текући директоријум",
     "Go to the \"{dir}\" directory" : "Иди у „{dir}” дирекотријум",
     "Drag and drop files here to upload" : "Да отпремите, превуците и отпустите фајлове овде",
-    "Upload successful" : "Отпремање је успешно",
+    "Your have used your space quota and cannot upload files anymore" : "Искористили сте квоту простора и више не можете да отпремате фајлове",
+    "You don’t have permission to upload or create files here" : "Немате дозволе да овде отпремате или стварате фајлове",
+    "Some files could not be uploaded" : "Неки фајлови нису могли да се отпреме",
+    "Files uploaded successfully" : "Фајлови су успешно отремљени",
     "\"{displayName}\" action executed successfully" : "Акција „{displayName}” је успешно извршена",
     "\"{displayName}\" action failed" : "Акција „{displayName}” није успела",
-    "Select the row for {displayName}" : "Изабери ред за {displayName}",
+    "Toggle selection for file \"{displayName}\"" : "Укљ./искљ. избор за фајл „{displayName}”",
+    "Toggle selection for folder \"{displayName}\"" : "Укљ./искљ. избор за фолдер „{displayName}”",
     "Rename file" : "Промени назив фајла",
     "File name" : "Име фајла",
     "Folder name" : "Назив фасцикле",
@@ -190,25 +195,21 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Не може да се промени име фајла „{fileName}” јер фајл више не постоји",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назив „{targetName}” се већ користи у директоријуму „{dir}”. Молимо вас да изаберете неко друго име.",
     "Could not rename \"{oldName}\"" : "Не може да се промени име фајла „{fileName}”",
-    "Could not copy {file}. {message}" : "{file} не може да се копира. {message}",
-    "Could not move {file}. {message}" : "{file} не може да се премести. {message}",
     "Total rows summary" : "Резиме укупног броја редова",
-    "Select all" : "Означи све",
-    "Unselect all" : "Поништи цео избор",
+    "Toggle selection for all files and folders" : "Укљ./искљ. избор за све фајлове и фолдере",
     "\"{displayName}\" failed on some elements " : "„{displayName}” није успело на неким елементима",
     "\"{displayName}\" batch action executed successfully" : "Пакетна акција „{displayName}” се успешно извршила",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} и {summaryFolder}",
     "List of files and folders." : "Листа фајлова и фолдера.",
     "Column headers with buttons are sortable." : "Заглавља колона са дугмићима могу да се соритрају.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ова листа није у потпуности приказана из разлога перформанси. Фајлови ће се приказивати како се крећете кроз листу.",
     "File not found" : "Фајл није нађен",
-    "_{count} file_::_{count} files_" : ["{count} фајл","{count} фајла","{count} фајлова"],
-    "_{count} folder_::_{count} folders_" : ["{count} фолдер","{count} фолдера","{count} фолдера"],
     "Storage informations" : "Информације о складишту`",
     "{usedQuotaByte} used" : "{usedQuotaByte} искоришћено",
     "{relative}% used" : "{relative}% искоришћено",
     "Could not refresh storage stats" : "Статистике складишта нису могле да се освеже",
     "Your storage is full, files can not be updated or synced anymore!" : "Ваше складиште је пуно. Фајлови више не могу бити ажурирани ни синхронизовани!",
+    "Create" : "Направи",
+    "A file or folder with that name already exists." : "Фајл или фолдер са тим именом већ постоји.",
     "Transfer ownership of a file or folder" : "Пренеси власништво фајла или фасцикле",
     "Choose file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
     "Change" : "Измени",
@@ -223,7 +224,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Изаберите фајл или фолдер на који показује линк",
     "Choose file" : "Изаберите фајл",
     "Choose {file}" : "Изабери {file}",
-    "Add" : "Додај",
     "Loading current folder" : "Учитавање текућег фолдера",
     "No files in here" : "Овде нема фајлова",
     "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
@@ -234,15 +234,15 @@ OC.L10N.register(
     "Shared" : "Подељено",
     "Switch to list view" : "Пређи на поглед листе",
     "Switch to grid view" : "Пређи на поглед мреже",
-    "Your have used your space quota and cannot upload files anymore" : "Искористили сте квоту простора и више не можете да отпремате фајлове",
-    "You don’t have permission to upload or create files here" : "Немате дозволе да овде отпремате или стварате фајлове",
     "Error during upload: {message}" : "Грешка при отпремању: {message}",
+    "Error during upload, status code {status}" : "Грешка приликом отпремања, кôд статуса {status}",
     "Unknown error during upload" : "Непозната грешка током отпремања",
     "Open the files app settings" : "Отвори подешавања апликације фајлови",
     "Files settings" : "Подешавања фајлова",
     "File cannot be accessed" : "Фајлу не може да се приступи",
-    "You might not have have permissions to view it, ask the sender to share it" : "Можда немате дозволе да га погледате, затражите од пошиљаоца да га подели са вама",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Фајл није могао да се пронађе или немате дозволу да га прегледате. Замолите пошиљаоца да га подели.",
     "Sort favorites first" : "Сортирај прво омиљене",
+    "Sort folders before files" : "Поређај фолдере испред фајлова",
     "Show hidden files" : "Прикажи скривене фајлове",
     "Crop image previews" : "Опсецање прегледа слика",
     "Enable the grid view" : "Укључи приказ мреже",
@@ -257,29 +257,41 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Неуспела промена стања омиљености фајла",
     "Error while loading the file data" : "Грешка при учитавању података фајла",
     "Pick a template for {name}" : "Изаберите шаблон за {name}",
-    "Create" : "Направи",
     "Create a new file with the selected template" : "Креирање новог фајла по изабраном шаблону",
     "Creating file" : "Креирање фајла",
     "Blank" : "Празно",
     "Unable to create new file from template" : "Из шаблона није могао да се креира нови фајл",
     "Delete permanently" : "Обриши заувек",
+    "Delete and unshare" : "Обриши и прекини дељење",
+    "You are about to delete {count} items." : "Управо ћете обрисати {count} ставки.",
+    "Confirm deletion" : "Потврди брисање",
+    "Cancel" : "Поништи",
+    "Deletion cancelled" : "Брисање је отказано",
     "Destination is not a folder" : "Одредиште није фолдер",
     "This file/folder is already in that directory" : "Овај фајл/фолдер се већ налази у том директоријуму",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Фајл/фолдер не можете да преместите у самог себе или у његов подфолдер",
+    "(copy)" : "(копиран)",
+    "(copy %n)" : "(копирано %n)",
+    "Move cancelled" : "Премештање је отказано",
     "A file or folder with that name already exists in this folder" : "У овом фолдеру већ постоји фајл или фолдер са тим именом",
-    "The files is locked" : "Фајл је закључан",
     "The file does not exist anymore" : "Фајл више не постоји",
-    "Chose destination" : "Изаберите одредиште",
+    "Choose destination" : "Изаберите одредиште",
     "Copy to {target}" : "Копирај у {target}",
     "Move to {target}" : "Премести у {target}",
     "Cancelled move or copy operation" : "Операција премештања или копирања је отказана",
+    "Move or copy operation failed" : "Није успела операција премештања или копирања",
     "Open folder {displayName}" : "Отвори фолдер {displayName}",
     "Open in Files" : "Отвори у Фајловима",
     "Open details" : "Отвори детаље",
+    "An error occurred while uploading. Please try again later." : "Дошло је до грешке током отпремања Покушајте поново касније.",
+    "Could not copy {file}. {message}" : "{file} не може да се копира. {message}",
+    "Could not move {file}. {message}" : "{file} не може да се премести. {message}",
+    "Created new folder \"{name}\"" : "Креиран је нови фолдер „{name}”",
+    "Filename" : "Назив фајла",
+    "Unable to initialize the templates directory" : "Фолдер са шаблонима није могао да се иницијализује",
     "Create new templates folder" : "Креирај нови фолдер шаблона",
     "Templates" : "Шаблони",
-    "Unable to initialize the templates directory" : "Фолдер са шаблонима није могао да се иницијализује",
-    "Created new folder \"{name}\"" : "Креиран је нови фолдер „{name}”",
+    "New template folder" : "Нови фолдер шаблона",
     "One of the dropped files could not be processed" : "Један од упуштених фајлова не може да се обради",
     "Uploading \"{filename}\" failed" : "Није успело отпремање „{filename}”",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} фолдер","{folderCount} фолдера","{folderCount} фолдера"],
@@ -292,19 +304,27 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
     "All files" : "Сви фајлови",
     "List of your files and folders." : "Листа ваших фајлова и фолдера.",
+    "Personal Files" : "Лични фајлови",
+    "List of your files and folders that are not shared." : "Листа ваших фајлова и фолдера који се не деле.",
+    "No personal files found" : "Није пронађен ниједан лични фајл",
+    "Files that are not shared will show up here." : "Овде ће се појавити фајлови који се не деле.",
     "List of recently modified files and folders." : "Листа фајлова и директоријума који су недавно измењени.",
     "No recently modified files" : "Нема недавно промењених фајлова",
     "Files and folders you recently modified will show up here." : "Овде ће се појавити фајлови и фолдери које сте недавно изменили.",
-    "Toggle %1$s sublist" : "Укљ./искљ. %1$s подлисте",
     "No entries found in this folder" : "Нема ничега у овој фасцикли",
+    "Select all" : "Означи све",
     "Upload too large" : "Отпремање је превелико",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
     "Text file" : "Tекстуални фајл",
     "New text file.txt" : "Нов текстуални фајл.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Копиран је директан линк (функционише само за кориснике који имају приступ овом фајлу/фолдеру)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директну везу (ради само за кориснике који имају приступ овом фајлу/фасциклу)",
     "You can only favorite a single file or folder at a time" : "Можете поставити као омиљени само један фајл или фасциклу одједном",
+    "\"remote user\"" : "„удаљени корисник“",
     "Search users" : "Претражи кориснике",
-    "Cancel" : "Поништи",
+    "You might not have have permissions to view it, ask the sender to share it" : "Можда немате дозволе да га погледате, затражите од пошиљаоца да га подели са вама",
     "Set up templates folder" : "Постављање фолдера са шаблонима",
+    "Toggle %1$s sublist" : "Укљ./искљ. %1$s подлисте",
     "Toggle grid view" : "Укључи/искључи приказ мреже",
     "Deleted files" : "Обрисани фајлови",
     "Shares" : "Дељења",
@@ -314,13 +334,17 @@ OC.L10N.register(
     "Pending shares" : "Дељења на чекању",
     "This file has the tag {tag}" : "Овај фајл има ознаку {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Овај фајл има ознаке {firstTags} и {lastTag}",
+    "Select the row for {displayName}" : "Изабери ред за {displayName}",
     "Open folder {name}" : "Отвори фолдер {name}",
+    "Unselect all" : "Поништи цео избор",
     "ascending" : "растуће",
     "descending" : "опадајуће",
     "Sort list by {column} ({direction})" : "Поређај листу по {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ова листа није у потпуности приказана из разлога перформанси. Фајлови ће се приказивати како се крећете кроз листу.",
     "Search for an account" : "Претражите налог",
     "Choose" : "Изаберите",
-    "No files or folders have been deleted yet" : "Још увек није обрисан ниједан фајл или фолдер"
+    "No files or folders have been deleted yet" : "Још увек није обрисан ниједан фајл или фолдер",
+    "Add" : "Додај",
+    "The files is locked" : "Фајл је закључан"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
