@@ -37,10 +37,10 @@ OC.L10N.register(
     "Set reminder" : "Ställ in påminnelse",
     "Edit locally" : "Redigera lokalt",
     "Open" : "Öppna",
-    "Delete file" : "Ta bort fil",
-    "Delete folder" : "Ta bort mapp",
-    "Disconnect storage" : "Koppla bort lagring",
-    "Leave this share" : "Lämna denna delning",
+    "_Delete file_::_Delete files_" : ["Radera fil","Radera filer"],
+    "_Delete folder_::_Delete folders_" : ["Radera mapp","Radera mappar"],
+    "_Disconnect storage_::_Disconnect storages_" : ["Koppla bort lagring","Koppla bort lagringar"],
+    "_Leave this share_::_Leave these shares_" : ["Lämna denna delning","Lämna dessa delningar"],
     "Could not load info for file \"{file}\"" : "Kunde inte läsa in information för filen \"{file}\"",
     "Files" : "Filer",
     "Details" : "Detaljer",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matcha \"{filter}\"","matcha \"{filter}\""],
     "View in folder" : "Utforska i mapp",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlänk kopierades (fungerar endast för användare som har tillgång till denna fil/mapp)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Direktlänk kopierades (fungerar endast för användare som har tillgång till denna fil/mapp)",
     "Path" : "Sökväg",
     "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
     "Favorited" : "Favoriserad",
     "Favorite" : "Favorit",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för användare som har åtkomst till denna fil eller mapp)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för användare som har åtkomst till denna fil/mapp)",
     "New folder" : "Ny mapp",
     "Create new folder" : "Skapa ny mapp",
     "Upload file" : "Ladda upp fil",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Återställd av {user}",
     "Renamed by {user}" : "Filnamn ändrat av {user}",
     "Moved by {user}" : "Flyttad av {user}",
-    "\"remote user\"" : "\"extern användare\"",
+    "\"remote account\"" : "\"externt konto\"",
     "You created {file}" : "Du skapade {file}",
     "You created an encrypted file in {file}" : "Du skapade en krypterad fil i {file}",
     "{user} created {file}" : "{user} skapade {file}",
@@ -169,13 +169,18 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "Ägaröverföringen av {path} från {user} är klar.",
     "in %s" : "om %s",
     "File Management" : "Filhantering",
+    "Current directory path" : "Aktuell katalogsökväg",
     "Reload current directory" : "Ladda om nuvarande mapp",
     "Go to the \"{dir}\" directory" : "Gå till \"{dir}\" mappen",
     "Drag and drop files here to upload" : "Dra och släpp filer här för att ladda upp",
-    "Upload successful" : "Uppladdningen lyckades",
+    "Your have used your space quota and cannot upload files anymore" : "Du har använt din utrymmeskvot och kan inte längre ladda upp filer",
+    "You don’t have permission to upload or create files here" : "Du har inte tillåtelse att ladda upp eller skapa filer här",
+    "Some files could not be uploaded" : "Vissa filer kunde inte laddas upp",
+    "Files uploaded successfully" : "Filerna uppladdade",
     "\"{displayName}\" action executed successfully" : "\"{displayName}\"-åtgärden har utförts",
     "\"{displayName}\" action failed" : "\"{displayName}\"-åtgärden misslyckades",
-    "Select the row for {displayName}" : "Välj raden för {displayName}",
+    "Toggle selection for file \"{displayName}\"" : "Växla markering för filen \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Växla markering för mappen \"{displayName}\"",
     "Rename file" : "Byt namn på fil",
     "File name" : "Filnamn",
     "Folder name" : "Mappnamn",
@@ -190,25 +195,21 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Kunde inte byta namn på \"{oldName}\", den finns inte längre",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{newName}\" används redan i mappen \"{dir}\". Välj ett annat namn.",
     "Could not rename \"{oldName}\"" : "Kunde inte byta namn på \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Kunde inte kopiera {file}. {message}",
-    "Could not move {file}. {message}" : "Kunde inte flytta {file}. {message}",
     "Total rows summary" : "Sammanfattning antal rader",
-    "Select all" : "Välj allt",
-    "Unselect all" : "Avmarkera alla",
+    "Toggle selection for all files and folders" : "Växla markering för alla filer och mappar",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" misslyckades med vissa element",
     "\"{displayName}\" batch action executed successfully" : "Batchåtgärden \"{displayName}\" har utförts",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} och {summaryFolder}",
     "List of files and folders." : "Lista över filer och mappar.",
     "Column headers with buttons are sortable." : "Kolumnrubriker med knappar är sorterbara.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
     "File not found" : "Filen kunde inte hittas",
-    "_{count} file_::_{count} files_" : ["{count} fil","{count} filer"],
-    "_{count} folder_::_{count} folders_" : ["{count} mapp","{count} mappar"],
     "Storage informations" : "Lagringsinformation",
     "{usedQuotaByte} used" : "{usedQuotaByte} använt",
     "{relative}% used" : "{relative}% använt",
     "Could not refresh storage stats" : "Det gick inte att uppdatera lagringsstatistiken",
     "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
+    "Create" : "Skapa",
+    "A file or folder with that name already exists." : "En fil eller mapp med det namnet finns redan.",
     "Transfer ownership of a file or folder" : "Överför ägarskap av en fil eller mapp",
     "Choose file or folder to transfer" : "Välj fil eller mapp att överföra",
     "Change" : "Ändra",
@@ -223,7 +224,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Välj fil eller mapp att länka till",
     "Choose file" : "Välj fil",
     "Choose {file}" : "Välj {file}",
-    "Add" : "Lägg till",
     "Loading current folder" : "Laddar aktuell mapp",
     "No files in here" : "Inga filer kunde hittas",
     "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
@@ -234,15 +234,15 @@ OC.L10N.register(
     "Shared" : "Delad",
     "Switch to list view" : "Växla till listvy",
     "Switch to grid view" : "Växla till rutnätsvy",
-    "Your have used your space quota and cannot upload files anymore" : "Du har använt din utrymmeskvot och kan inte längre ladda upp filer",
-    "You don’t have permission to upload or create files here" : "Du har inte tillåtelse att ladda upp eller skapa filer här",
     "Error during upload: {message}" : "Fel vid uppladdning: {message}",
+    "Error during upload, status code {status}" : "Fel vid uppladdning, statuskod {status}",
     "Unknown error during upload" : "Okänt fel under uppladdning",
     "Open the files app settings" : "Öppna filappens inställningar",
     "Files settings" : "Filinställningar",
     "File cannot be accessed" : "Det går inte att komma åt filen",
-    "You might not have have permissions to view it, ask the sender to share it" : "Du kanske inte har behörighet att se den, be avsändaren att dela den",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen kunde inte hittas eller så har du inte behörighet att visa den. Be avsändaren att dela den.",
     "Sort favorites first" : "Sortera favoriter först",
+    "Sort folders before files" : "Sortera mappar före filer",
     "Show hidden files" : "Visa dolda filer",
     "Crop image previews" : "Beskär förhandsgranskningar för bilder",
     "Enable the grid view" : "Aktivera rutnätsvy",
@@ -257,29 +257,41 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Kan inte ändra filens favoritstatus",
     "Error while loading the file data" : "Fel vid inläsning av fildata",
     "Pick a template for {name}" : "Välj en mall för {name}",
-    "Create" : "Skapa",
     "Create a new file with the selected template" : "Skapa en ny fil med den valda mallen",
     "Creating file" : "Skapar fil",
     "Blank" : "Tom",
     "Unable to create new file from template" : "Kunde inte skapa fil från mall",
     "Delete permanently" : "Ta bort permanent",
+    "Delete and unshare" : "Radera och sluta dela",
+    "You are about to delete {count} items." : "Du är på väg att ta bort {count} objekt.",
+    "Confirm deletion" : "Bekräfta radering",
+    "Cancel" : "Avbryt",
+    "Deletion cancelled" : "Radering avbruten",
     "Destination is not a folder" : "Destinationen är inte en mapp",
     "This file/folder is already in that directory" : "Den här filen/mappen finns redan i den katalogen",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan inte flytta en fil/mapp till sig själv eller till en undermapp till sig själv",
+    "(copy)" : "(kopia)",
+    "(copy %n)" : "(kopia %n)",
+    "Move cancelled" : "Flytt avbruten",
     "A file or folder with that name already exists in this folder" : "En fil eller mapp med det namnet finns redan i den här mappen",
-    "The files is locked" : "Filerna är låsta",
     "The file does not exist anymore" : "Filen finns inte längre",
-    "Chose destination" : "Välj destination",
+    "Choose destination" : "Välj destination",
     "Copy to {target}" : "Kopiera till {target}",
     "Move to {target}" : "Flytta till {target}",
     "Cancelled move or copy operation" : "Flytta eller kopiera avbröts",
+    "Move or copy operation failed" : "Flytta eller kopiera misslyckades",
     "Open folder {displayName}" : "Öppna mappen {displayName}",
     "Open in Files" : "Öppna i Filer",
     "Open details" : "Öppna detaljer",
+    "An error occurred while uploading. Please try again later." : "Ett fel inträffade vid uppladdningen. Försök igen senare.",
+    "Could not copy {file}. {message}" : "Kunde inte kopiera {file}. {message}",
+    "Could not move {file}. {message}" : "Kunde inte flytta {file}. {message}",
+    "Created new folder \"{name}\"" : "Skapat ny mapp \"{name}\"",
+    "Filename" : "Filnamn",
+    "Unable to initialize the templates directory" : "Kunde inte initialisera mall-mappen",
     "Create new templates folder" : "Skapa ny mallmapp",
     "Templates" : "Mallar",
-    "Unable to initialize the templates directory" : "Kunde inte initialisera mall-mappen",
-    "Created new folder \"{name}\"" : "Skapat ny mapp \"{name}\"",
+    "New template folder" : "Ny mallmapp",
     "One of the dropped files could not be processed" : "En av de släppta filerna kunde inte bearbetas",
     "Uploading \"{filename}\" failed" : "Uppladdning av \"{filename}\" misslyckades",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapp","{folderCount} mappar"],
@@ -292,19 +304,27 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
     "All files" : "Alla filer",
     "List of your files and folders." : "Lista över dina filer och mappar.",
+    "Personal Files" : "Personliga filer",
+    "List of your files and folders that are not shared." : "Lista över dina filer och mappar som inte delas.",
+    "No personal files found" : "Inga personliga filer hittades",
+    "Files that are not shared will show up here." : "Filer som inte delas kommer att visas här.",
     "List of recently modified files and folders." : "Lista över nyligen ändrade filer och mappar.",
     "No recently modified files" : "Inga nyligen ändrade filer",
     "Files and folders you recently modified will show up here." : "Filer och mappar som du nyligen ändrat kommer att visas här.",
-    "Toggle %1$s sublist" : "Växla %1$s sublista",
     "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
+    "Select all" : "Välj allt",
     "Upload too large" : "För stor uppladdning",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
     "Text file" : "Textfil",
     "New text file.txt" : "Ny textfil.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlänk kopierades (fungerar endast för användare som har tillgång till denna fil/mapp)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för användare som har åtkomst till denna fil eller mapp)",
     "You can only favorite a single file or folder at a time" : "Du kan bara favoritmarkera en fil eller mapp åt gången",
+    "\"remote user\"" : "\"extern användare\"",
     "Search users" : "Sök användare",
-    "Cancel" : "Avbryt",
+    "You might not have have permissions to view it, ask the sender to share it" : "Du kanske inte har behörighet att se den, be avsändaren att dela den",
     "Set up templates folder" : "Skapa en mapp för mallar",
+    "Toggle %1$s sublist" : "Växla %1$s sublista",
     "Toggle grid view" : "Växla rutnätsvy",
     "Deleted files" : "Borttagna filer",
     "Shares" : "Delningar",
@@ -314,13 +334,17 @@ OC.L10N.register(
     "Pending shares" : "Väntande delningar",
     "This file has the tag {tag}" : "Den här filen har taggen {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Den här filen har taggarna {firstTags} och {lastTag}",
+    "Select the row for {displayName}" : "Välj raden för {displayName}",
     "Open folder {name}" : "Öppna mappen {name}",
+    "Unselect all" : "Avmarkera alla",
     "ascending" : "stigande",
     "descending" : "fallande",
     "Sort list by {column} ({direction})" : "Sortera listan efter {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
     "Search for an account" : "Sök efter ett konto",
     "Choose" : "Välj",
-    "No files or folders have been deleted yet" : "Inga filer eller mappar har tagits bort än"
+    "No files or folders have been deleted yet" : "Inga filer eller mappar har tagits bort än",
+    "Add" : "Lägg till",
+    "The files is locked" : "Filerna är låsta"
 },
 "nplurals=2; plural=(n != 1);");
