@@ -37,10 +37,10 @@ OC.L10N.register(
     "Set reminder" : "Встановити нагадування",
     "Edit locally" : "Редагувати локально",
     "Open" : "Відкрити",
-    "Delete file" : "Вилучити файл",
-    "Delete folder" : "Вилучити каталог",
-    "Disconnect storage" : "Від’єднати сховище",
-    "Leave this share" : "Вийти зі спільного доступу",
+    "_Delete file_::_Delete files_" : ["Вилучити файл","Вилучити файли","Вилучити файли","Вилучити файли"],
+    "_Delete folder_::_Delete folders_" : ["Вилучити каталог","Вилучити каталоги","Вилучити каталоги","Вилучити каталоги"],
+    "_Disconnect storage_::_Disconnect storages_" : ["Від'єднати сховище","Від'єднати сховища","Від'єднати сховища","Від'єднати сховища"],
+    "_Leave this share_::_Leave these shares_" : ["Вийти зі спільного доступу","Вийти зі спільного доступу","Вийти зі спільного доступу","Вийти зі спільного доступу"],
     "Could not load info for file \"{file}\"" : "Не вдалося завантажити дані про файл \"{file}\"",
     "Files" : "Файли",
     "Details" : "Деталі",
@@ -101,12 +101,12 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ваше сховище майже заповнено ({usedSpacePercent}%).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["відповідає \"{filter}\"","відповідає \"{filter}\"","відповідає \"{filter}\"","відповідає \"{filter}\""],
     "View in folder" : "Переглянути у каталозі",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Пряме посилання скопійовано (застосовується у разі, якщо користувач має доступ до ресурсу)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Пряме посилання було скопійовано (дійсне лише для користувачів, які мають відповідні права доступу)",
     "Path" : "Шлях",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байти","%n байт","%n байт(ів)"],
     "Favorited" : "Із зірочкою",
     "Favorite" : "Додати зірочку",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Копіювати пряме посилання (користувачі мають мати доступ до цього файлу чи каталогу)",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Копіювати пряме посилання (дійсне лише для користувачів, які мають відповідні права доступу)",
     "New folder" : "Новий каталог",
     "Create new folder" : "Створити новий каталог",
     "Upload file" : "Завантажити файл",
@@ -127,7 +127,7 @@ OC.L10N.register(
     "Restored by {user}" : "Відновлено користувачем {user}",
     "Renamed by {user}" : "Перейменовано {user}",
     "Moved by {user}" : "Переміщено користувачем {user}",
-    "\"remote user\"" : "\"віддалений користувач\"",
+    "\"remote account\"" : "\"віддалений обліковий запис\"",
     "You created {file}" : "Ви створили {file}",
     "You created an encrypted file in {file}" : "Ви створили зашифрований файл у {file}",
     "{user} created {file}" : "{user} створив(-ла) файл {file}",
@@ -175,9 +175,12 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Перетягніть файли сюди для завантаження",
     "Your have used your space quota and cannot upload files anymore" : "Ви вже використали квоту на місце та не можете завантажувати файли",
     "You don’t have permission to upload or create files here" : "У вас недостатньо прав для завантаження або створення файлів тут",
-    "Upload successful" : "Успішно завантажено",
+    "Some files could not be uploaded" : "Не вдалося завантажити окремі файли",
+    "Files uploaded successfully" : "Файли успішно завантажено",
     "\"{displayName}\" action executed successfully" : "Дію \"{displayName}\" успішно виконано",
     "\"{displayName}\" action failed" : "Дію \"{displayName}\" не вдалося виконати",
+    "Toggle selection for file \"{displayName}\"" : "Перемкнути вибір для файлу \"{displayName}\"",
+    "Toggle selection for folder \"{displayName}\"" : "Перемкнути вибір для каталогу \"{displayName}\"",
     "Rename file" : "Перейменувати файл",
     "File name" : "Ім'я файлу",
     "Folder name" : "Назва каталогу",
@@ -192,9 +195,8 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Не вдалося перейментувати \"{oldName}\", оскільки він вже відсутній",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Ім'я \"{newName}\" вже використовується у каталозі \"{dir}\". Виберіть інше ім'я.",
     "Could not rename \"{oldName}\"" : "Не вдалося перейменувати \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Не вдалося скопіювати файл {file}. {message}",
-    "Could not move {file}. {message}" : "Не вдалося перемістити файл {file}. {message}",
     "Total rows summary" : "Загалом рядків",
+    "Toggle selection for all files and folders" : "Перемкнути вибір для всіх файлів та каталогів",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" не показується в окремих елементах",
     "\"{displayName}\" batch action executed successfully" : "Операцію \"{displayName}\" успішно виконано",
     "List of files and folders." : "Список файлів та каталогів",
@@ -206,6 +208,8 @@ OC.L10N.register(
     "{relative}% used" : "{relative}% використано",
     "Could not refresh storage stats" : "Неможливо оновити статистику сховища",
     "Your storage is full, files can not be updated or synced anymore!" : "Ваше сховище переповнене, файли більше не можуть бути оновлені або синхронізовані!",
+    "Create" : "Створити",
+    "A file or folder with that name already exists." : "Файл або каталог з таким ім'ям вже присутній.",
     "Transfer ownership of a file or folder" : "Передавання прав власника на файл або каталог",
     "Choose file or folder to transfer" : "Виберіть файл або каталог для передавання",
     "Change" : "Змінити",
@@ -220,7 +224,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Виберіть файл або каталог, до якого потрібно застосувати посилання",
     "Choose file" : "Вибрати файл",
     "Choose {file}" : "Виберіть {file}",
-    "Add" : "Додати",
     "Loading current folder" : "Завантаження поточного каталогу",
     "No files in here" : "Тут немає файлів",
     "Upload some content or sync with your devices!" : "Завантажте вміст або синхронізуйтеся з вашими пристроями!",
@@ -232,12 +235,14 @@ OC.L10N.register(
     "Switch to list view" : "У вигляді списку",
     "Switch to grid view" : "У вигляді сітки",
     "Error during upload: {message}" : "Помилка під час завантаження: {message}",
+    "Error during upload, status code {status}" : "Помилка під час завантаження, код стану {status}",
     "Unknown error during upload" : "Невідома помилка під час завантаження",
     "Open the files app settings" : "Перейти до налаштувань застосунку файлів",
     "Files settings" : "Налаштування",
     "File cannot be accessed" : "Неможливо отримати доступ до файлу",
-    "You might not have have permissions to view it, ask the sender to share it" : "Ймовірно у вас відсутні права на перегляд. Попросіть відправника поділитися доступом.",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не вдалося знайти файл або у вас відсутній дозвіл на перегляд файлу. Попросіть поділитися цим файлом.",
     "Sort favorites first" : "Спочатку впорядковувати із зірочкою",
+    "Sort folders before files" : "Впорядковувати каталоги поререду файлів",
     "Show hidden files" : "Показувати приховані файли",
     "Crop image previews" : "Попередній перегляд перед кадруванням",
     "Enable the grid view" : "Увімкнути перегляд у вигляді сітки",
@@ -252,30 +257,41 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Неможливо змінити стан \"зірочка\" для цього файла",
     "Error while loading the file data" : "Помилка під час завантаження даних про файл",
     "Pick a template for {name}" : "Вибрати шаблон для {name}",
-    "Create" : "Створити",
     "Create a new file with the selected template" : "Створити новий файл на основі вибраного шаблону",
     "Creating file" : "Створення файлу",
     "Blank" : "Порожньо",
     "Unable to create new file from template" : "Неможливо створити новий файл з шаблону",
-    "Unshare" : "Закрити доступ",
     "Delete permanently" : "Вилучити назавжди",
+    "Delete and unshare" : "Вилучити та прибрати спільний доступ",
+    "You are about to delete {count} items." : "Ви намагаєтеся вилучити {count} ресурсів.",
+    "Confirm deletion" : "Підтвердіть вилучення",
+    "Cancel" : "Скасувати",
+    "Deletion cancelled" : "Вилучення скасовано",
     "Destination is not a folder" : "Місце призначення не є каталогом",
     "This file/folder is already in that directory" : "Такий файл чи каталог вже присутні в цьому каталозі",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Неможливо перемістити файл чи каталог до самого себе або у цей саме підкаталог",
+    "(copy)" : "(копія)",
+    "(copy %n)" : "(копія %n)",
+    "Move cancelled" : "Переміщення скасовано",
     "A file or folder with that name already exists in this folder" : "Файл чи каталог з таким ім'ям вже присутній в цьому каталозі",
-    "The files is locked" : "Файл заблоковано",
     "The file does not exist anymore" : "Цей файл більше недоступний",
     "Choose destination" : "Виберіть каталог призначення",
     "Copy to {target}" : "Копіювати до {target}",
     "Move to {target}" : "Перемістити до {target}",
     "Cancelled move or copy operation" : "Переміщення або копіювання скасовано",
+    "Move or copy operation failed" : "Не вдалося скопіювати або перемістити",
     "Open folder {displayName}" : "Відкрити каталог {displayName}",
     "Open in Files" : "Відкрити у Файлах",
     "Open details" : "Показати деталі",
+    "An error occurred while uploading. Please try again later." : "Помилка під час завантаження. Спробуйте ще раз пізніше.",
+    "Could not copy {file}. {message}" : "Не вдалося скопіювати файл {file}. {message}",
+    "Could not move {file}. {message}" : "Не вдалося перемістити файл {file}. {message}",
+    "Created new folder \"{name}\"" : "Створив(-ла) новий каталог \"{name}\"",
+    "Filename" : "Ім'я файлу",
+    "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
     "Create new templates folder" : "Створіть новий каталог для шаблонів",
     "Templates" : "Шаблони",
-    "Unable to initialize the templates directory" : "Неможливо встановити каталог з шаблонами",
-    "Created new folder \"{name}\"" : "Створив(-ла) новий каталог \"{name}\"",
+    "New template folder" : "Новий каталог шаблонів",
     "One of the dropped files could not be processed" : "Один із завантажених файлів не вдалося обробити",
     "Uploading \"{filename}\" failed" : "Завантаження \"{filename}\" не вдалося",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} каталог","{folderCount} каталоги","{folderCount} каталогів","{folderCount} каталогів"],
@@ -288,20 +304,27 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Файли та каталоги із зірочкою з’являться тут",
     "All files" : "Усі файли",
     "List of your files and folders." : "Список ваших файлів та каталогів.",
+    "Personal Files" : "Приватні файли",
+    "List of your files and folders that are not shared." : "Перелік ваших файлів та каталогів, які не є у спільному доступі.",
+    "No personal files found" : "Приватні файли не знайдено",
+    "Files that are not shared will show up here." : "Тут показуватимуться файли, які не є у спільному доступі.",
     "List of recently modified files and folders." : "Список нещодавно змінених файлів та каталогів.",
     "No recently modified files" : "Відсутні файли із нещодавними змінами",
     "Files and folders you recently modified will show up here." : "Тут показуватимуться файли та каталоги, які було нещодавно змінено.",
-    "Toggle %1$s sublist" : "Перемкнути вкладений список %1$s",
     "No entries found in this folder" : "В цьому каталозі нічого не знайдено",
     "Select all" : "Вибрати все",
     "Upload too large" : "Файл занадто великий",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файли, які ви намагаєтеся завантажити, перевищують максимально дозволений розмір завантаження файлів на сервер.",
     "Text file" : "Текстовий файл",
     "New text file.txt" : "Новий текстовий файл.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Пряме посилання скопійовано (застосовується у разі, якщо користувач має доступ до ресурсу)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Копіювати пряме посилання (користувачі мають мати доступ до цього файлу чи каталогу)",
     "You can only favorite a single file or folder at a time" : "Одночасно можна додати зірочку лише для одного файлу чи каталогу",
+    "\"remote user\"" : "\"віддалений користувач\"",
     "Search users" : "Пошук користувачів",
-    "Cancel" : "Скасувати",
+    "You might not have have permissions to view it, ask the sender to share it" : "Ймовірно у вас відсутні права на перегляд. Попросіть відправника поділитися доступом.",
     "Set up templates folder" : "Встановити каталог з шаблонами",
+    "Toggle %1$s sublist" : "Перемкнути вкладений список %1$s",
     "Toggle grid view" : "Перемкнути подання сіткою",
     "Deleted files" : "Кошик",
     "Shares" : "Спільне",
@@ -320,6 +343,8 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Через обмеження, пов'язані з потужністю, список не показується повністю. Файли показуватимуться, щойно ви рухатиметеся списком.",
     "Search for an account" : "Пошук облікового запису",
     "Choose" : "Вибрати",
-    "No files or folders have been deleted yet" : "Поки жодного каталогу чи файлу не було вилучено"
+    "No files or folders have been deleted yet" : "Поки жодного каталогу чи файлу не було вилучено",
+    "Add" : "Додати",
+    "The files is locked" : "Файл заблоковано"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
