@@ -22,8 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "Một lỗi không rõ đã xảy ra",
     "File could not be uploaded" : "Không thể tải lên tập tin",
     "Uploading …" : "Đang tải lên …",
-    "{remainingTime} ({currentNumber}/{total})" : "{thời gian còn lại} ({số lượng hiện tại}/{tổng số})",
-    "Uploading … ({currentNumber}/{total})" : "Đang tải lên … ({số lượng hiện tại}/{tổng số})",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "Đang tải lên … ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} trong tổng số {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "‎Tải lên mục ‎‎đó không‎‎ được hỗ trợ‎",
     "Target folder does not exist any more" : "‎Thư  mục đích‎‎ không còn tồn tại nữa‎",
@@ -37,10 +37,6 @@ OC.L10N.register(
     "Set reminder" : "Thiết lập nhắc nhở",
     "Edit locally" : "Chỉnh sửa cục bộ/ngoại tuyến",
     "Open" : "Mở",
-    "Delete file" : "Xóa tệp",
-    "Delete folder" : "Xóa thư mục",
-    "Disconnect storage" : "Bộ lưu trữ đã ngắt kết nối",
-    "Leave this share" : "Rời khỏi mục chia sẻ này‎",
     "Could not load info for file \"{file}\"" : "Không thể tải thông tin cho tệp \"{file}\"",
     "Files" : "Tệp tin",
     "Details" : "Chi tiết",
@@ -101,12 +97,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "‎Dung lượng lưu trữ của bạn gần đầy rồi ({usedSpacePercent}%).‎",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["khớp với \"{filter}\""],
     "View in folder" : "Xem trong thư mục",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Đã sao chép đường dẫn trực tiếp(Chỉ áp dụng đối với người dùng có quyền truy cập vào thư mục/tệp tin)",
     "Path" : "Đường dẫn",
     "_%n byte_::_%n bytes_" : ["%n bytes"],
     "Favorited" : "Được ưa thích",
     "Favorite" : "Ưa thích",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Sao chép liên kết trực tiếp (chỉ hoạt động đối với những người dùng có quyền truy cập vào tệp / thư mục này)",
     "New folder" : "Tạo thư mục",
     "Create new folder" : "Tạo thư mục mới",
     "Upload file" : "Tải lên tập tin",
@@ -127,7 +121,6 @@ OC.L10N.register(
     "Restored by {user}" : "Được khôi phục bởi {user}",
     "Renamed by {user}" : "Đã đổi tên bởi {user}",
     "Moved by {user}" : "Đã di chuyển bởi {user}",
-    "\"remote user\"" : "\"người dùng từ xa\"",
     "You created {file}" : "Bạn đã tạo {file}",
     "You created an encrypted file in {file}" : "‎Bạn đã tạo một tệp được mã hóa trong {file}‎",
     "{user} created {file}" : "{user} đã tạo {file}",
@@ -172,10 +165,9 @@ OC.L10N.register(
     "Reload current directory" : "Tải lại thư mục hiện tại",
     "Go to the \"{dir}\" directory" : "Đi đến thư mục \"{dir}\"",
     "Drag and drop files here to upload" : "Kéo thả file vào đây để tải lên",
-    "Upload successful" : "Tải lên thành công",
+    "You don’t have permission to upload or create files here" : "Bạn không có quyền upload hoặc tạo files ở đây",
     "\"{displayName}\" action executed successfully" : "Hành động \"{displayName}\" đã thực thi thành công",
     "\"{displayName}\" action failed" : "Hành động \"{displayName}\" thất bại",
-    "Select the row for {displayName}" : "Chọn hàng cho {displayName}",
     "Rename file" : "Đổi tên tệp tin",
     "File name" : "Tên tệp tin",
     "Folder name" : "Tên thư mục",
@@ -190,24 +182,18 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "Không thể đổi tên \"{oldName}\", tệp tin không còn tồn tại",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{newName}\" đã được sử dụng trong thư mục \"{dir}\". Vui lòng chọn một tên khác.",
     "Could not rename \"{oldName}\"" : "Could not rename \"{oldName}\"",
-    "Could not copy {file}. {message}" : "Không thể sao chép {tệp}. {tin nhắn}",
-    "Could not move {file}. {message}" : "Không thể di chuyển {tệp}. {tin nhắn}",
     "Total rows summary" : "Tóm tắt tổng số hàng",
-    "Select all" : "Chọn tất cả",
-    "Unselect all" : "Bỏ chọn tất cả",
     "\"{displayName}\" failed on some elements " : "\"{displayName}\" không thành công trên một số thành phần",
     "\"{displayName}\" batch action executed successfully" : "Hành động hàng loạt \"{displayName}\" được thực hiện thành công",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} và {summaryFolder}",
     "List of files and folders." : "Danh sách các tập tin và thư mục.",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Danh sách này không được hiển thị đầy đủ vì lý do hiệu suất. Các tập tin sẽ được hiển thị khi bạn điều hướng qua danh sách.",
     "File not found" : "Không tìm thấy tập tin",
-    "_{count} file_::_{count} files_" : ["{đếm} tệp"],
-    "_{count} folder_::_{count} folders_" : ["{đếm} thư mục"],
     "Storage informations" : "Thông tin lưu trữ",
     "{usedQuotaByte} used" : "{usedQuotaByte} đã được sử dụng",
     "{relative}% used" : "{tương đối}% đã sử dụng",
     "Could not refresh storage stats" : "Không thể làm mới số liệu thống kê bộ nhớ",
     "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
+    "Create" : "‎Tạo‎",
     "Transfer ownership of a file or folder" : "‎Chuyển quyền sở hữu tệp hoặc thư mục‎",
     "Choose file or folder to transfer" : "‎Chọn tệp hoặc cặp để chuyển‎",
     "Change" : "Chỉnh sửa",
@@ -221,7 +207,6 @@ OC.L10N.register(
     "Cannot transfer ownership of a file or folder you do not own" : "Không thể chuyển quyền sở hữu tệp hoặc thư mục mà bạn không sở hữu",
     "Select file or folder to link to" : "Chọn tập tin hoặc thư mục để liên kết đến",
     "Choose {file}" : "Chọn {tập tin}",
-    "Add" : "Thêm",
     "Loading current folder" : "Đang tải thư mục hiện tại",
     "No files in here" : "Không có tệp nào",
     "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
@@ -232,11 +217,9 @@ OC.L10N.register(
     "Shared" : "Chia sẻ",
     "Switch to list view" : "Chuyển sang chế độ xem danh sách",
     "Switch to grid view" : "Chuyển sang chế độ xem dạng lưới",
-    "You don’t have permission to upload or create files here" : "Bạn không có quyền upload hoặc tạo files ở đây",
     "Open the files app settings" : "Mở cài đặt ứng dụng tệp",
     "Files settings" : "Cài đặt tệp tin",
     "File cannot be accessed" : "Không thể truy cập tập tin",
-    "You might not have have permissions to view it, ask the sender to share it" : "Bạn có thể không có quyền xem nó, hãy yêu cầu người gửi chia sẻ nó",
     "Sort favorites first" : "Sắp xếp mục yêu thích trước",
     "Show hidden files" : "Hiển thị các file ẩn",
     "Crop image previews" : "‎Xén ảnh ‎bản xem trước",
@@ -251,29 +234,30 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "‎Không thể thay đổi trạng thái yêu thích của tệp‎",
     "Error while loading the file data" : "‎Lỗi xảy ra trong khi tải dữ liệu tệp‎",
     "Pick a template for {name}" : "‎Chọn một mẫu cho {name}‎",
-    "Create" : "‎Tạo‎",
     "Create a new file with the selected template" : "‎Tạo tệp mới với mẫu đã chọn‎",
     "Creating file" : "‎Tạo tệp‎",
     "Blank" : "‎Trống‎",
     "Unable to create new file from template" : "‎Không thể tạo tệp mới từ mẫu‎",
     "Delete permanently" : "Xoá vĩnh viễn",
+    "Cancel" : "‎Hủy bỏ‎",
     "Destination is not a folder" : "Đích đến không phải là một thư mục",
     "This file/folder is already in that directory" : "Tệp/thư mục này đã có trong thư mục đó",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Bạn không thể di chuyển một tập tin/thư mục vào chính nó hoặc vào một thư mục con của chính nó",
     "A file or folder with that name already exists in this folder" : "Tệp hoặc thư mục có tên đó đã tồn tại trong thư mục này",
-    "The files is locked" : "Các tập tin bị khóa",
     "The file does not exist anymore" : "Tập tin không tồn tại nữa",
-    "Chose destination" : "Chọn điểm đến",
     "Copy to {target}" : "Copy to {mục tiêu}",
     "Move to {target}" : "Di chuyển đến {mục tiêu}",
     "Cancelled move or copy operation" : "Đã hủy thao tác di chuyển hoặc sao chép",
     "Open folder {displayName}" : "Mở thư mục {displayName}",
     "Open in Files" : "Mở trong Tệp",
     "Open details" : "Mở chi tiết",
+    "Could not copy {file}. {message}" : "Không thể sao chép {tệp}. {tin nhắn}",
+    "Could not move {file}. {message}" : "Không thể di chuyển {tệp}. {tin nhắn}",
+    "Created new folder \"{name}\"" : "Đã tạo thư mục mới \"{name}\"",
+    "Filename" : "Tên tập tin",
+    "Unable to initialize the templates directory" : "‎Không thể khởi tạo thư mục mẫu‎",
     "Create new templates folder" : "Tạo thư mục mẫu mới",
     "Templates" : "‎Mẫu‎",
-    "Unable to initialize the templates directory" : "‎Không thể khởi tạo thư mục mẫu‎",
-    "Created new folder \"{name}\"" : "Đã tạo thư mục mới \"{name}\"",
     "_{folderCount} folder_::_{folderCount} folders_" : ["thư mục {folderCount}"],
     "_{fileCount} file_::_{fileCount} files_" : ["tệp {fileCount}"],
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 tệp và thư mục {folderCount}"],
@@ -287,16 +271,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "Danh sách các tập tin và thư mục được sửa đổi gần đây.",
     "No recently modified files" : "Không có tập tin được sửa đổi gần đây",
     "Files and folders you recently modified will show up here." : "Các tập tin và thư mục bạn sửa đổi gần đây sẽ hiển thị ở đây.",
-    "Toggle %1$s sublist" : "Chuyển đổi danh sách phụ %1$s",
     "No entries found in this folder" : "Chưa có mục nào trong thư mục",
+    "Select all" : "Chọn tất cả",
     "Upload too large" : "Tập tin tải lên quá lớn",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
     "Text file" : "Tập tin văn bản",
     "New text file.txt" : "‎Tệp văn bản mới.txt‎",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Đã sao chép đường dẫn trực tiếp(Chỉ áp dụng đối với người dùng có quyền truy cập vào thư mục/tệp tin)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Sao chép liên kết trực tiếp (chỉ hoạt động đối với những người dùng có quyền truy cập vào tệp / thư mục này)",
     "You can only favorite a single file or folder at a time" : "‎Bạn chỉ có thể chọn yêu thích một tệp hoặc thư mục duy nhất tại một thời điểm‎",
+    "\"remote user\"" : "\"người dùng từ xa\"",
     "Search users" : "‎Tìm kiếm người dùng‎",
-    "Cancel" : "‎Hủy bỏ‎",
+    "You might not have have permissions to view it, ask the sender to share it" : "Bạn có thể không có quyền xem nó, hãy yêu cầu người gửi chia sẻ nó",
     "Set up templates folder" : "‎Thiết lập thư mục mẫu‎",
+    "Toggle %1$s sublist" : "Chuyển đổi danh sách phụ %1$s",
     "Toggle grid view" : "‎Chuyển đổi dạng xem lưới‎",
     "Deleted files" : "Thùng rác",
     "Shares" : "Chia sẻ",
@@ -306,13 +294,17 @@ OC.L10N.register(
     "Pending shares" : "Chia sẻ đang chờ xử lý‎",
     "This file has the tag {tag}" : "Tập tin này có nhãn {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Tệp tin này có nhãn {firstTags} và {lastTag}",
+    "Select the row for {displayName}" : "Chọn hàng cho {displayName}",
     "Open folder {name}" : "Mở thư mục {name}",
+    "Unselect all" : "Bỏ chọn tất cả",
     "ascending" : "tăng dần",
     "descending" : "giảm dần",
     "Sort list by {column} ({direction})" : "Sắp xếp danh sách theo {column} ({direction})",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "anh sách này không được hiển thị đầy đủ vì lý do hiệu suất. Các tập tin sẽ được hiển thị khi bạn điều hướng qua danh sách.",
     "Search for an account" : "Tìm kiếm tài khoản",
     "Choose" : "Chọn",
-    "No files or folders have been deleted yet" : "Chưa có tập tin hoặc thư mục nào bị xóa"
+    "No files or folders have been deleted yet" : "Chưa có tập tin hoặc thư mục nào bị xóa",
+    "Add" : "Thêm",
+    "The files is locked" : "Các tập tin bị khóa"
 },
 "nplurals=1; plural=0;");
