@@ -37,10 +37,6 @@ OC.L10N.register(
     "Set reminder" : "设置提醒",
     "Edit locally" : "本地编辑",
     "Open" : "打开",
-    "Delete file" : "删除文件",
-    "Delete folder" : "删除文件夹",
-    "Disconnect storage" : "断开与存储空间的连接",
-    "Leave this share" : "离开这个共享",
     "Could not load info for file \"{file}\"" : "无法加载文件“{file}”的信息",
     "Files" : "文件",
     "Details" : "详细信息",
@@ -101,12 +97,10 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "您的存储空间几乎已满（{usedSpacePercent}%）",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["匹配“{filter}”"],
     "View in folder" : "在文件夹中查看",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "已复制直链（仅适用于有权访问此文件/文件夹的用户）",
     "Path" : "路径",
     "_%n byte_::_%n bytes_" : ["%n 字节"],
     "Favorited" : "已收藏",
     "Favorite" : "收藏",
-    "Copy direct link (only works for users who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
     "New folder" : "新建文件夹",
     "Create new folder" : "创建新文件夹",
     "Upload file" : "上传文件",
@@ -127,7 +121,6 @@ OC.L10N.register(
     "Restored by {user}" : "由 {user} 恢复",
     "Renamed by {user}" : "由 {user} 重命名",
     "Moved by {user}" : "由 {user} 移动",
-    "\"remote user\"" : "“远程用户”",
     "You created {file}" : "您创建了 {file}",
     "You created an encrypted file in {file}" : "您在 {file} 创建了一个加密文件",
     "{user} created {file}" : "{user} 创建了 {file}",
@@ -169,13 +162,13 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "来自 {user} 的 {path} 的所有权转移已完成。",
     "in %s" : "在 %s",
     "File Management" : "文件管理",
+    "Current directory path" : "当前文件目录",
     "Reload current directory" : "重新载入当前目录",
     "Go to the \"{dir}\" directory" : "前往“{dir}”目录",
     "Drag and drop files here to upload" : "将文件拖拽至此处以上传",
-    "Upload successful" : "上传成功",
+    "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
     "\"{displayName}\" action executed successfully" : "“{displayName}”操作执行成功",
     "\"{displayName}\" action failed" : "“{displayName}”操作执行失败",
-    "Select the row for {displayName}" : "选择 {displayName} 的行",
     "Rename file" : "重命名文件",
     "File name" : "文件名",
     "Folder name" : "文件夹名称",
@@ -190,25 +183,19 @@ OC.L10N.register(
     "Could not rename \"{oldName}\", it does not exist any more" : "无法重命名“{fileName}”，此文件已经不存在",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名称「{newName}」在这个文件夹「{dir}」已经被使用。请选择其他名称。",
     "Could not rename \"{oldName}\"" : "无法重命名“{fileName}”",
-    "Could not copy {file}. {message}" : "无法复制 {file}。{message}",
-    "Could not move {file}. {message}" : "无法移动 {file}。{message}",
     "Total rows summary" : "总行摘要",
-    "Select all" : "全部选择",
-    "Unselect all" : "取消全选",
     "\"{displayName}\" failed on some elements " : "“{displayName}”在某些元素上失败",
     "\"{displayName}\" batch action executed successfully" : "批量操作“{displayName}”运行成功",
-    "{summaryFile} and {summaryFolder}" : "{summaryFile} 及 {summaryFolder}",
     "List of files and folders." : "文件与文件夹列表。",
     "Column headers with buttons are sortable." : "带有按钮的列标题可进行排序。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出于性能考虑，此列表未完全呈现。文件将在您浏览列表时呈现。",
     "File not found" : "文件未找到",
-    "_{count} file_::_{count} files_" : ["{count} 个文件"],
-    "_{count} folder_::_{count} folders_" : ["{count} 个文件夹"],
     "Storage informations" : "存储信息",
     "{usedQuotaByte} used" : "{usedQuotaByte} 已使用",
     "{relative}% used" : "{relative}% 已使用",
     "Could not refresh storage stats" : "无法刷新存储统计数据",
     "Your storage is full, files can not be updated or synced anymore!" : "您的存储空间已满，文件将无法更新或同步！",
+    "Create" : "创建",
     "Transfer ownership of a file or folder" : "转移文件或文件夹的所有权",
     "Choose file or folder to transfer" : "选择要转移的文件或文件夹",
     "Change" : "修改",
@@ -222,7 +209,6 @@ OC.L10N.register(
     "Cannot transfer ownership of a file or folder you do not own" : "无法转让您未拥有的文件或文件夹的所有权",
     "Select file or folder to link to" : "选择需要链接的文件或文件夹",
     "Choose {file}" : "选择 {file}",
-    "Add" : "添加",
     "Loading current folder" : "正在载入当前文件夹",
     "No files in here" : "这里没有文件",
     "Upload some content or sync with your devices!" : "上传一些内容或与您的设备同步！",
@@ -233,11 +219,9 @@ OC.L10N.register(
     "Shared" : "已共享",
     "Switch to list view" : "切换为列表视图",
     "Switch to grid view" : "切换到网格视图",
-    "You don’t have permission to upload or create files here" : "您没有权限在此上传或创建文件",
     "Open the files app settings" : "打开文件设置",
     "Files settings" : "文件设置",
     "File cannot be accessed" : "文件无法访问",
-    "You might not have have permissions to view it, ask the sender to share it" : "您可能没有权限浏览它，请要求发送者分享它",
     "Sort favorites first" : "收藏排序优先",
     "Show hidden files" : "显示隐藏文件",
     "Crop image previews" : "裁剪图片预览",
@@ -253,29 +237,30 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "无法修改文件的收藏状态",
     "Error while loading the file data" : "加载文件数据时出错",
     "Pick a template for {name}" : "给 {name} 挑选一个模板",
-    "Create" : "创建",
     "Create a new file with the selected template" : "用所选模板创建一个新文件",
     "Creating file" : "正在创建文件",
     "Blank" : "空白",
     "Unable to create new file from template" : "无法从模板创建新文件",
     "Delete permanently" : "彻底删除",
+    "Cancel" : "取消",
     "Destination is not a folder" : "目标不是一个文件夹",
     "This file/folder is already in that directory" : "该文件/文件夹已经存在与该目录中",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "你无法将文件/文件夹移动至其自身或子文件夹中",
     "A file or folder with that name already exists in this folder" : "相同的文件/文件夹已存在于该文件夹中",
-    "The files is locked" : "文件已锁定",
     "The file does not exist anymore" : "文件不存在",
-    "Chose destination" : "选择目的地",
     "Copy to {target}" : "复制到 {target}",
     "Move to {target}" : "移动到 {target}",
     "Cancelled move or copy operation" : "已取消移动或复制操作",
     "Open folder {displayName}" : "打开文件夹{displayName}",
     "Open in Files" : "在文件中打开",
     "Open details" : "打开详情",
+    "Could not copy {file}. {message}" : "无法复制 {file}。{message}",
+    "Could not move {file}. {message}" : "无法移动 {file}。{message}",
+    "Created new folder \"{name}\"" : "创建了新文件夹「{name}」",
+    "Filename" : "文件名",
+    "Unable to initialize the templates directory" : "无法初始化模板目录",
     "Create new templates folder" : "新建模板文件夹",
     "Templates" : "模板",
-    "Unable to initialize the templates directory" : "无法初始化模板目录",
-    "Created new folder \"{name}\"" : "创建了新文件夹「{name}」",
     "Uploading \"{filename}\" failed" : "上传 “{filename}” 失败",
     "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} 个文件夹"],
     "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} 个文件"],
@@ -290,16 +275,20 @@ OC.L10N.register(
     "List of recently modified files and folders." : "最近修改的文件与文件夹列表。",
     "No recently modified files" : "近期无修改文件",
     "Files and folders you recently modified will show up here." : "您最近修改的文件与文件夹将会显示在此处。",
-    "Toggle %1$s sublist" : "切换 %1$s 子列表",
     "No entries found in this folder" : "在此文件夹中找不到项目",
+    "Select all" : "全部选择",
     "Upload too large" : "上传文件过大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您尝试上传的文件大小超过了服务器的限制。",
     "Text file" : "文本文件",
     "New text file.txt" : "新建文本文档.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "已复制直链（仅适用于有权访问此文件/文件夹的用户）",
+    "Copy direct link (only works for users who have access to this file/folder)" : "复制直接链接(仅适用于有权访问此文件/文件夹的用户)",
     "You can only favorite a single file or folder at a time" : "您一次只能收藏一个文件或文件夹",
+    "\"remote user\"" : "“远程用户”",
     "Search users" : "搜索用户",
-    "Cancel" : "取消",
+    "You might not have have permissions to view it, ask the sender to share it" : "您可能没有权限浏览它，请要求发送者分享它",
     "Set up templates folder" : "设置模板文件夹",
+    "Toggle %1$s sublist" : "切换 %1$s 子列表",
     "Toggle grid view" : "切换网格视图",
     "Deleted files" : "已删除的文件",
     "Shares" : "共享",
@@ -309,13 +298,17 @@ OC.L10N.register(
     "Pending shares" : "待定共享",
     "This file has the tag {tag}" : "这个文件有 {tag} 标签",
     "This file has the tags {firstTags} and {lastTag}" : "这个文件有 {firstTags} 和 {lastTag} 标签",
+    "Select the row for {displayName}" : "选择 {displayName} 的行",
     "Open folder {name}" : "打开文件夹 {name}",
+    "Unselect all" : "取消全选",
     "ascending" : "升序",
     "descending" : "降序",
     "Sort list by {column} ({direction})" : "按 {column} ({direction}) 排序列表",
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "因为性能原因，该列表没有完全加载。这些文件将会在您浏览列表的时候加载。",
     "Search for an account" : "搜索一个账户",
     "Choose" : "选择",
-    "No files or folders have been deleted yet" : "尚未删除任何文件或文件夹"
+    "No files or folders have been deleted yet" : "尚未删除任何文件或文件夹",
+    "Add" : "添加",
+    "The files is locked" : "文件已锁定"
 },
 "nplurals=1; plural=0;");
