@@ -62,7 +62,14 @@ class System implements ISystem {
 			$result = null;
 			$output = [];
 			exec("which $binary 2>&1", $output, $result);
-			$this->paths[$binary] = $result === 0 && isset($output[0]) ? (string)$output[0] : null;
+
+			if ($result === 0 && isset($output[0])) {
+				$this->paths[$binary] = (string)$output[0];
+			} else if (is_executable("/usr/bin/$binary")) {
+				$this->paths[$binary] = "/usr/bin/$binary";
+			} else {
+				$this->paths[$binary] = null;
+			}
 		}
 		return $this->paths[$binary];
 	}
