@@ -1,6 +1,12 @@
 OC.L10N.register(
     "files_external",
     {
+    "Grant access" : "Conceder acceso",
+    "Error configuring OAuth1" : "Se presentó un error al configurar OAuth1",
+    "Please provide a valid app key and secret." : "Por favor proporciona una llave de aplicación y secreto válidos.",
+    "Error configuring OAuth2" : "Se presentó un error al configurar OAuth2",
+    "Generate keys" : "Generar llaves",
+    "Error generating key pair" : "Se presentó un error al generar el juego de llaves",
     "Compatibility with Mac NFD encoding (slow)" : "Compatibilidad con codificación Mac NFD (lenta)",
     "Enable encryption" : "Habilitar encripción",
     "Enable previews" : "Habilitar vistas previas",
@@ -25,7 +31,6 @@ OC.L10N.register(
     "Unsatisfied authentication mechanism parameters" : "Parámetros no satisfechos del mecanismo de autenticación",
     "Insufficient data: %s" : "Datos insuficientes: %s",
     "%s" : "%s",
-    "Storage with ID \"%d\" is not user editable" : "El almacenamiento con ID \"%d\" no puede ser editado por el usuario",
     "Access key" : "Llave de acceso",
     "Secret key" : "Llave secreta",
     "Builtin" : "Integrado",
@@ -36,7 +41,7 @@ OC.L10N.register(
     "OAuth2" : "OAuth2",
     "Client ID" : "ID del cliente",
     "Client secret" : "Secreto del cliente",
-    "Username" : "Usuario",
+    "Login" : "Iniciar sesión",
     "Password" : "Contraseña",
     "Tenant name" : "Nombre de inquilino",
     "Identity endpoint URL" : "URL del punto de enlace de Identidad",
@@ -45,9 +50,7 @@ OC.L10N.register(
     "API key" : "Llave de API",
     "Global credentials" : "Credenciales globales",
     "Log-in credentials, save in database" : "Credenciales de inicio de sesión, guardar en la base de datos",
-    "Username and password" : "Usuario y contraseña",
     "Log-in credentials, save in session" : "Credenciales de inicio de sesión, guardar en la sesión",
-    "User entered, store in database" : "Usuario ingresado, almacenar en la base de datos",
     "RSA public key" : "Llave pública RSA",
     "Public key" : "Llave pública",
     "Amazon S3" : "Amazon S3",
@@ -72,7 +75,6 @@ OC.L10N.register(
     "SFTP with secret key login" : "Inicio de sesión SFTP con llave secreta",
     "Share" : "Compartir",
     "Show hidden files" : "Mostrar archivos ocultos",
-    "Username as share" : "Usuario como elemento compartido",
     "OpenStack Object Storage" : "OpenStack Object Storage",
     "Service name" : "Nombre del servicio",
     "Request timeout (seconds)" : "Tiemo de vida de la solicitud (segundos)",
@@ -93,13 +95,6 @@ OC.L10N.register(
     "Available for" : "Disponible para",
     "Add storage" : "Agregar almacenamiento",
     "Advanced settings" : "Configuraciones avanzadas",
-    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo",
-    "Grant access" : "Conceder acceso",
-    "Error configuring OAuth1" : "Se presentó un error al configurar OAuth1",
-    "Please provide a valid app key and secret." : "Por favor proporciona una llave de aplicación y secreto válidos.",
-    "Error configuring OAuth2" : "Se presentó un error al configurar OAuth2",
-    "Generate keys" : "Generar llaves",
-    "Error generating key pair" : "Se presentó un error al generar el juego de llaves",
     "Empty response from the server" : "Respuesta del servidor vacía",
     "Couldn't access. Please log out and in again to activate this mount point" : "No fue posible accesar. Por favor sal de la sesión y vuelve a entrar para activar este punto de montaje",
     "Couldn't get the information from the remote server: {code} {type}" : "No fue posible obtener la información del servidor remoto: {code} {type}",
@@ -108,9 +103,15 @@ OC.L10N.register(
     "external-storage" : "almacenamiento externo",
     "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "No fue posible obtener el listado de los puntos de motaje de unidades de red Windows. Respuesta vacía del servidor",
     "Please enter the credentials for the {mount} mount" : "Por favor ingresa las credenciales para el montaje {mount}",
+    "Username" : "Usuario",
     "Credentials saved" : "Credenciales guardadas",
     "Credentials saving failed" : "Se ha presentado una falla al guardar las credenciales",
     "Credentials required" : "Se requieren credenciales",
-    "Name" : "Nombre"
+    "Storage with ID \"%d\" is not user editable" : "El almacenamiento con ID \"%d\" no puede ser editado por el usuario",
+    "Username and password" : "Usuario y contraseña",
+    "User entered, store in database" : "Usuario ingresado, almacenar en la base de datos",
+    "Username as share" : "Usuario como elemento compartido",
+    "Name" : "Nombre",
+    "Allow users to mount external storage" : "Permitir a los usuarios montar almacenamiento externo"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
