@@ -1,7 +1,12 @@
 OC.L10N.register(
     "files_external",
     {
-    "Type to select user or group." : "Kirjoita valitaksesi käyttäjän tai ryhmän.",
+    "Grant access" : "Salli pääsy",
+    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
+    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
+    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
+    "Generate keys" : "Luo avaimet",
+    "Error generating key pair" : "Virhe luotaessa avainparia",
     "(Group)" : "(Ryhmä)",
     "Compatibility with Mac NFD encoding (slow)" : "Yhteensopivuus Mac NFD -enkoodauksen kanssa (hidas)",
     "Enable encryption" : "Käytä salausta",
@@ -28,7 +33,6 @@ OC.L10N.register(
     "Unsatisfied authentication mechanism parameters" : "Riittämättömät tunnistautumismekanismin parametrit",
     "Insufficient data: %s" : "Puutteellinen data: %s",
     "%s" : "%s",
-    "Storage with ID \"%d\" is not user editable" : "Tallennustila tunnisteella \"%d\" ei ole käyttäjän muokattavissa",
     "Access key" : "Pääsyavain",
     "Secret key" : "Salainen avain",
     "Builtin" : "Sisäänrakennettu",
@@ -40,7 +44,7 @@ OC.L10N.register(
     "Client ID" : "Asiakkaan tunniste",
     "Client secret" : "Asiakassalaisuus",
     "OpenStack v2" : "OpenStack v2",
-    "Username" : "Käyttäjätunnus",
+    "Login" : "Kirjaudu sisään",
     "Password" : "Salasana",
     "Tenant name" : "Tenant nimi",
     "Identity endpoint URL" : "Määritä URL-päätepiste",
@@ -50,10 +54,7 @@ OC.L10N.register(
     "API key" : "API-avain",
     "Global credentials" : "Yleiset tunnistetiedot",
     "Log-in credentials, save in database" : "Kirjautumistiedot, tallennetaan tietokantaan",
-    "Username and password" : "Käyttäjätunnus ja salasana",
     "Log-in credentials, save in session" : "Kirjautumistiedot, tallenna istuntoon",
-    "Global credentials, user entered" : "Yleiset tunnistetiedot, käyttäjän syöttämät",
-    "User entered, store in database" : "Käyttäjän antama, tallennettu tietokantaan",
     "RSA public key" : "Julkinen RSA-avain",
     "Public key" : "Julkinen avain",
     "RSA private key" : "Yksityinen RSA-avain",
@@ -85,7 +86,6 @@ OC.L10N.register(
     "Show hidden files" : "Näytä piilotiedostot",
     "Verify ACL access when listing files" : "Vahvista ACL-pääsy tiedostoja listatessa",
     "Timeout" : "Aikakatkaisu",
-    "Username as share" : "Käyttäjänimi jakona",
     "OpenStack Object Storage" : "OpenStack Object Storage",
     "Service name" : "Palvelun nimi",
     "Request timeout (seconds)" : "Pyynnön aikakatkaisu (sekunneissa)",
@@ -110,16 +110,9 @@ OC.L10N.register(
     "Available for" : "Saatavuus",
     "Click to recheck the configuration" : "Napsauta tarkistaaksesi uudelleen määritykset",
     "Add storage" : "Lisää tallennustila",
-    "All users" : "Kaikki käyttäjät",
     "Advanced settings" : "Lisäasetukset",
-    "Allow users to mount external storage" : "Salli käyttäjien liittää erillisiä tallennustiloja",
     "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Yleisiä tunnistetietoja voidaan käyttää useisiin ulkoisiin tallennustiloihin tunnistautumiseen, joissa käytetään samoja tunnistetietoja.",
-    "Grant access" : "Salli pääsy",
-    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
-    "Please provide a valid app key and secret." : "Sovellusavain ja salaus ovat virheelliset",
-    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
-    "Generate keys" : "Luo avaimet",
-    "Error generating key pair" : "Virhe luotaessa avainparia",
+    "Type to select user or group." : "Kirjoita valitaksesi käyttäjän tai ryhmän.",
     "Empty response from the server" : "Tyhjä vastaus palvelimelta",
     "Couldn't access. Please log out and in again to activate this mount point" : "Käyttö ei onnistunut. Kirjaudu ulos ja takaisin sisään aktivoidaksesi tämän liitoskohdan",
     "Couldn't get the information from the remote server: {code} {type}" : "Tietojen saaminen etäpalvelimelta epäonnistui: {code} {type}",
@@ -128,9 +121,17 @@ OC.L10N.register(
     "external-storage" : "external-storage",
     "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Ei voitu noutaa listaa Windows-verkkoasemien liitoskohdista: tyhjä vastaus palvelimelta",
     "Please enter the credentials for the {mount} mount" : "Anna kirjautumistiedot liitokselle {mount}",
+    "Username" : "Käyttäjätunnus",
     "Credentials saved" : "Kirjautumistiedot tallennettu",
     "Credentials saving failed" : "Kirjautumistietojen tallentaminen epäonnistui",
     "Credentials required" : "Kirjautumistiedot vaaditaan",
-    "Name" : "Nimi"
+    "Storage with ID \"%d\" is not user editable" : "Tallennustila tunnisteella \"%d\" ei ole käyttäjän muokattavissa",
+    "Username and password" : "Käyttäjätunnus ja salasana",
+    "Global credentials, user entered" : "Yleiset tunnistetiedot, käyttäjän syöttämät",
+    "User entered, store in database" : "Käyttäjän antama, tallennettu tietokantaan",
+    "Username as share" : "Käyttäjänimi jakona",
+    "Name" : "Nimi",
+    "All users" : "Kaikki käyttäjät",
+    "Allow users to mount external storage" : "Salli käyttäjien liittää erillisiä tallennustiloja"
 },
 "nplurals=2; plural=(n != 1);");
