@@ -1,6 +1,12 @@
 OC.L10N.register(
     "files_external",
     {
+    "Grant access" : "Дозволи пристап",
+    "Error configuring OAuth1" : "Грешка во конфигурацијата на OAuth1",
+    "Please provide a valid app key and secret." : "Внесете валиден клуч на апликацијата и лозинка.",
+    "Error configuring OAuth2" : "Грешка во конфигурацијата на OAuth2",
+    "Generate keys" : "Генерирај клучеви",
+    "Error generating key pair" : "Грешка при генерирање на клучеви",
     "(Group)" : "(Група)",
     "Compatibility with Mac NFD encoding (slow)" : "Компатибилно со Mac NFD енкрипција (бавно)",
     "Enable encryption" : "Овозможи енкрипција",
@@ -20,7 +26,6 @@ OC.L10N.register(
     "Invalid mount point" : "Погрешна точка на монтирање",
     "Insufficient data: %s" : "Недоволни податоци: %s",
     "%s" : "%s",
-    "Storage with ID \"%d\" is not user editable" : "Складиштето со ID \"%d\" неможе да се измени од корисник",
     "Access key" : "Клуч за пристап",
     "Secret key" : "Таен клуч",
     "Builtin" : "Вграден",
@@ -32,17 +37,14 @@ OC.L10N.register(
     "Client ID" : "Клиент ИД",
     "Client secret" : "Тајна на клиент",
     "OpenStack v2" : "OpenStack v2",
-    "Username" : "Корисничко име",
+    "Login" : "Најава",
     "Password" : "Лозинка",
     "OpenStack v3" : "OpenStack v3",
     "Domain" : "Домен",
     "API key" : "API key",
     "Global credentials" : "Глобални акредитиви",
     "Log-in credentials, save in database" : "Акредитиви за најавување, зачувани во базата со податоци",
-    "Username and password" : "Корисничко име и лозинка",
     "Log-in credentials, save in session" : "Акредитиви за најавување, зачувани во сесија",
-    "Global credentials, user entered" : "Глобални акредитиви, внесени од корисник",
-    "User entered, store in database" : "Внесени од корисник, зачувани во базата со податоци",
     "RSA public key" : "RSA јавен клуч",
     "Public key" : "Јавен клуч",
     "RSA private key" : "RSA приватен клуч",
@@ -75,6 +77,7 @@ OC.L10N.register(
     "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" не е инсалиран. Монтирањето на %2$s не е возможно. Контактирајте го администраторот.",
     "External storage" : "Надворешно складиште",
     "External storage support" : "Поддршка за надворешно складиште",
+    "Open in Files" : "Отвори во датотеките",
     "External mount error" : "Грешка при надворешно монтирање",
     "Storage type" : "Вид на складиште",
     "Unknown" : "Непознат",
@@ -83,23 +86,14 @@ OC.L10N.register(
     "System" : "Систем",
     "No external storage configured or you don't have the permission to configure them" : "Немате конфигурирано надворешно складиште или немате дозвола да го конфигурирате",
     "Open documentation" : "Отвори ја документацијата",
-    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "Надворешното складирање ви овозможува да ги монтирате услугите и уредите за надворешно складирање како секундарни уреди за складирање на Nextcloud. Исто така може да им дозволите на корисниците да монтираат свои услуги за надворешно складирање.",
     "Folder name" : "Име на папка",
     "Authentication" : "Автентикација",
     "Configuration" : "Конфигурација",
     "Available for" : "Достапно за",
     "Click to recheck the configuration" : "Кликни за проверка на конфигурацијата",
     "Add storage" : "Додади складиште",
-    "All users" : "Сите корисници",
     "Advanced settings" : "Напредни параметри",
-    "Allow users to mount external storage" : "Дозволи на корисниците да монтираат надворешни складишта",
     "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Глобалните акредитиви можат да се искористат за пристапување во повеќе надворешни складишта кој користат исти акредитиви.",
-    "Grant access" : "Дозволи пристап",
-    "Error configuring OAuth1" : "Грешка во конфигурацијата на OAuth1",
-    "Please provide a valid app key and secret." : "Внесете валиден клуч на апликацијата и лозинка.",
-    "Error configuring OAuth2" : "Грешка во конфигурацијата на OAuth2",
-    "Generate keys" : "Генерирај клучеви",
-    "Error generating key pair" : "Грешка при генерирање на клучеви",
     "Empty response from the server" : "Нема одговор од серверот",
     "Couldn't access. Please log out and in again to activate this mount point" : "Неможе да се пристапи. Ве молиме одјавете се и повторно најавете се за да се активира монтираната точка.",
     "Couldn't get the information from the remote server: {code} {type}" : "Неможат да се преземат информациите од серверот: {code} {type}",
@@ -108,9 +102,17 @@ OC.L10N.register(
     "external-storage" : "Надворешно складиште",
     "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Неможат да се преземе листата на надворешните монтирани точки: Празен одговор од серверот",
     "Please enter the credentials for the {mount} mount" : "Внесете акредитиви за {mount}",
+    "Username" : "Корисничко име",
     "Credentials saved" : "Акредитивите се зачувани",
     "Credentials saving failed" : "Неуспешно зачувување на акредитивите",
     "Credentials required" : "Акредитивите се задолжителни",
-    "Name" : "Име"
+    "Storage with ID \"%d\" is not user editable" : "Складиштето со ID \"%d\" неможе да се измени од корисник",
+    "Username and password" : "Корисничко име и лозинка",
+    "Global credentials, user entered" : "Глобални акредитиви, внесени од корисник",
+    "User entered, store in database" : "Внесени од корисник, зачувани во базата со податоци",
+    "Name" : "Име",
+    "External storage enables you to mount external storage services and devices as secondary Nextcloud storage devices. You may also allow users to mount their own external storage services." : "Надворешното складирање ви овозможува да ги монтирате услугите и уредите за надворешно складирање како секундарни уреди за складирање на Nextcloud. Исто така може да им дозволите на корисниците да монтираат свои услуги за надворешно складирање.",
+    "All users" : "Сите корисници",
+    "Allow users to mount external storage" : "Дозволи на корисниците да монтираат надворешни складишта"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
