@@ -31,6 +31,7 @@ namespace OCA\Files_External\Config;
 
 use OC\Files\Storage\FailedStorage;
 use OC\Files\Storage\Wrapper\Availability;
+use OC\Files\Storage\Wrapper\KnownMtime;
 use OCA\Files_External\Lib\PersonalMount;
 use OCA\Files_External\Lib\StorageConfig;
 use OCA\Files_External\Service\UserGlobalStoragesService;
@@ -40,29 +41,17 @@ use OCP\Files\Storage;
 use OCP\Files\Storage\IStorageFactory;
 use OCP\Files\StorageNotAvailableException;
 use OCP\IUser;
+use Psr\Clock\ClockInterface;
 
 /**
  * Make the old files_external config work with the new public mount config api
  */
 class ConfigAdapter implements IMountProvider {
-
-	/** @var UserStoragesService */
-	private $userStoragesService;
-
-	/** @var UserGlobalStoragesService */
-	private $userGlobalStoragesService;
-
-	/**
-	 * @param UserStoragesService $userStoragesService
-	 * @param UserGlobalStoragesService $userGlobalStoragesService
-	 */
 	public function __construct(
-		UserStoragesService $userStoragesService,
-		UserGlobalStoragesService $userGlobalStoragesService
-	) {
-		$this->userStoragesService = $userStoragesService;
-		$this->userGlobalStoragesService = $userGlobalStoragesService;
-	}
+		private UserStoragesService $userStoragesService,
+		private UserGlobalStoragesService $userGlobalStoragesService,
+		private ClockInterface $clock,
+	) {}
 
 	/**
 	 * Process storage ready for mounting
@@ -155,7 +144,10 @@ class ConfigAdapter implements IMountProvider {
 					$this->userStoragesService,
 					$storageConfig,
 					$storageConfig->getId(),
-					$storage,
+					new KnownMtime([
+						'storage' => $storage,
+						'clock' => $this->clock,
+					]),
 					'/' . $user->getUID() . '/files' . $storageConfig->getMountPoint(),
 					null,
 					$loader,
@@ -163,7 +155,7 @@ class ConfigAdapter implements IMountProvider {
 					$storageConfig->getId()
 				);
 			} else {
-				return new ExternalMountPoint(
+				return new SystemMountPoint(
 					$storageConfig,
 					$storage,
 					'/' . $user->getUID() . '/files' . $storageConfig->getMountPoint(),
