@@ -482,25 +482,25 @@ class Swift extends \OC\Files\Storage\Common {
 		}
 	}
 
-	public function copy($path1, $path2) {
-		$path1 = $this->normalizePath($path1);
-		$path2 = $this->normalizePath($path2);
+	public function copy($source, $target) {
+		$source = $this->normalizePath($source);
+		$target = $this->normalizePath($target);
 
-		$fileType = $this->filetype($path1);
+		$fileType = $this->filetype($source);
 		if ($fileType) {
 			// make way
-			$this->unlink($path2);
+			$this->unlink($target);
 		}
 
 		if ($fileType === 'file') {
 			try {
-				$source = $this->fetchObject($path1);
-				$source->copy([
-					'destination' => $this->bucket . '/' . $path2
+				$sourceObject = $this->fetchObject($source);
+				$sourceObject->copy([
+					'destination' => $this->bucket . '/' . $target
 				]);
 				// invalidate target object to force repopulation on fetch
-				$this->objectCache->remove($path2);
-				$this->objectCache->remove($path2 . '/');
+				$this->objectCache->remove($target);
+				$this->objectCache->remove($target . '/');
 			} catch (BadResponseError $e) {
 				\OC::$server->get(LoggerInterface::class)->error($e->getMessage(), [
 					'exception' => $e,
@@ -510,13 +510,13 @@ class Swift extends \OC\Files\Storage\Common {
 			}
 		} elseif ($fileType === 'dir') {
 			try {
-				$source = $this->fetchObject($path1 . '/');
-				$source->copy([
-					'destination' => $this->bucket . '/' . $path2 . '/'
+				$sourceObject = $this->fetchObject($source . '/');
+				$sourceObject->copy([
+					'destination' => $this->bucket . '/' . $target . '/'
 				]);
 				// invalidate target object to force repopulation on fetch
-				$this->objectCache->remove($path2);
-				$this->objectCache->remove($path2 . '/');
+				$this->objectCache->remove($target);
+				$this->objectCache->remove($target . '/');
 			} catch (BadResponseError $e) {
 				\OC::$server->get(LoggerInterface::class)->error($e->getMessage(), [
 					'exception' => $e,
@@ -525,14 +525,14 @@ class Swift extends \OC\Files\Storage\Common {
 				return false;
 			}
 
-			$dh = $this->opendir($path1);
+			$dh = $this->opendir($source);
 			while ($file = readdir($dh)) {
 				if (\OC\Files\Filesystem::isIgnoredDir($file)) {
 					continue;
 				}
 
-				$source = $path1 . '/' . $file;
-				$target = $path2 . '/' . $file;
+				$source = $source . '/' . $file;
+				$target = $target . '/' . $file;
 				$this->copy($source, $target);
 			}
 		} else {
@@ -543,22 +543,22 @@ class Swift extends \OC\Files\Storage\Common {
 		return true;
 	}
 
-	public function rename($path1, $path2) {
-		$path1 = $this->normalizePath($path1);
-		$path2 = $this->normalizePath($path2);
+	public function rename($source, $target) {
+		$source = $this->normalizePath($source);
+		$target = $this->normalizePath($target);
 
-		$fileType = $this->filetype($path1);
+		$fileType = $this->filetype($source);
 
 		if ($fileType === 'dir' || $fileType === 'file') {
 			// copy
-			if ($this->copy($path1, $path2) === false) {
+			if ($this->copy($source, $target) === false) {
 				return false;
 			}
 
 			// cleanup
-			if ($this->unlink($path1) === false) {
+			if ($this->unlink($source) === false) {
 				throw new \Exception('failed to remove original');
-				$this->unlink($path2);
+				$this->unlink($target);
 				return false;
 			}
 
