@@ -7,8 +7,15 @@ OC.L10N.register(
     "View folder" : "Visa mapp",
     "Set file reminders" : "Ställ in filpåminnelser",
     "**📣 File reminders**\n\nSet file reminders." : "**📣 Filpåminnelser**\n\nStäll in filpåminnelser.",
-    "Back" : "Tillbaka",
+    "We will remind you of this file" : "Vi kommer att påminna dig om denna fil",
+    "Please choose a valid date & time" : "Välj ett giltigt datum och tid",
+    "Cancel" : "Avbryt",
+    "Set reminder" : "Ställ in påminnelse",
+    "Set reminder for \"{fileName}\"" : "Ställ in påminnelse för \"{fileName}\"",
+    "Set reminder at custom date & time" : "Ställ in påminnelse vid anpassat datum och tid",
     "Clear reminder" : "Rensa påminnelse",
+    "Reminder set for \"{fileName}\"" : "Påminnelse inställd för \"{fileName}\"",
+    "Failed to set reminder" : "Kunde inte ställa in påminnelsen",
     "Set custom reminder" : "Ställ in anpassad påminnelse",
     "Later today" : "Senare idag",
     "Set reminder for later today" : "Ställ in påminnelse för senare idag",
@@ -18,10 +25,7 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Ställ in påminnelse för denna helg",
     "Next week" : "Nästa vecka",
     "Set reminder for next week" : "Ställ in påminnelse för nästa vecka",
-    "Set reminder at custom date & time" : "Ställ in påminnelse vid anpassat datum och tid",
-    "Reminder set for \"{fileName}\"" : "Påminnelse inställd för \"{fileName}\"",
-    "Failed to set reminder" : "Kunde inte ställa in påminnelsen",
-    "Please choose a valid date & time" : "Välj ett giltigt datum och tid",
+    "Back" : "Tillbaka",
     "Reminder cleared" : "Påminnelsen rensad",
     "Failed to clear reminder" : "Kunde inte rensa påminnelsen",
     "Failed to load reminder" : "Kunde inte läsa in påminnelsen"
