@@ -1,6 +1,6 @@
 OC.L10N.register(
     "files_rightclick",
     {
-    "Select" : "Esbillar"
+    "Unselect all" : "Deseleicionar too"
 },
 "nplurals=2; plural=(n != 1);");
