@@ -1,8 +1,8 @@
 OC.L10N.register(
     "files_rightclick",
     {
-    "Unselect" : "Зняти виділення",
-    "Share folder" : "Спільний доступ для каталогу",
+    "Unselect all" : "Зняти вибір",
+    "Share folder" : "Спільний доступ до каталогу",
     "Share file" : "Поділитися файлом",
     "Select" : "Вибрати",
     "Copied !" : "Скопійовано!",
