@@ -79,7 +79,6 @@ OC.L10N.register(
     "Wrong path, file/folder does not exist" : "Väärä polku, tiedostoa/kansiota ei ole olemassa",
     "Could not create share" : "Jaon luominen epäonnistui",
     "Invalid permissions" : "Virheelliset käyttöoikeudet",
-    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
     "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
     "Please specify a valid group" : "Määritä kelvollinen ryhmä",
     "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
@@ -110,21 +109,12 @@ OC.L10N.register(
     "Accept" : "Hyväksy",
     "Reject" : "Hylkää",
     "Sharing" : "Jakaminen",
-    "Accept user and group shares by default" : "Hyväksy käyttäjä- ja ryhmäjaot oletuksena",
     "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
     "Reset" : "Palauta",
     "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
     "Choose a default folder for accepted shares" : "Valitse oletuskansio hyväksytyille jaoille",
     "Invalid path selected" : "Virheellinen polku valittu",
     "Unknown error" : "Tuntematon virhe",
-    "Allow editing" : "Salli muokkaus",
-    "Read only" : "Vain luku",
-    "Allow upload and editing" : "Salli lähetys ja muokkaus",
-    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
-    "Custom permissions" : "Mukautetut oikeudet",
-    "Read" : "Lue",
-    "Upload" : "Lähetä",
-    "Edit" : "Muokkaa",
     "group" : "ryhmä",
     "conversation" : "keskustelu",
     "remote" : "etä",
@@ -139,8 +129,6 @@ OC.L10N.register(
     "Internal link" : "Sisäinen linkki",
     "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
     "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
-    "Only works for users with access to this folder" : "Toimii vain käyttäjille, joilla on oikeus tähän kansioon",
-    "Only works for users with access to this file" : "Toimii vain käyttäjille, joilla on käyttöoikeus tähän tiedostoon",
     "Link copied" : "Linkki kopioitu",
     "Please enter the following required information before creating the share" : "Anna seuraavat vaaditut tiedot, ennen kuin luot jaon",
     "Password protection (enforced)" : "Salasanasuojaus (pakotettu)",
@@ -166,6 +154,7 @@ OC.L10N.register(
     "View only" : "Vain katselu",
     "Can edit" : "Voi muokata",
     "File drop" : "Tiedoston pudotus",
+    "Custom permissions" : "Mukautetut oikeudet",
     "Search for share recipients" : "Etsi jaon vastaanottajia",
     "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
     "Resharing is not allowed" : "Uudelleenjako ei ole sallittu",
@@ -181,27 +170,30 @@ OC.L10N.register(
     "Talk conversation" : "Talk-keskustelu",
     "Deck board" : "Deck-taulu",
     "on {server}" : "palvelimella {server}",
+    "Allow upload and editing" : "Salli lähetys ja muokkaus",
+    "Allow editing" : "Salli muokkaus",
     "Advanced settings" : "Lisäasetukset",
     "Share label" : "Jaon nimi",
     "Set password" : "Aseta salasana",
     "Password" : "Salasana",
     "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
     "Password expired" : "Salasana vanheni",
+    "Video verification" : "Videovarmistus",
     "Set expiration date" : "Aseta vanhenemispäivä",
     "Expiration date" : "Vanhenemispäivä",
     "Hide download" : "Piilota lataus",
-    "Video verification" : "Videovarmistus",
     "Allow download" : "Salli lataus",
     "Note to recipient" : "Huomio vastaanottajalle",
     "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
+    "Read" : "Lue",
     "Create" : "Luo",
-    "Update" : "Päivitä",
+    "Edit" : "Muokkaa",
     "Share" : "Jaa",
     "Delete share" : "Poista jako",
+    "Share with" : "Jaa",
     "Save share" : "Tallenna jako",
     "Update share" : "Päivitä jako",
     "Others with access" : "Muut, joilla on käyttöoikeus",
-    "No other users with access found" : "Ei löytynyt muita käyttäjiä, joilla olisi käyttöoikeus",
     "Toggle list of others with access to this directory" : "Vaihda näkymää kansioon käyttöoikeuden omaavista käyttäjistä",
     "Toggle list of others with access to this file" : "Vaihda näkymää tiedostoon käyttöoikeuden omaavista käyttäjistä",
     "Unable to load the shares list" : "Jakolistan haku epäonnistui",
@@ -250,15 +242,6 @@ OC.L10N.register(
     "List of unapproved shares." : "Luettelo hyväksymättömistä jaoista.",
     "No pending shares" : "Ei odottavia jakoja",
     "Shares you have received but not approved will show up here" : "Vastaanottamasi jaot, joita ei ole hyväksytty, näkyvät täällä",
-    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
-    "Name" : "Nimi",
-    "Share time" : "Jakamisen ajankohta",
-    "Sorry, this link does not seem to work anymore." : "Valitettavasti tämä linkki ei vaikuta enää toimivan.",
-    "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
-    "the item was removed" : "kohde poistettiin",
-    "the link expired" : "linkki vanheni",
-    "sharing is disabled" : "jakaminen on poistettu käytöstä",
-    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
     "Share note" : "Jaa muistiinpano",
     "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
     "Note" : "Huomio",
@@ -278,11 +261,28 @@ OC.L10N.register(
     "Something happened. Unable to accept the share." : "Jotain tapahtui. Jakoa ei voitu hyväksyä.",
     "Something happened. Unable to reject the share." : "Tapahtui virhe. Ei voida hylätä jakoa.",
     "No expiration date set" : "Ei vanhenemispäivää asetettu",
-    "One or more of your shares will expire tomorrow" : "Yksi tai useampi jaoistasi vanhenee huomenna",
+    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
+    "Accept user and group shares by default" : "Hyväksy käyttäjä- ja ryhmäjaot oletuksena",
+    "Read only" : "Vain luku",
+    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
+    "Upload" : "Lähetä",
     "Allow creating" : "Salli luominen",
     "Allow deleting" : "Salli poistaminen",
     "Allow resharing" : "Salli uudelleenjakaminen",
     "Expiration date enforced" : "Vanhenemispäivä pakotettu",
-    "Password protect" : "Suojaa salasanalla"
+    "Only works for users with access to this folder" : "Toimii vain käyttäjille, joilla on oikeus tähän kansioon",
+    "Only works for users with access to this file" : "Toimii vain käyttäjille, joilla on käyttöoikeus tähän tiedostoon",
+    "Password protect" : "Suojaa salasanalla",
+    "No other users with access found" : "Ei löytynyt muita käyttäjiä, joilla olisi käyttöoikeus",
+    "No entries found in this folder" : "Ei kohteita tässä kansiossa",
+    "Name" : "Nimi",
+    "Share time" : "Jakamisen ajankohta",
+    "Sorry, this link does not seem to work anymore." : "Valitettavasti tämä linkki ei vaikuta enää toimivan.",
+    "Reasons might be:" : "Mahdollisia syitä saattavat olla:",
+    "the item was removed" : "kohde poistettiin",
+    "the link expired" : "linkki vanheni",
+    "sharing is disabled" : "jakaminen on poistettu käytöstä",
+    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
+    "Update" : "Päivitä"
 },
 "nplurals=2; plural=(n != 1);");
