@@ -64,7 +64,6 @@ OC.L10N.register(
     "Please specify a file or folder path" : "Por favor, especifique um ficheiro ou caminho de pasta",
     "Wrong path, file/folder does not exist" : "Caminho errado, ficheiro/pasta não existe",
     "Could not create share" : "Não foi possível criar partilha",
-    "Please specify a valid user" : "Por favor, especifique um utilizador válido",
     "Group sharing is disabled by the administrator" : "A partilha em grupo está desativada pelo administrador",
     "Please specify a valid group" : "Por favor, especifique um grupo válido",
     "Public link sharing is disabled by the administrator" : "A partilha da hiperligação pública está desativada pelo administrador",
@@ -86,13 +85,6 @@ OC.L10N.register(
     "Sharing" : "Partilha",
     "Reset" : "Reiniciar",
     "Unknown error" : "Erro desconhecido",
-    "Allow editing" : "Permitir edição",
-    "Read only" : "Apenas leitura",
-    "Allow upload and editing" : "Permtir carregamentos e edições",
-    "File drop (upload only)" : "Pasta de carregamento apenas",
-    "Read" : "Ler",
-    "Upload" : "Upload",
-    "Edit" : "Editar",
     "group" : "grupo",
     "conversation" : "conversação",
     "remote" : "remoto",
@@ -100,7 +92,6 @@ OC.L10N.register(
     "guest" : "convidado",
     "Unshare" : "Cancelar partilha",
     "Cannot copy, please copy the link manually" : "Não foi possível copiar, copie a ligação manualmente",
-    "Only works for users with access to this folder" : "Apenas funciona para utilizadores com acesso a esta pasta",
     "Link copied" : "Link copiado",
     "Password protection" : "Protegido por palavra-passe",
     "Enter a password" : "Insira uma palavra-passe",
@@ -119,6 +110,8 @@ OC.L10N.register(
     "Group" : "Grupo",
     "Email" : "E-mail",
     "Circle" : "Círculo",
+    "Allow upload and editing" : "Permtir carregamentos e edições",
+    "Allow editing" : "Permitir edição",
     "Advanced settings" : "Definições avançadas",
     "Set password" : "Definir palavra-passe",
     "Password" : "Password",
@@ -126,9 +119,11 @@ OC.L10N.register(
     "Expiration date" : "Data de expiração",
     "Hide download" : "Ocultar transferência",
     "Note to recipient" : "Nota para o destinatário",
+    "Read" : "Ler",
     "Create" : "Criar",
-    "Update" : "Atualizar",
+    "Edit" : "Editar",
     "Share" : "Partilhar",
+    "Share with" : "Partilhar com",
     "Shared with you by {owner}" : "Partilhado consigo por {owner}",
     "Shared" : "Partilhados",
     "Shared by" : "Partilhado por",
@@ -144,14 +139,6 @@ OC.L10N.register(
     "Nothing shared yet" : "Ainda não foi partilhado nada",
     "Shared by link" : "Partilhado por hiperligação",
     "No shared links" : "Sem hiperligações partilhadas",
-    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
-    "Name" : "Nome",
-    "Share time" : "Hora da Partilha",
-    "Reasons might be:" : "As razões poderão ser:",
-    "the item was removed" : "o item foi removido",
-    "the link expired" : "a hiperligação expirou",
-    "sharing is disabled" : "a partilha está desativada",
-    "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
     "Share note" : "Partilhar nota",
     "Upload files to %s" : "Enviar ficheiros para %s",
     "Note" : "Nota",
@@ -163,10 +150,24 @@ OC.L10N.register(
     "Files and folders you share by link will show up here" : "Os ficheiros e as pastas que partilha por hiperligação, serão mostrados aqui",
     "Restore" : "Restaurar",
     "No expiration date set" : "Data de expiração não definida",
+    "Please specify a valid user" : "Por favor, especifique um utilizador válido",
+    "Read only" : "Apenas leitura",
+    "File drop (upload only)" : "Pasta de carregamento apenas",
+    "Upload" : "Upload",
     "Allow creating" : "Permitir criar",
     "Allow deleting" : "Permitir eliminar",
     "Allow resharing" : "Permitir repartilha",
     "Expiration date enforced" : "Imposta data de expiração",
-    "Password protect" : "Proteger com palavra-passe"
+    "Only works for users with access to this folder" : "Apenas funciona para utilizadores com acesso a esta pasta",
+    "Password protect" : "Proteger com palavra-passe",
+    "No entries found in this folder" : "Não foram encontradas entradas nesta pasta",
+    "Name" : "Nome",
+    "Share time" : "Hora da Partilha",
+    "Reasons might be:" : "As razões poderão ser:",
+    "the item was removed" : "o item foi removido",
+    "the link expired" : "a hiperligação expirou",
+    "sharing is disabled" : "a partilha está desativada",
+    "For more info, please ask the person who sent this link." : "Para mais informação, por favor, pergunte à pessoa que lhe enviou esta hiperligação.",
+    "Update" : "Atualizar"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
