@@ -24,10 +24,22 @@
  */
 namespace OCA\Files_Versions;
 
+use OCP\App\IAppManager;
 use OCP\Capabilities\ICapability;
+use OCP\IConfig;
 
 class Capabilities implements ICapability {
-	
+	private IConfig $config;
+	private IAppManager $appManager;
+
+	public function __construct(
+		IConfig $config,
+		IAppManager $appManager
+	) {
+		$this->config = $config;
+		$this->appManager = $appManager;
+	}
+
 	/**
 	 * Return this classes capabilities
 	 *
@@ -36,7 +48,9 @@ class Capabilities implements ICapability {
 	public function getCapabilities() {
 		return [
 			'files' => [
-				'versioning' => true
+				'versioning' => true,
+				'version_labeling' => $this->config->getSystemValueBool('enable_version_labeling', true),
+				'version_deletion' => $this->config->getSystemValueBool('enable_version_deletion', true),
 			]
 		];
 	}
