@@ -1,10 +1,35 @@
 OC.L10N.register(
     "firstrunwizard",
     {
-    "Copied!" : "已复制！",
-    "Not supported!" : "不支持！",
-    "Press ⌘-C to copy." : "按 ⌘-C 复制。",
-    "Press Ctrl-C to copy." : "按 Ctrl-C 复制。",
+    "Welcome to {cloudName}!" : "欢迎来到 {cloudName}！",
+    "A collaboration platform that puts you in control" : "一个由您掌握的协作平台",
+    "Privacy" : "隐私",
+    "Host your data and files where you decide." : "把数据和文件保管在您决定的地方",
+    "Productivity" : "生产力",
+    "Collaborate and communicate across any platform." : "跨任何平台进行沟通和协作",
+    "Interoperability" : "互通性",
+    "Import and export anything you want with open standards." : "使用开放标准导入导出您想要的任何东西",
+    "Community" : "社区",
+    "Enjoy constant improvements from a thriving open-source community." : "生机勃勃的开源社区持续优化您的体验",
+    "Download on Apple app store" : "从苹果应用商店下载",
+    "Download on Google play store" : "从Google Play商店下载",
+    "Sync your files across your devices with the desktop and mobile apps, and connect your calendar and contacts." : "使用桌面和移动应用在您的设备间同步文件，并连接您的日历和通讯录",
+    "Seamless integration with your devices." : "无缝集成到您的设备中",
+    "Desktop app ↗" : "桌面应用 ↗",
+    "Download For Windows, Mac OS and Linux." : "下载支持 Windows、macOS和Linux的版本",
+    "Calendar and contacts ↗" : "日历及通讯录",
+    "Connect your calendar and contacts with your devices." : "连接您不同设备间的日历和通讯录",
+    "More about Nextcloud" : "更多关于 Nextcloud 的信息",
+    "Explore more apps ↗" : "发现更多应用 ↗",
+    "Extend the functionality of Nextcloud with hundreds of community-developed apps." : "数百款社区开发的应用为您的 Nextcloud 扩展更多功能",
+    "Get involved! ↗" : "参与其中！",
+    "Be a part of the community that helps build, design, translate and promote Nextcloud!" : "成为构建、设计、翻译和推广Nextcloud的社区的一份子！",
+    "Need help? ↗" : "需要帮助？↗",
+    "Find out more about your Nextcloud setup with the admin, user or developer documentation." : "通过管理员、用户和开发者手册进一步熟悉您的 Nextcloud 安装",
+    "For large organisations ↗" : "面向大型组织",
+    "Get Nextcloud Enterprise for mission critical environments where advanced security and compliance are important." : "任务关键环境中，Nextcloud Enterprise可提供必须的高级安全和合规特性",
+    "Nextcloud on all your devices" : "您所有设备上的 Nextcloud",
+    "Get started!" : "即刻开始！",
     "First run wizard" : "首次运行显示向导",
     "Add your profile information! For example your email is needed to receive notifications." : "添加你的个人资料信息！例如，需要你的电子邮件来接收通知。",
     "Add your profile information! For example your email is needed to receive notifications and reset your password." : "添加你的个人资料信息！例如，需要你的电子邮件来接收通知并重置密码。",
@@ -21,15 +46,17 @@ OC.L10N.register(
     "Sync tasks from various devices with your Nextcloud and edit them online." : "将各种设备的任务与 Nextcloud 同步，然后在线进行编辑。",
     "App recommendation: Deck" : "应用推荐：看板",
     "Kanban style organization for personal planning and team projects." : "看板式的组织个人计划和团队项目。",
+    "App recommendation: Forms" : "推荐应用：表单",
+    "Simple surveys and questionnaires, self-hosted" : "简单的自托管调查问卷",
+    "App recommendation: Recognize" : "推荐应用：智能识别",
     "Smart media tagging for Nextcloud" : "智能的媒体文件标签分类",
     "App recommendation: Group folders" : "应用推荐：群组文件夹",
     "Admin-configured folders shared by everyone in a group." : "由管理员配置的被用户组所有成员共享的文件夹。",
     "About" : "关于",
     "A welcome and introduction wizard for Nextcloud" : "Nextcloud 的欢迎和介绍向导",
     "This application enables a pop-up window when a user first logs into Nextcloud. This window welcomes new users to Nextcloud, and contains links to the standard desktop client, Android app, and the iOS app. The window also shows a link for accessing Nextcloud via WebDAV. At any time, the first run wizard can be opened again via link \"About\" on settings menu.\nThe First run wizard can be customized to meet specific design goals, or to change links and messages. Create an appropriate theme following the Theming documentation, and changes to the look and feel of this Wizard are simple. More information is available in the first run wizard documentation, as well as the theming documentation." : "此应用在用户初次登录Nextcloud时启用一个弹窗。此弹窗欢迎新用户来到Nextcloud，包含标准桌面客户端，Android应用和iOS应用的链接。这个窗口也会显示从WebDAV访问Nextcloud的链接。在任何时间，初次运行向导都能通过 设置 目录上的\"关于\"链接再次打开。\n初次运行向导可以定制以满足某些设计需求，或修改链接和消息。可以很容易地按主题设置文档来创建合适的主题，以及改变向导的外观。更多信息请参见初次运行向导文档以及主题设置文档。",
-    "Welcome to {cloudName}!" : "欢迎来到 {cloudName}！",
-    "Privacy" : "隐私",
-    "Community" : "社区",
+    "Go to previous page" : "回到前一页",
+    "Close dialog" : "关闭对话框",
     "Get the apps to sync your files" : "安装应用进行文件同步",
     "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "走到哪里，文件跟到哪里！ %s 免费客户端支持电脑手机的各大主流平台",
     "Desktop client" : "桌面客户端",
@@ -46,7 +73,10 @@ OC.L10N.register(
     "Server address" : "服务器地址",
     "Use this link to connect your apps and desktop client to this server:" : "使用此链接将您的应用和桌面客户端连接到此服务器：",
     "Copy link" : "复制链接",
-    "Copy to clipboard" : "复制到剪贴板",
+    "Copied!" : "已复制！",
+    "Not supported!" : "不支持！",
+    "Press ⌘-C to copy." : "按 ⌘-C 复制。",
+    "Press Ctrl-C to copy." : "按 Ctrl-C 复制。",
     "Start using {cloudName}" : "开始使用 {cloudName}",
     "Extend your cloud" : "扩展您的云",
     "Find more than 100 apps in the Nextcloud App Store to customize your cloud:" : "在 Nextcloud 应用商店内找到 100 多款应用程序来定制您的云:",
@@ -62,9 +92,11 @@ OC.L10N.register(
     "Connect your desktop apps to %s" : "使用桌面应用连接到 %s",
     "Get help" : "获取帮助",
     "Start contributing" : "开始贡献",
-    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "您想改进 Nextcloud？您发现了一个问题？您想帮助翻译，促进 Nextcloud 或为其编写文档？",
-    "Become part of the Community" : "成为社区的一分子",
+    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "您想改进 Nextcloud？您发现了一个问题？您想帮助翻译，推广 Nextcloud 或为其编写文档？",
+    "Become part of the Community" : "加入社区",
     "Enterprise support" : "企业级技术支持",
+    "If you run Nextcloud in a mission critical environment where security and compliance are important, you need the certainty of Nextcloud Enterprise." : "若您在需要安全性与合规性的任务关键环境中运行 Nextcloud，Nextcloud Enterprise将为您保驾护航",
+    "Learn more about Nextcloud Enterprise" : "详细了解 Nextcloud Enterprise",
     "Get more information" : "获取更多信息",
     "The Nextcloud documentation for home users:" : "适用于家庭用户的 Nextcloud 文档：",
     "User manual" : "用户手册",
@@ -75,6 +107,8 @@ OC.L10N.register(
     "A safe home for all your data" : "给您所有数据一个安全的家",
     "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud 将您的数据置于您的掌控之中。在您公司、家中、我们的一个供应商或您了解的数据中心里的服务器上保存您的文档、日历、联系人以及照片。",
     "Host your data and files where you decide" : "把数据和文件保管在您想要的地方",
+    "Open standards and interoperability" : "开放标准和互通性",
+    "100%% open source & community-focused" : "100%% 开源，专注于为社区用户服务",
     "Learn more about %s" : "了解更多关于 %s 的详情",
     "This Nextcloud is on version %s" : "这个 Nextcloud 实例版本为 %s"
 },
