@@ -2,6 +2,10 @@ OC.L10N.register(
     "logreader",
     {
     "Logging" : "Registre",
+    "Errors in the log" : "Errors en el registre",
+    "No errors in the logs since %s" : "No hi ha errors als registres des del dia %s",
+    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n error als registres des del dia %s","%n errors als registres des del dia %s"],
+    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n advertència als registres des del dia %s","%n avisos als registres des del dia %s"],
     "Log Reader" : "Lector del registre",
     "A log reader for Nextcloud" : "Lector del registre per al Nextcloud",
     "Log reader for Nextcloud" : "Lector del registre per al Nextcloud",
@@ -26,12 +30,16 @@ OC.L10N.register(
     "Log entry successfully copied" : "L'entrada del registre s'ha copiat correctament",
     "Search log entries" : "Cerca entrades de registre",
     "Caused by {exception}" : "Causat per {exception}",
+    "Line {line}" : "Línia {line}",
     "Filter log levels" : "Filtre els nivells de registre",
+    "Set log level" : "Estableix el nivell de registre",
     "Time format" : "Format d'hora",
     "Live view" : "Visualització en directe",
+    "Download/Upload logs" : "Baixada/pujada de registres",
     "Download logs" : "Baixa els registres",
     "Show local log file" : "Mostra el fitxer de registre local",
     "Upload local log file to be displayed" : "Pujada del fitxer de registre local que es mostrarà",
+    "Could not parse local log file" : "No s'ha pogut analitzar el fitxer de registre local",
     "Raw data" : "Dades sense format",
     "Local time" : "Hora local",
     "UTC time" : "Hora UTC",
@@ -40,9 +48,11 @@ OC.L10N.register(
     "Could not change date time format." : "No s'ha pogut canviar el format de data i hora.",
     "Polling is disabled because server is not configured to log to file" : "L'enquesta està desactivada perquè el servidor no està configurat per iniciar sessió al fitxer",
     "Polling (live view)" : "Enquesta (visualització en directe)",
-    "Could not change live view setting." : "No s'ha pogut canviar la configuració de visualització en directe.",
+    "Could not change live view setting." : "No s'ha pogut canviar el paràmetre de visualització en directe.",
     "Filter logging levels" : "Filtre els nivells de registre",
     "Could not set logging levels to show" : "No s'han pogut configurar els nivells de registre per mostrar",
+    "Set backend loglevel" : "Estableix el nivell de registre del rerefons",
+    "Could not set logging level" : "No s'ha pogut establir el nivell de registre",
     "Application" : "Aplicació",
     "Message" : "Missatge",
     "Log entry actions" : "Accions d'entrada de registre",
@@ -56,6 +66,7 @@ OC.L10N.register(
     "Warning" : "Avís",
     "Error" : "Error",
     "Fatal" : "Crític",
+    "Could not load log entries" : "No s'han pogut carregar les entrades de registre",
     "Could not fetch new log entries (server unavailable)" : "No s'han pogut obtenir entrades de registre noves (servidor no disponible)",
     "Could not fetch new entries" : "No s'han pogut obtenir entrades noves",
     "Could not copy to clipboard, please copy manually:" : "No s'ha pogut copiar al porta-retalls, copieu-lo manualment:",
@@ -74,6 +85,6 @@ OC.L10N.register(
     "Log content" : "Contingut del registre",
     "Live update" : "Actualització en directe",
     "line {line}" : "línia {line}",
-    "Download / Upload logs" : "Baixar/pujar registres"
+    "Download / Upload logs" : "Baixada/pujada de registres"
 },
 "nplurals=2; plural=(n != 1);");
