@@ -8,7 +8,9 @@ OC.L10N.register(
     "Level" : "Nivel",
     "App" : "Aplicación",
     "Time" : "Hora",
+    "Line {line}" : "Línea {line}",
     "Download logs" : "Descargar bitácoras",
+    "Ctrl" : "Ctrl",
     "Application" : "Aplicación",
     "Message" : "Mensaje",
     "Show details" : "Mostrar detalles",
