@@ -5,28 +5,30 @@ OC.L10N.register(
     "Log Reader" : "Lokilukija",
     "A log reader for Nextcloud" : "Nextcloudin lokilukija",
     "Log reader for Nextcloud" : "Nextcloudin lokilukija",
-    "Error parsing log" : "Virhe jäsentäessä lokia",
-    "Caused by " : "Aiheuttanut",
+    "Level" : "Taso",
+    "App" : "Sovellus",
+    "Time" : "Aika",
+    "Download logs" : "Lataa lokit",
+    "Application" : "Sovellus",
+    "Message" : "Viesti",
+    "Show details" : "Näytä lisätiedot",
     "Debug" : "Vianjäljitys",
     "Info" : "Tietoa",
     "Warning" : "Varoitus",
     "Error" : "Virhe",
     "Fatal" : "Kriittinen",
+    "Error parsing log" : "Virhe jäsentäessä lokia",
+    "Caused by " : "Aiheuttanut",
     "Copy" : "Kopioi",
     "Copy raw" : "Kopioi raakatekstinä",
     "Copy formatted" : "Kopioi muotoiltuna",
     "No server logs" : "Ei palvelinlokeja",
     "One or more entries are hidden by the log level filter" : "Yksi tai useampi kirjaus on piilotettu lokitason valitsimella",
     "Everything is working fine" : "Kaikki toimii hyvin",
-    "Level" : "Taso",
-    "App" : "Sovellus",
-    "Message" : "Viesti",
-    "Time" : "Aika",
     "Load log file" : "Lataa lokitiedosto",
     "Invalid log file" : "Virheellinen lokitiedosto",
     "Log levels" : "Lokitasot",
     "Log content" : "Lokin sisältö",
-    "Live update" : "Live-päivitys",
-    "Download logs" : "Lataa lokit"
+    "Live update" : "Live-päivitys"
 },
 "nplurals=2; plural=(n != 1);");
