@@ -2,6 +2,10 @@ OC.L10N.register(
     "logreader",
     {
     "Logging" : "Уписивање у дневник",
+    "Errors in the log" : "Грешке у дневнику",
+    "No errors in the logs since %s" : "У дневнику нема грешака од %s",
+    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["У дневнику има %n грешка од %s","У дневнику има %n грешке од %s","У дневнику има %n грешака од %s"],
+    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["У дневнику има %n упозорење од %s","У дневнику има %n упозорења од %s","У дневнику има %n упозорења од %s"],
     "Log Reader" : "Читач дневника",
     "A log reader for Nextcloud" : "Читач дневника за Некстклауд",
     "Log reader for Nextcloud" : "Читач дневника за Некстклауд",
@@ -26,14 +30,18 @@ OC.L10N.register(
     "Log entry successfully copied" : "Успешно је копирана ставка дневника",
     "Search log entries" : "Претражи ставке дневника",
     "Caused by {exception}" : "Изазвао је {exception}",
-    "line {line}" : "линија {line}",
+    "Line {line}" : "Линија {line}",
     "Filter log levels" : "Филтрирај нивое дневника",
+    "Set log level" : "Постави ниво уписа у дневник",
     "Time format" : "Формат времена",
     "Live view" : "Приказ уживо",
-    "Download / Upload logs" : "Преузми / Отпреми дневнике",
+    "Download/Upload logs" : "Преузми/Отпреми дневнике",
+    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Такође можете да прикажете ис тавке дневника копиране у клипборд тако што их налепите у приказ дневника користећи: {keyboardShortcut}",
     "Download logs" : "Скини дневнике",
     "Show local log file" : "Прикажи локални фајл дневника",
     "Upload local log file to be displayed" : "Отпреми локални фајл дневника који треба да се прикаже",
+    "Ctrl" : "Ctrl",
+    "Could not parse local log file" : "Не може да се парсира фајл локалног дневника",
     "Raw data" : "Сирови подаци",
     "Local time" : "Локално време",
     "UTC time" : "UTC време",
@@ -45,6 +53,8 @@ OC.L10N.register(
     "Could not change live view setting." : "Не може да се промени подешавања приказа уживо.",
     "Filter logging levels" : "Филтрирај нивое белеђења дневника",
     "Could not set logging levels to show" : "Нису могли да се поставе нивои бележења дневника који се приказују",
+    "Set backend loglevel" : "Постави ниво уписа у дневник позадинског механизма",
+    "Could not set logging level" : "Није могао да се постави ниво уписа у дневник",
     "Application" : "Апликација",
     "Message" : "Порука",
     "Log entry actions" : "Акције ставке дневника",
@@ -58,6 +68,9 @@ OC.L10N.register(
     "Warning" : "Упозорење",
     "Error" : "Грешка",
     "Fatal" : "Фатално",
+    "Could not load log entries" : "Нису могле да се учитају ставке дневника",
+    "Clipboard" : "Клипборд",
+    "Could not parse clipboard content" : "Не може да се парсира садржај клипборда",
     "Could not fetch new log entries (server unavailable)" : "Не могу да се прибаве нове ставке дневника (сервер није доступан)",
     "Could not fetch new entries" : "Не могу да се добаве нове ставке",
     "Could not copy to clipboard, please copy manually:" : "Не може да се копира у клипборд, молимо вас да ручно копирате:",
@@ -74,6 +87,8 @@ OC.L10N.register(
     "Invalid log file" : "Неисправан фајл дневника",
     "Log levels" : "Нивои логовања",
     "Log content" : "Садржај дневника",
-    "Live update" : "Ажурирање уживо"
+    "Live update" : "Ажурирање уживо",
+    "line {line}" : "линија {line}",
+    "Download / Upload logs" : "Преузми / Отпреми дневнике"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
