@@ -36,9 +36,12 @@ OC.L10N.register(
     "Time format" : "時間格式",
     "Live view" : "即時檢視",
     "Download/Upload logs" : "下載/上傳紀錄檔",
+    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "您也可以使用以下命令將從剪貼簿複製的紀錄條目貼上到紀錄檢視中來顯示它們：{keyboardShortcut}",
     "Download logs" : "下載紀錄檔",
     "Show local log file" : "顯示本機紀錄檔",
     "Upload local log file to be displayed" : "上傳要顯示的本機紀錄檔",
+    "Ctrl" : "Ctrl",
+    "Could not parse local log file" : "無法解析本機紀錄檔",
     "Raw data" : "原始資料",
     "Local time" : "本地時間",
     "UTC time" : "UTC 時間",
@@ -66,6 +69,8 @@ OC.L10N.register(
     "Error" : "Error",
     "Fatal" : "Fatal",
     "Could not load log entries" : "無法載入紀錄檔條目",
+    "Clipboard" : "剪貼簿",
+    "Could not parse clipboard content" : "無法解析剪貼簿內容",
     "Could not fetch new log entries (server unavailable)" : "無法擷取新紀錄項目（伺服器不可用）",
     "Could not fetch new entries" : "無法擷取新項目",
     "Could not copy to clipboard, please copy manually:" : "無法複製到剪貼簿，請手動複製：",
