@@ -6,8 +6,6 @@ OC.L10N.register(
     "Read more" : "מידע נוסף",
     "Disable announcements" : "השבתת הכרזות",
     "(These announcements are only shown to administrators)" : "(ההכרזות האלו מופיעות למנהלים בלבד)",
-    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "הכרזות Nextcloud מביאות את החדשות העדכניות ביותר של Nextcloud להתראות שלך",
-    "Shows the latest news of Nextcloud in your notifications." : "מציג את החדשות העדכניות ביותר של Nextcloud בהתראות שלך.",
-    "These groups will be notified about the announcements." : "הקבוצות האלו יקבלו התראות על ההכרזות."
+    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "הכרזות Nextcloud מביאות את החדשות העדכניות ביותר של Nextcloud להתראות שלך"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
