@@ -9,6 +9,8 @@ OC.L10N.register(
     "You can change the frequency of these emails or disable them in the settings: %s" : "Vous pouvez changer la fréquence de ces e-mails ou les désactiver dans les paramètres : %s",
     "Admin notifications" : "Notifications d'administration",
     "Notifications" : "Notifications",
+    "Push notifications - Fair use policy" : "Notifications push - Politique d'utilisation équitable",
+    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH sponsorise une passerelle de notification push gratuite pour les utilisateurs privés. Pour assurer un bon service, la passerelle limite le nombre de notifications push par serveur et la limite a été atteinte pour ce serveur. Pour les utilisateurs professionnels, une passerelle plus modulable est disponible.",
     "This app provides a backend and frontend for the notification API available in Nextcloud." : "Cette application fournit un backend et une interface pour l'API de notification disponible dans Nextcloud.",
     "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "\tCette application fournit un backend et une interface pour l'API de notification disponible dans Nextcloud.\n📬 Partage de fichiers fédérés: vous avez reçu un nouveau partage distant\n\n📑 Commentaires: Un autre utilisateur vous a mentionné dans un commentaire sur un fichier.\n\n🚢 Notification de mise à jour: mise à jour disponible pour une application ou nextcloud elle-même.\n\n📣 Centre d'annonces: Une annonce a été publiée par un administrateur",
     "Failed to perform action" : "Échec lors de la réalisation de l'action",
