@@ -1,14 +1,21 @@
 OC.L10N.register(
     "password_policy",
     {
+    "Password is expired, please use forgot password method to reset" : "Password is expired, please use forgot password method to reset",
+    "Password must not have been used recently before." : "Password must not have been used recently before.",
     "Password is among the 1,000,000 most common ones. Please make it unique." : "گذرواژه در میان 1000000 رایج ترین آن است. لطفا آن را منحصر به فرد کنید.",
     "Password is present in compromised password list. Please choose a different password." : "گذرواژه در لیست گذرواژه به خطر افتاده است. لطفاً یک رمز عبور دیگر انتخاب کردن",
+    "Password needs to be at least %s characters long." : "Password needs to be at least %s characters long.",
     "Password needs to contain at least one numeric character." : "گذرواژه باید حداقل دارای یک شخصیت عددی باشد.",
     "Password needs to contain at least one special character." : "گذرواژه باید حداقل دارای یک شخصیت خاص باشد.",
     "Password needs to contain at least one lower and one upper case character." : "گذرواژه باید حداقل یک شخصیت کوچک و یک مورد بزرگ داشته باشد.",
     "Password policy" : "خط مشی رمز عبور",
     "Allows admins to configure a password policy" : "به مدیران اجازه می دهد خط مشی رمز عبور را پیکربندی کنند",
     "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "اجازه مدیر برای تعریف خاصی از پیش شرایط برای رمز عبور، به عنوان مثال، حداقل طول را اجرا کنید",
+    "Minimum password length" : "Minimum password length",
+    "User password history" : "User password history",
+    "Number of days until user password expires" : "Number of days until user password expires",
+    "Number of login attempts before the user account is blocked (0 for no limit)" : "Number of login attempts before the user account is blocked (0 for no limit)",
     "Forbid common passwords" : "ممنوع کردن کلمه عبور مشترک",
     "Enforce upper and lower case characters" : "کاراکترهای بزرگ و پایین را اجرا کنید",
     "Enforce numeric characters" : "اجرای شخصیت های عددی",
@@ -16,7 +23,13 @@ OC.L10N.register(
     "Check password against the list of breached passwords from haveibeenpwned.com" : "گذرواژه را در برابر لیست گذرواژه های نقض شده از hasibeenpwned.com بررسی کنید",
     "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "این بررسی یک هشی از رمز عبور ایجاد می کند و 5 کاراکتر اول این هش را به API haveibeenpwned.com می فرستد تا لیستی از همه هش ها را که با آن شروع می شود بازیابی کنید. سپس در مثال نکست کلود بررسی می کند که آیا رمز عبور در مجموعه نتایج قرار دارد یا خیر.",
     "Unknown error" : "خطای ناشناخته",
+    "Minimal length has to be a non negative number" : "Minimal length has to be a non negative number",
+    "History size has to be a non negative number" : "History size has to be a non negative number",
+    "Expiration days have to be a non negative number" : "Expiration days have to be a non negative number",
+    "Maximum login attempts have to be a non negative number" : "Maximum login attempts have to be a non negative number",
     "Settings saved" : "تنظیمات ذخیره شد",
-    "Saved" : "دخیره شد"
+    "Error while saving settings" : "Error while saving settings",
+    "Saved" : "دخیره شد",
+    "Error while saving" : "Error while saving"
 },
 "nplurals=2; plural=(n > 1);");
