@@ -46,21 +46,18 @@ OC.L10N.register(
     "Failed to update album." : "Неуспешно обновяване на албум.",
     "This collection does not exist" : "Тази колекция не съществува",
     "An error occurred" : "Възникна грешка",
+    "Favorite" : "Любими",
     "Select image {imageName}" : "Избор на изображение {imageName}",
-    "The file is in the favorites" : "Файлът е в любими",
     "Open the full size \"{name}\" image" : "Отваряне на изображението\"{name}“  в пълен размер ",
-    "There are no photos or videos yet!" : "Все още няма снимки или видеоклипове!",
-    "Add to {destination}" : "Добавяне към  {destination}",
-    "Open the \"{name}\" sub-directory" : "Отваряне на \"{name}“  поддиректория ",
+    "Go back" : "Назад",
     "Back to {folder}" : "Назад към {folder}",
     "Share this folder" : "Споделяне на тази папка",
+    "Add to {destination}" : "Добавяне към  {destination}",
+    "There are no photos or videos yet!" : "Все още няма снимки или видеоклипове!",
     "_{years} year ago_::_{years} years ago_" : ["Преди {years} години","Преди {years} години"],
     "Enable squared photos view" : "Активирайте изгледа на снимки в квадратче",
-    "Default Photos upload and Albums location" : "Качване на снимки и местоположение на албуми по подразбиране",
-    "Select the default location for your media" : "Избор на местоположение по подразбиране за вашата медия",
-    "Invalid location selected" : "Избрано е невалидно местоположение",
+    "Home" : "Начало",
     "View" : "Изглед",
-    "Photos directory" : "Директория със снимки",
     "_%n photo_::_%n photos_" : ["%n снимки","%n снимки"],
     "Unselect all" : "Отмяна на избора на всички",
     "Manage collaborators for this album" : "Управление на сътрудници за този албум",
@@ -80,7 +77,6 @@ OC.L10N.register(
     "Rename person" : "Преименуване на лице",
     "Merge with different person" : "Обединяване с различно лице",
     "Download selected photos" : "Изтегляне на избрани снимки",
-    "Favorite" : "Любими",
     "Remove from favorites" : "Премахване от любими",
     "Remove person" : "Премахване на лице",
     "Name of this person" : "Име лицето",
@@ -127,7 +123,6 @@ OC.L10N.register(
     "Failed to delete {fileName}." : "Неуспешно изтриване на {fileName}.",
     "Failed to set favorite state for {fileId}." : "Неуспешно задаване на предпочитано/любимо/ състояние за {fileId}.",
     "Failed to set favorite state for {fileName}." : "Неуспешно задаване на предпочитано/любимо/ състояние за {fileName}.",
-    "Locations" : "Местоположения",
     "Go back to the previous view." : "Връщане към предишния изглед.",
     "Go to the add collaborators view." : "Отиване до изглед за добавяне на сътрудници.",
     "Create the album." : "Създаване на албума.",
@@ -137,6 +132,12 @@ OC.L10N.register(
     "Add {collaboratorLabel} to the collaborators list" : "Добавяне на {collaboratorLabel} към списъка със сътрудници",
     "No collaborators available" : "Няма налични сътрудници",
     "Failed to fetch album." : "Неуспешно извличане на албум.",
+    "The file is in the favorites" : "Файлът е в любими",
+    "Open the \"{name}\" sub-directory" : "Отваряне на \"{name}“  поддиректория ",
+    "Default Photos upload and Albums location" : "Качване на снимки и местоположение на албуми по подразбиране",
+    "Select the default location for your media" : "Избор на местоположение по подразбиране за вашата медия",
+    "Invalid location selected" : "Избрано е невалидно местоположение",
+    "Photos directory" : "Директория със снимки",
     "Add photos to the album" : "Добавяне на снимки към албума",
     "Failed to fetch albums list." : "Неуспешно извличане на списък с албуми.",
     "Shared albums" : "Споделени албуми",
