@@ -52,19 +52,16 @@ OC.L10N.register(
     "Favorite" : "Favorit",
     "Select image {imageName}" : "Bild {imageName} auswählen",
     "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
-    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
-    "Add to {destination}" : "Hinzufügen zu {destination}",
-    "Open the \"{name}\" sub-directory" : "Öffne den \"{name}\" Unterordner",
+    "Go back" : "Zurückgehen",
     "Back to {folder}" : "Zurück zu {folder}",
     "Share this folder" : "Diesen Ordner teilen",
+    "Dates" : "Termine",
+    "Add to {destination}" : "Hinzufügen zu {destination}",
+    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
     "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
     "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
-    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
     "Choose default Photos upload and Albums location" : "Den Standardspeicherort für das Hochladen von Fotos und Alben wählen",
-    "Select the default location for your media" : "Standardspeicherort für deine Medien auswählen",
-    "Invalid location selected" : "Ungültiger Speicherort ausgewählt",
     "View" : "Ansicht",
-    "Photos directory" : "Verzeichnis für Fotos",
     "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
     "Unselect all" : "Auswahl aufheben",
     "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
@@ -144,6 +141,11 @@ OC.L10N.register(
     "No collaborators available" : "Keine Mitarbeitenden verfügbar",
     "Failed to fetch album." : "Album konnte nicht abgerufen werden.",
     "The file is in the favorites" : "Die Datei ist in den Favoriten",
+    "Open the \"{name}\" sub-directory" : "Öffne den \"{name}\" Unterordner",
+    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
+    "Select the default location for your media" : "Standardspeicherort für deine Medien auswählen",
+    "Invalid location selected" : "Ungültiger Speicherort ausgewählt",
+    "Photos directory" : "Verzeichnis für Fotos",
     "Add photos to the album" : "Fotos zum Album hinzufügen",
     "Failed to fetch albums list." : "Albumliste konnte nicht geladen werden.",
     "Shared albums" : "Geteilte Alben",
