@@ -51,20 +51,32 @@ OC.L10N.register(
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n nicht zugewiesenes Foto","%n nicht zugewiesene Fotos"],
     "Favorite" : "Favorisieren",
     "Select image {imageName}" : "Bild {imageName} auswählen",
+    "Favorite image, open the full size \"{name}\" image" : "Favorisiertes Bild, öffne das Bild \"{name}\" in Originalgröße",
     "Open the full size \"{name}\" image" : "Bild \"{name}\" in Originalgröße öffnen",
-    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
-    "Add to {destination}" : "Hinzufügen zu {destination}",
-    "Open the \"{name}\" sub-directory" : "Öffne den Unterordner \"{name}\" ",
+    "Open the \"{name}\" folder" : "Ordner \"{name}\" öffnen",
+    "Go back" : "Zurückgehen",
     "Back to {folder}" : "Zurück zu {folder}",
     "Share this folder" : "Diesen Ordner teilen",
+    "Dates" : "Daten",
+    "Jump to specific date in list" : "Zu einem bestimmten Datum in der Liste springen",
+    "Jump to {date}" : "Zu {date} springen",
+    "Add to {destination}" : "Hinzufügen zu {destination}",
+    "There are no photos or videos yet!" : "Es gibt noch keine Fotos oder Videos!",
     "_{years} year ago_::_{years} years ago_" : ["Vor {years} Jahr","Vor {years} Jahren"],
     "Enable squared photos view" : "Quadratische Fotoansicht aktivieren",
-    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
+    "Delete source directory" : "Quellverzeichnis löschen",
+    "All folders" : "Alle Ordner",
+    "Choose a source Photos for the timelines" : "Quelle in Photos für die Zeitleisten auswählen",
+    "Choose a different folder" : "Anderen Ordner wählen",
+    "Select a source folder for your media" : "Quellordner für Ihre Medien wählen",
+    "Home" : "Startseite",
     "Choose default Photos upload and Albums location" : "Den Standardspeicherort für das Hochladen von Fotos und Alben wählen",
-    "Select the default location for your media" : "Standardspeicherort für Ihre Medien auswählen",
-    "Invalid location selected" : "Ungültigen Speicherort ausgewählt",
+    "Select the default upload location for your media" : "Standardspeicherort für Ihre hochgeladenen Medien auswählen",
     "View" : "Ansicht",
-    "Photos directory" : "Fotoverzeichnis",
+    "Media folder" : "Medienordner",
+    "Choose the folders from where photos and videos are shown." : "Ordner wählen, aus dem Fotos und Videos angezeigt werden.",
+    "Upload folder" : "Hochladen-Ordner",
+    "Choose the folder where photos and albums are uploaded to." : "Ordner wählen, in den Fotos und Videos hochgeladen werden.",
     "_%n photo_::_%n photos_" : ["%n Foto","%n Fotos"],
     "Unselect all" : "Auswahl aufheben",
     "Manage collaborators for this album" : "Mitbearbeitende für dieses Album verwalten",
@@ -109,6 +121,7 @@ OC.L10N.register(
     "No tags yet" : "Noch keine Schlagworte vorhanden",
     "Photos with tags will show up here" : "Fotos mit Schlagworten werden hier angezeigt",
     "Popular tags" : "Beliebte Schlagworte",
+    "The source folder does not exists" : "Quellordner existiert nicht",
     "Add" : "Hinzufügen",
     "Add to album" : "Zum Album hinzufügen",
     "Delete selection" : "Auswahl löschen",
@@ -134,6 +147,7 @@ OC.L10N.register(
     "Failed to delete {fileName}." : "{fileName} konnte nicht gelöscht werden.",
     "Failed to set favorite state for {fileId}." : "Fehler beim Festlegen des Favoritenstatus für {fileId}.",
     "Failed to set favorite state for {fileName}." : "Fehler beim Festlegen des Favoritenstatus für {fileName}.",
+    "Could not load photos folder" : "Fotos-Ordner konnte nicht geladen werden",
     "Go back to the previous view." : "Zur vorherigen Ansicht zurückgehen.",
     "Go to the add collaborators view." : "Zur Ansicht Mitbearbeitende hinzufügen wechseln.",
     "Create the album." : "Das Album erstellen.",
@@ -144,6 +158,11 @@ OC.L10N.register(
     "No collaborators available" : "Keine Mitarbeitenden verfügbar",
     "Failed to fetch album." : "Album konnte nicht abgerufen werden.",
     "The file is in the favorites" : "Die Datei befindet sich in den Favoriten",
+    "Open the \"{name}\" sub-directory" : "Öffne den Unterordner \"{name}\" ",
+    "Default Photos upload and Albums location" : "Standardspeicherort für das Hochladen von Fotos und Alben",
+    "Select the default location for your media" : "Standardspeicherort für Ihre Medien auswählen",
+    "Invalid location selected" : "Ungültigen Speicherort ausgewählt",
+    "Photos directory" : "Fotoverzeichnis",
     "Add photos to the album" : "Fotos zum Album hinzufügen",
     "Failed to fetch albums list." : "Albumliste konnte nicht geladen werden.",
     "Shared albums" : "Geteilte Alben",
