@@ -4,6 +4,7 @@ OC.L10N.register(
     "Public link" : "Publika ligilo",
     "Photos" : "Fotoj",
     "Videos" : "Videaĵoj",
+    "People" : "Homoj",
     "Folders" : "Dosierujoj",
     "Favorites" : "Pliŝataĵoj",
     "Shared with you" : "Kunhavata kun vi",
@@ -15,6 +16,8 @@ OC.L10N.register(
     "Group" : "Grupo",
     "An error occurred" : "Eraro okazis",
     "Favorite" : "Pliŝatati",
+    "Go back" : "Reveni",
+    "Home" : "Hejmo",
     "View" : "Vidi",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
     "Add" : "Aldoni",
