@@ -51,20 +51,31 @@ OC.L10N.register(
     "_%n unassigned photo_::_%n unassigned photos_" : ["Esleitu gabeko argazki %n","%n esleitu gabeko argazki"],
     "Favorite" : "Egin gogoko",
     "Select image {imageName}" : "Hautatu irudia {imageName}",
+    "Favorite image, open the full size \"{name}\" image" : "Irudi gogokoa, ireki \"{name}\" irudia neurri handian",
     "Open the full size \"{name}\" image" : "Ireki \"{name}\" neurri handian",
-    "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
-    "Add to {destination}" : "Gehitu hona: {destination}",
-    "Open the \"{name}\" sub-directory" : "Ireki \"{name}\" azpi-direktorioa",
+    "Open the \"{name}\" folder" : "Ireki \"{name}\" karpeta",
+    "Go back" : "Atzera",
     "Back to {folder}" : "Itzuli {folder}(e)ra",
     "Share this folder" : "Partekatu karpeta hau",
+    "Dates" : "Datak",
+    "Jump to specific date in list" : "Joan zerrendako data zehatz batera",
+    "Jump to {date}" : "Joan {date} datara",
+    "Add to {destination}" : "Gehitu hona: {destination}",
+    "There are no photos or videos yet!" : "Ez dago argazki edo bideorik oraindik!",
     "_{years} year ago_::_{years} years ago_" : ["orain dela urte {years}","orain dela {years} urte"],
     "Enable squared photos view" : "Gaitu lauki formako argazki ikuspegia",
-    "Default Photos upload and Albums location" : "Argazkien karga eta albumen kokaleku lehenetsia",
+    "Delete source directory" : "Ezabatu iturburuko direktorioa",
+    "All folders" : "Karpeta guztiak",
+    "Choose a different folder" : "Aukeratu beste karpeta bat",
+    "Select a source folder for your media" : "Hautatu iturburu karpeta bat zure multimedia fitxategientzat",
+    "Home" : "Etxea",
     "Choose default Photos upload and Albums location" : "Aukeratu argazkien igoera eta albumen kokaleku lehenetsia",
-    "Select the default location for your media" : "Hautatu zure multimediaren kokaleku lehenetsia",
-    "Invalid location selected" : "Kokaleku baliogabea hautatu da",
+    "Select the default upload location for your media" : "Hautatu lehenetsitako kokalekua zure multimedia fitxategiak igotzeko",
     "View" : "Ikusi",
-    "Photos directory" : "Argazkien direktorioa",
+    "Media folder" : "Multimedia karpeta",
+    "Choose the folders from where photos and videos are shown." : "Aukeratu zein karpetatatik erakutsiko diren argazki eta bideoak.",
+    "Upload folder" : "Igo karpeta",
+    "Choose the folder where photos and albums are uploaded to." : "Aukeratu zein karpetatara igoko diren argazki eta albumak.",
     "_%n photo_::_%n photos_" : ["argazki %n","%n argazki"],
     "Unselect all" : "Desautatu dena",
     "Manage collaborators for this album" : "Kudeatu album honen kolaboratzaileak",
@@ -98,6 +109,7 @@ OC.L10N.register(
     "This folder does not exist" : "Karpeta hau ez da existitzen",
     "Loading folders …" : "Karpetak kargatzen ...",
     "No photos in here" : "Argazkirik ez hemen",
+    "Taken on {date} at {time}" : "{date} egunean {time} orduan ateratakoa",
     "This place does not have any photos or videos yet!" : "Toki honek ez du argazki edo bideorik oraindik!",
     "Add photos to this place" : "Gehitu argazkiak leku honetara",
     "Cover photo for place {placeName}" : "{placeName} tokiaren azaleko argazkia",
@@ -108,6 +120,7 @@ OC.L10N.register(
     "No tags yet" : "Etitketarik ez oraindik",
     "Photos with tags will show up here" : "Etiketadun argazkiak hemen erakutsiko dira",
     "Popular tags" : "Etiketa ohikoak",
+    "The source folder does not exists" : "Iturburuko karpeta ez da existitzen",
     "Add" : "Gehitu",
     "Add to album" : "Gehitu albumera",
     "Delete selection" : "Ezabatu hautatutakoak",
@@ -133,6 +146,7 @@ OC.L10N.register(
     "Failed to delete {fileName}." : "{fileName} ezabatzeak huts egin du.",
     "Failed to set favorite state for {fileId}." : "Ezin izan da ezarri gogoko egoera {fileId}(r)entzat.",
     "Failed to set favorite state for {fileName}." : "Ezin izan da ezarri gogoko egoera {fileName}(r)entzat.",
+    "Could not load photos folder" : "Ezin izan da argazkien karpeta kargatu",
     "Go back to the previous view." : "Itzuli aurreko ikuspegira.",
     "Go to the add collaborators view." : "Joan kolaboratzaileak gehitzeko ikuspegira.",
     "Create the album." : "Sortu albuma.",
@@ -143,6 +157,11 @@ OC.L10N.register(
     "No collaborators available" : "Ez dago kolaboratzailerik eskuragarri",
     "Failed to fetch album." : "Ezin izan da albuma lortu.",
     "The file is in the favorites" : "Fitxategia gogokoetan dago",
+    "Open the \"{name}\" sub-directory" : "Ireki \"{name}\" azpi-direktorioa",
+    "Default Photos upload and Albums location" : "Argazkien karga eta albumen kokaleku lehenetsia",
+    "Select the default location for your media" : "Hautatu zure multimediaren kokaleku lehenetsia",
+    "Invalid location selected" : "Kokaleku baliogabea hautatu da",
+    "Photos directory" : "Argazkien direktorioa",
     "Add photos to the album" : "Gehitu argazkiak albumera",
     "Failed to fetch albums list." : "Ezin izan da album zerrenda eskuratu.",
     "Shared albums" : "Partekaturiko albumak",
