@@ -12,7 +12,7 @@ OC.L10N.register(
     "Folders" : "Dossiers",
     "Favorites" : "Favoris",
     "On this day" : "Ce même jour",
-    "Shared with you" : "Partagé avec vous",
+    "Shared with you" : "Partagés avec vous",
     "Tags" : "Étiquettes",
     "Places" : "Lieux",
     "Map" : "Carte",
@@ -22,15 +22,10 @@ OC.L10N.register(
     "Remove selection from favorites" : "Retirer la sélection des favoris",
     "Name of the album" : "Nom de l'album",
     "Location of the album" : "Emplacement de l'album",
-    "Go back to the previous view." : "Revenir à la vue précédente",
     "Back" : "Retour",
-    "Go to the add collaborators view." : "Allez à la vue d'ajout de collaborateurs",
     "Add collaborators" : "Ajouter des collaborateurs",
-    "Save." : "Enregistrer",
-    "Create the album." : "Créer l'album",
     "Save" : "Enregistrer",
     "Create album" : "Créer un album",
-    "Back to the new album form." : "Retour au formulaire de nouvel album",
     "Add to Album" : "Ajouter à l'album",
     "Add selection to album {albumName}" : "Ajouter la sélection à l'album {albumName}",
     "Shared by" : "Partagé par",
@@ -54,22 +49,31 @@ OC.L10N.register(
     "This collection does not exist" : "Cette collection n'existe pas",
     "An error occurred" : "Une erreur est survenue",
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n photo non assignée","%n photos non assignées","%n photos non assignées"],
+    "Favorite" : "Favoris",
     "Select image {imageName}" : "Sélectionner l'image {imageName}",
-    "The file is in the favorites" : "Le fichier se trouve dans les favoris",
     "Open the full size \"{name}\" image" : "Ouvrir l'image \"{name}\" dans sa taille originale",
-    "There are no photos or videos yet!" : "Il n'y a pas encore de photos ou de vidéos !",
-    "Add to {destination}" : "Ajouter à {destination}",
-    "Open the \"{name}\" sub-directory" : "Ouvrir le sous-dossier \"{name}\"",
+    "Open the \"{name}\" folder" : "Ouvrir le dossier « {name} »",
+    "Go back" : "Revenir en arrière",
     "Back to {folder}" : "Revenir au dossier {folder}",
     "Share this folder" : "Partager ce dossier",
+    "Dates" : "Dates",
+    "Jump to {date}" : "Aller au {date}",
+    "Add to {destination}" : "Ajouter à {destination}",
+    "There are no photos or videos yet!" : "Il n'y a pas encore de photos ou de vidéos !",
     "_{years} year ago_::_{years} years ago_" : ["Il y a {years} ans","Il y a {years} ans","Il y a {years} an(s)"],
     "Enable squared photos view" : "Activer l'affichage en miniatures carrées",
-    "Default Photos upload and Albums location" : "Emplacement par défaut du téléversement des photos et des albums",
+    "Delete source directory" : "Supprimer le dossier source",
+    "All folders" : "Tous les dossiers",
+    "Choose a different folder" : "Choisir un dossier différent ",
+    "Select a source folder for your media" : "Sélectionner un dossier source pour vos médias",
+    "Home" : "Personnel",
     "Choose default Photos upload and Albums location" : "Choisir l'emplacement par défaut pour le téléversement des photos et des albums",
-    "Select the default location for your media" : "Sélectionnez l'emplacement par défaut de vos médias",
-    "Invalid location selected" : "Emplacement sélectionné non valide",
+    "Select the default upload location for your media" : "Sélectionnez l'emplacement de téléversement par défaut de vos médias",
     "View" : "Affichage",
-    "Photos directory" : "Dossier des photos",
+    "Media folder" : "Dossier médias",
+    "Choose the folders from where photos and videos are shown." : "Choisir les dossiers où les photos et vidéos seront affichées.",
+    "Upload folder" : "Téléverser un dossier",
+    "Choose the folder where photos and albums are uploaded to." : "Choisir le dossier où les photos et albums sont téléversés.",
     "_%n photo_::_%n photos_" : ["%n photo","%n photos","%n photos"],
     "Unselect all" : "Tout désélectionner",
     "Manage collaborators for this album" : "Gérer les collaborateurs pour cet album",
@@ -90,10 +94,10 @@ OC.L10N.register(
     "Rename person" : "Renommer la personne",
     "Merge with different person" : "Fusionner avec une différente personne",
     "Download selected photos" : "Télécharger les photos sélectionnées",
-    "Favorite" : "Favoris",
     "Remove from favorites" : "Retirer des favoris",
     "Remove person" : "Retirer la personne",
     "Name of this person" : "Nom de cette personne",
+    "Save." : "Enregistrer",
     "Merge person" : "Fusionner une personne",
     "Move to different person" : "Changer de personne",
     "_Move photo to a different person_::_Move photos to a different person_" : ["Déplacer la photo vers une autre personne","Déplacer les photos vers une autre personne","Déplacer les photos vers une autre personne"],
@@ -103,6 +107,7 @@ OC.L10N.register(
     "This folder does not exist" : "Ce dossier n'existe pas",
     "Loading folders …" : "Chargement des dossiers ...",
     "No photos in here" : "Aucune photo",
+    "Taken on {date} at {time}" : "Prise le {date} à {time}",
     "This place does not have any photos or videos yet!" : "Ce lieu n'a pas encore de photos ou de vidéos !",
     "Add photos to this place" : "Ajouter des photos à ce lieu",
     "Cover photo for place {placeName}" : "Photo de couverture pour le lieu {nom du lieu}",
@@ -113,6 +118,7 @@ OC.L10N.register(
     "No tags yet" : "Aucune étiquette pour le moment",
     "Photos with tags will show up here" : "Les photos étiquetées apparaîtront ici",
     "Popular tags" : "Étiquettes populaires",
+    "The source folder does not exists" : "Le dossier source n'existe pas",
     "Add" : "Ajouter",
     "Add to album" : "Ajouter à l'album",
     "Delete selection" : "Supprimer la sélection",
@@ -131,18 +137,29 @@ OC.L10N.register(
     "Tagged photo {title}" : "Photo étiquetée {title}",
     "{title}'s face" : "Visage de {title}",
     "{startDate} to {endDate}" : "{startDate} au {endDate}",
+    "Details" : "Détails",
     "Failed to rename {oldName} to {faceName}." : "Échec du renommage de {oldName} en {faceName}.",
     "Failed to delete {faceName}." : "Échec de la suppression de {faceName}.",
     "Failed to delete {fileId}." : "Échec de la suppression de {fileId}.",
     "Failed to delete {fileName}." : "Échec de la suppression de {fileName}.",
     "Failed to set favorite state for {fileId}." : "Impossible de définir l'état des favoris pour {fileId}.",
     "Failed to set favorite state for {fileName}." : "Échec de la définition de l'état des favoris pour {fileName}.",
-    "Locations" : "Lieux",
+    "Could not load photos folder" : "Impossible de charger le dossier des photos",
+    "Go back to the previous view." : "Revenir à la vue précédente",
+    "Go to the add collaborators view." : "Allez à la vue d'ajout de collaborateurs",
+    "Create the album." : "Créer l'album",
+    "Back to the new album form." : "Retour au formulaire de nouvel album",
     "_Share with %n user_::_Share with %n users_" : ["Partager avec %n utilisateur","Partager avec %n utilisateurs","Partager avec %n utilisateurs"],
     "Search for collaborators" : "Rechercher des collaborateurs",
     "Add {collaboratorLabel} to the collaborators list" : "Ajouter {collaboratorLabel} à la liste des collaborateurs",
     "No collaborators available" : "Aucun collaborateur disponible",
     "Failed to fetch album." : "Impossible de récupérer l'album.",
+    "The file is in the favorites" : "Le fichier se trouve dans les favoris",
+    "Open the \"{name}\" sub-directory" : "Ouvrir le sous-dossier \"{name}\"",
+    "Default Photos upload and Albums location" : "Emplacement par défaut du téléversement des photos et des albums",
+    "Select the default location for your media" : "Sélectionnez l'emplacement par défaut de vos médias",
+    "Invalid location selected" : "Emplacement sélectionné non valide",
+    "Photos directory" : "Dossier des photos",
     "Add photos to the album" : "Ajouter des photos à l'album",
     "Failed to fetch albums list." : "Impossible de récupérer la liste des albums.",
     "Shared albums" : "Albums partagés",
