@@ -21,9 +21,13 @@ OC.L10N.register(
     "Share via public link" : "Kopīgojiet, izmantojot publisko saiti",
     "An error occurred" : "Gadījās kļūda",
     "Favorite" : "Favorīts",
+    "Go back" : "Atpakaļ",
+    "Dates" : "Datumi",
+    "Home" : "Sākums",
     "View" : "Skats",
     "Remove from favorites" : "Noņemt no izlases",
     "Add" : "Pievienot",
-    "Details" : "Detaļas"
+    "Details" : "Detaļas",
+    "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta "
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
