@@ -46,21 +46,18 @@ OC.L10N.register(
     "Failed to update album." : "Неуспешно ажурирање на албум.",
     "This collection does not exist" : "Оваа колекција не постои",
     "An error occurred" : "Настана грешка",
+    "Favorite" : "Омилени",
     "Select image {imageName}" : "Избери слика {imageName}",
-    "The file is in the favorites" : "Оваа датотека е во омилеми",
     "Open the full size \"{name}\" image" : "Отвори ја сликата \"{name}\" во целосна големина",
-    "There are no photos or videos yet!" : "Овде сеуште нема фотографии и видеа!",
-    "Add to {destination}" : "Додај до {destination}",
-    "Open the \"{name}\" sub-directory" : "Отвори го поддиректориумот \"{name}\"",
+    "Go back" : "Назад",
     "Back to {folder}" : "Назад кон {folder}",
     "Share this folder" : "Сподели ја оваа папка",
+    "Add to {destination}" : "Додај до {destination}",
+    "There are no photos or videos yet!" : "Овде сеуште нема фотографии и видеа!",
     "_{years} year ago_::_{years} years ago_" : ["пред 1 година","пред {years} години"],
     "Enable squared photos view" : "Овозможи поглед на фотографиите во квадрати",
-    "Default Photos upload and Albums location" : "Стандардна локација за прикачени фотографии и албуми",
-    "Select the default location for your media" : "Изберете стандардна локација за вашите медиа датотеки",
-    "Invalid location selected" : "Избрана невалидна локација",
+    "Home" : "Дома",
     "View" : "Погледни",
-    "Photos directory" : "Директориум за фотографии",
     "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографии"],
     "Unselect all" : "Од-означи се",
     "Manage collaborators for this album" : "Уреди соработници за овој албум",
@@ -80,7 +77,6 @@ OC.L10N.register(
     "Rename person" : "Преименувај личност",
     "Merge with different person" : "Спој со друга личност",
     "Download selected photos" : "Преземи ги означените фотографии",
-    "Favorite" : "Омилени",
     "Remove from favorites" : "Отстрани од фаворити",
     "Remove person" : "Отстрани личност",
     "Name of this person" : "Име на личноста",
@@ -120,13 +116,13 @@ OC.L10N.register(
     "Tagged photo {title}" : "Означена фотографија {title}",
     "{title}'s face" : "Лицето на {title}",
     "{startDate} to {endDate}" : "{startDate} до {endDate}",
+    "Details" : "Детали",
     "Failed to rename {oldName} to {faceName}." : "Неуспешно преименување на {oldName} во {faceName}.",
     "Failed to delete {faceName}." : "Неуспешно бришење на {faceName}.",
     "Failed to delete {fileId}." : "Неуспешно бришење на {fileId}.",
     "Failed to delete {fileName}." : "Неуспешно бришење на {fileName}.",
     "Failed to set favorite state for {fileId}." : "Неуспешно поставување на омилен статус за {fileId}.",
     "Failed to set favorite state for {fileName}." : "Неуспешно поставување на омилен статус за {fileName}.",
-    "Locations" : "Локации",
     "Go back to the previous view." : "Врати се на предходниот поглед",
     "Go to the add collaborators view." : "Оди за да додадеш соработници",
     "Create the album." : "Креирај го албумот.",
@@ -136,6 +132,12 @@ OC.L10N.register(
     "Add {collaboratorLabel} to the collaborators list" : "Додади {collaboratorLabel} на листата на соработници",
     "No collaborators available" : "Нема достапни соработници",
     "Failed to fetch album." : "Неуспешно добивање на албум",
+    "The file is in the favorites" : "Оваа датотека е во омилеми",
+    "Open the \"{name}\" sub-directory" : "Отвори го поддиректориумот \"{name}\"",
+    "Default Photos upload and Albums location" : "Стандардна локација за прикачени фотографии и албуми",
+    "Select the default location for your media" : "Изберете стандардна локација за вашите медиа датотеки",
+    "Invalid location selected" : "Избрана невалидна локација",
+    "Photos directory" : "Директориум за фотографии",
     "Add photos to the album" : "Додади фотографии во албумот",
     "Failed to fetch albums list." : "Неуспешно добивање на листа со албуми.",
     "Shared albums" : "Споделени албуми",
