@@ -42,27 +42,43 @@ OC.L10N.register(
     "Public link copied!" : "Offentlig lenke er kopiert!",
     "Copy public link" : "Kopier offentlig lenke",
     "Delete the public link" : "Slett den offentlige lenken",
+    "Create public link share" : "Opprett offentlig koblingsdeling",
     "Share via public link" : "Del via offentlig lenke",
     "Failed to fetch collaborators list." : "Kunne ikke hente listen over samarbeidspartnere.",
     "Failed to update album." : "Kunne ikke oppdatere albumet.",
     "This collection does not exist" : "Denne samlingen eksisterer ikke",
     "An error occurred" : "En feil oppsto",
+    "_%n unassigned photo_::_%n unassigned photos_" : ["%nikke-tilordnet bilde","%n ikke-tilordnede bilder"],
+    "Favorite" : "Favoritt",
     "Select image {imageName}" : "Velg bilde {imageName}",
-    "The file is in the favorites" : "Filen er i favorittene",
+    "Favorite image, open the full size \"{name}\" image" : "Favorittbilde, åpne {name}-bildet i full størrelse",
     "Open the full size \"{name}\" image" : "Åpne full størrelse av bildet \"{name}\"",
-    "There are no photos or videos yet!" : "Det er ingen bilder eller videoer ennå!",
-    "Add to {destination}" : "Legg til i {destination}",
-    "Open the \"{name}\" sub-directory" : "Åpne undermappen \"{name}\"",
+    "Open the \"{name}\" folder" : "Åpne {name}-mappen",
+    "Go back" : "Gå tilbake",
     "Back to {folder}" : "Tilbake til {folder}",
     "Share this folder" : "Del denne mappen",
+    "Dates" : "Datoer",
+    "Jump to specific date in list" : "Gå til spesifikk dato i listen",
+    "Jump to {date}" : "Gå til {date}",
+    "Add to {destination}" : "Legg til i {destination}",
+    "There are no photos or videos yet!" : "Det er ingen bilder eller videoer ennå!",
     "_{years} year ago_::_{years} years ago_" : ["{years} år siden","{years} år siden"],
     "Enable squared photos view" : "Aktiver visning med kvadratiske bilder",
-    "Default Photos upload and Albums location" : "Standard bildeopplasting og albumplassering",
-    "Select the default location for your media" : "Velg standardplassering for mediefilene dine",
-    "Invalid location selected" : "Invalid location selected",
+    "Delete source directory" : "Slett kildekatalog",
+    "All folders" : "Alle mapper",
+    "Choose a source Photos for the timelines" : "Velg en kilde Bilder for tidslinjene",
+    "Choose a different folder" : "Velg en annen mappe",
+    "Select a source folder for your media" : "Velg en kildemappe for mediene dine",
+    "Home" : "Hjem",
+    "Choose default Photos upload and Albums location" : "Velg standard bildeopplasting og albumplassering",
+    "Select the default upload location for your media" : "Velg standard opplastingssted for mediene dine",
     "View" : "Vis",
-    "Photos directory" : "Bildemappe",
+    "Media folder" : "Mediemappe",
+    "Choose the folders from where photos and videos are shown." : "Velg mappene der bilder og videoer vises.",
+    "Upload folder" : "Opplastingsmappe",
+    "Choose the folder where photos and albums are uploaded to." : "Velg mappen der bilder og album lastes opp.",
     "_%n photo_::_%n photos_" : ["%n bilde","%n bilder"],
+    "Unselect all" : "Fravelg alle",
     "Manage collaborators for this album" : "Administrer samarbeidspartnere for dette albumet",
     "Open actions menu" : "Åpne handlingsmenyen",
     "Edit album details" : "Rediger albumdetaljer",
@@ -72,6 +88,7 @@ OC.L10N.register(
     "Remove selection from album" : "Fjern utvalg fra album",
     "This album does not have any photos or videos yet!" : "Dette albumet har ingen bilder eller videoer ennå!",
     "Add photos to this album" : "Legg til bilder i dette albumet",
+    "Add photos to {albumName}" : "Legg bilder til {albumName}",
     "Manage collaborators" : "Administrer samarbeidspartnere",
     "Save collaborators for this album." : "Lagre samarbeidspartnere for dette albumet.",
     "Cover photo for album {albumName}" : "Forsidebilde for albumet {albumName}",
@@ -80,12 +97,12 @@ OC.L10N.register(
     "Rename person" : "Gi nytt navn til person",
     "Merge with different person" : "Slå sammen med en annen person",
     "Download selected photos" : "Last ned valgte bilder",
-    "Favorite" : "Favoritt",
     "Remove from favorites" : "Fjern fra favoritter",
     "Remove person" : "Fjern person",
     "Name of this person" : "Navnet på denne personen",
     "Save." : "Lagre.",
     "Merge person" : "Slå sammen person",
+    "Move to different person" : "Flytt til en annen person",
     "_Move photo to a different person_::_Move photos to a different person_" : ["Flytt bildet til en annen person","Flytt bilder til en annen person"],
     "_Remove photo from person_::_Remove photos from person_" : ["Fjern bildet fra personen","Fjern bilder fra personen"],
     "This might take some time depending on the size of your photo library." : "Dette kan ta litt tid avhengig av størrelsen på bildebiblioteket ditt.",
@@ -93,17 +110,26 @@ OC.L10N.register(
     "This folder does not exist" : "Denne mappen finnes ikke",
     "Loading folders …" : "Laster inn mapper…",
     "No photos in here" : "Ingen bilder her",
+    "Taken on {date} at {time}" : "Tatt på {date} kl. {time}",
+    "This place does not have any photos or videos yet!" : "Denne plasseringen har ingen bilder eller video enda!",
+    "Add photos to this place" : "Legg bilder til denne plasseringen",
+    "Cover photo for place {placeName}" : "Forsidebilde for sted {placeName}",
+    "There is no place yet!" : "Det er ingen steder enda!",
     "Cover photo for shared album {albumName}." : "Forsidebilde for delt album {albumName}.",
     "Back to tags overview" : "Tilbake til merkelappoversikt",
     "No photos with this tag yet" : "Ingen bilder med denne merkelappen ennå",
     "No tags yet" : "Ingen etiketter enda",
     "Photos with tags will show up here" : "Bilder med etiketter vises her",
     "Popular tags" : "Populære merkelapper",
+    "The source folder does not exists" : "Kildemappen finnes ikke",
     "Add" : "Legg til",
     "Add to album" : "Legg til i album",
     "Delete selection" : "Slett utvalg",
     "No photos or videos in here" : "Ingen bilder eller videoer her",
+    "Unassigned faces" : "Ikke-tilordnede ansikter",
     "_%n photos_::_%n photos_" : ["%n bilder","%n bilder"],
+    "Failed to fetch collection." : "Henting av samling feilet.",
+    "Failed to fetch collections list." : "Henting av samlingslisten feilet",
     "Failed to fetch faces list." : "Kunne ikke hente ansiktslisten.",
     "All your media" : "Alle mediefilene dine",
     "Album {title}" : "Album {title}",
@@ -113,6 +139,7 @@ OC.L10N.register(
     "Tagged photos" : "Bilder med merkelapper",
     "Tagged photo {title}" : "Merket bilde {title}",
     "{title}'s face" : "{title} sitt ansikt",
+    "{startDate} to {endDate}" : "{startDate} til {endDate}",
     "Details" : "Detaljer",
     "Failed to rename {oldName} to {faceName}." : "Kunne ikke endre navn på {oldName} til {faceName}.",
     "Failed to delete {faceName}." : "Kunne ikke slette {faceName}.",
@@ -120,7 +147,7 @@ OC.L10N.register(
     "Failed to delete {fileName}." : "Kunne ikke slette {fileName}.",
     "Failed to set favorite state for {fileId}." : "Kunne ikke angi favorittstatus for {fileId}.",
     "Failed to set favorite state for {fileName}." : "Kunne ikke angi favorittstatus for {fileName}.",
-    "Locations" : "Steder",
+    "Could not load photos folder" : "Kunne ikke laste bildemappen",
     "Go back to the previous view." : "Gå tilbake til forrige visning.",
     "Go to the add collaborators view." : "Gå til visningen Legg til samarbeidspartnere.",
     "Create the album." : "Lag albumet.",
@@ -130,6 +157,12 @@ OC.L10N.register(
     "Add {collaboratorLabel} to the collaborators list" : "Legg til {collaboratorLabel} i samarbeidspartnerlisten",
     "No collaborators available" : "Ingen samarbeidspartnere tilgjengelig",
     "Failed to fetch album." : "Kunne ikke hente albumet.",
+    "The file is in the favorites" : "Filen er i favorittene",
+    "Open the \"{name}\" sub-directory" : "Åpne undermappen \"{name}\"",
+    "Default Photos upload and Albums location" : "Standard bildeopplasting og albumplassering",
+    "Select the default location for your media" : "Velg standardplassering for mediefilene dine",
+    "Invalid location selected" : "Invalid location selected",
+    "Photos directory" : "Bildemappe",
     "Add photos to the album" : "Legg til bilder i albumet",
     "Failed to fetch albums list." : "Kunne ikke hente albumlisten.",
     "Shared albums" : "Delte album",
