@@ -52,19 +52,17 @@ OC.L10N.register(
     "Favorite" : "Ulubiony",
     "Select image {imageName}" : "Wybierz obraz {imageName}",
     "Open the full size \"{name}\" image" : "Otwórz obraz \"{name}\" w pełnym rozmiarze",
-    "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
-    "Add to {destination}" : "Dodaj do {destination}",
-    "Open the \"{name}\" sub-directory" : "Otwórz podkatalog \"{name}\"",
+    "Go back" : "Wstecz",
     "Back to {folder}" : "Powrót do {folder}",
     "Share this folder" : "Udostępnij ten katalog",
+    "Dates" : "Daty",
+    "Add to {destination}" : "Dodaj do {destination}",
+    "There are no photos or videos yet!" : "Nie ma jeszcze zdjęć ani filmów!",
     "_{years} year ago_::_{years} years ago_" : ["{years} rok temu","{years} lata temu","{years} lat temu","{years} lat temu"],
     "Enable squared photos view" : "Włącz zdjęcia w widoku kwadratowym",
-    "Default Photos upload and Albums location" : "Domyślna lokalizacja wysyłania zdjęć i albumów",
+    "Home" : "Strona główna",
     "Choose default Photos upload and Albums location" : "Wybierz domyślną lokalizację wysyłania zdjęć i albumów",
-    "Select the default location for your media" : "Wybierz domyślną lokalizację swoich multimediów",
-    "Invalid location selected" : "Wybrano nieprawidłową lokalizację",
     "View" : "Podgląd",
-    "Photos directory" : "Katalog zdjęć",
     "_%n photo_::_%n photos_" : ["%n zdjęcie","%n zdjęcia","%n zdjęć","%n zdjęć"],
     "Unselect all" : "Odznacz wszystko",
     "Manage collaborators for this album" : "Zarządzaj współpracownikami tego albumu",
@@ -144,6 +142,11 @@ OC.L10N.register(
     "No collaborators available" : "Brak dostępnych współpracowników",
     "Failed to fetch album." : "Nie udało się pobrać albumu.",
     "The file is in the favorites" : "Plik znajduje się w ulubionych",
+    "Open the \"{name}\" sub-directory" : "Otwórz podkatalog \"{name}\"",
+    "Default Photos upload and Albums location" : "Domyślna lokalizacja wysyłania zdjęć i albumów",
+    "Select the default location for your media" : "Wybierz domyślną lokalizację swoich multimediów",
+    "Invalid location selected" : "Wybrano nieprawidłową lokalizację",
+    "Photos directory" : "Katalog zdjęć",
     "Add photos to the album" : "Dodaj zdjęcia do albumu",
     "Failed to fetch albums list." : "Nie udało się pobrać listy albumów.",
     "Shared albums" : "Udostępnione albumy",
