@@ -52,19 +52,17 @@ OC.L10N.register(
     "Favorite" : "Favorito",
     "Select image {imageName}" : "Selecionar imagem {imageName}",
     "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho normal",
-    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
-    "Add to {destination}" : "Adicionar a {destionation}",
-    "Open the \"{name}\" sub-directory" : "Abrir o subdiretório \"{name}\"",
+    "Go back" : "Voltar",
     "Back to {folder}" : "Voltar para {folder}",
     "Share this folder" : "Compartilhar esta pasta",
+    "Dates" : "Datas",
+    "Add to {destination}" : "Adicionar a {destionation}",
+    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
     "_{years} year ago_::_{years} years ago_" : ["{anos} ano atrás","{anos} anos atrás","{anos} anos atrás"],
     "Enable squared photos view" : "Ativar exibição de fotos quadradas",
-    "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
+    "Home" : "Início",
     "Choose default Photos upload and Albums location" : "Escolha o upload padrão de fotos e o local dos álbuns",
-    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
-    "Invalid location selected" : "Invalidar localização selecionada",
     "View" : "Exibição",
-    "Photos directory" : "Diretório de fotos",
     "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
     "Unselect all" : "Desmarque todos",
     "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
@@ -98,6 +96,7 @@ OC.L10N.register(
     "This folder does not exist" : "Esta pasta não existe",
     "Loading folders …" : "Carregando pastas…",
     "No photos in here" : "Não há fotos aqui",
+    "Taken on {date} at {time}" : "Tirada em {data} às {time}",
     "This place does not have any photos or videos yet!" : "This place does not have any photos or videos yet!",
     "Add photos to this place" : "Adicionar fotos a este espaço",
     "Cover photo for place {placeName}" : "Foto da capa do lespaço {placeName}",
@@ -143,6 +142,11 @@ OC.L10N.register(
     "No collaborators available" : "Nenhum colaborador disponível",
     "Failed to fetch album." : "Falha ao buscar álbum.",
     "The file is in the favorites" : "Esse arquivo está nos favoritos",
+    "Open the \"{name}\" sub-directory" : "Abrir o subdiretório \"{name}\"",
+    "Default Photos upload and Albums location" : "Localização padrão de upload para fotos e álbuns",
+    "Select the default location for your media" : "Selecione o local padrão para sua mídia",
+    "Invalid location selected" : "Invalidar localização selecionada",
+    "Photos directory" : "Diretório de fotos",
     "Add photos to the album" : "Adicionar fotos ao álbum",
     "Failed to fetch albums list." : "Falha ao buscar lista de álbuns.",
     "Shared albums" : "Álbuns compartilhados",
