@@ -52,19 +52,17 @@ OC.L10N.register(
     "Favorite" : "В избранное",
     "Select image {imageName}" : "Выбрать изображение «{imageName}»",
     "Open the full size \"{name}\" image" : "Отрыть полноразмерное изображение «{name}»",
-    "There are no photos or videos yet!" : "Пока не содержит ни одной фотографии или видео.",
-    "Add to {destination}" : "Добавить в {destination}",
-    "Open the \"{name}\" sub-directory" : "Открыть вложенную папке «{name}»",
+    "Go back" : "Назад",
     "Back to {folder}" : "Вернуться в {folder}",
     "Share this folder" : "Опубликовать эту папку",
+    "Dates" : "Даты",
+    "Add to {destination}" : "Добавить в {destination}",
+    "There are no photos or videos yet!" : "Пока не содержит ни одной фотографии или видео.",
     "_{years} year ago_::_{years} years ago_" : ["{years} год назад","{years} лет назад","{years} лет назад","{years} лет назад"],
     "Enable squared photos view" : "Включить квадратный просмотр фотографий",
-    "Default Photos upload and Albums location" : "Расположение загружаемых на сервер фотографий и альбомов по умолчанию",
+    "Home" : "Главная страница",
     "Choose default Photos upload and Albums location" : "Выберите местоположение загрузки фотографий и альбомов по умолчанию",
-    "Select the default location for your media" : "Выбор расположения медиафайлов по умолчанию",
-    "Invalid location selected" : "Указано недействительное расположение",
     "View" : "Просмотр",
-    "Photos directory" : "Каталог с фотографиями",
     "_%n photo_::_%n photos_" : ["%n фотография","%n фотографии","%n фотографий","%n фотографии"],
     "Unselect all" : "Отменить выделение для всех",
     "Manage collaborators for this album" : "Управление списком соавторов альбома",
@@ -90,7 +88,7 @@ OC.L10N.register(
     "Name of this person" : "Имя",
     "Save." : "Сохранить",
     "Merge person" : "Объединить метки",
-    "Move to different person" : "Перейти к другому человеку",
+    "Move to different person" : "Назначить другую метку лица",
     "_Move photo to a different person_::_Move photos to a different person_" : ["Переместить к другой метке лица","Переместить к другой метке лица","Переместить к другой метке лица","Переместить к другой метке лица"],
     "_Remove photo from person_::_Remove photos from person_" : ["Снять отметку лица с фотографии","Снять отметку лица с фотографий","Снять отметку лица с фотографий","Снять отметку лица с фотографий"],
     "This might take some time depending on the size of your photo library." : "Выполнение этого действия может занять некоторое время, зависящее от размера библиотеки фотографий.",
@@ -143,6 +141,11 @@ OC.L10N.register(
     "No collaborators available" : "Нет ни одного возможного соавтора",
     "Failed to fetch album." : "Не удалось получить альбом.",
     "The file is in the favorites" : "Этот файл добавлен в избранное",
+    "Open the \"{name}\" sub-directory" : "Открыть вложенную папке «{name}»",
+    "Default Photos upload and Albums location" : "Расположение загружаемых на сервер фотографий и альбомов по умолчанию",
+    "Select the default location for your media" : "Выбор расположения медиафайлов по умолчанию",
+    "Invalid location selected" : "Указано недействительное расположение",
+    "Photos directory" : "Каталог с фотографиями",
     "Add photos to the album" : "Добавить фотографии в альбом",
     "Failed to fetch albums list." : "Не удалось получить список альбомов.",
     "Shared albums" : "Полученные альбомы",
