@@ -47,21 +47,19 @@ OC.L10N.register(
     "Failed to update album." : "Posodabljanje albuma je spodletelo.",
     "This collection does not exist" : "Zbirka ne obstaja.",
     "An error occurred" : "Prišlo je do napake.",
+    "Favorite" : "Priljubljeno",
     "Select image {imageName}" : "Izbor slike {imageName}",
-    "The file is in the favorites" : "Datoteka je med priljubljenimi",
     "Open the full size \"{name}\" image" : "Odpri sliko »{name}« v polni velikosti",
-    "There are no photos or videos yet!" : "Ni še naloženih fotografij in posnetkov!",
-    "Add to {destination}" : "Dodaj k {cilju}",
-    "Open the \"{name}\" sub-directory" : "Odpri podmapo »{name}«",
+    "Go back" : "Skoči nazaj",
     "Back to {folder}" : "Nazaj v mapo {folder}",
     "Share this folder" : "Omogoči souporabo mape",
+    "Dates" : "Datumi",
+    "Add to {destination}" : "Dodaj k {cilju}",
+    "There are no photos or videos yet!" : "Ni še naloženih fotografij in posnetkov!",
     "_{years} year ago_::_{years} years ago_" : ["pred {years} letom","pred {years} letoma","pred {years} leti","pred {years} leti"],
     "Enable squared photos view" : "Omogoči kvadratne prikaze slik",
-    "Default Photos upload and Albums location" : "Privzeto mesto albuma in odložišča",
-    "Select the default location for your media" : "Izbor privzetega mesta za predstavne datoteke",
-    "Invalid location selected" : "Izbrano je neveljavno mesto",
+    "Home" : "Začetna stran",
     "View" : "Poglej",
-    "Photos directory" : "Slikovna mapa",
     "_%n photo_::_%n photos_" : ["%n fotografija","%n fotografiji","%n fotografije","%n fotografij"],
     "Unselect all" : "Odstrani izbor",
     "Manage collaborators for this album" : "Upravljanje sodelujočih za izbran album",
@@ -81,7 +79,6 @@ OC.L10N.register(
     "Rename person" : "Preimenuj osebo",
     "Merge with different person" : "Združi z obstoječo osebo",
     "Download selected photos" : "Prejmi izbrane datoteke",
-    "Favorite" : "Priljubljeno",
     "Remove from favorites" : "Odstrani iz priljubljenih",
     "Remove person" : "Odstrani osebo",
     "Name of this person" : "Ime osebe",
@@ -112,7 +109,6 @@ OC.L10N.register(
     "Details" : "Podrobnosti",
     "Failed to delete {fileId}." : "Brisanje polja {fileId} je spodletelo.",
     "Failed to delete {fileName}." : "Brisanje datoteke {fileName} je spodletelo.",
-    "Locations" : "Mesta",
     "Go back to the previous view." : "Vrni na predhodni pogled.",
     "Go to the add collaborators view." : "Skoči na pogled dodajanja sodelujočih.",
     "Create the album." : "Ustvari album",
@@ -121,6 +117,12 @@ OC.L10N.register(
     "Add {collaboratorLabel} to the collaborators list" : "Dodaj {collaboratorLabel} na seznam sodelujočih",
     "No collaborators available" : "Ni navedenih sodelujočih urejevalcev",
     "Failed to fetch album." : "Pridobivanje albuma je spodletelo.",
+    "The file is in the favorites" : "Datoteka je med priljubljenimi",
+    "Open the \"{name}\" sub-directory" : "Odpri podmapo »{name}«",
+    "Default Photos upload and Albums location" : "Privzeto mesto albuma in odložišča",
+    "Select the default location for your media" : "Izbor privzetega mesta za predstavne datoteke",
+    "Invalid location selected" : "Izbrano je neveljavno mesto",
+    "Photos directory" : "Slikovna mapa",
     "Add photos to the album" : "Dodaj fotografije v album",
     "Shared albums" : "Albumi v souporabi",
     "Create a new album" : "Ustvari nov album",
