@@ -51,20 +51,32 @@ OC.L10N.register(
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n недодељена фотографија","%n недодељене фотографије","%n недодељених фотографија"],
     "Favorite" : "Омиљени",
     "Select image {imageName}" : "Изабери слику {imageName}",
+    "Favorite image, open the full size \"{name}\" image" : "Омиљена слика, отвори слику „{name}” у пуној величини",
     "Open the full size \"{name}\" image" : "Отвори слику „{name}” у пуној величини",
-    "There are no photos or videos yet!" : "Још увек нема фотографија или видео снимака!",
-    "Add to {destination}" : "Додај у {destination}",
-    "Open the \"{name}\" sub-directory" : "Отвори „{name}” поддиректоријум",
+    "Open the \"{name}\" folder" : "Отвори „{name}” директоријум",
+    "Go back" : "Иди назад",
     "Back to {folder}" : "Назад у {folder}",
     "Share this folder" : "Дели ову фасциклу",
+    "Dates" : "Датуми",
+    "Jump to specific date in list" : "Скок на одређени датум у листи",
+    "Jump to {date}" : "Скочи на {date}",
+    "Add to {destination}" : "Додај у {destination}",
+    "There are no photos or videos yet!" : "Још увек нема фотографија или видео снимака!",
     "_{years} year ago_::_{years} years ago_" : ["пре {years} године","пре {years} године","пре {years} година"],
     "Enable squared photos view" : "Укључи квадратасти приказ слика",
-    "Default Photos upload and Albums location" : "Подразумевано место за отпремање фотографија и албума",
+    "Delete source directory" : "Обриши изворни директоријум",
+    "All folders" : "Сви фолдери",
+    "Choose a source Photos for the timelines" : "Изабери изворне Фотографије за временске линије",
+    "Choose a different folder" : "Изаберите неки други фолдер",
+    "Select a source folder for your media" : "Изаберите извирни фолдер за своје медије",
+    "Home" : "Почетна",
     "Choose default Photos upload and Albums location" : "Изаберите подразумевано место за отпремање Фотографија и албума",
-    "Select the default location for your media" : "Изаберите подразумевано место за своје медије",
-    "Invalid location selected" : "Изабрана је неисправна локација",
+    "Select the default upload location for your media" : "Изаберите подразумевано место отпремања својих медија",
     "View" : "Погледај",
-    "Photos directory" : "Директоријум фотографија",
+    "Media folder" : "Фолдер медија",
+    "Choose the folders from where photos and videos are shown." : "Изаберите фолдере из којих се приказују фотографије и видео снимци.",
+    "Upload folder" : "Фолдер отпремања",
+    "Choose the folder where photos and albums are uploaded to." : "Изаберите фолдер у који се отпремају фотографије и албуми.",
     "_%n photo_::_%n photos_" : ["%n фотографија","%n фотографије","%n фотографија"],
     "Unselect all" : "Поништи цео избор",
     "Manage collaborators for this album" : "Управљање сарадницима на овом албуму",
@@ -109,6 +121,7 @@ OC.L10N.register(
     "No tags yet" : "Још нема ознака",
     "Photos with tags will show up here" : "Слике са ознакама ће се појавити овде",
     "Popular tags" : "Популарне ознаке",
+    "The source folder does not exists" : "Изворни фолдер не постоји",
     "Add" : "Додај",
     "Add to album" : "Додај у албум",
     "Delete selection" : "Обриши одабир",
@@ -134,6 +147,7 @@ OC.L10N.register(
     "Failed to delete {fileName}." : "Није успело брисање {fileName}.",
     "Failed to set favorite state for {fileId}." : "Није успело постављање стања омиљено за {fileId}.",
     "Failed to set favorite state for {fileName}." : "Није успело постављање стања омиљено за {fileName}.",
+    "Could not load photos folder" : "Не може да се учита фолдер фотографија",
     "Go back to the previous view." : "Повратак на претходни поглед.",
     "Go to the add collaborators view." : "Враћање на поглед додавања сарадника",
     "Create the album." : "Креирање албума.",
@@ -144,6 +158,11 @@ OC.L10N.register(
     "No collaborators available" : "Нема достуоних сарадника",
     "Failed to fetch album." : "Није успело добављање албума.",
     "The file is in the favorites" : "Фајл се налази у омиљенима",
+    "Open the \"{name}\" sub-directory" : "Отвори „{name}” поддиректоријум",
+    "Default Photos upload and Albums location" : "Подразумевано место за отпремање фотографија и албума",
+    "Select the default location for your media" : "Изаберите подразумевано место за своје медије",
+    "Invalid location selected" : "Изабрана је неисправна локација",
+    "Photos directory" : "Директоријум фотографија",
     "Add photos to the album" : "Додај фотографије у албум",
     "Failed to fetch albums list." : "Није успело добављање листе албума.",
     "Shared albums" : "Дељени албуми",
