@@ -51,20 +51,30 @@ OC.L10N.register(
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n ej tilldelat foto","%n ej tilldelade foton"],
     "Favorite" : "Favorit",
     "Select image {imageName}" : "Välj bild {imageName}",
+    "Favorite image, open the full size \"{name}\" image" : "Favoritbild, öppna bilden \"{name}\" i full storlek",
     "Open the full size \"{name}\" image" : "Öppna bilden \"{name}\" i full storlek",
-    "There are no photos or videos yet!" : "Det finns inga bilder eller videor än!",
-    "Add to {destination}" : "Lägg till i {destination}",
-    "Open the \"{name}\" sub-directory" : "Öppna undermappen \"{name}\"",
+    "Open the \"{name}\" folder" : "Öppna mappen \"{name}\"",
+    "Go back" : "Gå tillbaks",
     "Back to {folder}" : "Tillbaka till {folder}",
     "Share this folder" : "Dela denna mapp",
+    "Dates" : "Datum",
+    "Jump to specific date in list" : "Hoppa till specifikt datum i listan",
+    "Jump to {date}" : "Gå till {date}",
+    "Add to {destination}" : "Lägg till i {destination}",
+    "There are no photos or videos yet!" : "Det finns inga bilder eller videor än!",
     "_{years} year ago_::_{years} years ago_" : ["{years} år sedan","{years} år sedan"],
     "Enable squared photos view" : "Aktivera kvadratiska bild-vyn",
-    "Default Photos upload and Albums location" : "Standardplats för album och bilder",
+    "Delete source directory" : "Ta bort källkatalog",
+    "All folders" : "Alla mappar",
+    "Choose a different folder" : "Välj annan mapp",
+    "Select a source folder for your media" : "Välj en källmapp för ditt media",
+    "Home" : "Hem",
     "Choose default Photos upload and Albums location" : "Välj standardplats uppladdning av bilder och plats för album",
-    "Select the default location for your media" : "Välj standardplats för din media",
-    "Invalid location selected" : "Ogiltig plats vald",
+    "Select the default upload location for your media" : "Välj standarduppladdningsplats för ditt media",
     "View" : "Visa",
-    "Photos directory" : "Bildmapp",
+    "Media folder" : "Mediamapp",
+    "Upload folder" : "Ladda upp mapp",
+    "Choose the folder where photos and albums are uploaded to." : "Välj mapp dit foton och album laddas upp.",
     "_%n photo_::_%n photos_" : ["%n bild","%n bilder"],
     "Unselect all" : "Avmarkera alla",
     "Manage collaborators for this album" : "Hantera medlemmar för det här albumet",
@@ -109,6 +119,7 @@ OC.L10N.register(
     "No tags yet" : "Inga taggar än",
     "Photos with tags will show up here" : "Bilder med taggar visas här",
     "Popular tags" : "Populära taggar",
+    "The source folder does not exists" : "Källmappen finns inte",
     "Add" : "Lägg till",
     "Add to album" : "Lägg till i album",
     "Delete selection" : "Ta bort urval",
@@ -134,6 +145,7 @@ OC.L10N.register(
     "Failed to delete {fileName}." : "Misslyckades att radera {fileName}.",
     "Failed to set favorite state for {fileId}." : "Det gick inte att ange favoritstatus för {fileId}.",
     "Failed to set favorite state for {fileName}." : "Det gick inte att ange favoritstatus för {fileName}.",
+    "Could not load photos folder" : "Kunde inte ladda fotomappen",
     "Go back to the previous view." : "Gå tillbaka till föregående vy",
     "Go to the add collaborators view." : "Gå till vyn lägg till medlemmar.",
     "Create the album." : "Skapa albumet.",
@@ -144,6 +156,11 @@ OC.L10N.register(
     "No collaborators available" : "Inga medlemmar är tillgängliga",
     "Failed to fetch album." : "Misslyckades att hämta album.",
     "The file is in the favorites" : "Filen finns bland favoriterna",
+    "Open the \"{name}\" sub-directory" : "Öppna undermappen \"{name}\"",
+    "Default Photos upload and Albums location" : "Standardplats för album och bilder",
+    "Select the default location for your media" : "Välj standardplats för din media",
+    "Invalid location selected" : "Ogiltig plats vald",
+    "Photos directory" : "Bildmapp",
     "Add photos to the album" : "Lägg till bilder i albumet",
     "Failed to fetch albums list." : "Misslyckades att hämta albumlistan.",
     "Shared albums" : "Delade album",
