@@ -10,7 +10,7 @@ OC.L10N.register(
     "Collaborative albums" : "Спільні альбоми",
     "People" : "Люди",
     "Folders" : "Каталоги",
-    "Favorites" : "Вподобане",
+    "Favorites" : "Із зірочкою",
     "On this day" : "Цього дня",
     "Shared with you" : "Вам надано доступ",
     "Tags" : "Мітки",
@@ -51,20 +51,32 @@ OC.L10N.register(
     "_%n unassigned photo_::_%n unassigned photos_" : ["%n неідентифікована світлина","%n неідентифіковані світлини","%n неідентифікованих світлин","%n неідентифікованих світлин"],
     "Favorite" : "До улюблених",
     "Select image {imageName}" : "Виберіть зображення {imageName}",
+    "Favorite image, open the full size \"{name}\" image" : "Вподобати зображення, відкрити повнорозмірне зображення: \"{name}\"",
     "Open the full size \"{name}\" image" : "Відкрити повнорозмірне зображення: \"{name}\"",
-    "There are no photos or videos yet!" : "Ще немає фото чи відео!",
-    "Add to {destination}" : "Додати до {destination}",
-    "Open the \"{name}\" sub-directory" : "Відкрити підкаталог \"{name}\"",
+    "Open the \"{name}\" folder" : "Відкрити каталог \"{name}\"",
+    "Go back" : "Повернутися назад",
     "Back to {folder}" : "Повернутися до каталогу {folder}",
     "Share this folder" : "Надати спільний доступ до каталогу",
+    "Dates" : "Дати",
+    "Jump to specific date in list" : "Перейти до певної дати зі списку",
+    "Jump to {date}" : "Перейти до {date}",
+    "Add to {destination}" : "Додати до {destination}",
+    "There are no photos or videos yet!" : "Ще немає фото чи відео!",
     "_{years} year ago_::_{years} years ago_" : ["{years} рік тому","{years} років тому","{years} років тому","{years} років тому"],
     "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
-    "Default Photos upload and Albums location" : "Типове місце завантажених світлин та альбомів",
+    "Delete source directory" : "Вилучити каталог джерела",
+    "All folders" : "Усі каталоги",
+    "Choose a source Photos for the timelines" : "Виберіть світлини для хронології",
+    "Choose a different folder" : "Виберіть інший каталог",
+    "Select a source folder for your media" : "Виберіть каталог джерела для ваших світлин чи відеозаписів",
+    "Home" : "Домівка",
     "Choose default Photos upload and Albums location" : "Виберіть типове розташування для завантаження світлин та альбомів",
-    "Select the default location for your media" : "Виберіть типове розташування для ваших зображень та відео",
-    "Invalid location selected" : "Вибрано недійсне місце розташування",
+    "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
     "View" : "Перегляд",
-    "Photos directory" : "Каталог фотографій",
+    "Media folder" : "Каталог для світлин чи відеозаписів",
+    "Choose the folders from where photos and videos are shown." : "Виберіть каталоги, з яких показувати світлини та відеозаписи.",
+    "Upload folder" : "Завантажити каталог",
+    "Choose the folder where photos and albums are uploaded to." : "Виберіть каталог, до якого завантажувати світлини та альбоми.",
     "_%n photo_::_%n photos_" : ["%n фото","%n фото","%n фото","%n фото"],
     "Unselect all" : "Зняти вибір",
     "Manage collaborators for this album" : "Керуйте співавторами для цього альбому",
@@ -109,6 +121,7 @@ OC.L10N.register(
     "No tags yet" : "Ще немає міток",
     "Photos with tags will show up here" : "Світлини з мітками буде показано тут",
     "Popular tags" : "Популярні мітки",
+    "The source folder does not exists" : "Каталог джерела відсутній",
     "Add" : "Додати",
     "Add to album" : "Додати в альбом",
     "Delete selection" : "Вилучити виділення",
@@ -134,6 +147,7 @@ OC.L10N.register(
     "Failed to delete {fileName}." : "Не вдалося вилучити {fileName}.",
     "Failed to set favorite state for {fileId}." : "Не вдалося встановити улюблений стан для {fileId}.",
     "Failed to set favorite state for {fileName}." : "Не вдалося встановити улюблений стан для {fileName}.",
+    "Could not load photos folder" : "Неможливо завантажити каталог зі світлинами",
     "Go back to the previous view." : "Повернутися до попереднього перегляду.",
     "Go to the add collaborators view." : "Перейдіть до перегляду додавання співавторів.",
     "Create the album." : "Створіть альбом.",
@@ -144,6 +158,11 @@ OC.L10N.register(
     "No collaborators available" : "Співавторів немає",
     "Failed to fetch album." : "Не вдалося отримати альбом.",
     "The file is in the favorites" : "Файл знаходиться в обраному",
+    "Open the \"{name}\" sub-directory" : "Відкрити підкаталог \"{name}\"",
+    "Default Photos upload and Albums location" : "Типове місце завантажених світлин та альбомів",
+    "Select the default location for your media" : "Виберіть типове розташування для ваших зображень та відео",
+    "Invalid location selected" : "Вибрано недійсне місце розташування",
+    "Photos directory" : "Каталог фотографій",
     "Add photos to the album" : "Додайте фотографії в альбом",
     "Failed to fetch albums list." : "Не вдалося отримати список альбомів.",
     "Shared albums" : "Альбоми із спільним доступом",
