@@ -16,14 +16,15 @@ OC.L10N.register(
     "Group" : "Nhóm",
     "Copy public link" : "Sao chép liên kết công khai",
     "An error occurred" : "Có lỗi đã xảy ra",
+    "Favorite" : "Ưa thích",
     "Open the full size \"{name}\" image" : "Mở kích thước đủ của ảnh \"{name}\"",
-    "Open the \"{name}\" sub-directory" : "Mở thư mục phụ của \"{name}\" ",
+    "Go back" : "Quay lại",
     "Back to {folder}" : "Trở về {folder}",
     "Share this folder" : "Chia sẻ thư mục này",
     "Enable squared photos view" : "Bật chế độ xem theo ô",
+    "Home" : "Trang chủ",
     "View" : "Xem",
     "Unselect all" : "Bỏ chọn tất cả",
-    "Favorite" : "Ưa thích",
     "Remove from favorites" : "Xóa khỏi ưa thích",
     "This folder does not exist" : "Thư mục này không tồn tại",
     "No photos in here" : "Không có ảnh nào trong này",
@@ -32,7 +33,7 @@ OC.L10N.register(
     "Add" : "Thêm",
     "Tagged photos" : "Ảnh gắn nhãn",
     "Details" : "Chi tiết",
-    "Locations" : "Các địa điểm",
+    "Open the \"{name}\" sub-directory" : "Mở thư mục phụ của \"{name}\" ",
     "Shared albums" : "Các tập ảnh đã chia sẽ"
 },
 "nplurals=1; plural=0;");
