@@ -4,18 +4,38 @@ OC.L10N.register(
     "Privacy" : "Privatnost",
     "-" : "-",
     "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centar privatnosti vam pokazuje gdje se vaši podaci pohranjuju i tko im može pristupiti jer ste ih podijelili ili zato što se radi o administratorima.",
+    "Administrators" : "Administratori",
     "Add external admin" : "Dodaj vanjskog administratora",
+    "Cancel" : "Odustani",
+    "Add" : "Dodaj",
     "Name of external admin" : "Ime vanjskog administratora",
+    "Encryption" : "Šifriranje",
+    "Edit" : "Uredi",
     "This server is using full-disk-encryption." : "Ovaj poslužitelj koristi šifriranje cijelog diska.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Vaše datoteke na vanjskim spremištima za pohranu mogu se {linkopen}šifrirati na poslužitelju ↗{linkclose} s pomoću glavnog ključa na temelju njihove konfiguracije.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Vaše datoteke na vanjskim spremištima za pohranu mogu se {linkopen}šifrirati na poslužitelju ↗{linkclose} s pomoću odgovarajućeg ključa na temelju njihove konfiguracije.",
     "Additionally, this server is protected with full-disk-encryption." : "Ovaj je poslužitelj također zaštićen šifriranjem cijelog diska.",
     "This server is protected with full-disk-encryption." : "Ovaj je poslužitelj zaštićen šifriranjem cijelog diska.",
     "Your files are not protected by encryption." : "Vaše datoteke nisu zaštićene šifriranjem.",
+    "Privacy policy" : "Pravila o privatnosti",
+    "Who has access to your data?" : "Tko ima pristup vašim podacima?",
+    "Where is your data?" : "Gdje su vaši podaci?",
     "Your data is located in:" : "Vaši se podaci nalaze u:",
     "Change data location" : "Promijeni lokaciju podataka",
+    "Region" : "Regija",
     "Please select a region" : "Odaberite regiju",
-    "You don't have any shares with individual users." : "Nemate dijeljenja s pojedinačnim korisnicima.",
+    "User Data Manifesto 2.0" : "Manifest o podacima korisnika 2.0",
+    "Control" : "Kontrola",
+    "over user data access" : "pristupa podacima korisnika",
+    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Podaci koje korisnik neposredno i voljno otpremi moraju biti pod krajnjom kontrolom korisnika. Korisnici bi trebali biti u mogućnosti odlučivati kome će odobriti izravan pristup svojim podacima i s kojim dopuštenjima i licencama takav pristup treba odobriti.",
+    "Knowledge" : "Znanje",
+    "of how the data is stored" : "o načinu pohrane podataka",
+    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kada se podaci otpreme određenom davatelju usluga, korisnike bi trebalo obavijestiti gdje taj određeni davatelj usluga pohranjuje podatke, koliko dugo, u kojoj nadležnosti djeluje određeni davatelj usluga i koji se zakoni primjenjuju.",
+    "Freedom" : "Sloboda",
+    "to choose a platform" : "biranja platforme",
+    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Korisnici bi trebali uvijek biti u mogućnosti izdvojiti svoje podatke iz usluge u bilo kojem trenutku bez ikakvih uplitanja davatelja usluge. Otvoreni standardi formata i protokola nužni su kako bi se to zajamčilo.",
+    "Learn more ↗" : "Saznajte više ↗",
+    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vaši podaci predstavljaju vas i lako ih se može zloupotrijebiti. Mi u Nextcloudu vjerujemo da imate pravo odlučivati što će se dogoditi s vašim podacima. Nextcloud štiti vaša prava kako su definirana u Manifestu o podacima korisnika!",
     "Somaliland" : "Somaliland",
     "Andorra" : "Andora",
     "United Arab Emirates" : "Ujedinjeni Arapski Emirati",
@@ -110,9 +130,9 @@ OC.L10N.register(
     "Guam" : "Guam",
     "Guinea-Bissau" : "Gvineja Bisau",
     "Guyana" : "Gvajana",
-    "Honduras" : "Honduras",
     "Hong Kong" : "Hong Kong",
     "Heard Island and McDonald Islands" : "Otok Heard i otočje McDonald",
+    "Honduras" : "Honduras",
     "Croatia" : "Hrvatska",
     "Haiti" : "Haiti",
     "Hungary" : "Mađarska",
@@ -263,27 +283,9 @@ OC.L10N.register(
     "South Africa" : "Južna Afrika",
     "Zambia" : "Zambija",
     "Zimbabwe" : "Zimbabve",
-    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vaši podaci predstavljaju vas i lako ih se može zloupotrijebiti. Mi u Nextcloudu vjerujemo da imate pravo odlučivati što će se dogoditi s vašim podacima. Nextcloud štiti vaša prava kako su definirana u Manifestu o podacima korisnika!",
-    "User Data Manifesto 2.0" : "Manifest o podacima korisnika 2.0",
+    "You don't have any shares with individual users." : "Nemate dijeljenja s pojedinačnim korisnicima.",
     "Defining basic rights for people to control their own data in the internet age" : "Definiranje osnovnih prava koje osobama omogućuju nadzor nad vlastitim podacima u doba interneta",
-    "Control" : "Kontrola",
-    "over user data access" : "pristupa podacima korisnika",
-    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Podaci koje korisnik neposredno i voljno otpremi moraju biti pod krajnjom kontrolom korisnika. Korisnici bi trebali biti u mogućnosti odlučivati kome će odobriti izravan pristup svojim podacima i s kojim dopuštenjima i licencama takav pristup treba odobriti.",
-    "Knowledge" : "Znanje",
-    "of how the data is stored" : "o načinu pohrane podataka",
-    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Kada se podaci otpreme određenom davatelju usluga, korisnike bi trebalo obavijestiti gdje taj određeni davatelj usluga pohranjuje podatke, koliko dugo, u kojoj nadležnosti djeluje određeni davatelj usluga i koji se zakoni primjenjuju.",
-    "Freedom" : "Sloboda",
-    "to choose a platform" : "biranja platforme",
-    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Korisnici bi trebali uvijek biti u mogućnosti izdvojiti svoje podatke iz usluge u bilo kojem trenutku bez ikakvih uplitanja davatelja usluge. Otvoreni standardi formata i protokola nužni su kako bi se to zajamčilo.",
-    "Learn more ↗" : "Saznajte više ↗",
-    "Where is your data?" : "Gdje su vaši podaci?",
-    "Who has access to your data?" : "Tko ima pristup vašim podacima?",
-    "Administrators" : "Administratori",
     "People you shared with" : "Osobe s kojima ih dijelite",
-    "Privacy policy" : "Pravila o privatnosti",
-    "Read the privacy policy." : "Pročitajte pravila o privatnosti.",
-    "Encryption" : "Šifriranje",
-    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Vaša kućna pohrana {linkopen}šifrirana je na poslužitelju ↗{linkclose} s pomoću glavnog ključa.",
-    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Vaša kućna pohrana {linkopen}šifrirana je na poslužitelju ↗{linkclose} s pomoću odgovarajućeg korisničkog ključa."
+    "Read the privacy policy." : "Pročitajte pravila o privatnosti."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
