@@ -5,12 +5,17 @@ OC.L10N.register(
     "-" : "-",
     "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "O centro de privacidade mostra onde seus dados estão armazenados e quem pode acessá-los, seja porque você compartilhou com eles ou porque são administradores.",
     "Administrators" : "Administradores",
+    "Loading administrators …" : "Carregando administradores…",
     "Remove external {propertyName} admin" : "Remover administrador externo {propertyName}",
     "Add external admin" : "Adicionar administrador externo",
     "Cancel" : "Cancelar",
     "Add" : "Adicionar",
     "Name of external admin" : "Nome do administrador externo",
+    "Error loading additional administrator." : "Erro ao carregar administrador adicional.",
+    "Error adding new administrator." : "Erro ao adicionar novo administrador.",
+    "Error deleting new administrator." : "Erro ao excluir novo administrador.",
     "Encryption" : "Criptografia",
+    "Edit encryption" : "Editar criptografia",
     "Edit" : "Editar",
     "This server is using full-disk-encryption." : "Este servidor está usando criptografia-de-disco-completo.",
     "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key. It means that administrators can access your files, but not read their content." : "Seu armazenamento doméstico é criptografado usando {linkopen}criptografia do lado do servidor ↗{linkclose} com uma chave mestra. Isso significa que os administradores podem acessar seus arquivos, mas não podem ler seu conteúdo.",
@@ -20,14 +25,20 @@ OC.L10N.register(
     "Additionally, this server is protected with full-disk-encryption." : "Além disso, este servidor está protegido com criptografia completa de disco.",
     "This server is protected with full-disk-encryption." : "Este servidor está protegido com criptografia-de-disco-completo.",
     "Your files are not protected by encryption." : "Seus arquivos não estão criptografados.",
+    "Error saving new state of full-disk-encryption" : "Erro ao salvar o novo estado de criptografia completa do disco",
     "Privacy policy" : "Política de privacidade",
+    "Read the privacy policy ↗" : "Leia a política de privacidade ↗",
+    "Error loading information about shares." : "Erro ao carregar informações sobre compartilhamentos.",
     "Who has access to your data?" : "Quem tem acesso aos seus dados?",
     "Where is your data?" : "Onde estão seus dados?",
     "Your data is located in:" : "Seus dados estão localizados em: ",
+    "An admin has not selected the location of the server yet." : "Um administrador ainda não selecionou o local do servidor.",
     "Change data location" : "Alterar a localização dos dados",
     "Region" : "Região",
     "Please select a region" : "Selecione uma região",
+    "Error saving new location of the server" : "Erro ao salvar o novo local do servidor",
     "User Data Manifesto 2.0" : "Manifesto de Dados do Usuário 2.0",
+    "Defining basic rights for people to control their own data in the internet age." : "Definir direitos básicos para as pessoas controlarem os seus próprios dados na era da Internet.",
     "Control" : "Controle",
     "over user data access" : "sobre o acesso aos dados do usuário",
     "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Os dados carregados explicitamente e de bom grado por um usuário devem estar sob o controle final dele. Os usuários podem decidir quem tem acesso direto aos dados e com quais permissões e licenças esse acesso deve ser concedido.",
@@ -38,6 +49,7 @@ OC.L10N.register(
     "to choose a platform" : "para escolher uma plataforma",
     "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Os usuários podem extrair seus dados do serviço a qualquer momento sem qualquer bloqueio do fornecedor. Padrões abertos para formatos e protocolos são necessários para garantir isso.",
     "Learn more ↗" : "Saiba mais ↗",
+    "Your {serverName} account" : "Sua conta {serverName}",
     "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Seus dados representam quem você é e podem ser facilmente usados. Na Nextcloud acreditamos que você tem o direito de decidir o que acontece com eles. O Nextcloud protege seus direitos conforme definido no Manifesto de Dados do Usuário!",
     "Somaliland" : "Somalilândia",
     "Andorra" : "Andorra",
@@ -292,6 +304,9 @@ OC.L10N.register(
     "Your %s account" : "Sua conta %s",
     "Defining basic rights for people to control their own data in the internet age" : "Definição dos direitos básicos para as pessoas controlarem seus próprios dados na era da internet",
     "People you shared with" : "Pessoas com quem você compartilhou",
-    "Read the privacy policy." : "Leia a política de privacidade."
+    "Read the privacy policy." : "Leia a política de privacidade.",
+    "You don" : "Você não",
+    "Loading people you" : "Carregando pessoas que você",
+    "People you" : "Pessoas que você"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
