@@ -2,13 +2,13 @@ OC.L10N.register(
     "recommendations",
     {
     "Recommended files" : "Προτεινόμενα αρχεία",
+    "No recommendations yet" : "Δεν υπάρχουν προτάσεις ακόμα",
     "Recently commented" : "Σχολιάστηκε πρόσφατα",
     "Recently edited" : "Επεξεργάστηκε πρόσφατα",
     "Recently shared" : "Διαμοιράστηκε πρόσφατα",
     "Recommendations" : "Συστάσεις",
-    "Shows recommended files" : "Εμφάνιση συνιστώμενων αρχείων",
+    "Shows recommended files" : "Εμφάνιση προτεινόμενων αρχείων",
     "Shows recommended files for quick access of files and folders with recent activity" : "Εμφανίζει τα συνιστώμενα αρχεία για γρήγορη πρόσβαση αρχείων και φακέλων με πρόσφατη δραστηριότητα",
-    "No recommendations yet" : "Δεν υπάρχουν προτάσεις ακόμα",
     "Show recommendations" : "Εμφάνιση προτεινόμενων"
 },
 "nplurals=2; plural=(n != 1);");
