@@ -4,7 +4,7 @@ OC.L10N.register(
     "Calendar" : "Календар",
     "Deck" : "Deck",
     "Files" : "Датотеки",
-    "Talk" : "Разговор",
-    "Talk conversation" : "Talk раговор"
+    "Talk conversation" : "Talk раговор",
+    "Talk" : "Разговор"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
