@@ -71,12 +71,9 @@ OC.L10N.register(
     "Use this end point to connect an external monitoring tool:" : "Diesen Endpunkt verwenden, um mit einem externen Überwachungstool zu verbinden:",
     "Copy" : "Kopieren",
     "Output in JSON" : "Ausgabe in JSON",
-    "Skip app updates (including app updates will send an external request to the app store)" : "App-Updates überspringen (einschließlich App-Updates, die  eine externe Anfrage an den App Store sendet)",
+    "Skip app updates (including app updates will send an external request to the app store)" : "App-Updates überspringen (einschließlich App-Updates, die eine externe Anfrage an den App Store sendet)",
     "Skip server update" : "Serveraktualisierung überspringen",
     "To use an access token, please generate one then set it using the following command:" : "Um ein Zugriffstoken zu verwenden, generieren Sie bitte eines und legen Sie es mit dem folgenden Befehl fest:",
-    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergeben Sie dann das Token mit dem Header \"NC-Token\" durch Aufrufen der obigen URL.",
-    "You will get a notification once one of your disks is nearly full." : "Sie erhalten eine Benachrichtigung, sobald eines Ihrer Speichermedien fast voll ist.",
-    "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
-    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wenn Sie \"?format=json\" am Ende der URL anhängen, erhalten Sie das Ergebnis in JSON."
+    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Übergeben Sie dann das Token mit dem Header \"NC-Token\" durch Aufrufen der obigen URL."
 },
 "nplurals=2; plural=(n != 1);");
