@@ -7,6 +7,7 @@ OC.L10N.register(
     "RAM info not available" : "Información de RAM no disponible",
     "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Uso actual: {swapUsageBytes}",
     "SWAP info not available" : "Información de SWAP no disponible",
+    "Copied!" : "¡Copiado!",
     "Not supported!" : "¡No soportado!",
     "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
     "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
@@ -67,11 +68,8 @@ OC.L10N.register(
     "Database" : "Base de datos",
     "Type:" : "Tipo:",
     "External monitoring tool" : "Herramienta de monitoreo externa",
-    "You can connect an external monitoring tool by using this end point:" : "Puedes conectar una herramienta de monitoreo externa usando este punto final:",
     "Copy" : "Copiar",
-    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Agregando \"?format=json\" al final de la URL te dará el resultado en formato JSON.",
     "To use an access token, please generate one then set it using the following command:" : "Para usar un token de acceso, por favor genera uno y luego configúralo usando el siguiente comando:",
-    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Luego pasa el token con la cabecera \"NC-Token\" al consultar la URL anterior.",
-    "You will get a notification once one of your disks is nearly full." : "Recibirás una notificación cuando uno de tus discos esté casi lleno."
+    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Luego pasa el token con la cabecera \"NC-Token\" al consultar la URL anterior."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
