@@ -74,9 +74,6 @@ OC.L10N.register(
     "Skip app updates (including app updates will send an external request to the app store)" : "略過應用程式更新（包含應用程式更新將會向應用程式商店傳送外部請求）",
     "Skip server update" : "略過伺服器更新",
     "To use an access token, please generate one then set it using the following command:" : "要使用存取權杖，請產生一個，然後使用下列指令設定：",
-    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上面的 URL 時，將權杖與「NC-Token」標頭一起傳遞。",
-    "You will get a notification once one of your disks is nearly full." : "你將在硬碟使用量快要用完前收到一次通知。",
-    "You can connect an external monitoring tool by using this end point:" : "您可以使用此端點連結外部監視工具：",
-    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "在 URL 結尾接上 \"?format=json\" 即可取得 JSON 格式的回傳結果。"
+    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "然後在查詢上面的 URL 時，將權杖與「NC-Token」標頭一起傳遞。"
 },
 "nplurals=1; plural=0;");
