@@ -45,15 +45,11 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Groget eo al lemel pall da %1$s",
     "Remote wipe has finished on %1$s" : "Echuet eo bet al lemel pell da %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Ho <strong>ger-tremen</strong> pe <strong>postel</strong> a zo bet cheñchet",
-    "Apps" : "Meziant",
+    "Settings" : "Arventennoù",
     "Wrong password" : "Ger-tremen fall",
     "Saved" : "Enrollet",
-    "No user supplied" : "Implijour roet ebet",
     "Authentication error" : "Fazi dilesa",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Mar-plij, roit ur ger-tremen adtapout d'ar merour; mod all e vo kollet roadennoù an implijer.",
     "Wrong admin recovery password. Please check the password and try again." : "Ger-tremen adtapout ar merour fall. Gwiriit ar ger-tremen ha klaskit en dro.",
-    "Federated Cloud Sharing" : "Federated Cloud Sharing",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL a zo o implij ur stumm mkozh eus %1$s (%2$s). Adnevesait ho sistem ober pe ne labouro ket mat perzhioù 'zo evel %3$s.",
     "Administrator documentation" : "Dielvadur ar merour",
     "User documentation" : "Dielvadur an implijer",
     "Invalid SMTP password." : "Ger-tremen SMTP fall.",
@@ -62,7 +58,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Ma eo bet resevet ar postel ganeoc'h, stummadur ar bostel a seblant bezañ bet graet mat.",
     "Email could not be sent. Check your mail server log" : "N'eo ket posupl kas ar postel. Gwiriit kazetenn servijour evit ar bostel.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ur gudenn a zo bet en ur kas ar bostel. Adstummit o stumm (Fazi : %s)",
-    "Users" : "Implijer",
     "Invalid mail address" : "Chom-lec'h postel fall",
     "Settings saved" : "Stummoù enrollet",
     "Unable to change full name" : "Dibosupl cheñch tout an anv",
@@ -85,14 +80,13 @@ OC.L10N.register(
     "Welcome aboard" : "Donemat e bourz",
     "Welcome aboard %s" : "Donemat e bourz %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Donemat d'ho c'hont %s, posupl eo deoc'h ouzhpennañ, gwarezi ha rannañ o roadennoù.",
-    "Your username is: %s" : "Ho anv implijer a zo : %s",
     "Set your password" : "Lakaat ho ger-tremen",
     "Go to %s" : "Mont da %s",
     "Install Client" : "Stalia ar c'hliant",
-    "Logged in user must be a subadmin" : "An trement e implijer a zo ret bezañ un iz-merour",
-    "Settings" : "Arventennoù",
+    "Apps" : "Meziant",
     "Personal" : "Personel",
     "Administration" : "Merouriez",
+    "Users" : "Implijer",
     "Additional settings" : "Stummoù ouzhpenn",
     "Groupware" : "Labour a stroll",
     "Overview" : "Taol-lagad",
@@ -104,18 +98,34 @@ OC.L10N.register(
     "Email server" : "Servijour postel",
     "Security & setup warnings" : "Kemmenadennoù suretez ha stumm",
     "Background jobs" : "Labour diadreñv",
-    "Create" : "Krouiñ",
-    "Change" : "Cheñch",
-    "Delete" : "Dilemel",
-    "Reshare" : "Adrannañ",
     "Unlimited" : "Didermenet",
     "Verifying" : "O gwiriañ",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankout a ra kolonennoù er roadennoù-diaz dibabapl. Abalamour e kemer amzer ouzhpennañ kolonennoù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-columns\" eo posupl ouzhpennañ ar c'holonennoù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ouzhpennet ar c'holonennoù, goulennoù savet d'an taolennoù a vo buanaet.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankout a ra rollioù er roadenn-diaz. Abalamour e kemer amzer ouzhpennañ rollioù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-indices\" eo posupl ouzhpennañ ar rollioù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ar rollioù ouzhpennet, goulennoù savet d'an taolennoù a vo buanaet.",
+    "Disabled" : "Disaotreañ",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Stumm ar sifrañ kostez ar servijour kozh a zo aotreet. Aliet eo hen disaotreañ.",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "N'eo ket posupl implijout arc’hwel PHP \"set_time_limit\". Galout a ra ar gudenn-se herzel skriptoù e-kreiz o labour, terriñ ar staliadur. Aotreañ an arc'hwel a zo aliet-mat.",
+    "Supported" : "Douget",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ho PHP ne zoug ket FreeType, terriñ ar skeudennoù trolinenn ha stummoù an etrefas.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne seblant ket bezañ staliet mat evit goulenn d'ar sistem argemennoù endro. An amprouenn gant getenv(\"PATH\") a ro ur respont goullo.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Aotreet a zo bet ar stumm lenn-nemetken. Ampechiñ a ra cheñch stummoù dre an etrefas-web. Ouzhpenn-se, ar restr en deus ezhomm bezañ adlakaet da  vezañ embannapl dre dorn evit pep adneveziñ.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ho roadennoù-diaz ne droont ket gant al live \"READ COMMITTED\". Kudennoù a zo posupl kaout pa vez graet meur a ober war an dro.",
     "Nextcloud settings" : "Stummoù Nextcloud",
     "None" : "Hini ebet",
+    "Allow apps to use the Share API" : "Aotreañ ar meziant d'a implijout Share API",
+    "Allow resharing" : "Aotrea an adrannañ",
+    "Allow sharing with groups" : "Aotreañ ar rannan gant ur strollad ",
+    "Restrict users to only share with users in their groups" : "Redia an implijourien da ranna nemet gant an implijourien en o strolladoù",
+    "Allow public uploads" : "Aotreañ ar bellkas publik",
+    "Always ask for a password" : "Goulenn ar ger-tremen bewech.",
+    "Enforce password protection" : "Rediañ ar gwarez dre ger-tremen",
+    "Exclude groups from sharing" : "Lemel ar strolladoù eus ar rannañ",
+    "These groups will still be able to receive shares, but not to initiate them." : "Posupl vo d'ar strolad resev rannadennoù, mes ne vo ket posuple d'eo o krouiñ.",
+    "Set default expiration date for shares" : "Lakaat un deizat termen dre ziouer evit ar rannañ",
+    "Enforce expiration date" : "Rediañ an deiziat diamzerañ",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Diskouezet e vo an destenn war ar bajenn publik palkass liammoù pa eo kouachet ar roll restroù.",
+    "Default share permissions" : "Aotreoù rannañ dre ziouer",
     "Two-Factor Authentication" : "Dilesa daou-elfenn",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "An dilesa daou-elfenn a zo posupl rediañ evit tout an implijourieñ ha strolladoù 'zo. Ma n'ho deus get stummet ar goulenner deao-elfenn, ne vo ket posupl dezho mon-tre er sistem.",
     "Enforce two-factor authentication" : "Reddiañ an dilesa daou-elfenn",
     "Limit to groups" : "Nemet d'ar strolladoù",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Posupl eo rediañ an dilesa daou-elfenn da strolladoù 'zo nemetken.",
@@ -123,7 +133,6 @@ OC.L10N.register(
     "Enforced groups" : "Rediañ strollad",
     "Two-factor authentication is not enforced for members of the following groups." : "N'eo ket rediet an dilesa daoi-elfenn evit izili ar strolladoù dindan.",
     "Excluded groups" : "Strolladoù argaset",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Pa vez choazet/argaset strolladoù, implijoet a vez gantez ar vezoniezh da heul evit gouzout ma eo bet rediet un dilesa daou-elfenn d'un implijer :  m'a n'eo ket bet choazet strollad ebet, an dilesa daou-elfenn a zo aotreet evit tout ar strolladoù estreget ar re argaset. M'az eo bet choazet strolladoù, an dilesa daou-elfenn a zo aotreet evito. M'az eo un implijer en ur strollad choazt hag un argaset, an hini choazet zo lakaet war-raok hag an dilesa daou-elfenn a vez rediet.",
     "Save changes" : "Enrollañ ar cheñchamantoù",
     "All" : "Pep tra",
     "Limit app usage to groups" : "Lakaat ar meziant da veza implijet gant ar strolladoù nemetken",
@@ -140,7 +149,6 @@ OC.L10N.register(
     "Admin documentation" : "Dielvadur ar merour",
     "Developer documentation" : "Diellvadur an digeler",
     "This app is supported via your current Nextcloud subscription." : "Ar meziant-mañ a vez douget dre ho kommanant Nextcloud.",
-    "Supported" : "Douget",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Meziantoù perzhiet a vez digeliet gant ha e-vbarzh ar gummuniezh. Perzhioù penna a vez roet gante ha prest int da krouiñ reoù all.",
     "Featured" : "Perzhiet",
     "Update to {update}" : "Adnevesiñ da {update}",
@@ -158,37 +166,18 @@ OC.L10N.register(
     "Rename" : "Adenvel",
     "Revoke" : "Digargañ",
     "Wipe device" : "Lemel an dra",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome evit Android",
-    "iPhone" : "iPhone",
-    "iPad" : "Pad",
-    "Sync client - {os}" : "Kempren kliant - {os}",
     "This session" : "An estez-mañ",
     "Device" : "Ardivink",
     "Last activity" : "Oberenn divezhañ",
     "Devices & sessions" : "Ardivinkoù ha estezioù",
     "Web, desktop and mobile clients currently logged in to your account." : "Ar c'hliant Web, burev ha hezouk a zo kenstaget en ho c'hont.",
-    "Do you really want to wipe your data from this device?" : "C'hoant o peus lemel ar roadennoù diouzh o ardivink ?",
-    "Confirm wipe" : "Gwiriañ al lemel",
-    "Error while creating device token" : "Ur fazi a zo bet en ur groiñ jedour an ardivink",
-    "Error while updating device token scope" : "Ur fazi a zo bet en ur adnevesiñ pellder ar jedouer",
-    "Error while updating device token name" : "Ur fazi a zo bet en ur adnevesiñ anv jedouer an ardivink",
-    "Error while deleting the token" : "Ur fazi zo bet en ur lemmek ar jedouer",
-    "Error while wiping the device with the token" : "Ur fazi a zo bet en ul lemel an ardivink gant ar jedouer",
     "App name" : "Anv meziant",
     "Create new app password" : "Krouiñ ur ger-tremen meziant nevez",
-    "Use the credentials below to configure your app or device." : "Implij kretaatoù dindan evit stummañ o meziant pe ardivink.",
-    "For security reasons this password will only be shown once." : "Ne vo diskwellet ar ger-tremen ur wech nemetken abalamour d'ar surentez.",
-    "Username" : "anv implijer",
+    "Error while creating device token" : "Ur fazi a zo bet en ur groiñ jedour an ardivink",
+    "Login" : "Anv arveriad",
     "Password" : "Ger-tremen",
-    "Done" : "Graet",
     "Show QR code for mobile apps" : "Diskouez ar c'hod QR evit ar meziant hezouk",
-    "Copied!" : "Eilet eo !",
-    "Copy" : "Eilañ",
     "Could not copy app password. Please copy it manually." : "N'eo ket posupl eilan ar ger-tremen meziant. Eilit anezhan gant an dorn.",
     "Use system cron service to call the cron.php file every 5 minutes." : "Implijit sevichoù ar sistem cron evit gervel restr cron.php pep 5 munutenn.",
     "Enable" : "Aotreañ",
@@ -217,6 +206,10 @@ OC.L10N.register(
     "No language set" : "Yezh ebet lakaet",
     "Your phone number" : "O niverenn pelgomzer",
     "Add" : "Ouzhpennañ",
+    "Create" : "Krouiñ",
+    "Change" : "Cheñch",
+    "Delete" : "Dilemel",
+    "Reshare" : "Adrannañ",
     "Default language" : "Yezh dre ziouer",
     "Common languages" : "Yezh boutiñ",
     "Password change is disabled because the master key is disabled" : "N'eo ket aotreet cheñch ger-tremen peogwir n'eo ket aotreet an alc'hwez meur",
@@ -226,18 +219,13 @@ OC.L10N.register(
     "Quota" : "Quota",
     "Language" : "Yezh",
     "Avatar" : "Avatar",
+    "Username" : "anv implijer",
     "Group admin for" : "Strollad merour evit",
     "User backend" : "Backen implijer",
     "Storage location" : "Lec'h berniañ",
     "Last login" : "Mont-tre divezhañ",
-    "You do not have permissions to see the details of this user" : "N'oc'h ket aotreet da gwellet munudoù an implijer",
-    "Set user as admin for" : "Lakaat an implijer da merour evit",
-    "Select user quota" : "Choaz quota an implijer",
     "{size} used" : "{size} implijet",
-    "Delete user" : "Lemel implijer",
     "Wipe all devices" : "Lemel pep ardivink",
-    "Disable user" : "Disaotreañ an implijour",
-    "Enable user" : "Aotreañ an implijour",
     "Resend welcome email" : "Adkas ar postel degemer mat",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Ma peus kollet o ardivink pe kuitaet ar strollad, posupl e vefe lemet a pell roadennoù Nextcloud eus tout o ardivinkoù liamet gant {userid}. Ne gerzh nemet ma eo kenstaget an ardivinkoù gant internet.",
     "Remote wipe of devices" : "Lemel a bell an ardivink",
@@ -246,9 +234,8 @@ OC.L10N.register(
     "Account deletion" : "Lemel ar c'hont",
     "Delete {userid}'s account" : "Lemel kont {userid}",
     "Welcome mail sent!" : "Postel degemer kaset !",
-    "Toggle user actions menu" : "Diskwell/koachañ ar roll ober",
+    "Done" : "Graet",
     "Edit" : "Cheñch",
-    "Show user backend" : "Diskouez backend an implijer",
     "Show storage path" : "Diskouez an hent klenkañ",
     "Show last login" : "Diskouez ar c'hennask diwezhañ",
     "Send email" : "Kas postel",
@@ -267,12 +254,11 @@ OC.L10N.register(
     "No devices configured." : "Ardivink stummet ebet.",
     "The following devices are configured for your account:" : "Stummet eo bet an ardivinkoù ma d'ho c'hont.",
     "Your browser does not support WebAuthn." : "Ne vez ket douget WebAuthn gant o furcher.",
-    "Your apps" : "Ho meziantoù",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Evel ar merour eo posupl deoc'h stumañ pizh penaos e vez rannet. Sellit ouz an diellvadur evit muioc'h a ditouroù.",
     "{license}-licensed" : "{license}-aotre",
     "by {author}\n{license}" : "great gant {author}\n{license}",
     "Admins" : "Merourien",
     "Disabled users" : "Disaotreañ implijer",
-    "Not saved" : "N'eo ket bet enrollet",
     "Sending…" : "O kas...",
     "Email sent" : "Postel kaset",
     "Location" : "Lec'hiadur",
@@ -281,9 +267,9 @@ OC.L10N.register(
     "Full name" : "Tout an anv",
     "Phone number" : "Niverenn pellgomzer",
     "Role" : "Roll",
-    "Twitter" : "Twitter",
     "Website" : "Lec'hien web",
     "Locale" : "Diabarzh",
+    "Your apps" : "Ho meziantoù",
     "Active apps" : "Meziantoù lakaet en dro",
     "Disabled apps" : "Meziantoù disaotreet",
     "Updates" : "Adnevesadennoù",
@@ -294,10 +280,14 @@ OC.L10N.register(
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "N'eo ket ar meziant keverlec'h gant stumm Nextcloud. Ma kendalc'hit e o posupl deoc'h staliañ ar meziant. Taolit evez, ne labouro ket ar meziant evel ma zlefe.",
     "Never" : "James",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aotreet eo bet ar meziant mes ezomm e deus bezhan adnevesaet. Kaset a voc'h d'ar bajenn adneveziñ a benn 5 eilenn.",
+    "Do you really want to wipe your data from this device?" : "C'hoant o peus lemel ar roadennoù diouzh o ardivink ?",
+    "Confirm wipe" : "Gwiriañ al lemel",
+    "Error while wiping the device with the token" : "Ur fazi a zo bet en ul lemel an ardivink gant ar jedouer",
+    "Error while updating device token name" : "Ur fazi a zo bet en ur adnevesiñ anv jedouer an ardivink",
+    "Error while updating device token scope" : "Ur fazi a zo bet en ur adnevesiñ pellder ar jedouer",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Re a goulennoù a zo bet eus ar rouedat. Klaskit en dro diwezhatoc'h pe galvit ho merour m'az eus ur fazi.",
     "Documentation" : "Diellvadur",
     "Forum" : "Forum",
-    "Login" : "Anv arveriad",
     "Open documentation" : "Digeriñ an dielvadur",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Pouezus eo stummañ ar servijour avit ma c'helfe kas posteloù, evit kemenadennoù pe posteloù evit cheñch ar ger-tremen.",
     "Send mode" : "Mod kas",
@@ -308,7 +298,6 @@ OC.L10N.register(
     "Port" : "Porzh",
     "Authentication required" : "Eus un dilesa ez eus ezhomp",
     "Credentials" : "Kretaatoù",
-    "SMTP Username" : "Anv implijer SMTP",
     "SMTP Password" : "Ger-tremen SMTP",
     "Save" : "Enrollañ",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pouezus eo evit ar surentez hag ar mont en dro ho azgoulenn e vefe pep tra stummet mat. Evit sikour ac'hanoc'h e vez graet gwiradennoù otomatek. Sellit ouz an diellvadur liammet evit muioc'h a ditouroù.",
@@ -318,21 +307,6 @@ OC.L10N.register(
     "Checking for system and security issues." : "O gwiriañ ne vefe kuden ebet gant ar sistem hag ar surentez.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Sellit ouzh <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">sturier ar staliañ ↗</a>, ha gwiriit ne vefe fazi pe diwal ebet er <a href=\"%2$s\">gazetenn</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Gwiriit surentez ho Nextcoud war <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">hon skan surentez ↗</a>.",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Evel ar merour eo posupl deoc'h stumañ pizh penaos e vez rannet. Sellit ouz an diellvadur evit muioc'h a ditouroù.",
-    "Allow apps to use the Share API" : "Aotreañ ar meziant d'a implijout Share API",
-    "Set default expiration date for shares" : "Lakaat un deizat termen dre ziouer evit ar rannañ",
-    "Enforce expiration date" : "Rediañ an deiziat diamzerañ",
-    "Allow public uploads" : "Aotreañ ar bellkas publik",
-    "Always ask for a password" : "Goulenn ar ger-tremen bewech.",
-    "Enforce password protection" : "Rediañ ar gwarez dre ger-tremen",
-    "Set default expiration date" : "Lakaat un deizat termen dre ziouer",
-    "Allow resharing" : "Aotrea an adrannañ",
-    "Allow sharing with groups" : "Aotreañ ar rannan gant ur strollad ",
-    "Restrict users to only share with users in their groups" : "Redia an implijourien da ranna nemet gant an implijourien en o strolladoù",
-    "Exclude groups from sharing" : "Lemel ar strolladoù eus ar rannañ",
-    "These groups will still be able to receive shares, but not to initiate them." : "Posupl vo d'ar strolad resev rannadennoù, mes ne vo ket posuple d'eo o krouiñ.",
-    "This text will be shown on the public link upload page when the file list is hidden." : "Diskouezet e vo an destenn war ar bajenn publik palkass liammoù pa eo kouachet ar roll restroù.",
-    "Default share permissions" : "Aotreoù rannañ dre ziouer",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Digelet gant {communityopen}kummuniezh NExtcloud{linkclose}, ar {githubopen}c'hod orin{linkclose} a zo dindan aotre {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Liamm d'hon bajenn Facebook",
     "Follow us on Twitter" : "Heuliit ac'henomp war Twitter",
@@ -340,15 +314,42 @@ OC.L10N.register(
     "Check out our blog" : "Sellit ouzh hon vlog",
     "Subscribe to our newsletter" : "Koumannantit d'hon kemenadennoù nevesadur",
     "Use a second factor besides your password to increase security for your account." : "Implijour un eil-elfenn d'ho ger-tremen a gwella urentez o c'hont.",
-    "You created app password \"{token}\"" : "Ar ger-tremen meziant \"{token}\" o peus krouet",
+    "No user supplied" : "Implijour roet ebet",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Mar-plij, roit ur ger-tremen adtapout d'ar merour; mod all e vo kollet roadennoù an implijer.",
+    "Federated Cloud Sharing" : "Federated Cloud Sharing",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL a zo o implij ur stumm mkozh eus %1$s (%2$s). Adnevesait ho sistem ober pe ne labouro ket mat perzhioù 'zo evel %3$s.",
+    "Your username is: %s" : "Ho anv implijer a zo : %s",
+    "Logged in user must be a subadmin" : "An trement e implijer a zo ret bezañ un iz-merour",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "An dilesa daou-elfenn a zo posupl rediañ evit tout an implijourieñ ha strolladoù 'zo. Ma n'ho deus get stummet ar goulenner deao-elfenn, ne vo ket posupl dezho mon-tre er sistem.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Pa vez choazet/argaset strolladoù, implijoet a vez gantez ar vezoniezh da heul evit gouzout ma eo bet rediet un dilesa daou-elfenn d'un implijer :  m'a n'eo ket bet choazet strollad ebet, an dilesa daou-elfenn a zo aotreet evit tout ar strolladoù estreget ar re argaset. M'az eo bet choazet strolladoù, an dilesa daou-elfenn a zo aotreet evito. M'az eo un implijer en ur strollad choazt hag un argaset, an hini choazet zo lakaet war-raok hag an dilesa daou-elfenn a vez rediet.",
     "Enable all" : "Aotreñ pep tra",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "Pad",
+    "Sync client - {os}" : "Kempren kliant - {os}",
+    "Error while deleting the token" : "Ur fazi zo bet en ur lemmek ar jedouer",
+    "Use the credentials below to configure your app or device." : "Implij kretaatoù dindan evit stummañ o meziant pe ardivink.",
+    "For security reasons this password will only be shown once." : "Ne vo diskwellet ar ger-tremen ur wech nemetken abalamour d'ar surentez.",
+    "Copied!" : "Eilet eo !",
+    "Copy" : "Eilañ",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Ezhomm ez eus eus astennenn PHP POSIX evit al lakaat da dreiñ. Sellit ouzh {linkstart}diellvadur PHP{linkend} evit muioc'h a ditouroù.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "O vont da lemel ar strollad {group} emaoc'h. An implijourienn NA VEZONT KET lemet.",
     "Please confirm the group removal " : "Gwiriit an dilemel",
     "png or jpg, max. 20 MB" : "png pe jpg, 20 MB d'ar muiañ",
     "Your email address" : "O chom-lec'h postel",
+    "You do not have permissions to see the details of this user" : "N'oc'h ket aotreet da gwellet munudoù an implijer",
     "Add new password" : "Ouzhpennañ ur ger-tremen",
     "Add new email address" : "Ouzhpennañ ur chom-lec'h postel nevez",
+    "Set user as admin for" : "Lakaat an implijer da merour evit",
+    "Select user quota" : "Choaz quota an implijer",
+    "Toggle user actions menu" : "Diskwell/koachañ ar roll ober",
+    "Delete user" : "Lemel implijer",
+    "Disable user" : "Disaotreañ an implijour",
+    "Enable user" : "Aotreañ an implijour",
     "Edit User" : "Embann implijer",
     "Will be autogenerated" : "A vo krouet en un doare otomatek",
     "Add a new user" : "Ouzhpennan un im^lijer",
@@ -357,12 +358,12 @@ OC.L10N.register(
     "Add group" : "Ouzhpenn strollad",
     "Default quota:" : "Quota dre ziouer :",
     "Show Languages" : "Diskouez Yezhoù",
+    "Show user backend" : "Diskouez backend an implijer",
     "Send email to new user" : "Kes postel d'an implijer nevez",
+    "Not saved" : "N'eo ket bet enrollet",
+    "Twitter" : "Twitter",
     "Enable untested app" : "Aotreañ ar meziant disamprouet",
-    "Plain" : "Sklaer",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Doare dilesa"
+    "SMTP Username" : "Anv implijer SMTP",
+    "Set default expiration date" : "Lakaat un deizat termen dre ziouer"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
