@@ -50,18 +50,15 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "S'ha engegat la neteja remota a %1$s",
     "Remote wipe has finished on %1$s" : "Ha finalitzat la neteja remota a %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "S'ha modificat la vostra <strong>contrasenya</strong> o <strong>correu electrònic</strong>",
-    "Apps" : "Aplicacions",
+    "Settings" : "Paràmetres",
     "Could not remove app." : "No s'ha pogut suprimir l'aplicació.",
     "Could not update app." : "No s'ha pogut actualitzar l'aplicació.",
     "Wrong password" : "Contrasenya incorrecta",
     "Unable to change personal password" : "No s'ha pogut canviar la contrasenya personal",
     "Saved" : "S'ha desat",
-    "No user supplied" : "No heu proporcionat cap usuari",
     "Unable to change password. Password too long." : "No s'ha pogut canviar la contrasenya. És massa llarga.",
     "Authentication error" : "Error d'autenticació",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Si us plau, proporcioneu una contrasenya d'administrador de recuperació; en cas contrari, es perdran totes les dades.",
     "Wrong admin recovery password. Please check the password and try again." : "La contrasenya d'administrador de recuperació és incorrecta. Si us plau, comproveu-la i torneu-ho a provar.",
-    "Backend does not support password change, but the user's encryption key was updated." : "El rerefons no admet el canvi de contrasenya, però s'ha actualitzat la clau de xifratge de l'usuari.",
     "Administrator documentation" : "Documentació d'administrador",
     "User documentation" : "Documentació per a usuaris",
     "Nextcloud help overview" : "Informació general d'ajuda de Nextcloud",
@@ -71,9 +68,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Si heu rebut aquest correu electrònic, sembla que la configuració del correu electrònic és correcta.",
     "Email could not be sent. Check your mail server log" : "No s'ha pogut enviar el correu electrònic. Comproveu el registre del servidor de correu",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hi ha hagut un problema mentre s'enviava el correu electrònic. Reviseu els paràmetres. (Error: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Heu d'establir el correu electrònic d'usuari abans de poder enviar correus de prova. Aneu a %s per fer-ho.",
-    "Users" : "Usuaris",
-    "Invalid user" : "Usuari no vàlid",
+    "Invalid account" : "Compte invàlid",
     "Invalid mail address" : "Adreça de correu electrònic no vàlida",
     "Settings saved" : "S'han desat els paràmetres",
     "Unable to change full name" : "No s'ha pogut canviar el nom complet",
@@ -99,14 +94,13 @@ OC.L10N.register(
     "Welcome aboard" : "Us donem la benvinguda",
     "Welcome aboard %s" : "Us donem la benvinguda, %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Benvingut al compte %s, podeu afegir, protegir i compartir les vostres dades.",
-    "Your username is: %s" : "El vostre nom d'usuari és: %s",
     "Set your password" : "Establiu la vostra contrasenya",
     "Go to %s" : "Ves a %s",
     "Install Client" : "Instal·la el Client",
-    "Logged in user must be a subadmin" : "L’usuari que ha iniciat la sessió ha de ser un subadministrador",
-    "Settings" : "Paràmetres",
+    "Apps" : "Aplicacions",
     "Personal" : "Personal",
     "Administration" : "Administració",
+    "Users" : "Usuaris",
     "Additional settings" : "Paràmetres addicionals",
     "Artificial Intelligence" : "Intel·ligència artificial",
     "Administration privileges" : "Privilegis d'administració",
@@ -127,9 +121,6 @@ OC.L10N.register(
     "Your remote address could not be determined." : "No s'ha pogut determinar la teva adreça remota.",
     "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "La vostra adreça remota s'ha identificat com a \"%s\" i en aquests moments s'està limitant per força bruta, cosa que ralenteix el rendiment de diverses sol·licituds. Si l'adreça remota no és la vostra, això pot ser una indicació que un servidor intermediari no està configurat correctament.",
     "Your remote address \"%s\" is not brute-force throttled." : "La vostra adreça remota \"%s\" no està limitada per força bruta.",
-    "Old user imported certificates" : "Certificats importats d'usuari antic",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Hi ha un treball en segon pla pendent que de comprovar els certificats SSL importats per l'usuari. Comproveu-ho més tard.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hi ha alguns certificats SSL importats per l'usuari que ja no s'utilitzen amb Nextcloud 21. Es poden importar en la línia d'ordres a través de l'ordre «occ security:certificates:import». A continuació se'n mostren els camins dins del directori de dades.",
     "Database missing columns" : "Falten columnes a la base de dades",
     "Missing optional column \"%s\" in table \"%s\"." : "Falta la columna opcional \"%s\" a la taula \"%s\".",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Falten algunes columnes opcionals en la base de dades. Com que afegir columnes a taules grans pot tardar una estona i són opcionals, no s'han afegit automàticament. Podeu executar «occ db:add-missing-columns» per a afegir les columnes que falten manualment amb la instància en funcionament. Després d'afegir les columnes, és possible que millori el temps de resposta o la usabilitat d'algunes característiques.",
@@ -141,6 +132,7 @@ OC.L10N.register(
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Falten algunes claus principals en la base de dades. Com que afegir les claus principals a taules grans pot tardar una estona, no s'han afegit automàticament. Podeu executar «occ db:add-missing-primary-keys» per a afegir les claus principals que falten manualment amb la instància en funcionament.",
     "Database pending bigint migrations" : "Base de dades pendent de migracions bigint",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Algunes columnes de la base de dades no tenen una conversió a big int. A causa del fet que canviar els tipus de columnes a les taules grans podria trigar un temps, no es van canviar automàticament. Si executeu \"occ db:convert-filecache-bigint\", aquests canvis pendents es podrien aplicar manualment. Aquesta operació s'ha de fer mentre la instància està fora de línia.",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Aquesta instància s'està executant en mode de depuració. Habiliteu-ho només per a desenvolupament local i no en entorns de producció.",
     "Default phone region" : "Regió del telèfon per defecte",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "La vostra instal·lació no té definida cap regió de telèfon per defecte. Això és necessari per validar els números de telèfon als paràmetres del perfil sense un codi de país. Per permetre números sense codi de país, afegiu \"default_phone_region\" amb el codi ISO 3166-1 respectiu de la regió al vostre fitxer de configuració.",
     "Email test" : "Prova de correu electrònic",
@@ -257,7 +249,6 @@ OC.L10N.register(
     "Deleted disclaimer text" : "S'ha suprimit el text d'exempció de responsabilitat",
     "Could not set disclaimer text" : "No s'ha pogut establir el text d'exempció de responsabilitat",
     "Two-Factor Authentication" : "Autenticació de doble factor",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L’autenticació de doble factor pot ser forçada per a tots els usuaris i grups específics. Si no tenen un proveïdor de doble factor configurat, no podran accedir en el sistema.",
     "Enforce two-factor authentication" : "Força l'autenticació de doble factor",
     "Limit to groups" : "Limita per grups",
     "Enforcement of two-factor authentication can be set for certain groups only." : "L’obligació d'autenticació de doble factor es pot definir només per a certs grups.",
@@ -265,7 +256,6 @@ OC.L10N.register(
     "Enforced groups" : "Grups forçats",
     "Two-factor authentication is not enforced for members of the following groups." : "L'autenticació de doble factor no està obligada per als membres dels següents grups.",
     "Excluded groups" : "Grups exclosos",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quan es seleccionen/exclouen grups, es fa servir la lògica següent per determinar si un usuari té 2FA (Autenticació de 2 Factors) forçosa: si no hi ha grups seleccionats, 2FA està habilitat per a tothom, a excepció de membres dels grups exclosos. Si els grups estan seleccionats, 2FA està activada per a tots els membres d'aquests. Si un usuari està tant en un grup seleccionat com exclòs, els seleccionats tenen prioritat i 2FA s'imposa.",
     "Save changes" : "Desa els canvis",
     "All" : "Tots",
     "Limit app usage to groups" : "Limita l’ús de l’aplicació als grups",
@@ -327,7 +317,7 @@ OC.L10N.register(
     "Error while creating device token" : "S'ha produït un error mentre es creava el testimoni del dispositiu",
     "New app password" : "Nova contrasenya de l'aplicació",
     "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Utilitzeu les credencials següents per configurar la vostra aplicació o dispositiu. Per motius de seguretat, aquesta contrasenya només es mostrarà una vegada.",
-    "Username" : "Nom d'usuari",
+    "Login" : "Inici de sessió",
     "Password" : "Contrasenya",
     "Show QR code for mobile apps" : "Mostra el codi QR per aplicacions mòbils",
     "App password copied!" : "S'ha copiat la contrasenya de l'aplicació!",
@@ -341,16 +331,12 @@ OC.L10N.register(
     "Last job ran {relativeTime}." : "L'última tasca es va executar {relativeTime}.",
     "Background job did not run yet!" : "La tasca en segon pla encara no s'ha executat!",
     "AJAX" : "AJAX",
-    "Execute one task with each page loaded. Use case: Single user instance." : "Executeu una tasca amb cada pàgina carregada. Cas d'ús: instància d'un sol usuari.",
     "Webcron" : "Webcron",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php està registrat en un servei webcron per cridar a cron.php cada 5 minuts per HTTP. Cas d'ús: instància molt petita (1-5 usuaris segons l'ús).",
     "Cron (Recommended)" : "Cron (recomanat)",
     "Use system cron service to call the cron.php file every 5 minutes." : "Utilitza el servei cron del sistema per cridar el fitxer cron.php cada 5 minuts.",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "El cron.php l'ha d'executar l'usuari del sistema \"{user}\".",
     "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "L'extensió PHP POSIX és necessària. Consulteu la {linkstart}documentació de PHP{linkend} per obtenir més detalls.",
     "Unable to update background job mode" : "No s'ha pogut actualitzar el mode de tasca en segon pla",
     "Profile" : "Perfil",
-    "Enable or disable profile by default for new users." : "Habilitar o deshabilitar el perfil per defecte per als usuaris nous.",
     "Enable" : "Activa",
     "Unable to update profile default setting" : "No s'ha pogut actualitzar els paràmetres predeterminats del perfil",
     "Server-side encryption" : "Xifratge en el servidor",
@@ -367,7 +353,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Heu de migrar les claus de xifratge del xifratge anterior (ownCloud .= 8.0) al nou. Habiliteu el \"Mòdul de xifratge peredeterminat\" i executeu {command}",
     "Unable to update server side encryption config" : "No es pot actualitzar la configuració del xifratge de la banda del servidor",
     "Please confirm the group removal" : "Confirmeu l'eliminació del grup",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Esteu a punt de suprimir el grup \"{group}\". Els usuaris NO s'eliminaran.",
     "Cancel" : "Cancel·la",
     "Confirm" : "Confirma",
     "Submit" : "Envia",
@@ -398,12 +383,13 @@ OC.L10N.register(
     "You are using <strong>{usage}</strong>" : "Esteu utilitzant <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Esteu utilitzant <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "El vostre nom complet",
-    "Email options" : "Opcions de correu electrònic",
+    "Back" : "Torna",
+    "This address is not confirmed" : "Aquesta adreça no està confirmada",
     "Primary email for password reset and notifications" : "Adreça de correu electrònic principal per a restablir la contrasenya i per a les notificacions",
+    "Email options" : "Opcions de correu electrònic",
     "Remove primary email" : "Treu l'adreça de correu electrònic principal",
     "Delete email" : "Treu l'adreça de correu electrònic",
     "Unset as primary email" : "Desactivat com a correu electrònic principal",
-    "This address is not confirmed" : "Aquesta adreça no està confirmada",
     "Set as primary email" : "Estableix com a correu electrònic principal",
     "Additional email address {index}" : "Adreça de correu electrònic addicional {index}",
     "Unable to delete primary email address" : "No es pot suprimir l'adreça de correu electrònic principal",
@@ -425,7 +411,6 @@ OC.L10N.register(
     "Your organisation" : "La vostra organització",
     "Your phone number" : "El vostre número de telèfon",
     "Edit your Profile visibility" : "Edició de la visibilitat del vostre perfil",
-    "Enable Profile" : "Habilita el perfil",
     "Unable to update profile enabled state" : "No es pot actualitzar l'estat d'habilitació del perfil",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "El paràmetre més restrictiu de visibilitat o abast es respecta al vostre perfil. Per exemple, si la visibilitat s'estableix a \"Mostra a tothom\" i l'abast s'estableix a \"Privat\", es respectarà \"Privat\".",
     "Unable to update visibility of {displayId}" : "No es pot actualitzar la visibilitat de {displayId}",
@@ -443,9 +428,6 @@ OC.L10N.register(
     "Change" : "Canvia",
     "Delete" : "Suprimeix",
     "Reshare" : "Tornar a compartir",
-    "No users" : "Cap usuari",
-    "Loading users …" : "S'estan carregant usuaris …",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Llista d'usuaris. Aquesta llista no es presenta completament per motius de rendiment. Els usuaris es mostraran mentre navegueu per la llista.",
     "Default language" : "Llengua per defecte",
     "Common languages" : "Llengües freqüents",
     "Other languages" : "Altres llengües",
@@ -470,36 +452,31 @@ OC.L10N.register(
     "Username will be autogenerated" : "El nom d'usuari es generarà automàticament",
     "Username (required)" : "Nom d'usuari (obligatori)",
     "Total rows summary" : "Resum de totes les files",
+    "Loading users …" : "S'estan carregant usuaris …",
     "Scroll to load more rows" : "Desplaceu-vos per carregar més files",
     "_{userCount} user …_::_{userCount} users …_" : ["{userCount} usuari …","{userCount} usuaris …"],
     "_{userCount} user_::_{userCount} users_" : ["{userCount} usuari","{userCount} usuaris"],
     "Avatar" : "Avatar",
+    "Username" : "Nom d'usuari",
     "Group admin for" : "Administrador de grup per",
     "User backend" : "Rerefons d'usuari",
     "Storage location" : "Ubicació de l'emmagatzematge",
     "Last login" : "Darrer inici de sessió",
     "User actions" : "Accions de l'usuari",
     "Password or insufficient permissions message" : "Contrasenya o missatge de permisos insuficients",
-    "Loading user …" : "S'està carregant l'usuari …",
     "Change display name" : "Canvia el nom de visualització",
     "Set new password" : "Estableix una contrasenya nova",
-    "You do not have permissions to see the details of this user" : "No teniu els permisos necessaris per veure els detalls d'aquest usuari",
     "Set new email address" : "Estableix una nova adreça de correu electrònic",
     "Add user to group" : "Afegeix l'usuari al grup",
-    "Set user as admin for" : "Posa l'usuari com a administrador per",
-    "Select user quota" : "Selecciona la quota d'usuari",
     "Set the language" : "Estableix la llengua",
     "{size} used" : "{size} en ús",
-    "Delete user" : "Suprimeix l'usuari",
+    "Delete account" : "Suprimeix el compte",
     "Wipe all devices" : "Esborra tots els dispositius",
-    "Disable user" : "Inhabilita l'usuari",
-    "Enable user" : "Habilita l'usuari",
     "Resend welcome email" : "Torna a enviar el correu electrònic de benvinguda",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "En cas de perdre un dispositiu o sortir de l’organització, es pot esborrar de forma remota les dades del Nextcloud de tots els dispositius associats a {userid}. Només funciona si els dispositius estan connectats a Internet.",
     "Remote wipe of devices" : "Neteja remota de dispositius",
     "Wipe {userid}'s devices" : "Neteja els dispositius de {userid}",
     "Wiped {userid}'s devices" : "S'han esborrat els dispositius de {userid}",
-    "Failed to update user manager" : "No s'ha pogut actualitzar el gestor d'usuaris",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Suprimir completament el compte de {userid} inclosos tots els seus fitxers personals, dades d'aplicacions, etc.",
     "Account deletion" : "Supressió del compte",
     "Delete {userid}'s account" : "Suprimir el compte de {userid}",
@@ -507,17 +484,13 @@ OC.L10N.register(
     "Password was successfully changed" : "La contrasenya s'ha canviat correctament",
     "Email was successfully changed" : "El correu electrònic s'ha canviat correctament",
     "Welcome mail sent!" : "S'ha enviat el correu electrònic de benvinguda!",
-    "Toggle user actions menu" : "Commuta el menú d'accions d'usuari",
     "Done" : "Fet",
     "Edit" : "Edició",
-    "User management settings" : "Paràmetres de gestió d'usuaris",
     "Visibility" : "Visibilitat",
     "Show language" : "Mostra la llengua",
-    "Show user backend" : "Mostra el rerefons d'usuari",
     "Show storage path" : "Mostra el camí del magatzem",
     "Show last login" : "Mostra el darrer inici de sessió",
     "Send email" : "Envia el correu electrònic",
-    "Send welcome email to new users" : "Envieu un correu electrònic de benvinguda als nous usuaris",
     "Defaults" : "Valors per defecte",
     "Default quota" : "Quota per defecte",
     "Select default quota" : "Seleccioneu la quota per defecte",
@@ -539,15 +512,13 @@ OC.L10N.register(
     "{license}-licensed" : "sota la llicència - {license}",
     "Changelog" : "Registre de canvis",
     "by {author}\n{license}" : "{author}\n{license}",
-    "User management" : "Gestió d'usuaris",
-    "Active users" : "Usuaris actius",
+    "New account" : "Nou compte",
     "Admins" : "Administradors",
     "Disabled users" : "Usuaris inhabilitats",
     "Creating group …" : "S'està creant un grup …",
     "Create group" : "Crear grup",
     "Group name" : "Nom del grup",
     "Please enter a valid group name" : "Introduïu un nom de grup vàlid",
-    "User group: {group}" : "Grup d'usuaris: {group}",
     "Failed to create group" : "No s'ha pogut crear el grup",
     "Sending…" : "S'està enviant…",
     "Email sent" : "S'ha enviat el correu electrònic",
@@ -566,8 +537,6 @@ OC.L10N.register(
     "Profile visibility" : "Visibilitat del perfil",
     "Locale" : "Configuració regional",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "No disponible, ja que aquesta propietat és necessària per a les funcions bàsiques, com ara compartir fitxers i invitacions al calendari",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "No està disponible perquè la federació s'ha inhabilitat per al vostre compte, poseu-vos en contacte amb l'administrador del sistema si teniu cap pregunta",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "No està disponible perquè no es permet la publicació de dades específiques de l'usuari al servidor de cerca, poseu-vos en contacte amb l'administrador del sistema si teniu cap pregunta",
     "Your apps" : "Les vostres aplicacions",
     "Active apps" : "Aplicacions actives",
     "Disabled apps" : "Aplicacions inhabilitades",
@@ -576,13 +545,13 @@ OC.L10N.register(
     "Featured apps" : "Aplicacions destacades",
     "Supported apps" : "Aplicacions compatibles",
     "Show to everyone" : "Mostra a tothom",
-    "Show to logged in users only" : "Mostra només als usuaris connectats",
     "Hide" : "Amaga",
     "Download and enable" : "Baixa i activa",
     "Allow untested app" : "Permet l'aplicació no provada",
     "The app will be downloaded from the App Store" : "L'aplicació es baixarà des del Magatzem d'aplicacions",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Aquesta aplicació no està marcada com a compatible amb la vostra versió de Nextcloud. Si continueu, encara podreu instal·lar l’aplicació. Tingueu en compte que pot ser que l’aplicació no funcioni correctament.",
     "Never" : "Mai",
+    "Active users" : "Usuaris actius",
     "An error occurred during the request. Unable to proceed." : "S'ha produït un error durant la sol·licitud. No es pot continuar.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "L'aplicació s'ha habilitat però ha de ser actualitzada. Sereu redirigits a la pàgina d’actualització d'aquí 5 segons.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Error: aquesta aplicació no es pot habilitar perquè fa que el servidor sigui inestable",
@@ -593,13 +562,12 @@ OC.L10N.register(
     "Error while updating device token name" : "S'ha produït un error mentre s'actualitzava el nom del testimoni del dispositiu",
     "Error while updating device token scope" : "S'ha produït un error mentre s'actualitzava l’abast de testimonis del dispositiu",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Hi havia massa sol·licituds de la seva xarxa. Reintentar més tard o contactar amb l'administrador si això és un error.",
+    "Account documentation" : "Documentació del compte",
+    "Administration documentation" : "Documentació administrativa",
     "Documentation" : "Documentació",
     "Forum" : "Fòrum",
     "Nextcloud help resources" : "Recursos d'ajuda de Nextcloud",
-    "Account documentation" : "Documentació del compte",
-    "Administration documentation" : "Documentació administrativa",
     "General documentation" : "Documentació general",
-    "Login" : "Inici de sessió",
     "None/STARTTLS" : "Cap/STARTTLS",
     "SSL" : "SSL",
     "Open documentation" : "Obre la documentació",
@@ -613,7 +581,6 @@ OC.L10N.register(
     "Authentication" : "Autenticació",
     "Authentication required" : "Cal autenticació",
     "Credentials" : "Credencials",
-    "SMTP Username" : "Nom d'usuari SMTP",
     "SMTP Password" : "Contrasenya SMTP",
     "Save" : "Desa",
     "Test and verify email settings" : "Prova i verifica els paràmetres del correu electrònic",
@@ -634,6 +601,9 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Aquest llançament de la comunitat de Nextcloud no és compatible i les notificacions instantànies no estan disponibles.",
     "Use a second factor besides your password to increase security for your account." : "Feu servir un segon factor a més de la vostra contrasenya per augmentar la seguretat del vostre compte.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si utilitzeu aplicacions de tercers per a connectar-vos a Nextcloud, assegureu-vos de crear i configurar una contrasenya d'aplicació per a cadascuna abans d'habilitar l'autenticació de segon factor.",
+    "No user supplied" : "No heu proporcionat cap usuari",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Si us plau, proporcioneu una contrasenya d'administrador de recuperació; en cas contrari, es perdran totes les dades.",
+    "Backend does not support password change, but the user's encryption key was updated." : "El rerefons no admet el canvi de contrasenya, però s'ha actualitzat la clau de xifratge de l'usuari.",
     "installing and updating apps via the App Store or Federated Cloud Sharing" : "instal·lació i actualització d'aplicacions a través del magatzem d'aplicacions o el Núvol Federat",
     "Federated Cloud Sharing" : "Compartició de Núvols Federats",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL està fent servir una versió %1$s antiquada (%2$s). Si us plau, actualitzeu el vostre sistema operatiu o característiques com %3$s no funcionaran amb fiabilitat.",
@@ -646,7 +616,15 @@ OC.L10N.register(
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "Gairebé s'ha excedit el nombre màxim de claus d'OPcache. Per assegurar-vos que tots els scripts es puguin mantenir a la memòria cau, us recomanem que s'apliqui <code>opcache.max.accelerated.files</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "La memòria intermèdia d'OPcache està gairebé plena. Per garantir que tots els scripts es puguin mantenir a la memòria cau, us recomanem que s'apliqui <code>opcache.memory.consumption</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "La memòria cau de cadenes internades OPcache està gairebé plena. Per assegurar-vos que les cadenes que es repeteixen es poden emmagatzemar a la memòria cau de manera efectiva, es recomana que s'apliqui <code>opcache.interned.strings.buffer</code> a la configuració de PHP amb un valor superior a <code>%s</code>.",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "Heu d'establir el correu electrònic d'usuari abans de poder enviar correus de prova. Aneu a %s per fer-ho.",
+    "Invalid user" : "Usuari no vàlid",
+    "Your username is: %s" : "El vostre nom d'usuari és: %s",
+    "Logged in user must be a subadmin" : "L’usuari que ha iniciat la sessió ha de ser un subadministrador",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Hi ha un treball en segon pla pendent que de comprovar els certificats SSL importats per l'usuari. Comproveu-ho més tard.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hi ha alguns certificats SSL importats per l'usuari que ja no s'utilitzen amb Nextcloud 21. Es poden importar en la línia d'ordres a través de l'ordre «occ security:certificates:import». A continuació se'n mostren els camins dins del directori de dades.",
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "S'han trobat UUID no vàlids d'usuaris o grups LDAP. Reviseu els paràmetres de l'\"Anul·lació de detecció d'UUID\" a la part Experta de la configuració LDAP i utilitzeu \"occ ldap:update-uuid\" per actualitzar-los.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "L’autenticació de doble factor pot ser forçada per a tots els usuaris i grups específics. Si no tenen un proveïdor de doble factor configurat, no podran accedir en el sistema.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Quan es seleccionen/exclouen grups, es fa servir la lògica següent per determinar si un usuari té 2FA (Autenticació de 2 Factors) forçosa: si no hi ha grups seleccionats, 2FA està habilitat per a tothom, a excepció de membres dels grups exclosos. Si els grups estan seleccionats, 2FA està activada per a tots els membres d'aquests. Si un usuari està tant en un grup seleccionat com exclòs, els seleccionats tenen prioritat i 2FA s'imposa.",
     "Enable all" : "Habilita tot",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
@@ -661,17 +639,29 @@ OC.L10N.register(
     "For security reasons this password will only be shown once." : "Per raons de seguretat aquesta contrasenya només es mostrarà una vegada.",
     "Copied!" : "S'ha copiat!",
     "Copy" : "Copia",
+    "Execute one task with each page loaded. Use case: Single user instance." : "Executeu una tasca amb cada pàgina carregada. Cas d'ús: instància d'un sol usuari.",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php està registrat en un servei webcron per cridar a cron.php cada 5 minuts per HTTP. Cas d'ús: instància molt petita (1-5 usuaris segons l'ús).",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Per executar això es necessita l'extensió POSIX de PHP. Per més detalls, vegeu {linkstart}documentació de PHP{linkend}.",
     "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Utilitzeu el servei cron del sistema per a cridar el fitxer cron.php cada 5 minuts. Recomanat per a totes les instàncies.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "El cron.php l'ha d'executar l'usuari del sistema \"{user}\".",
+    "Enable or disable profile by default for new users." : "Habilitar o deshabilitar el perfil per defecte per als usuaris nous.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Esteu a punt de suprimir el grup {group}. Els usuaris NO seran suprimits.",
     "Please confirm the group removal " : "Confirmeu la supressió del grup ",
     "Choose profile picture from files" : "Trieu una imatge de perfil als fitxers",
     "png or jpg, max. 20 MB" : "png o jpg, màx. 20 MB",
     "Your email address" : "El vostre correu electrònic",
     "Your location" : "La vostra localització",
+    "Enable Profile" : "Habilita el perfil",
     "Your Twitter handle" : "El teu identificador de Twitter",
+    "You do not have permissions to see the details of this user" : "No teniu els permisos necessaris per veure els detalls d'aquest usuari",
     "Add new password" : "Afegeix una nova contrasenya",
     "Add new email address" : "Afegeix una nova adreça de correu electrònic",
+    "Set user as admin for" : "Posa l'usuari com a administrador per",
+    "Select user quota" : "Selecciona la quota d'usuari",
+    "Toggle user actions menu" : "Commuta el menú d'accions d'usuari",
+    "Delete user" : "Suprimeix l'usuari",
+    "Disable user" : "Inhabilita l'usuari",
+    "Enable user" : "Habilita l'usuari",
     "Edit User" : "Edita Usuari",
     "Will be autogenerated" : "Serà auto-generat",
     "Add a new user" : "Afegeix un nou usuari",
@@ -680,10 +670,15 @@ OC.L10N.register(
     "Add group" : "Afegeix un grup",
     "Default quota:" : "Quota per defecte:",
     "Show Languages" : "Mostra els idiomes",
+    "Show user backend" : "Mostra el rerefons d'usuari",
     "Send email to new user" : "Enviar correu electrònic al nou usuari",
     "Not saved" : "No s'ha desat",
     "Twitter" : "Twitter",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "No està disponible perquè la federació s'ha inhabilitat per al vostre compte, poseu-vos en contacte amb l'administrador del sistema si teniu cap pregunta",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "No està disponible perquè no es permet la publicació de dades específiques de l'usuari al servidor de cerca, poseu-vos en contacte amb l'administrador del sistema si teniu cap pregunta",
+    "Show to logged in users only" : "Mostra només als usuaris connectats",
     "Enable untested app" : "Habilita aplicacions no provades",
+    "SMTP Username" : "Nom d'usuari SMTP",
     "Expire after" : "Caduca després",
     "day(s)" : "dies",
     "Exclude groups from password requirements:" : "Excloure grups dels requisits de contrasenya:",
@@ -696,6 +691,16 @@ OC.L10N.register(
     "Select manager" : "Seleccioneu el gestor",
     "User's table" : "Taula d'usuaris",
     "Select user manager" : "Seleccioneu el gestor d'usuaris",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "En aquesta instància li falten alguns mòduls PHP recomanats. Per millorar el rendiment i la compatibilitat, és molt recomanable instal·lar-los: %s."
+    "Old user imported certificates" : "Certificats importats d'usuari antic",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "En aquesta instància li falten alguns mòduls PHP recomanats. Per millorar el rendiment i la compatibilitat, és molt recomanable instal·lar-los: %s.",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Esteu a punt de suprimir el grup \"{group}\". Els usuaris NO s'eliminaran.",
+    "No users" : "Cap usuari",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Llista d'usuaris. Aquesta llista no es presenta completament per motius de rendiment. Els usuaris es mostraran mentre navegueu per la llista.",
+    "Loading user …" : "S'està carregant l'usuari …",
+    "Failed to update user manager" : "No s'ha pogut actualitzar el gestor d'usuaris",
+    "User management settings" : "Paràmetres de gestió d'usuaris",
+    "Send welcome email to new users" : "Envieu un correu electrònic de benvinguda als nous usuaris",
+    "User management" : "Gestió d'usuaris",
+    "User group: {group}" : "Grup d'usuaris: {group}"
 },
 "nplurals=2; plural=(n != 1);");
