@@ -42,15 +42,11 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Defora forviŝado komenciĝis ĉe %1$s",
     "Remote wipe has finished on %1$s" : "Defora forviŝado finis ĉe %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Via <strong>pasvorto</strong> aŭ <strong>retpoŝtadreso</strong> estis modifita",
-    "Apps" : "Aplikaĵoj",
+    "Settings" : "Agordoj",
     "Wrong password" : "Neĝusta pasvorto",
     "Saved" : "Konservita",
-    "No user supplied" : "Neniu uzanto provizita",
     "Authentication error" : "Aŭtentiga eraro",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Bonvolu doni reekhava pasvorton de administranto; aliokaze, ĉiuj uzanto-datumoj perdiĝos.",
     "Wrong admin recovery password. Please check the password and try again." : "Neĝusta reekhava pasvorto de administranto. Bv. kontroli la pasvorton kaj reprovi.",
-    "Federated Cloud Sharing" : "Federnuba kunhavado",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL uzas neĝisdatan version %1$s (%2$s). Bv. ĝisdatigi vian operaciumon aŭ programon, aŭ trajtoj kiel %3$s ne plu funkcios fidinde.",
     "Administrator documentation" : "Dokumentaro por administranto",
     "User documentation" : "Dokumentaro por uzanto",
     "Invalid SMTP password." : "Nevalida SMTP-pasvorto.",
@@ -59,8 +55,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Se vi ricevis tiun ĉi retmesaĝon, retpoŝta agordo estas ĝusta, espereble.",
     "Email could not be sent. Check your mail server log" : "Retmesaĝo ne eblis esti sendita. Kontrolu vian servil-protokolon.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Problem dum sendado de la retmesaĝo. Bv. ekzameni viajn agordojn. (Eraro: %s)",
-    "Users" : "Uzantoj",
-    "Invalid user" : "Nevalida uzanto",
     "Invalid mail address" : "Nevalida retpoŝtadreso",
     "Settings saved" : "Agordoj konservitaj",
     "Unable to change full name" : "Ne eblis ŝanĝi la plenan nomon",
@@ -82,14 +76,13 @@ OC.L10N.register(
     "Welcome aboard" : "Bonvenon",
     "Welcome aboard %s" : "Bonvenon %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Bonvenon ĉe via konto %s; vi povas aldoni, protekti kaj kunhavigi viajn datumojn.",
-    "Your username is: %s" : "Via uzantnomo estas: %s",
     "Set your password" : "Agordi vian pasvorton",
     "Go to %s" : "Iri al %s",
     "Install Client" : "Instali kienton",
-    "Logged in user must be a subadmin" : "La konektita uzanto estu subadministranto.",
-    "Settings" : "Agordoj",
+    "Apps" : "Aplikaĵoj",
     "Personal" : "Persona",
     "Administration" : "Administrado",
+    "Users" : "Uzantoj",
     "Additional settings" : "Plia agordo",
     "Groupware" : "Grupa kunlaborado",
     "Overview" : "Superrigardo",
@@ -103,7 +96,11 @@ OC.L10N.register(
     "Background jobs" : "Fonaj taskoj",
     "Unlimited" : "Senlima",
     "Verifying" : "Kontrolado",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankas kelkaj malnepraj kolumnoj en la datumbazo. Pro la ebla malrapideco aldoni kolumnojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-columns“, dum la servilo estas funkcianta. Kiam la kolumnoj aldoniĝos, la uzo de tiuj tabelojn estos kutime pli rapida.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankas kelkaj indeksoj en la datumbazo. Pro la ebla malrapideco aldoni indeksojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-indices“, dum la servilo estas funkcianta. Kiam la indeksoj ekzistos, la uzo de tiuj tabelojn estos kutime pli rapida.",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Mankas kelkaj ĉefŝlosiloj en la datumbazo. Pro la ebla malrapideco aldoni ĉefŝlosilojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-primary-keys“, dum la servilo estas funkcianta.",
     "Disabled" : "Malkapabligita",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La PHP-funkcio „set_time_limit“ (angle „difini tempolimo“) ne disponeblas. Pro tio, skriptoj povus halti mezvoje, eble difektante vian instalaĵon. Ebligi tiun funkcion estas tre rekomendita.",
     "Supported" : "Subtenite",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Via PHP ne subtenas la bibliotekon FreeType, kio provokos misfunkcion de profilbildo kaj de la agorda fasado.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ŝajnas ne esti taŭge agordita por informpeti sistemajn medivariablojn. La testado kun getenv(\"PATH\") revenigas nur malplenan respondon.",
@@ -129,7 +126,6 @@ OC.L10N.register(
     "Enforcement of two-factor authentication can be set for certain groups only." : "Devigo de dufaza aŭtentigo povas ekzisti nur por certaj grupoj.",
     "Enforced groups" : "Devigataj grupoj",
     "Excluded groups" : "Nedevigataj grupoj",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Kiam grupoj estas aŭ elektitaj aŭ nedevigataj, ili sekvas la jenan logikon por decidi, ĉu uzanto estas devigata uzi dufazan aŭtentigon (2FA). Se neniu grupo estas elektita, 2FA estas devigata por ĉiuj escepte membrojn de la nedevigataj grupoj. Se uzanto estas samtempe en elektita kaj nedevigata grupo, la elektita ekprioritatas kaj 2FA estas devigata.",
     "Save changes" : "Konservi modifojn",
     "All" : "Ĉio",
     "Limit app usage to groups" : "Limigi aplikaĵan uzon al grupoj",
@@ -163,37 +159,18 @@ OC.L10N.register(
     "Rename" : "Alinomi",
     "Revoke" : "Senvalidigi",
     "Wipe device" : "Forviŝi aparaton",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome por Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Sinkroniga kliento — {os}",
     "This session" : "Tiu ĉi seanco",
     "Device" : "Aparato",
     "Last activity" : "Lasta aktivaĵo",
     "Devices & sessions" : "Aparatoj kaj seancoj",
     "Web, desktop and mobile clients currently logged in to your account." : "Reta, surtabla kaj portebla klientoj nun konektitaj al via konto.",
-    "Do you really want to wipe your data from this device?" : "Ĉu vi vere volas forviŝi viajn datumojn el tiu ĉi aparato?",
-    "Confirm wipe" : "Konfirmi forviŝadon",
-    "Error while creating device token" : "Eraro dum kreo de aparata ĵetono",
-    "Error while updating device token scope" : "Eraro dum ĝisdatigo de la amplekso de la aparataj ĵetonoj",
-    "Error while updating device token name" : "Eraro dum ĝisdatigo de la nomo de la aparataj ĵetonoj",
-    "Error while deleting the token" : "Eraro dum forigado de la ĵetono",
-    "Error while wiping the device with the token" : "Eraro dum forviŝado de la aparato kun la ĵetono",
     "App name" : "Aplikaĵa nomo",
     "Create new app password" : "Krei novan aplikaĵan pasvorton",
-    "Use the credentials below to configure your app or device." : "Uzu la ĉi-subajn akreditilojn por agordi vian aplikaĵon aŭ aparaton.",
-    "For security reasons this password will only be shown once." : "Pro sekurigaj kialoj, tiu ĉi pasvorto montriĝos nur unufoje.",
-    "Username" : "Uzantonomo",
+    "Error while creating device token" : "Eraro dum kreo de aparata ĵetono",
+    "Login" : "Ensaluti",
     "Password" : "Pasvorto",
-    "Done" : "Farita",
     "Show QR code for mobile apps" : "Montri rapidrespondan (QR) kodon por porteblaj aplikaĵoj",
-    "Copied!" : "Kopiita!",
-    "Copy" : "Kopii",
     "Could not copy app password. Please copy it manually." : "Ne eblis kopii la aplikaĵan pasvorton. Bv. kopii ĝin permane.",
     "Use system cron service to call the cron.php file every 5 minutes." : "Uzu la sisteman „cron“-servon por voki cron.php ĉiujn 5 minutojn.",
     "Enable" : "Ŝalti",
@@ -218,6 +195,7 @@ OC.L10N.register(
     "Details" : "Detaloj",
     "You are a member of the following groups:" : "Vi estas membro el la jenaj grupoj:",
     "No email address set" : "Neniu retpoŝta adreso agordita",
+    "Languages" : "Lingvoj",
     "Help translate" : "Helpu traduki",
     "No language set" : "Neniu lingvo agordita",
     "Your phone number" : "Via telefonnumero",
@@ -234,18 +212,14 @@ OC.L10N.register(
     "Quota" : "Kvoto",
     "Language" : "Lingvo",
     "Avatar" : "Avataro",
+    "Username" : "Uzantonomo",
     "Group admin for" : "Grupadministranto por",
     "User backend" : "Uzanto-loko",
     "Storage location" : "Konserveja loko",
     "Last login" : "Lasta ensaluto",
-    "You do not have permissions to see the details of this user" : "Vi ne rajtas vidi detalojn pri tiu ĉu uzanto",
-    "Set user as admin for" : "Agordi uzanton kiel administranto por",
-    "Select user quota" : "Elekti uzant-kvoton",
     "{size} used" : "{size} uzataj",
-    "Delete user" : "Forigi uzanton",
+    "Delete account" : "Forigi konton",
     "Wipe all devices" : "Forviŝi ĉiujn aparaton",
-    "Disable user" : "Malebligi uzanton",
-    "Enable user" : "Ebligi uzanton",
     "Resend welcome email" : "Resendi bonvenan retpoŝtmesaĝon",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Okaze de perdo de aparato aŭ eliro de la organizaĵo, tio povas defore forviŝi la datumojn de Nextcloud el ĉiuj aparatoj ligitaj per {userid}. Nur funkcias, se la aparatoj estas konektitaj  al interreto.",
     "Remote wipe of devices" : "Defora forviŝado de aparatoj",
@@ -254,18 +228,16 @@ OC.L10N.register(
     "Account deletion" : "Forigo de konto",
     "Delete {userid}'s account" : "Forigi konton de {userid}",
     "Welcome mail sent!" : "Bonvena retpoŝtmesaĝo sendita!",
+    "Done" : "Farita",
     "Edit" : "Modifi",
-    "Show user backend" : "Montri uzantolokon",
     "Show storage path" : "Montri vojon al konservejo",
     "Show last login" : "Montri lastan ensaluton",
     "Send email" : "Sendi retpoŝtmesaĝon",
     "Default quota" : "Defaŭlta kvoto",
     "Select default quota" : "Elekti defaŭltan kvoton",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Kiel administranto, vi povas agordi plidetale la kunhavigon. Bv. vidi la dokumentaron pri tio.",
-    "Your apps" : "Viaj aplikaĵoj",
     "{license}-licensed" : "Permesilo: {license}",
     "Changelog" : "Ŝanĝoprotokolo",
-    "Active users" : "Aktivaj uzantoj",
     "Admins" : "Administrantoj",
     "Disabled users" : "Malebligitaj uzantoj",
     "Group name" : "Gruponomo",
@@ -278,6 +250,7 @@ OC.L10N.register(
     "Phone number" : "Telefonnumero",
     "Website" : "Retejo",
     "Locale" : "Lokaĵaro",
+    "Your apps" : "Viaj aplikaĵoj",
     "Active apps" : "Aktivaj aplikaĵoj",
     "Disabled apps" : "Malŝaltitaj aplikaĵoj",
     "Updates" : "Ĝisdatigoj",
@@ -286,10 +259,16 @@ OC.L10N.register(
     "Download and enable" : "Elŝuti kaj ŝalti",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Tiu aplikaĵo ne kongruas kun via Nextcloud-versio. Se vi daŭrigas, vi tamen povos instali ĝin, sed eble tiu aplikaĵo ne funkcios bone.",
     "Never" : "Neniam",
+    "Active users" : "Aktivaj uzantoj",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplikaĵo estis ŝaltita, sed ĝi bezonas ĝisdatiĝi. Vi estos direktita al ĝisdatiga paĝon post 5 sekundoj.",
+    "Do you really want to wipe your data from this device?" : "Ĉu vi vere volas forviŝi viajn datumojn el tiu ĉi aparato?",
+    "Confirm wipe" : "Konfirmi forviŝadon",
+    "Error while wiping the device with the token" : "Eraro dum forviŝado de la aparato kun la ĵetono",
+    "Error while updating device token name" : "Eraro dum ĝisdatigo de la nomo de la aparataj ĵetonoj",
+    "Error while updating device token scope" : "Eraro dum ĝisdatigo de la amplekso de la aparataj ĵetonoj",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Estis tro multaj petoj de via reto. Reprovu poste aŭ kontaktu vian administranton se tio estas eraro.",
     "Documentation" : "Dokumentaro",
     "Forum" : "Forumo",
-    "Login" : "Ensaluti",
     "SSL" : "SSL",
     "Open documentation" : "Malfermi la dokumentaron",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Gravas agordi tiun ĉi servilon por povi sendi retpoŝtmesaĝojn, ekz. por restarigo de pasvorto aŭ sciigoj.",
@@ -302,7 +281,6 @@ OC.L10N.register(
     "Authentication" : "Aŭtentigo",
     "Authentication required" : "Aŭtentiĝo nepras",
     "Credentials" : "Aŭtentigiloj",
-    "SMTP Username" : "SMTP-uzantonomo",
     "SMTP Password" : "SMTP-pasvorto",
     "Save" : "Konservi",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Gravas por sekureco kaj rapideco de via servilo, ke ĉio estu agordita bone. Por helpi vin pri tio, ni faras kelkajn aŭtomatajn testojn. Bv. vidi la dokumentaron por pli da informoj.",
@@ -320,28 +298,51 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "Aboni nian retan bultenon",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tiu elkomunuma eldono de Nextcloud ne estas subtenata, kaj tuj-sciigoj ne disponeblas.",
     "Use a second factor besides your password to increase security for your account." : "Uzu duan fazon krom via pasvorto por plisekurigi vian konton.",
-    "You created app password \"{token}\"" : "Vi kreis aplikaĵan pasvorton „{token}“",
+    "No user supplied" : "Neniu uzanto provizita",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Bonvolu doni reekhava pasvorton de administranto; aliokaze, ĉiuj uzanto-datumoj perdiĝos.",
+    "Federated Cloud Sharing" : "Federnuba kunhavado",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL uzas neĝisdatan version %1$s (%2$s). Bv. ĝisdatigi vian operaciumon aŭ programon, aŭ trajtoj kiel %3$s ne plu funkcios fidinde.",
+    "Invalid user" : "Nevalida uzanto",
+    "Your username is: %s" : "Via uzantnomo estas: %s",
+    "Logged in user must be a subadmin" : "La konektita uzanto estu subadministranto.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Kiam grupoj estas aŭ elektitaj aŭ nedevigataj, ili sekvas la jenan logikon por decidi, ĉu uzanto estas devigata uzi dufazan aŭtentigon (2FA). Se neniu grupo estas elektita, 2FA estas devigata por ĉiuj escepte membrojn de la nedevigataj grupoj. Se uzanto estas samtempe en elektita kaj nedevigata grupo, la elektita ekprioritatas kaj 2FA estas devigata.",
     "Enable all" : "Ŝalti ĉiujn",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Sync client - {os}" : "Sinkroniga kliento — {os}",
+    "Error while deleting the token" : "Eraro dum forigado de la ĵetono",
+    "Use the credentials below to configure your app or device." : "Uzu la ĉi-subajn akreditilojn por agordi vian aplikaĵon aŭ aparaton.",
+    "For security reasons this password will only be shown once." : "Pro sekurigaj kialoj, tiu ĉi pasvorto montriĝos nur unufoje.",
+    "Copied!" : "Kopiita!",
+    "Copy" : "Kopii",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Por ruli iton, vi bezonas la PHP-modulon pri POSIX. Vidu la {linkstart}PHP-dokumentaron{linkend} pro pli da detaloj.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Vi tuj forigos grupon {group}. La uzantoj NE estos forigitaj.",
     "Please confirm the group removal " : "Bv. konfirmi forigadon de la grupo",
     "png or jpg, max. 20 MB" : "png aŭ jpg, maksimume 20 MB",
     "Your email address" : "Via retpoŝta adreso",
+    "You do not have permissions to see the details of this user" : "Vi ne rajtas vidi detalojn pri tiu ĉu uzanto",
+    "Set user as admin for" : "Agordi uzanton kiel administranto por",
+    "Select user quota" : "Elekti uzant-kvoton",
+    "Delete user" : "Forigi uzanton",
+    "Disable user" : "Malebligi uzanton",
+    "Enable user" : "Ebligi uzanton",
     "Will be autogenerated" : "Estos memgenerita",
     "Add a new user" : "Aldoni novan uzanton",
     "No users in here" : "Neniu uzanto ĉi tie",
     "Add group" : "Aldoni grupon",
     "Default quota:" : "Defaŭlta kvoto:",
     "Show Languages" : "Montri lingvojn",
+    "Show user backend" : "Montri uzantolokon",
     "Send email to new user" : "Sendi retmesaĝon al nova uzanto",
     "Not saved" : "Ne konservita",
     "Twitter" : "Twitter",
     "Enable untested app" : "Ŝalti netestitan aplikaĵon",
-    "Plain" : "Plena",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Aŭtentiga metodo",
+    "SMTP Username" : "SMTP-uzantonomo",
     "Set default expiration date" : "Agordi defaŭltan limdaton"
 },
 "nplurals=2; plural=(n != 1);");
