@@ -23,14 +23,11 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Ha iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autienticación de dos-factores ha fallado (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Su <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
-    "Apps" : "Aplicaciones",
+    "Settings" : "Ajustes",
     "Wrong password" : "Contraseña incorrecta",
     "Saved" : "Guardado",
-    "No user supplied" : "No se proporcionó un usuario",
     "Authentication error" : "Error de autenticación",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Favor de proporcionar una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Favor de verificarla e inténtelo de nuevo.",
-    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
     "Administrator documentation" : "Documentación de adminsitrador",
     "User documentation" : "Documentación del usuario",
     "Invalid SMTP password." : "Constraseña SMTP inválida. ",
@@ -39,8 +36,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Si usted ha recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
     "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Favor de verficiar la bitácora de su servidor de correo",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Favor de revisar sus configuraciones (Error: %s)",
-    "Users" : "Ususarios",
-    "Invalid user" : "Usuario inválido",
+    "Invalid account" : "Cuenta inválida",
     "Invalid mail address" : "Dirección de correo inválida",
     "Settings saved" : "Se han guardado las configuraciones ",
     "Unable to change full name" : "No fue posible cambiar el nombre completo",
@@ -61,12 +57,12 @@ OC.L10N.register(
     "Your %s account was created" : "Su %s cuenta ha sido creada",
     "Welcome aboard" : "Bienvenido a bordo",
     "Welcome aboard %s" : "Bienvenido a bordo %s",
-    "Your username is: %s" : "Su nombre de usuario es: %s",
     "Set your password" : "Establezca su contraseña",
     "Go to %s" : "Ir a %s",
     "Install Client" : "Instalar el cliente",
-    "Settings" : "Ajustes",
+    "Apps" : "Aplicaciones",
     "Personal" : "Personal",
+    "Users" : "Ususarios",
     "Additional settings" : "Configuraciones adicionales",
     "Overview" : "Visión general",
     "Basic settings" : "Configuraciones  básicas",
@@ -117,28 +113,16 @@ OC.L10N.register(
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
     "Rename" : "Renombrar",
     "Revoke" : "Revocar",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome para Android",
-    "Sync client - {os}" : "Sync client - {os}",
     "This session" : "Esta sesión",
     "Device" : "Dispositivo",
     "Last activity" : "Última actividad",
     "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en su cuenta. ",
-    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
-    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
     "App name" : "Nombre de la aplicación",
     "Create new app password" : "Crear una nueva contraseña de aplicación",
-    "Use the credentials below to configure your app or device." : "Use las siguientes credenciales para configurar su aplicación o dispositivo. ",
-    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
-    "Username" : "Nombre de usuario",
+    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
+    "Login" : "Inicio de sesión",
     "Password" : "Contraseña",
-    "Done" : "Terminado",
-    "Copied!" : "¡Credenciales!",
-    "Copy" : "Copiar",
     "Profile" : "Perfil",
     "Enable" : "Habilitar",
     "Server-side encryption" : "Encripción del lado del servidor",
@@ -159,6 +143,7 @@ OC.L10N.register(
     "Change password" : "Cambiar contraseña",
     "Picture provided by original account" : "Imagen proporcionadoa por la cuenta original ",
     "Details" : "Detalles",
+    "Back" : "Volver",
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Help translate" : "Ayude a traducir",
     "Your phone number" : "Su número telefónico",
@@ -172,20 +157,20 @@ OC.L10N.register(
     "Quota" : "Cuota",
     "Language" : "Idioma",
     "Avatar" : "Avatar",
+    "Username" : "Nombre de usuario",
     "Group admin for" : "Administrador del grupo para",
     "User backend" : "Backend del usuario",
     "Storage location" : "Úbicación del almacenamiento",
     "Last login" : "Último inicio de sesión",
+    "Delete account" : "Borrar cuenta",
+    "Done" : "Terminado",
     "Edit" : "Editar",
-    "Show user backend" : "Mostrar backend del usuario",
     "Show last login" : "Mostrar último inicio de sesión",
     "Send email" : "Enviar correo electrónico",
     "Default quota" : "Cuota predeterminada",
     "Unnamed device" : "Dispositivo sin nombre",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, usted puede hacer ajustes finos al comportamiento de compartir. Favor de consultar la documentación para más información. ",
-    "Your apps" : "Sus aplicaciones",
     "Changelog" : "Bitácora de cambios",
-    "Active users" : "Usuarios activos",
     "Admins" : "Administradores",
     "Group name" : "Nombre del grupo",
     "Sending…" : "Enviando...",
@@ -196,15 +181,16 @@ OC.L10N.register(
     "Full name" : "Nombre completo",
     "Phone number" : "Número de teléfono",
     "Website" : "Sitio web",
+    "Your apps" : "Sus aplicaciones",
     "Disabled apps" : "Aplicaciones deshabilitadas",
     "Updates" : "Actualizaciones",
     "App bundles" : "Paquetes de aplicacion",
     "Hide" : "Ocultar",
     "Never" : "Nunca",
+    "Active users" : "Usuarios activos",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Usted será redireccionado a la página de actualización en 5 segundos. ",
     "Documentation" : "Documentación",
     "Forum" : "Foro",
-    "Login" : "Inicio de sesión",
     "SSL" : "SSL",
     "Open documentation" : "Abrir documentación",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
@@ -216,7 +202,6 @@ OC.L10N.register(
     "Authentication" : "Autenticación",
     "Authentication required" : "Autenticación requerida",
     "Credentials" : "Credenciales",
-    "SMTP Username" : "nombre de usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
     "All checks passed." : "Pasaron todas las verificaciones. ",
@@ -225,19 +210,32 @@ OC.L10N.register(
     "Follow us on Twitter" : "Síguenos en Twitter",
     "Check out our blog" : "Echa un vistazo a nuestro blog.",
     "Subscribe to our newsletter" : "Suscríbete a nuestro boletín",
+    "No user supplied" : "No se proporcionó un usuario",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Favor de proporcionar una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
+    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
+    "Invalid user" : "Usuario inválido",
+    "Your username is: %s" : "Su nombre de usuario es: %s",
     "Enable all" : "Habilitar todo",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Sync client - {os}" : "Sync client - {os}",
+    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
+    "Use the credentials below to configure your app or device." : "Use las siguientes credenciales para configurar su aplicación o dispositivo. ",
+    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
+    "Copied!" : "¡Credenciales!",
+    "Copy" : "Copiar",
     "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
     "Your email address" : "Su dirección de correo electrónico",
     "Your Twitter handle" : "Su cuenta de Twitter",
     "Add group" : "Agregar grupo",
+    "Show user backend" : "Mostrar backend del usuario",
     "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
     "Not saved" : "No guardado",
     "Twitter" : "Twitter",
-    "Plain" : "Plano",
-    "NT LAN Manager" : "Administrador de LAN NT",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Método de autenticación",
+    "SMTP Username" : "nombre de usuario SMTP",
     "Set default expiration date" : "Establecer la fecha de expiración predeterminada"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
