@@ -25,14 +25,11 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autenticación de dos-factores ha fallado (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
-    "Apps" : "Aplicaciones",
+    "Settings" : "Configuraciones ",
     "Wrong password" : "Contraseña incorrecta",
     "Saved" : "Guardado",
-    "No user supplied" : "No se proporcionó usuario alguno",
     "Authentication error" : "Error de autenticación",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
-    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
     "Administrator documentation" : "Documentación del adminsitrador",
     "User documentation" : "Documentación del usuario",
     "Invalid SMTP password." : "Constraseña SMTP inválida. ",
@@ -41,8 +38,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Si has recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
     "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Por favor verfica la bitácora de tu servidor de correo",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Por favor revisa tus configuraciones (Error: %s)",
-    "Users" : "Usuarios",
-    "Invalid user" : "Usuario inválido",
+    "Invalid account" : "Cuenta inválida",
     "Invalid mail address" : "Dirección de correo inválida",
     "Settings saved" : "Se han guardado las configuraciones ",
     "Unable to change full name" : "No fue posible cambiar el nombre completo",
@@ -64,14 +60,13 @@ OC.L10N.register(
     "Welcome aboard" : "Bienvenido a bordo",
     "Welcome aboard %s" : "Bienvenido a bordo %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenido a tu cuenta %s, puedes agregar, proteger y compartir tus datos.",
-    "Your username is: %s" : "Tu Usuario es: %s",
     "Set your password" : "Establece tu contraseña",
     "Go to %s" : "Ir a %s",
     "Install Client" : "Instalar el cliente",
-    "Logged in user must be a subadmin" : "El usuario firmado debe ser un subadministrador ",
-    "Settings" : "Configuraciones ",
+    "Apps" : "Aplicaciones",
     "Personal" : "Personal",
     "Administration" : "Administración",
+    "Users" : "Usuarios",
     "Additional settings" : "Configuraciones adicionales",
     "Overview" : "Generalidades",
     "Basic settings" : "Configuraciones  básicas",
@@ -81,12 +76,26 @@ OC.L10N.register(
     "Email server" : "Servidor de correo electrónico",
     "Security & setup warnings" : "Advertencias de seguridad y configuración",
     "Background jobs" : "Trabajos en segundo plano",
-    "Create" : "Crear",
-    "Change" : "Cambiar",
-    "Delete" : "Borrar",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
+    "Disabled" : "Deshabilitado",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
     "None" : "Ninguno",
+    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
+    "Allow resharing" : "Permitir volver a compartir",
+    "Allow sharing with groups" : "Permitir compartir con grupos",
+    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
+    "Allow public uploads" : "Permitir cargas públicas",
+    "Always ask for a password" : "Siempre pedir una contraseña",
+    "Enforce password protection" : "Forzar protección de contraseñas",
+    "Exclude groups from sharing" : "Evitar que los grupos compartan",
+    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
+    "Enforce expiration date" : "Forzar fecha de expiración",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de la liga pública cuando la lista de archivos esté oculta. ",
+    "Default share permissions" : "Permisos predeterminados para compartir",
     "Limit to groups" : "Limitar a grupos",
     "Save changes" : "Guardar cambios",
     "All" : "Todos",
@@ -112,29 +121,17 @@ OC.L10N.register(
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
     "Rename" : "Renombrar",
     "Revoke" : "Revocar",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome para Android",
-    "Sync client - {os}" : "Sync client - {os}",
     "This session" : "Esta sesión",
     "Device" : "Dispositivo",
     "Last activity" : "Última actividad",
     "Devices & sessions" : "Dispositivos y sesiones",
     "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
-    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
-    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
     "App name" : "Nombre de la aplicación",
     "Create new app password" : "Crear una nueva contraseña de aplicación",
-    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
-    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
-    "Username" : "Usuario",
+    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
+    "Login" : "Iniciar sesión",
     "Password" : "Contraseña",
-    "Done" : "Terminado",
-    "Copied!" : "¡Copiado!",
-    "Copy" : "Copiar",
     "Enable" : "Habilitar",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
@@ -157,31 +154,33 @@ OC.L10N.register(
     "No email address set" : "No se ha establecido la dirección de correo electrónico",
     "Help translate" : "Ayuda a traducir",
     "Your phone number" : "Su número telefónico",
-    "Your Twitter handle" : "Tu cuenta de Twitter",
     "Your website" : "Tu sitio web",
     "Add" : "Agregar",
+    "Create" : "Crear",
+    "Change" : "Cambiar",
+    "Delete" : "Borrar",
     "Display name" : "Nombre a desplegar",
     "Email" : "Correo electrónico",
     "Quota" : "Cuota",
     "Language" : "Idioma",
     "Avatar" : "Avatar",
+    "Username" : "Usuario",
     "Group admin for" : "Administrador del grupo para",
     "User backend" : "Backend del usuario",
     "Storage location" : "Úbicación del almacenamiento",
     "Last login" : "Último inicio de sesión",
     "{size} used" : "{size} usado",
+    "Delete account" : "Borrar cuenta",
+    "Done" : "Terminado",
     "Edit" : "Editar",
-    "Show user backend" : "Mostrar backend del usuario",
     "Show last login" : "Mostrar último inicio de sesión",
     "Send email" : "Enviar correo electrónico",
     "Default quota" : "Cuota predeterminada",
     "Unnamed device" : "Dispositivo sin nombre",
-    "Your apps" : "Tus aplicaciones",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
     "Changelog" : "Bitácora de cambios",
-    "Active users" : "Usuarios activos",
     "Admins" : "Administradores",
     "Group name" : "Nombre del grupo",
-    "Not saved" : "No guardado",
     "Sending…" : "Enviando...",
     "Email sent" : "Correo electrónico enviado",
     "Location" : "Ubicación",
@@ -189,17 +188,17 @@ OC.L10N.register(
     "About" : "Acerca de",
     "Full name" : "Nombre completo",
     "Phone number" : "Número de teléfono",
-    "Twitter" : "Twitter",
     "Website" : "Sitio web",
+    "Your apps" : "Tus aplicaciones",
     "Disabled apps" : "Aplicaciones deshabilitadas",
     "Updates" : "Actualizaciones",
     "App bundles" : "Paquetes de aplicación",
     "Hide" : "Ocultar",
     "Never" : "Nunca",
+    "Active users" : "Usuarios activos",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación ha sido habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
     "Documentation" : "Documentación",
     "Forum" : "Foro",
-    "Login" : "Iniciar sesión",
     "SSL" : "SSL",
     "Open documentation" : "Abrir documentación",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
@@ -211,39 +210,42 @@ OC.L10N.register(
     "Authentication" : "Autenticación",
     "Authentication required" : "Autenticación requerida",
     "Credentials" : "Credenciales",
-    "SMTP Username" : "Usuario SMTP",
     "SMTP Password" : "Contraseña SMTP",
     "Save" : "Guardar",
     "All checks passed." : "Pasaron todas las verificaciones. ",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
-    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
-    "Enforce expiration date" : "Forzar fecha de expiración",
-    "Allow public uploads" : "Permitir cargas públicas",
-    "Always ask for a password" : "Siempre pedir una contraseña",
-    "Enforce password protection" : "Forzar protección de contraseñas",
-    "Set default expiration date" : "Establecer la fecha de expiración predeterminada",
-    "Allow resharing" : "Permitir volver a compartir",
-    "Allow sharing with groups" : "Permitir compartir con grupos",
-    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
-    "Exclude groups from sharing" : "Evitar que los grupos compartan",
-    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
-    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de la liga pública cuando la lista de archivos esté oculta. ",
-    "Default share permissions" : "Permisos predeterminados para compartir",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
     "Follow us on Twitter" : "Síguenos en Twitter",
     "Check out our blog" : "Visita nuestro blog",
     "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
+    "No user supplied" : "No se proporcionó usuario alguno",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
+    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
+    "Invalid user" : "Usuario inválido",
+    "Your username is: %s" : "Tu Usuario es: %s",
+    "Logged in user must be a subadmin" : "El usuario firmado debe ser un subadministrador ",
     "Enable all" : "Habilitar todo",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Sync client - {os}" : "Sync client - {os}",
+    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
+    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
+    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
+    "Copied!" : "¡Copiado!",
+    "Copy" : "Copiar",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
     "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
     "Your email address" : "Tu dirección de correo electrónico",
+    "Your Twitter handle" : "Tu cuenta de Twitter",
     "Add group" : "Agregar grupo",
+    "Show user backend" : "Mostrar backend del usuario",
     "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
-    "Plain" : "Plano",
-    "NT LAN Manager" : "Administrador de LAN NT",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Método de autenticación"
+    "Not saved" : "No guardado",
+    "Twitter" : "Twitter",
+    "SMTP Username" : "Usuario SMTP",
+    "Set default expiration date" : "Establecer la fecha de expiración predeterminada"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
