@@ -36,13 +36,11 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Logisid edukalt sisse, kasutades kaheastmelist autentimiset (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Sisselogimiskatse kaheastmelise autentimisega ebaõnnestus (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Sinu <strong>parooli</strong> või <strong>e-posti aadressi</strong> muudeti",
-    "Apps" : "Rakendused",
+    "Settings" : "Seaded",
     "Wrong password" : "Vale parool",
     "Saved" : "Salvestatud",
-    "No user supplied" : "Kasutajat ei sisestatud",
     "Authentication error" : "Autentimise viga",
     "Wrong admin recovery password. Please check the password and try again." : "Vale administraatori taasteparool. Palun kontrolli parooli ning proovi uuesti.",
-    "Federated Cloud Sharing" : "Jagamine liitpilves",
     "Administrator documentation" : "Administraatori dokumentatsioon",
     "User documentation" : "Kasutaja dokumentatsioon",
     "Invalid SMTP password." : "Vale SMTP parool.",
@@ -51,9 +49,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Kui said selle kirja, näib e-posti seadistus õige.",
     "Email could not be sent. Check your mail server log" : "E-kirja saatmine ebaõnnestus. Kontrolli oma meiliserveri logi",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "E-kirja saatmisel tekkis viga. Palun vaata seaded üle. (Viga: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Enne e-kirjade saatmist pead seadistama oma e-posti aadress. Selleks mine %s.",
-    "Users" : "Kasutajad",
-    "Invalid user" : "Vigane kasutaja",
     "Invalid mail address" : "Vigane e-posti aadress",
     "Settings saved" : "Seaded salvestatud",
     "Unable to change full name" : "Täisnime muutmine ebaõnnestus",
@@ -73,13 +68,13 @@ OC.L10N.register(
     "Welcome aboard" : "Tere tulemast",
     "Welcome aboard %s" : "Tere tulemast %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Tere tulemast oma %s kontole. Sa saad lisada, kaitsta ja jagada oma andmeid.",
-    "Your username is: %s" : "Sinu kasutajanimi on: %s",
     "Set your password" : "Määra oma parool",
     "Go to %s" : "Mine %s",
     "Install Client" : "Paigalda kliendiprogramm",
-    "Settings" : "Seaded",
+    "Apps" : "Rakendused",
     "Personal" : "Isiklik",
     "Administration" : "Haldus",
+    "Users" : "Kasutajad",
     "Additional settings" : "Lisaseaded",
     "Groupware" : "Grupitöö",
     "Overview" : "Ülevaade",
@@ -132,29 +127,17 @@ OC.L10N.register(
     "Allow filesystem access" : "Luba juurdepääs failisüsteemile",
     "Rename" : "Nimeta ümber",
     "Revoke" : "Tühista",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome for Android",
-    "Sync client - {os}" : "Kliendiprogramm - {os}",
     "This session" : "See sessioon",
     "Device" : "Seade",
     "Last activity" : "Viimane tegevus",
     "Devices & sessions" : "Seadmed & sessioonid",
     "Web, desktop and mobile clients currently logged in to your account." : "Sinu kontole hetkel sisse loginud veebi-, töölaua-, ja mobiilsed kliendid.",
-    "Error while creating device token" : "Tõrge seadme märke loomisel",
-    "Error while deleting the token" : "Tõrge seadme märke kustutamisel",
     "App name" : "Rakenduse nimi",
     "Create new app password" : "Loo uus rakenduse parool",
-    "Use the credentials below to configure your app or device." : "Rakenduse või seadme konfigureerimiseks kasutage allpool toodud mandaate.",
-    "For security reasons this password will only be shown once." : "Turvalisuse huvides kuvatakse see parool ainult üks kord.",
-    "Username" : "Kasutajanimi",
+    "Error while creating device token" : "Tõrge seadme märke loomisel",
+    "Login" : "Logi sisse",
     "Password" : "Parool",
-    "Done" : "Valmis",
-    "Copied!" : "Kopeeritud!",
-    "Copy" : "Kopeeri",
     "Enable" : "Lülita sisse",
     "Server-side encryption" : "Serveripoolne krüpteerimine",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Serveripoole krüpteerimine võimaldab serverisse üleslaetud faile krüpteerida. Sellega kaasnevad piirangud, näiteks jõudluskadu. Lülita see sisse ainult siis, kui vaja on.",
@@ -182,6 +165,7 @@ OC.L10N.register(
     "Create" : "Loo",
     "Change" : "Muuda",
     "Delete" : "Kustuta",
+    "Loading accounts …" : "Kontode laadimine ...",
     "Default language" : "Vaikekeel",
     "Common languages" : "Levinud keeled",
     "New user" : "Uus kasutaja",
@@ -190,17 +174,16 @@ OC.L10N.register(
     "Quota" : "Mahupiir",
     "Language" : "Keel",
     "Avatar" : "Avatar",
+    "Username" : "Kasutajanimi",
     "Group admin for" : "Grupi admin",
     "User backend" : "Kasutaja taustarakendus",
     "Storage location" : "Salvestusruumi asukoht",
     "Last login" : "Viimane sisselogimine",
-    "You do not have permissions to see the details of this user" : "Sul puuduvad õigused selle kasutaja üksikasjade vaatamiseks",
     "{size} used" : "{size} kasutatud",
-    "Delete user" : "Kustuta kasutaja",
-    "Disable user" : "Keela kasutaja",
-    "Enable user" : "Luba kasutaja",
+    "Delete account" : "Kustuta konto",
     "Resend welcome email" : "Saada tervitusmeil uuesti",
     "Welcome mail sent!" : "Tervitusmeil saadetud!",
+    "Done" : "Valmis",
     "Edit" : "Redigeeri",
     "Visibility" : "Nähtavus",
     "Show last login" : "Näita viimast sisselogimist",
@@ -210,7 +193,6 @@ OC.L10N.register(
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administraatorina saate jagamise valikuid täpselt seadistada. Lisateavet leiad dokumentatsioonist.",
     "{license}-licensed" : "{license} litsents",
     "Changelog" : "Muudatuste logi",
-    "Active users" : "Aktiivseid kasutajaid",
     "Admins" : "Haldurid",
     "Disabled users" : "Keelatud kasutajad",
     "Group name" : "Grupi nimi",
@@ -231,11 +213,11 @@ OC.L10N.register(
     "App bundles" : "Rakenduste kogumikud",
     "Hide" : "Peida",
     "Never" : "Mitte kunagi",
+    "Active users" : "Aktiivseid kasutajaid",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Rakendus on lubatud, aga see vajab uuendamist. Sind suunatakse 5 sekundi pärast uuendamise lehele.",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Sinu võrgust tuli liiga palju päringuid. Proovi hiljem uuesti, või võta ühendust administraatoriga, kui tegu on veaga.",
     "Documentation" : "Dokumentatsioon",
     "Forum" : "Foorum",
-    "Login" : "Logi sisse",
     "SSL" : "SSL",
     "Open documentation" : "Ava dokumentatsioon",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "E-kirjad saatmise võimekus on olulile seadistada paroolide lähtestamiseks ja teavituste saatmiseks.",
@@ -247,21 +229,41 @@ OC.L10N.register(
     "Authentication" : "Autentimine",
     "Authentication required" : "Autentimine on vajalik",
     "Credentials" : "Kasutajatunnused",
-    "SMTP Username" : "SMTP kasutajatunnus",
     "SMTP Password" : "SMTP parool",
     "Save" : "Salvesta",
     "All checks passed." : "Kõik kontrollid on läbitud.",
+    "No user supplied" : "Kasutajat ei sisestatud",
+    "Federated Cloud Sharing" : "Jagamine liitpilves",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "Enne e-kirjade saatmist pead seadistama oma e-posti aadress. Selleks mine %s.",
+    "Invalid user" : "Vigane kasutaja",
+    "Your username is: %s" : "Sinu kasutajanimi on: %s",
     "Enable all" : "Luba kõik",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "Sync client - {os}" : "Kliendiprogramm - {os}",
+    "Error while deleting the token" : "Tõrge seadme märke kustutamisel",
+    "Use the credentials below to configure your app or device." : "Rakenduse või seadme konfigureerimiseks kasutage allpool toodud mandaate.",
+    "For security reasons this password will only be shown once." : "Turvalisuse huvides kuvatakse see parool ainult üks kord.",
+    "Copied!" : "Kopeeritud!",
+    "Copy" : "Kopeeri",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Sa oled eemaldamas gruppi {group}. Selles grupis olevaid kasutajaid EI kustutata.",
     "Please confirm the group removal " : "Palun kinnita grupi eemaldamine",
     "png or jpg, max. 20 MB" : "png või jpg, max. 20 MB",
     "Your email address" : "Sinu e-posti aadress",
+    "You do not have permissions to see the details of this user" : "Sul puuduvad õigused selle kasutaja üksikasjade vaatamiseks",
+    "Delete user" : "Kustuta kasutaja",
+    "Disable user" : "Keela kasutaja",
+    "Enable user" : "Luba kasutaja",
     "Add a new user" : "Lisa uus kasutaja",
     "Add group" : "Lisa grupp",
     "Default quota:" : "Vaikekvoot:",
     "Send email to new user" : "Saada uuele kasutajale e-kiri",
     "Not saved" : "Ei ole salvestatud",
     "Twitter" : "Twitter",
+    "SMTP Username" : "SMTP kasutajatunnus",
     "Set default expiration date" : "Määra vaikimisi aegumise kuupäev"
 },
 "nplurals=2; plural=(n != 1);");
