@@ -48,16 +48,14 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Etätyhjennys aloitettiin %1$s",
     "Remote wipe has finished on %1$s" : "Etätyhjennys valmistui %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Salasanaasi</strong> tai <strong>sähköpostiosoitettasi</strong> muokattiin",
-    "Apps" : "Sovellukset",
+    "Settings" : "Asetukset",
     "Could not remove app." : "Sovellusta ei voitu poistaa.",
     "Could not update app." : "Sovellusta ei voitu päivittää.",
     "Wrong password" : "Väärä salasana",
     "Unable to change personal password" : "Henkilökohtaista salasanaa ei voitu vaihtaa",
     "Saved" : "Tallennettu",
-    "No user supplied" : "Käyttäjää ei määritetty",
     "Unable to change password. Password too long." : "Salasanaa ei voitu vaihtaa. Salasana on liian pitkä.",
     "Authentication error" : "Tunnistautumisvirhe",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Anna ylläpitäjän palautussalasana; muuten kaikki käyttäjien data menetetään.",
     "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
     "Administrator documentation" : "Ylläpidon dokumentaatio",
     "User documentation" : "Käyttäjädokumentaatio",
@@ -67,8 +65,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Jos vastaanotit tämän viestin, sähköpostimääritykset vaikuttavat olevan kunnossa.",
     "Email could not be sent. Check your mail server log" : "Sähköpostia ei voitu lähettää. Tarkista sähköpostipalvelimen lokitiedosto",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Sähköpostia lähettäessä tapahtui virhe. Tarkista asetukset. (Virhe: %s)",
-    "Users" : "Käyttäjät",
-    "Invalid user" : "Virheellinen käyttäjä",
+    "Invalid account" : "Virheellinen tili",
     "Invalid mail address" : "Virheellinen sähköpostiosoite",
     "Settings saved" : "Asetukset tallennettu",
     "Unable to change full name" : "Koko nimen muuttaminen epäonnistui",
@@ -93,13 +90,13 @@ OC.L10N.register(
     "Welcome aboard" : "Tervetuloa mukaan",
     "Welcome aboard %s" : "Tervetuloa mukaan %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Tervetuloa %s-tilillesi. Voit lisätä, suojata ja jakaa tietojasi.",
-    "Your username is: %s" : "Käyttäjätunnuksesi on: %s",
     "Set your password" : "Aseta salasanasi",
     "Go to %s" : "Siirry %s-palveluun",
     "Install Client" : "Asenna sovellus",
-    "Settings" : "Asetukset",
+    "Apps" : "Sovellukset",
     "Personal" : "Henkilökohtainen",
     "Administration" : "Ylläpito",
+    "Users" : "Käyttäjät",
     "Additional settings" : "Lisäasetukset",
     "Artificial Intelligence" : "Tekoäly",
     "Administration privileges" : "Ylläpitäjän oikeudet",
@@ -118,6 +115,7 @@ OC.L10N.register(
     "Verifying" : "Vahvistetaan",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Tietokannasta puuttuu indeksejä. Suuriin tauluihin indeksien lisääminen saattaa kestää kauan, ja sen vuoksi indeksejä ei lisätty automaattisesti. Suorita \"occ db:add-missing-indices\" lisätäksesi puuttuvat indeksit manuaalisesti samalla, kun instanssi pysyy käynnissä. Kun indeksit on lisätty, kyselyt kyseisiin tauluihin ovat yleensä huomattavasti aiempaa nopeampia.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Tietokannasta puuttuu primääriavaimia. Suuriin tauluihin primääriavainten lisääminen saattaa kestää kauan, ja sen vuoksi primääriavaimia ei lisätty automaattisesti. Suorita \"occ db:add-missing-primary-keys\" lisätäksesi puuttuvat primääriavaimet manuaalisesti samalla, kun instanssi pysyy käynnissä.",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Tämä instanssi toimii vianjäljitystilassa. Käytä vianjäljitystilaa vain paikalliseen kehitykseen, älä koskaan käytä sitä tuotantoympäristössä.",
     "File locking" : "Tiedostolukitus",
     "Internet connectivity" : "Internet-yhdistettävyys",
     "Disabled" : "Pois käytöstä",
@@ -168,7 +166,6 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "Tämä teksti näytetään julkisen linkin lähetyssivulla, kun tiedostolista on piilotettu.",
     "Default share permissions" : "Oletusjako-oikeudet",
     "Two-Factor Authentication" : "Kaksivaiheinen tunnistautuminen",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Kaksivaiheinen tunnistautuminen voidaan pakottaa kaikille käyttäjille ja halutuille ryhmille. Mikäli heillä ei ole kaksivaiheista tunnistautumistapaa määriteltynä, he eivät pysty kirjautumaan järjestelmään.",
     "Enforce two-factor authentication" : "Pakota kaksivaiheinen tunnistautuminen",
     "Limit to groups" : "Rajoita ryhmiin",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Kaksivaiheisen tunnistautumisen pakottaminen on mahdollista kohdentaa vain tietyille ryhmille.",
@@ -176,7 +173,6 @@ OC.L10N.register(
     "Enforced groups" : "Pakotetut ryhmät",
     "Two-factor authentication is not enforced for members of the following groups." : "Kaksivaiheisen tunnistautuminen ei ole pakotettu seuraavien ryhmien jäsenille.",
     "Excluded groups" : "Poissuljetut ryhmät",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Kun ryhmiä on valittu tai poissuljettu, ne käyttävät seuraavaa logiikkaa määrittääkseen käyttäjän kaksivaiheisen tunnistautumisen (2FA) pakottamisen: Jos ryhmiä ei ole valittu, 2FA on käytössä kaikilla paitsi poissuljetuilla ryhmillä. Jos ryhmiä on valittu, 2FA on käytössä kaikilla niiden jäsenillä. Jos käyttäjä on sekä valitussa että poissuljetussa ryhmässä, valittu ryhmä on etusijalla ja 2FA on käytössä.",
     "Save changes" : "Tallenna muutokset",
     "All" : "Kaikki",
     "Limit app usage to groups" : "Rajoita sovelluskäyttö ryhmiin",
@@ -229,7 +225,7 @@ OC.L10N.register(
     "Create new app password" : "Luo uusi sovellussalasana",
     "Error while creating device token" : "Virhe laitepolettia luotaessa",
     "New app password" : "Uusi sovellussalasana",
-    "Username" : "Käyttäjätunnus",
+    "Login" : "Kirjaudu",
     "Password" : "Salasana",
     "Show QR code for mobile apps" : "Näytä QR-koodi mobiilisovelluksia varten",
     "App password copied!" : "Sovellussalasana kopioitu!",
@@ -243,7 +239,6 @@ OC.L10N.register(
     "Cron (Recommended)" : "Cron (suositeltu)",
     "Use system cron service to call the cron.php file every 5 minutes." : "Käytä järjestelmän cron-palvelua cron.php-skriptin suorittamiseen 5 minuutin välein",
     "Profile" : "Profiili",
-    "Enable or disable profile by default for new users." : "Käytä tai poista käytöstä profiili oletusarvoisesti uusille käyttäjille.",
     "Enable" : "Käytä",
     "Unable to update profile default setting" : "Profiilin oletusasetuksen päivittäminen ei onnistunut",
     "Server-side encryption" : "Palvelinpään salaus",
@@ -258,7 +253,6 @@ OC.L10N.register(
     "No encryption module loaded, please enable an encryption module in the app menu." : "Salausmoduulia ei ole käytössä. Ota salausmoduuli käyttöön sovellusvalikosta.",
     "Select default encryption module:" : "Valitse oletuksena käytettävä salausmoduuli:",
     "Please confirm the group removal" : "Vahvista ryhmän poistaminen",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän \"{group}\". Käyttäjiä EI poisteta!",
     "Cancel" : "Peru",
     "Confirm" : "Vahvista",
     "Submit" : "Lähetä",
@@ -289,12 +283,13 @@ OC.L10N.register(
     "You are using <strong>{usage}</strong>" : "Käytössäsi on <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Käytössäsi on <strong>{usage}</strong>/<strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Koko nimesi",
-    "Email options" : "Sähköpostiasetukset",
+    "Back" : "Takaisin",
+    "This address is not confirmed" : "Tätä osoitetta ei ole vahvistettu",
     "Primary email for password reset and notifications" : "Ensisijainen sähköposti salasanan nollaamista ja ilmoituksia varten",
+    "Email options" : "Sähköpostiasetukset",
     "Remove primary email" : "Poista ensisijainen sähköpostiosoite",
     "Delete email" : "Poista sähköposti",
     "Unset as primary email" : "Poista ensisijaisesta sähköpostista",
-    "This address is not confirmed" : "Tätä osoitetta ei ole vahvistettu",
     "Set as primary email" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
     "Additional email address {index}" : "Lisäsähköpostiosoite {index}",
     "Unable to delete primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu poistaa",
@@ -302,6 +297,7 @@ OC.L10N.register(
     "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
     "Additional emails" : "Muut sähköpostit",
     "Your headline" : "Otsikkosi",
+    "Languages" : "Kielet",
     "Help translate" : "Auta kääntämisessä",
     "Unable to update language" : "Kieltä ei voi päivittää",
     "No language set" : "Kieltä ei ole asetettu",
@@ -311,7 +307,6 @@ OC.L10N.register(
     "Your organisation" : "Organisaatiosi",
     "Your phone number" : "Puhelinnumerosi",
     "Edit your Profile visibility" : "Muokkaa profiilisi näkyvyyttä",
-    "Enable Profile" : "Käytä profiilia",
     "Your role" : "Roolisi",
     "Your website" : "Verkkosivustosi",
     "Add additional email" : "Lisää toissijainen sähköpostiosoite",
@@ -320,8 +315,8 @@ OC.L10N.register(
     "Change" : "Muuta",
     "Delete" : "Poista",
     "Reshare" : "Jaa edelleen",
-    "No users" : "Ei käyttäjiä",
-    "Loading users …" : "Ladataan käyttäjiä…",
+    "No accounts" : "Ei tilejä",
+    "Loading accounts …" : "Ladataan tilejä…",
     "Default language" : "Oletuskieli",
     "Common languages" : "Yleiset kielet",
     "Other languages" : "Muut kielet",
@@ -340,29 +335,24 @@ OC.L10N.register(
     "Add new user" : "Lisää uusi käyttäjä",
     "Username will be autogenerated" : "Käyttäjänimi luodaan automaattisesti",
     "Username (required)" : "Käyttäjänimi (pakollinen)",
+    "Loading users …" : "Ladataan käyttäjiä…",
     "Scroll to load more rows" : "Vieritä ladataksesi enemmän rivejä",
     "_{userCount} user …_::_{userCount} users …_" : ["{userCount} käyttäjä…","{userCount} käyttäjää…"],
     "_{userCount} user_::_{userCount} users_" : ["{userCount} käyttäjä","{userCount} käyttäjää"],
     "Avatar" : "Profiilikuva",
+    "Username" : "Käyttäjätunnus",
     "Group admin for" : "Ryhmäylläpitäjä ryhmille",
     "User backend" : "Käyttäjätaustaosa",
     "Storage location" : "Tallennustilan sijainti",
     "Last login" : "Viimeisin kirjautuminen",
     "User actions" : "Käyttäjätoiminnot",
-    "Loading user …" : "Ladataan käyttäjää…",
     "Change display name" : "Vaihda näyttönimi",
     "Set new password" : "Aseta uusi salasana:",
-    "You do not have permissions to see the details of this user" : "Käyttöoikeutesi eivät riitä tämän käyttäjän tietojen näkemiseen",
     "Set new email address" : "Aseta uusi sähköpostiosoite",
     "Add user to group" : "Lisää käyttäjä ryhmään",
-    "Set user as admin for" : "Aseta käyttäjä järjestelmänvalvojaksi kohteelle",
-    "Select user quota" : "Valitse käyttäjäkiintiö",
     "Set the language" : "Aseta kieli",
     "{size} used" : "{size} käytetty",
-    "Delete user" : "Poista käyttäjä",
     "Wipe all devices" : "Tyhjennä kaikki laitteet",
-    "Disable user" : "Poista käyttäjä käytöstä",
-    "Enable user" : "Ota käyttäjä käyttöön",
     "Resend welcome email" : "Lähetä uudelleen tervetuloviesti",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Laitteen kadotessa tai organisaatiosta poistuessa voidaan käyttäjälle {userid} Nextcloudiin yhdistetyistä laitteista pyyhkiä  tiedot. Toimii vain laitteiden ollessa yhteydessä Internetiin.",
     "Remote wipe of devices" : "Laitteiden etätyhjennys",
@@ -375,17 +365,13 @@ OC.L10N.register(
     "Password was successfully changed" : "Salasana vaihdettiin onnistuneesti",
     "Email was successfully changed" : "Sähköpostiosoite vaihdettiin onnistuneesti",
     "Welcome mail sent!" : "Tervetuloviesti lähetetty!",
-    "Toggle user actions menu" : "Näytä tai piilota käyttäjätoimintojen valikko",
     "Done" : "Valmis",
     "Edit" : "Muokkaa",
-    "User management settings" : "Käyttäjähallinnan asetukset",
     "Visibility" : "Näkyvyys",
     "Show language" : "Näytä kieli",
-    "Show user backend" : "Näytä käyttäjätaustaosa",
     "Show storage path" : "Näytä tallennustilan polku",
     "Show last login" : "Näytä viimeisin sisäänkirjautuminen",
     "Send email" : "Lähetä sähköpostiviesti",
-    "Send welcome email to new users" : "Lähetä Tervetuloa-sähköposti uusille käyttäjille",
     "Defaults" : "Oletukset",
     "Default quota" : "Oletuskiintiö",
     "Select default quota" : "Valitse oletuskiintiö",
@@ -406,15 +392,13 @@ OC.L10N.register(
     "{license}-licensed" : "{license}-lisensoitu",
     "Changelog" : "Muutosloki",
     "by {author}\n{license}" : "tekijä {author}\n{license}",
-    "User management" : "Käyttäjähallinta",
-    "Active users" : "Aktiiviset käyttäjät",
+    "New account" : "Uusi tili",
     "Admins" : "Ylläpitäjät",
     "Disabled users" : "Käytöstä poistetut käyttäjät",
     "Creating group …" : "Luodaan ryhmää…",
     "Create group" : "Luo ryhmä",
     "Group name" : "Ryhmän nimi",
     "Please enter a valid group name" : "Kirjoita kelvollinen ryhmän nimi",
-    "User group: {group}" : "Käyttäjäryhmä: {group}",
     "Failed to create group" : "Ryhmän luonti epäonnistui",
     "Sending…" : "Lähetetään…",
     "Email sent" : "Sähköposti lähetetty",
@@ -440,13 +424,13 @@ OC.L10N.register(
     "Featured apps" : "Esitellyt sovellukset",
     "Supported apps" : "Tuetut sovellukset",
     "Show to everyone" : "Näytä kaikille",
-    "Show to logged in users only" : "Näytä vain sisäänkirjautuneille käyttäjille",
     "Hide" : "Piilota",
     "Download and enable" : "Lataa ja ota käyttöön",
     "Allow untested app" : "Salli testaamaton sovellus",
     "The app will be downloaded from the App Store" : "Sovellus ladataan sovelluskaupasta",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
     "Never" : "Ei koskaan",
+    "Active users" : "Aktiiviset käyttäjät",
     "An error occurred during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Virhe: Sovellusta ei voida ottaa käyttöön, koska se aiheuttaa palvelimen epävakauden",
@@ -455,13 +439,12 @@ OC.L10N.register(
     "Error while wiping the device with the token" : "Virhe tyhjennettäessä laitetta polettia käyttäen",
     "Error while updating device token name" : "Virhe laitepoletin nimeä päivittäessä",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Verkostasi tehtiin liian monta pyyntöä. Yritä myöhemmin uudelleen tai ole yhteydessä ylläpitäjään, jos tämä on mielestäsi virhe.",
+    "Account documentation" : "Tilin dokumentaatio",
+    "Administration documentation" : "Ylläpidon dokumentaatio",
     "Documentation" : "Dokumentaatio",
     "Forum" : "Keskustelupalsta",
     "Nextcloud help resources" : "Nextcloud-ohjeresurssit",
-    "Account documentation" : "Tilin dokumentaatio",
-    "Administration documentation" : "Ylläpidon dokumentaatio",
     "General documentation" : "Yleinen dokumentaatio",
-    "Login" : "Kirjaudu",
     "SSL" : "SSL",
     "Open documentation" : "Avaa dokumentaatio",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On tärkeää määrittää sähköpostipalvelinasetukset, jotta voidaan lähettää muun muassa salasanan palautus- ja ilmoitussähköpostiviestejä.",
@@ -474,7 +457,6 @@ OC.L10N.register(
     "Authentication" : "Tunnistautuminen",
     "Authentication required" : "Tunnistautuminen vaaditaan",
     "Credentials" : "Tilitiedot",
-    "SMTP Username" : "SMTP-käyttäjätunnus",
     "SMTP Password" : "SMTP-salasana",
     "Save" : "Tallenna",
     "Test and verify email settings" : "Testaa ja vahvista sähköpostiasetukset",
@@ -495,8 +477,14 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
     "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
+    "No user supplied" : "Käyttäjää ei määritetty",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Anna ylläpitäjän palautussalasana; muuten kaikki käyttäjien data menetetään.",
     "Federated Cloud Sharing" : "Federoitu pilvijakaminen",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL käyttää vanhentunutta %1$s versiota (%2$s). Päivitä käyttöjärjestelmäsi tai toiminnot, kuten %3$s, eivät toimi luotettavasti.",
+    "Invalid user" : "Virheellinen käyttäjä",
+    "Your username is: %s" : "Käyttäjätunnuksesi on: %s",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Kaksivaiheinen tunnistautuminen voidaan pakottaa kaikille käyttäjille ja halutuille ryhmille. Mikäli heillä ei ole kaksivaiheista tunnistautumistapaa määriteltynä, he eivät pysty kirjautumaan järjestelmään.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Kun ryhmiä on valittu tai poissuljettu, ne käyttävät seuraavaa logiikkaa määrittääkseen käyttäjän kaksivaiheisen tunnistautumisen (2FA) pakottamisen: Jos ryhmiä ei ole valittu, 2FA on käytössä kaikilla paitsi poissuljetuilla ryhmillä. Jos ryhmiä on valittu, 2FA on käytössä kaikilla niiden jäsenillä. Jos käyttäjä on sekä valitussa että poissuljetussa ryhmässä, valittu ryhmä on etusijalla ja 2FA on käytössä.",
     "Enable all" : "Ota kaikki käyttöön",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
@@ -512,15 +500,24 @@ OC.L10N.register(
     "Copied!" : "Kopioitu!",
     "Copy" : "Kopioi",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Tämän suorittamiseksi tarvitset PHP:n POSIX-laajennuksen. Lue {linkstart}PHP:n dokumentaatio{linkend} saadaksesi lisätietoja.",
+    "Enable or disable profile by default for new users." : "Käytä tai poista käytöstä profiili oletusarvoisesti uusille käyttäjille.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän {group}. Käyttäjiä EI poisteta!",
     "Please confirm the group removal " : "Vahvista ryhmän poistaminen",
     "Choose profile picture from files" : "Valitse profiilikuva tiedostoista",
     "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
     "Your email address" : "Sähköpostiosoitteesi",
     "Your location" : "Sijaintisi",
+    "Enable Profile" : "Käytä profiilia",
     "Your Twitter handle" : "Twitter-tunnuksesi",
+    "You do not have permissions to see the details of this user" : "Käyttöoikeutesi eivät riitä tämän käyttäjän tietojen näkemiseen",
     "Add new password" : "Lisää uusi salasana",
     "Add new email address" : "Lisää uusi sähköpostiosoite",
+    "Set user as admin for" : "Aseta käyttäjä järjestelmänvalvojaksi kohteelle",
+    "Select user quota" : "Valitse käyttäjäkiintiö",
+    "Toggle user actions menu" : "Näytä tai piilota käyttäjätoimintojen valikko",
+    "Delete user" : "Poista käyttäjä",
+    "Disable user" : "Poista käyttäjä käytöstä",
+    "Enable user" : "Ota käyttäjä käyttöön",
     "Edit User" : "Muokkaa käyttäjää",
     "Will be autogenerated" : "Luodaan automaattisesti",
     "Add a new user" : "Lisää uusi käyttäjä",
@@ -529,16 +526,26 @@ OC.L10N.register(
     "Add group" : "Lisää ryhmä",
     "Default quota:" : "Oletuskiintiö:",
     "Show Languages" : "Näytä kielet",
+    "Show user backend" : "Näytä käyttäjätaustaosa",
     "Send email to new user" : "Lähetä sähköpostia uudelle käyttäjälle",
     "Not saved" : "Ei tallennettu",
     "Twitter" : "Twitter",
+    "Show to logged in users only" : "Näytä vain sisäänkirjautuneille käyttäjille",
     "Enable untested app" : "Ota käyttöön testaamaton sovellus",
+    "SMTP Username" : "SMTP-käyttäjätunnus",
     "Expire after" : "Lopeta jako, kun on kulunut",
     "day(s)" : "päivä(ä)",
     "Exclude groups from password requirements:" : "Sulje ryhmiä salasanavaatimusten ulkopuolelle:",
     "Set default expiration date" : "Aseta lopettamispäivän oletus",
     "Allow username autocompletion in share dialog" : "Ota käyttöön käyttäjänimen automaattitäyttö jakolomakkeessa",
     "Allow username autocompletion to users within the same groups" : "Ota käyttöön käyttäjänimen automaattitäyttö saman ryhmän käyttäjille",
-    "Edit display name" : "Muokkaa näyttönimeä"
+    "Edit display name" : "Muokkaa näyttönimeä",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Olet aikeissa poistaa ryhmän \"{group}\". Käyttäjiä EI poisteta!",
+    "No users" : "Ei käyttäjiä",
+    "Loading user …" : "Ladataan käyttäjää…",
+    "User management settings" : "Käyttäjähallinnan asetukset",
+    "Send welcome email to new users" : "Lähetä Tervetuloa-sähköposti uusille käyttäjille",
+    "User management" : "Käyttäjähallinta",
+    "User group: {group}" : "Käyttäjäryhmä: {group}"
 },
 "nplurals=2; plural=(n != 1);");
