@@ -50,18 +50,15 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Iniciouse a limpeza remota en %1$s",
     "Remote wipe has finished on %1$s" : "Rematou a limpeza remota en %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Foi modificado o seu <strong>contrasinal</strong> ou o seu <strong>correo</strong>",
-    "Apps" : "Aplicacións",
+    "Settings" : "Axustes",
     "Could not remove app." : "Non foi posíbel retirar a aplicación.",
     "Could not update app." : "Non foi posíbel actualizar a aplicación.",
     "Wrong password" : "Contrasinal erróneo",
     "Unable to change personal password" : "Non é posíbel cambiar o contrasinal persoal",
     "Saved" : "Gardado",
-    "No user supplied" : "Non subministrado polo usuario",
     "Unable to change password. Password too long." : "Non é posíbel cambiar o contrasinal. O contrasinal é longo de máis.",
     "Authentication error" : "Produciuse un erro de autenticación",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Forneza un contrasinal de recuperación de administrador; senón perderase toda a información do usuario.",
     "Wrong admin recovery password. Please check the password and try again." : "Contrasinal de recuperación do administrador erróneo. Comprobe o contrasinal e ténteo de novo.",
-    "Backend does not support password change, but the user's encryption key was updated." : "A infraestrutura non admite o cambio de contrasinal, mais a chave de cifrado do usuario foi actualizada.",
     "Administrator documentation" : "Documentación da administración da instancia.",
     "User documentation" : "Documentación do usuario",
     "Nextcloud help overview" : "Vista xeral da axuda de Nextcloud",
@@ -71,9 +68,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Se Vde. ten recibido este correo, a configuración do correo semella ser correcta. ",
     "Email could not be sent. Check your mail server log" : "Non foi posíbel enviar o correo. Comprobe o rexistro do servidor de correo",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu un problema ao enviar o correo. Revise os seus axustes. (Erro: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "É necesario definir o seu correo de usuario antes de poder enviar correos de proba. Vaia a %spara iso.",
-    "Users" : "Usuarios",
-    "Invalid user" : "Usuario incorrecto",
+    "Invalid account" : "Conta incorrecta",
     "Invalid mail address" : "Enderezo de correo incorrecto",
     "Settings saved" : "Axustes gardados",
     "Unable to change full name" : "Non é posíbel cambiar o nome completo",
@@ -99,14 +94,13 @@ OC.L10N.register(
     "Welcome aboard" : "Dámoslle a benvida a bordo",
     "Welcome aboard %s" : "Dámoslle a benvida a bordo %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Benvido á súa conta %s , pode engadir, protexer e compartir os seus datos.",
-    "Your username is: %s" : "O seu nome de usuario é: %s",
     "Set your password" : "Defina o seu contrasinal",
     "Go to %s" : "Ira a %s",
     "Install Client" : "Instalar o cliente",
-    "Logged in user must be a subadmin" : "O usuario autenticado debe ser un subadministrador",
-    "Settings" : "Axustes",
+    "Apps" : "Aplicacións",
     "Personal" : "Persoal",
     "Administration" : "Administración",
+    "Users" : "Usuarios",
     "Additional settings" : "Axustes adicionais",
     "Artificial Intelligence" : "Intelixencia artificial",
     "Administration privileges" : "Privilexios de administración",
@@ -127,9 +121,6 @@ OC.L10N.register(
     "Your remote address could not be determined." : "Non foi posíbel determinar o seu enderezo remoto.",
     "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "O seu enderezo remoto foi identificado como «%s» e neste momento está estrangulado por forza bruta, o que reduce o rendemento de varias solicitudes. Se o enderezo remoto non é o seu enderezo, isto pode ser unha indicación de que un proxy non está configurado correctamente.",
     "Your remote address \"%s\" is not brute-force throttled." : "O seu enderezo remoto «%s» non está estrangulado por forza bruta.",
-    "Old user imported certificates" : "Certificados antigos importados polo usuario",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Está pendente un traballo en segundo plano que comprobe os certificados SSL importados polo usuario. Volva comprobar máis adiante.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hai algúns certificados SSL importados polo usuario, que xa non se usan con Nextcloud 21. Pódense importar coa liña de ordes mediante a orde «occ security:certificates:import». As súas rutas dentro do directorio de datos amosanse deseguido.",
     "Database missing columns" : "Faltan columnas na base de datos",
     "Missing optional column \"%s\" in table \"%s\"." : "Falta a columna opcional «%s» na táboa «%s».",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Á base de datos fáltanlle algunhas columnas opcionais. Por mor de que engadir columnas a grandes táboas podería levar moito tempo non foron engadidas automaticamente cando poden ser opcionais. Estas columnas poden engadirse manualmente mentres siga funcionando a instancia, executando «occ db:add-missing-columns». Unha vez se teñan engadidas as columnas, algunhas características poden mellorar a resposta ou a usabilidade.",
@@ -141,6 +132,8 @@ OC.L10N.register(
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Faltan algunhas chave primarias na base de datos. Por mor do feito de que a adición de chave primarias en táboas grandes podería levar algún tempo, non se engadiron automaticamente. Ao executar «occ db:add-missing-primary-keys», esas chave primarias que faltan poderían engadirse manualmente mentres a instancia segue funcionando.",
     "Database pending bigint migrations" : "Base de datos pendente de migracións «bigint»",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Algunhas columnas da base de datos non teñen unha conversión a «big int». por mor do feito de que cambiar os tipos de columnas en grandes táboas pode levar algún tempo, non se cambian automaticamente. Ao executar «occ db:convert-filecache-bigint» poderían aplicarse manualmente os cambios pendentes. Esta operación debe realizarse mentres a instancia está sen conexión.",
+    "Debug mode" : "Modo de depuración",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instancia está a executarse en modo de depuración. Active isto só para o desenvolvemento local e non en contornos de produción.",
     "Default phone region" : "Rexión telefónica predeterminada",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "A súa instalación non ten definida a rexión telefónica predeterminada. Isto é preciso para validar os números de teléfono nos axustes do perfil sen un código de país. Para permitir números sen código de país, engada «default_phone_region» co respectivo código ISO 3166-1 da rexión ao seu ficheiro de configuración.",
     "Email test" : "Correo de proba",
@@ -254,7 +247,6 @@ OC.L10N.register(
     "Deleted disclaimer text" : "Eliminouse o texto da exención de responsabilidade",
     "Could not set disclaimer text" : "Non foi posíbel definir o texto da exención de responsabilidade",
     "Two-Factor Authentication" : "Autenticación de dous factores",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "A autenticación de dous factores pode ser imposta para todos os usuarios e grupos específicos. Se non tiveran configurado un provedor de dous factores, non podería acceder ao sistema.",
     "Enforce two-factor authentication" : "Impor a autenticación de dous factores",
     "Limit to groups" : "Límite para grupos",
     "Enforcement of two-factor authentication can be set for certain groups only." : "A obrigatoriedade da autenticación de dous factores pode definirse só para certos grupos.",
@@ -262,7 +254,6 @@ OC.L10N.register(
     "Enforced groups" : "Grupos obrigados",
     "Two-factor authentication is not enforced for members of the following groups." : "A autenticación de dous factores non é obrigatoria para os membros dos seguintes grupos.",
     "Excluded groups" : "Grupos excluídos",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cando se seleccionan/exclúen os grupos, usase a seguinte lóxica para determinar se un usuario ten obrigada a A2F: Se non hai grupos seleccionados, a A2F está activa para todos agás os membros dos grupos excluídos. Se hai grupos seleccionados, a A2F está activa para todos os membros destes. Se un usuario está á vez nun grupo seleccionado e noutro excluído, o seleccionado ten preferencia e se lle obriga a A2F.",
     "Save changes" : "Gardar os cambios",
     "All" : "Todo",
     "Limit app usage to groups" : "Limitar o uso de aplicacións a grupos",
@@ -317,7 +308,7 @@ OC.L10N.register(
     "App name" : "Nome da aplicación",
     "Create new app password" : "Crear un novo contrasinal de aplicación",
     "Error while creating device token" : "Produciuse un erro ao crear un testemuño de dispositivo",
-    "Username" : "Nome de usuario",
+    "Login" : "Acceso",
     "Password" : "Contrasinal",
     "Show QR code for mobile apps" : "Amosar un código QR para aplicacións móbiles",
     "Could not copy app password. Please copy it manually." : "Non foi posíbel copiar o contrasinal da aplicación. Cópieo manualmente.",
@@ -326,16 +317,12 @@ OC.L10N.register(
     "Last job ran {relativeTime}." : "O último traballo executouse {relativeTime}.",
     "Background job did not run yet!" : "O traballo en segundo plano aínda non se executou!",
     "AJAX" : "AJAX",
-    "Execute one task with each page loaded. Use case: Single user instance." : "Executar unha tarefa con cada páxina cargada. Caso de uso: instancia de usuario único.",
     "Webcron" : "Webcron",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php está rexistrado nun servizo webcron para chamar a cron.php cada 5 minutos a través de HTTP. Caso de uso: instancia moi pequena (de 1 a 5 usuarios segundo o uso).",
     "Cron (Recommended)" : "Cron (Recomendado)",
     "Use system cron service to call the cron.php file every 5 minutes." : "Use o servizo «cron» do sistema para chamar ao ficheiro cron.php cada 5 minutos.",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "O cron.php debe ser executado polo usuario do sistema «{user}».",
     "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Precísase da extensión POSIX de PHP. Vexa a {linkstart}documentación de PHP{linkend} para obter máis detalles. ",
     "Unable to update background job mode" : "Non é posíbel actualizar o modo de traballo en segundo plano",
     "Profile" : "Perfil",
-    "Enable or disable profile by default for new users." : "Activar ou desactivar o perfil predeterminado para os novos usuarios.",
     "Enable" : "Activar",
     "Unable to update profile default setting" : "Non é posíbel actualizar a configuración predeterminada do perfil",
     "Server-side encryption" : "Cifrado no lado do servidor",
@@ -352,7 +339,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "É necesario migrar as súas chave de cifrado do antigo cifrado (ownCloud <= 8,0) cara ao novo. Active o «Módulo predeterminado de cifrado» e execute {command}",
     "Unable to update server side encryption config" : "Non é posíbel actualizar a configuración de cifrado do servidor",
     "Please confirm the group removal" : "Confirme a retirada do grupo",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Está a piques de retirar o grupo «{group}». Os usuarios NON van ser eliminados.",
     "Cancel" : "Cancelar",
     "Confirm" : "Confirmar",
     "Submit" : "Enviar",
@@ -383,12 +369,13 @@ OC.L10N.register(
     "You are using <strong>{usage}</strong>" : "Está a usar <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Está a usar <strong>{usage}</strong> de <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "O seu nome completo",
-    "Email options" : "Opcións de correo -e",
+    "Back" : "Atras",
+    "This address is not confirmed" : "Este enderezo non está confirmado",
     "Primary email for password reset and notifications" : "Correo-e principal para restabelecer o contrasinal e notificacións",
+    "Email options" : "Opcións de correo -e",
     "Remove primary email" : "Retirar o correo-e principal",
     "Delete email" : "Eliminar o correo-e",
     "Unset as primary email" : "Desactivar como correo principal",
-    "This address is not confirmed" : "Este enderezo non está confirmado",
     "Set as primary email" : "Definir como correo principal",
     "Additional email address {index}" : "Enderezo de correo adicional {index}",
     "Unable to delete primary email address" : "Non é posíbel eliminar o enderezo de correo principal",
@@ -410,7 +397,6 @@ OC.L10N.register(
     "Your organisation" : "A súa organización",
     "Your phone number" : "O seu número de teléfono",
     "Edit your Profile visibility" : "Edita a visibilidade do seu perfil",
-    "Enable Profile" : "Activar o perfil",
     "Unable to update profile enabled state" : "Non é posíbel actualizar o estado activado do perfil",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "No seu perfil respectase a configuración máis restritiva de visibilidade ou ámbito. Por exemplo, se a visibilidade está definida como«Amosar a todos» e o ámbito está configurado como «Privado», respéctase «Privado».",
     "Unable to update visibility of {displayId}" : "Non é posíbel actualizar a visibilidade de {displayId}",
@@ -428,9 +414,6 @@ OC.L10N.register(
     "Change" : "Cambiar",
     "Delete" : "Eliminar",
     "Reshare" : "Volver compartir",
-    "No users" : "Non hai usuarios",
-    "Loading users …" : "Cargando usuarios…",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Lista de usuarios. Esta lista non se representa de xeito completo por mor do rendemento. Os usuarios represéntanse mentres se despraza pola lista.",
     "Default language" : "Idioma predeterminado",
     "Common languages" : "Idiomas habituais",
     "Other languages" : "Outros idiomas",
@@ -455,36 +438,31 @@ OC.L10N.register(
     "Username will be autogenerated" : "O nome de usuario vai ser xerado automaticamente",
     "Username (required)" : "Nome de usuario (necesario)",
     "Total rows summary" : "Resumo total de filas",
+    "Loading users …" : "Cargando usuarios…",
     "Scroll to load more rows" : "Desprácese para cargar máis filas",
     "_{userCount} user …_::_{userCount} users …_" : ["{userCount} usuario…","{userCount} usuarios…"],
     "_{userCount} user_::_{userCount} users_" : ["{userCount} usuario","{userCount} usuarios"],
     "Avatar" : "Avatar",
+    "Username" : "Nome de usuario",
     "Group admin for" : "Administrador de grupo para",
     "User backend" : "Infraestrutura do usuario",
     "Storage location" : "Localización do almacenamento",
     "Last login" : "Último acceso",
     "User actions" : "Accións do usuario",
     "Password or insufficient permissions message" : "Mensaxe de contrasinal ou de permisos insuficientes",
-    "Loading user …" : "Cargando usuario…",
     "Change display name" : "Cambiar o nome para amosar",
     "Set new password" : "Definir un novo contrasinal",
-    "You do not have permissions to see the details of this user" : "Vde. non ten permisos para ver os detalles deste usuario",
     "Set new email address" : "Definir un novo enderezo de correo",
     "Add user to group" : "Engadir usuario ao grupo",
-    "Set user as admin for" : "Definir o usuario como administrador para",
-    "Select user quota" : "Seleccionar a cota de usuario",
     "Set the language" : "Definir o idioma",
     "{size} used" : "{size} usado",
-    "Delete user" : "Eliminar usuario",
+    "Delete account" : "Eliminar a conta",
     "Wipe all devices" : "Limpar todos os dispositivos",
-    "Disable user" : "Desactivar usuario",
-    "Enable user" : "Activar usuario",
     "Resend welcome email" : "Volver enviar o correo de benvida",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "No caso de perder o dispositivo ou saír da organización, pode limpar os datos de Nextcloud de xeito remoto de todos os dispositivos asociados a {userid}. Só funciona se os dispositivos están conectados Á Internet.",
     "Remote wipe of devices" : "Limpeza remota de dispositivos",
     "Wipe {userid}'s devices" : "Limpar os dispositivos de {userid}",
     "Wiped {userid}'s devices" : "Limpáronse os dispositivos de {userid}",
-    "Failed to update user manager" : "Produciuse un erro ao actualizar o xestor de usuarios",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eliminar completamente a conta de {userid} incluíndo todos os seus ficheiros persoais, datos de aplicacións, etc.",
     "Account deletion" : "Eliminación de conta",
     "Delete {userid}'s account" : "Eliminar a conta de {userid}",
@@ -492,17 +470,13 @@ OC.L10N.register(
     "Password was successfully changed" : "O contrasinal foi cambiado satisfactoriamente",
     "Email was successfully changed" : "O correo foi cambiado satisfactoriamente",
     "Welcome mail sent!" : "Enviado o correo de benvida!",
-    "Toggle user actions menu" : "Alternar o menú de accións do usuario",
     "Done" : "Feito",
     "Edit" : "Editar",
-    "User management settings" : "Axustes da xestión de usuarios",
     "Visibility" : "Visibilidade",
     "Show language" : "Amosar o idioma",
-    "Show user backend" : "Amosar a infraestrutura do usuario",
     "Show storage path" : "Amosar a ruta do almacenamento",
     "Show last login" : "Amosar o último acceso",
     "Send email" : "Enviar o correo",
-    "Send welcome email to new users" : "Enviar correo de benvida aos novos usuarios",
     "Defaults" : "Predeterminados",
     "Default quota" : "Cota predeterminada",
     "Select default quota" : "Seleccionar a cota predeterminada",
@@ -524,15 +498,13 @@ OC.L10N.register(
     "{license}-licensed" : "Licenciado baixo a {license}",
     "Changelog" : "Rexistro de cambios",
     "by {author}\n{license}" : "por {author}\n{license}",
-    "User management" : "Xestión de usuarios",
-    "Active users" : "Usuarios activos",
+    "New account" : "Conta nova",
     "Admins" : "Administración",
     "Disabled users" : "Usuarios desactivados",
     "Creating group …" : "Creando un grupo…",
     "Create group" : "Creando o grupo",
     "Group name" : "Nome do grupo",
     "Please enter a valid group name" : "Introduza un nome de grupo válido",
-    "User group: {group}" : "Grupo de usuarios: {group}",
     "Failed to create group" : "Produciuse un fallo ao crear o grupo",
     "Sending…" : "Enviando…",
     "Email sent" : "Correo enviado",
@@ -551,8 +523,6 @@ OC.L10N.register(
     "Profile visibility" : "Visibilidade do perfil",
     "Locale" : "Configuración rexional",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Non está dispoñíbel porque esta propiedade é precisa para as funcións básicas, como compartir ficheiros e convites de calendario",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Non está dispoñíbel porque a federación foi desactivada para a súa conta, póñase en contacto coa administración do sistema se ten algunha dúbida",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Non está dispoñíbel porque non se permite publicar datos específicos do usuario no servidor de buscas, póñase en contacto coa administración do sistema se ten algunha dúbida",
     "Your apps" : "As súas aplicacións",
     "Active apps" : "Aplicacións activas",
     "Disabled apps" : "Aplicacións desactivadas",
@@ -561,13 +531,13 @@ OC.L10N.register(
     "Featured apps" : "Aplicacións destacadas",
     "Supported apps" : "Aplicacións compatíbeis",
     "Show to everyone" : "Amosar a todos",
-    "Show to logged in users only" : "Amosar só aos usuarios que accederon",
     "Hide" : "Agochar",
     "Download and enable" : "Descargar e activar",
     "Allow untested app" : "Permitir aplicación non probada",
     "The app will be downloaded from the App Store" : "A aplicación descargarase da tenda de aplicacións",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Esta aplicación non está marcado como compatíbel coa súa versión de Nextcloud. Se continúa, poderá instalar a aplicación. Teña en conta que é probábel que a aplicación non funcione como se agarda.",
     "Never" : "Nunca",
+    "Active users" : "Usuarios activos",
     "An error occurred during the request. Unable to proceed." : "Produciuse un erro durante a solicitude. Non é posíbel continuar.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A aplicación foi activada pero necesita ser actualizada. Vai ser redirixido cara a páxina de actualizarións en 5 segundos.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Erro: non é posíbel activar esta aplicación porque fai que o servidor sexa inestábel",
@@ -577,13 +547,12 @@ OC.L10N.register(
     "Error while updating device token name" : "Produciuse un erro ao actualizar o nome do testemuño do dispositivo",
     "Error while updating device token scope" : "Produciuse un erro ao actualizar o ámbito do testemuño do dispositivo",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Houbo demasiadas solicitudes da súa rede. Volva tentalo máis adiante ou póñase en contacto coa administración desta instancia. se se trata dun erro.",
+    "Account documentation" : "Documentación da conta",
+    "Administration documentation" : "Documentación da administración da instancia",
     "Documentation" : "Documentación",
     "Forum" : "Foro",
     "Nextcloud help resources" : "Recursos de axuda de Nextcloud",
-    "Account documentation" : "Documentación da conta",
-    "Administration documentation" : "Documentación da administración da instancia",
     "General documentation" : "Documentación xeral",
-    "Login" : "Acceso",
     "None/STARTTLS" : "Ningún/STARTTLS",
     "SSL" : "SSL",
     "Open documentation" : "Abrir a documentación",
@@ -597,7 +566,6 @@ OC.L10N.register(
     "Authentication" : "Autenticación",
     "Authentication required" : "Precísase da autenticación",
     "Credentials" : "Credenciais",
-    "SMTP Username" : "Nome de usuario SMTP",
     "SMTP Password" : "Contrasinal SMTP",
     "Save" : "Gardar",
     "Test and verify email settings" : "Probe e verifique os axustes do correo",
@@ -618,6 +586,9 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Esta versión comunitaria de Nextcloud non é compatíbel e as notificacións instantáneas non están dispoñíbeis.",
     "Use a second factor besides your password to increase security for your account." : "Empregue un segundo factor ademais do seu contrasinal para aumentar a seguranza da súa conta.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "  Se usa aplicacións de terceiros para conectarse a Nextcloud, asegúrese de crear e configurar un contrasinal de aplicación para cada unha antes de activar a autenticación de segundo factor.",
+    "No user supplied" : "Non subministrado polo usuario",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Forneza un contrasinal de recuperación de administrador; senón perderase toda a información do usuario.",
+    "Backend does not support password change, but the user's encryption key was updated." : "A infraestrutura non admite o cambio de contrasinal, mais a chave de cifrado do usuario foi actualizada.",
     "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalar e actualizar aplicacións a través da tenda de aplicacións ou da nube federada compartida",
     "Federated Cloud Sharing" : "Nube federada compartida",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL está utilizando unha versión obsoleta %1$s (%2$s). Actualice o seu sistema operativo, caso contrario características como %3$s non funcionarán de xeito fiábel.",
@@ -630,7 +601,15 @@ OC.L10N.register(
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "O número máximo de chaves OPcache está case superado. Para garantir que todos os scripts poden manterse na caché, recoméndase aplicar <code>opcache.max_accelerated_files</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "O búfer OPcache está case cheo. Para garantir que todos os scripts se poidan gardar na caché, recoméndase aplicar <code>opcache.memory_consumption</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "O búfer de cadeas internas en OPcache está case cheo. Para asegurarse de que as cadeas que se repiten poidan almacenarse na caché de forma efectiva, recoméndase aplicar <code>opcache.interned_strings_buffer</code> á súa configuración de PHP cun valor superior a <code>%s</code>.",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "É necesario definir o seu correo de usuario antes de poder enviar correos de proba. Vaia a %spara iso.",
+    "Invalid user" : "Usuario incorrecto",
+    "Your username is: %s" : "O seu nome de usuario é: %s",
+    "Logged in user must be a subadmin" : "O usuario autenticado debe ser un subadministrador",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Está pendente un traballo en segundo plano que comprobe os certificados SSL importados polo usuario. Volva comprobar máis adiante.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Hai algúns certificados SSL importados polo usuario, que xa non se usan con Nextcloud 21. Pódense importar coa liña de ordes mediante a orde «occ security:certificates:import». As súas rutas dentro do directorio de datos amosanse deseguido.",
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Atopáronse UUID incorrectos de usuarios ou grupos LDAP. Revise a súa configuración de «Anular a detección de UUID» na parte Experto da configuración LDAP e utilice «occ ldap:update-uuid» para actualizalos.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "A autenticación de dous factores pode ser imposta para todos os usuarios e grupos específicos. Se non tiveran configurado un provedor de dous factores, non podería acceder ao sistema.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cando se seleccionan/exclúen os grupos, usase a seguinte lóxica para determinar se un usuario ten obrigada a A2F: Se non hai grupos seleccionados, a A2F está activa para todos agás os membros dos grupos excluídos. Se hai grupos seleccionados, a A2F está activa para todos os membros destes. Se un usuario está á vez nun grupo seleccionado e noutro excluído, o seleccionado ten preferencia e se lle obriga a A2F.",
     "Enable all" : "Activar todo",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
@@ -645,17 +624,29 @@ OC.L10N.register(
     "For security reasons this password will only be shown once." : "Por mor da seguranza ese contrasinal só se amosará unha vez. ",
     "Copied!" : "Copiado!",
     "Copy" : "Copiar",
+    "Execute one task with each page loaded. Use case: Single user instance." : "Executar unha tarefa con cada páxina cargada. Caso de uso: instancia de usuario único.",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php está rexistrado nun servizo webcron para chamar a cron.php cada 5 minutos a través de HTTP. Caso de uso: instancia moi pequena (de 1 a 5 usuarios segundo o uso).",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para executar isto necesitase a extensión POSIX de PHP. Vexa a {linkstart}documentación de PHP{linkend} para obter máis detalles. ",
     "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Use o servizo cron do sistema para chamar ao ficheiro cron.php cada 5 minutos. Recomendado para todos os casos.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "O cron.php debe ser executado polo usuario do sistema «{user}».",
+    "Enable or disable profile by default for new users." : "Activar ou desactivar o perfil predeterminado para os novos usuarios.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Está a piques de retirar o grupo {group}. Os usuarios NON van ser eliminados.",
     "Please confirm the group removal " : "Confirme a retirada do grupo ",
     "Choose profile picture from files" : "Escolla a imaxe de perfil en ficheiros",
     "png or jpg, max. 20 MB" : "png ou jpg, max. 20 MB",
     "Your email address" : "O seu enderezo de correo",
     "Your location" : "A súa localización",
+    "Enable Profile" : "Activar o perfil",
     "Your Twitter handle" : "O seu usuario do Twitter",
+    "You do not have permissions to see the details of this user" : "Vde. non ten permisos para ver os detalles deste usuario",
     "Add new password" : "Engadir un novo contrasinal",
     "Add new email address" : "Engadir un novo enderezo de correo",
+    "Set user as admin for" : "Definir o usuario como administrador para",
+    "Select user quota" : "Seleccionar a cota de usuario",
+    "Toggle user actions menu" : "Alternar o menú de accións do usuario",
+    "Delete user" : "Eliminar usuario",
+    "Disable user" : "Desactivar usuario",
+    "Enable user" : "Activar usuario",
     "Edit User" : "Editar usuario",
     "Will be autogenerated" : "Vai ser xerado automaticamente",
     "Add a new user" : "Engadir un novo usuario",
@@ -664,10 +655,15 @@ OC.L10N.register(
     "Add group" : "Engadir un grupo",
     "Default quota:" : "Cota predeterminada:",
     "Show Languages" : "Amosar os idiomas",
+    "Show user backend" : "Amosar a infraestrutura do usuario",
     "Send email to new user" : "Enviar correo ao novo usuario",
     "Not saved" : "Sen gardar",
     "Twitter" : "Twitter",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Non está dispoñíbel porque a federación foi desactivada para a súa conta, póñase en contacto coa administración do sistema se ten algunha dúbida",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Non está dispoñíbel porque non se permite publicar datos específicos do usuario no servidor de buscas, póñase en contacto coa administración do sistema se ten algunha dúbida",
+    "Show to logged in users only" : "Amosar só aos usuarios que accederon",
     "Enable untested app" : "Activar a aplicación sen probar",
+    "SMTP Username" : "Nome de usuario SMTP",
     "Expire after" : "Caduca após",
     "day(s)" : "día(s)",
     "Exclude groups from password requirements:" : "Excluír grupos dos requisitos de contrasinal:",
@@ -680,6 +676,16 @@ OC.L10N.register(
     "Select manager" : "Seleccionar o xestor",
     "User's table" : "Táboa de usuarios",
     "Select user manager" : "Seleccione o xestor de usuarios",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "A esta instancia fáltanlle algúns módulos PHP recomendados. Para mellorar o rendemento e unha mellor compatibilidade é moi recomendábel instalalos: %s."
+    "Old user imported certificates" : "Certificados antigos importados polo usuario",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "A esta instancia fáltanlle algúns módulos PHP recomendados. Para mellorar o rendemento e unha mellor compatibilidade é moi recomendábel instalalos: %s.",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Está a piques de retirar o grupo «{group}». Os usuarios NON van ser eliminados.",
+    "No users" : "Non hai usuarios",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Lista de usuarios. Esta lista non se representa de xeito completo por mor do rendemento. Os usuarios represéntanse mentres se despraza pola lista.",
+    "Loading user …" : "Cargando usuario…",
+    "Failed to update user manager" : "Produciuse un erro ao actualizar o xestor de usuarios",
+    "User management settings" : "Axustes da xestión de usuarios",
+    "Send welcome email to new users" : "Enviar correo de benvida aos novos usuarios",
+    "User management" : "Xestión de usuarios",
+    "User group: {group}" : "Grupo de usuarios: {group}"
 },
 "nplurals=2; plural=(n != 1);");
