@@ -45,15 +45,11 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "השמדת נתונים מרוחקת החלה ב־%1$s",
     "Remote wipe has finished on %1$s" : "השמדת נתונים מרוחקת הסתיימה ב־%1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "ה<strong>סמסה</strong> או <strong>כתוב הדוא״ל שלך</strong> השתנו",
-    "Apps" : "יישומונים",
+    "Settings" : "הגדרות",
     "Wrong password" : "ססמה שגויה",
     "Saved" : "נשמר",
-    "No user supplied" : "לא סופק שם משתמש",
     "Authentication error" : "שגיאת אימות",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "נא לספק ססמת שחזור של מנהלים, אחרת, כל נתוני המשתמשים ילכו לאיבוד.",
     "Wrong admin recovery password. Please check the password and try again." : "סיסמת המנהל לשחזור שגוייה. יש לבדוק את הסיסמא ולנסות שוב.",
-    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL משתמש בגרסה של %1$s שתוקפה פג (%2$s). נא לעדכן את מערכת ההפעלה או שתכונות כמו %3$s לא תפעלנה בצורה אמינה.",
     "Administrator documentation" : "תיעוד מנהל",
     "User documentation" : "תיעוד משתמש",
     "Invalid SMTP password." : "ססמת ה־SMTP שגויה.",
@@ -62,8 +58,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "אם קיבלת את הדוא״ל הזה, כנראה שתצורת הדוא״ל נכונה.",
     "Email could not be sent. Check your mail server log" : "לא ניתן לשלוח דוא״ל. נא לבדוק את רישומי שרת הדוא״ל שלך.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "בעיה אירעה בשליחת הדואר האלקטרוני. יש לשנות את ההגדרות שלך. (שגיאה: %s)",
-    "Users" : "משתמשים",
-    "Invalid user" : "משתמש שגוי",
+    "Invalid account" : "חשבון לא חוקי",
     "Invalid mail address" : "כתובת דואר אלקטרוני לא חוקית",
     "Settings saved" : "הגדרות נשמרו",
     "Unable to change full name" : "לא ניתן לשנות שם מלא",
@@ -88,14 +83,13 @@ OC.L10N.register(
     "Welcome aboard" : "ברוך בואך",
     "Welcome aboard %s" : "ברוך בואך %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "ברוך בואך לחשבונך ב־%s, יש לך את האפשרות להוסיף, להגן ולשתף את הנתונים שלך.",
-    "Your username is: %s" : "שם המשתמש שלך הוא: %s",
     "Set your password" : "הגדרת הססמה שלך",
     "Go to %s" : "מעבר אל %s",
     "Install Client" : "התקנת לקו",
-    "Logged in user must be a subadmin" : "המשתמש שנכנס חייב להיות תת־מנהל",
-    "Settings" : "הגדרות",
+    "Apps" : "יישומונים",
     "Personal" : "אישי",
     "Administration" : "ניהול",
+    "Users" : "משתמשים",
     "Additional settings" : "הגדרות נוספות",
     "Groupware" : "קבוצתי",
     "Overview" : "סקירה",
@@ -109,13 +103,12 @@ OC.L10N.register(
     "Background jobs" : "משימות רקע",
     "Unlimited" : "ללא הגבלה",
     "Verifying" : "מתבצע אימות",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "משימת רקע שבודקת את אישורי ה־SSL בייבוא המשתמש ממתינה. נא לדגום את הדף הזה שוב בהמשך.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "יש כמה אישורי SSL מיובאים קיימים שאינם בשימוש עוד ב־Nextcloud 21. אפשר לייבא אותם בשורת הפקודה עם הפקודה „occ security:certificates:import”. הנתיבים שלהם בתור תיקיית הנתונים מופיעים להלן.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "במסד הנתונים חסרים כמה עמודות אופציונליות. בשל העובדה שהוספת עמודות בטבלאות גדולות עשויה להימשך זמן מה, הן לא נוספו אוטומטית כאשר הן יכולות להיות אופציונליות. על ידי הפעלת \"occ db: add-missing-column\", ניתן להוסיף את העמודות החסרות האלה באופן ידני בזמן שהמופע ממשיך לפעול. לאחר הוספת העמודות, חלק מהתכונות עשויות לשפר את ההיענות או את השימושיות.",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "במסד הנתונים חסרים כמה מפתחות ראשיים. בשל העובדה שהוספת מפתחות ראשיים לטבלאות גדולות עשויה להימשך זמן מה, הם לא נוספו אוטומטית. על ידי הפעלת \"occ db: add-missing-primary-keys\", ניתן להוסיף מפתחות הראשיים החסרים האלה באופן ידני, בזמן שהמופע ממשיך לפעול.",
     "Disabled" : "מושבת",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "תצורת ההצפנה מצד השרת המיושנת מופעלת. אנו ממליצים להשבית אותה.",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "פונקציית ה־PHP‏ „set_time_limit” אינה זמינה. מצב זה עשוי לגרום לעצירת סקריפטים באמצע הפעולה ולפגיעה בהתקנה שלך. אנו ממליצים בחום להפעיל את הפונקציה הזאת.",
     "Supported" : "נתמך",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "ל־PHP שלך אין תמיכה ב־FreeType. מצב כזה יגרום לתמונות פרופיל משובשות לצד מנשק הגדרות משובש.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "מסתבר כי PHP לא מוגדר כראוי כדי לתשאל משתני סביבה. הבדיקה עם getenv(\"PATH\") מחזירה תשובה ריקה בלבד.",
@@ -138,7 +131,6 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "טקסט זה יופיע בקישור עמוד ההעלאה של הקישור הציבורי כאשר רשימת הקבצים מוסתרת.",
     "Default share permissions" : "הרשאות שיתוף כבררת מחדל",
     "Two-Factor Authentication" : "אימות דו־שלבי",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "ניתן לאכוף אימות דו־שלבי על כל המשתמשים ועל קבוצות מסוימות. אם אין להם ספק אימות דו־שלבי מוגדר, לא תהיה להם אפשרות להיכנס למערכת.",
     "Enforce two-factor authentication" : "אכיפת אימות דו־שלבי",
     "Limit to groups" : "הגבלה לקבוצות",
     "Enforcement of two-factor authentication can be set for certain groups only." : "ניתן להגדיר אכיפה של אימות דו־שלבי על קבוצות מסוימות בלבד.",
@@ -146,7 +138,6 @@ OC.L10N.register(
     "Enforced groups" : "קבוצות נאכפות",
     "Two-factor authentication is not enforced for members of the following groups." : "אימות דו־שלבי לא נאכף על החברים בקבוצות הבאות.",
     "Excluded groups" : "קבוצות חריגות",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "כאשר קבוצות נבחרות/מוחרגות, הן משתמשות בלוגיקה הבאה כדי להחליט האם נאכף על המשתמש אימות דו־שלבי: אם לא נבחרו קבוצות, אימות דו־שלבי פעיל עבור כולם למעט החברים בקבוצות שהוחרגו. אם נבחרו קבוצות, אימות דו־שלבי מופעל לכל החברים של הקבוצות האלו. אם משתמש נמצא גם בקבוצה נבחרת וגם בקבוצה מוחרגת, הנבחרת מקבלת עדיפות ואימות דו־שלבי נאכף.",
     "Save changes" : "שמירת שינויים",
     "All" : "הכל",
     "Limit app usage to groups" : "הגבלת השימוש ביישומון לקבוצות",
@@ -174,44 +165,25 @@ OC.L10N.register(
     "Results from other categories" : "תוצאות מקטגוריות אחרות",
     "No apps found for your version" : "לא נמצאו יישומים לגרסה שלך",
     "Disable all" : "להשבית הכול",
-    "_%n app has an update available_::_%n apps have an update available_" : ["לאחד היישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין"],
+    "_%n app has an update available_::_%n apps have an update available_" : ["לאחד היישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין","ל־%n יישומונים יש עדכון זמין"],
     "Marked for remote wipe" : "מסומן להשמדת נתונים מרחוק",
     "Device settings" : "הגדרות מכשיר",
     "Allow filesystem access" : "לאפשר גישה למערכת הקבצים",
     "Rename" : "שינוי שם",
     "Revoke" : "שלילה",
     "Wipe device" : "השמדת נתוני מכשיר",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome עבור Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "לקוח סנכרון - {os}",
     "This session" : "הפעלה זו",
     "Device" : "התקן",
     "Last activity" : "פעילות אחרונה",
     "Devices & sessions" : "התקנים והפעלות",
     "Web, desktop and mobile clients currently logged in to your account." : "לקוחות שמחוברים כעת לחשבון שלך דרך דפדפן, שולחן עבודה והתקנים ניידים.",
-    "Do you really want to wipe your data from this device?" : "להשמיד את הנתונים שלך במכשיר הזה?",
-    "Confirm wipe" : "אישור ההשמדה",
-    "Error while creating device token" : "שגיאה בזמן יצירת מחרוזת התקן",
-    "Error while updating device token scope" : "שגיאה בעדכון טווח אסימון מכשירים",
-    "Error while updating device token name" : "שגיאה בעת עדכון שם אסימון המכשיר",
-    "Error while deleting the token" : "שגיאה בזמן מחיקת המחרוזת",
-    "Error while wiping the device with the token" : "שגיאה בעת השמדת נתוני המכשיר עם האסימון",
     "App name" : "שם יישום",
     "Create new app password" : "יצירת סיסמת יישום חדשה",
-    "Use the credentials below to configure your app or device." : "יש להשתמש בפרטי הזיהוי שלהלן כדי להגדיר את היישומון או ההתקן שלך.",
-    "For security reasons this password will only be shown once." : "מטעמי אבטחה הססמה תופיע פעם אחת בלבד.",
-    "Username" : "שם משתמש",
+    "Error while creating device token" : "שגיאה בזמן יצירת מחרוזת התקן",
+    "Login" : "התחברות",
     "Password" : "ססמה",
-    "Done" : "הסתיים",
     "Show QR code for mobile apps" : "הצגת קוד QR ליישומונים לניידים",
-    "Copied!" : "הועתק!",
-    "Copy" : "העתקה",
     "Could not copy app password. Please copy it manually." : "לא ניתן להעתיק את הססמה של היישומון. נא להעתיק אותה ידנית.",
     "Use system cron service to call the cron.php file every 5 minutes." : "להשתמש בשירות ה־cron של המערכת כדי לקרוא לקובץ cron.php כל 5 דקות.",
     "Profile" : "פרופיל",
@@ -236,7 +208,9 @@ OC.L10N.register(
     "Picture provided by original account" : "תמונה סופקה על ידי חשבון מקור",
     "Details" : "פרטים",
     "You are a member of the following groups:" : "הקבוצות הבאות כוללות אותך:",
+    "Back" : "אחורה",
     "No email address set" : "לא נקבעה כתובת דואר אלקטרוני",
+    "Languages" : "שפות",
     "Help translate" : "עזרה בתרגום",
     "No language set" : "לא הוגדרה שפה",
     "Your phone number" : "מספר הטלפון שלך",
@@ -254,18 +228,14 @@ OC.L10N.register(
     "Quota" : "מכיסה",
     "Language" : "שפה",
     "Avatar" : "תמונה מייצגת",
+    "Username" : "שם משתמש",
     "Group admin for" : "הנהלת הקבוצה",
     "User backend" : "מנגנון משתמש",
     "Storage location" : "מיקום אחסון",
     "Last login" : "כניסה אחרונה",
-    "You do not have permissions to see the details of this user" : "אין לך הרשאות לצפות בפירוט על המשתמש",
-    "Set user as admin for" : "הגדרת משתמש כהנהלה של",
-    "Select user quota" : "בחירת מכסת משתמש",
     "{size} used" : "{size} בשימוש",
-    "Delete user" : "מחיקת משתמש",
+    "Delete account" : "מחיקת חשבון",
     "Wipe all devices" : "השמדת נתוני כל המכשירים",
-    "Disable user" : "השבתת משתמש",
-    "Enable user" : "הפעלת משתמש",
     "Resend welcome email" : "שליחת הודעת קבלת פנים בדוא״ל מחדש",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "במקרה של אובדן מכשיר או עזיבה של הארגון, מנגנון זה יכול להשמיד את נתוני ה־Nextcloud מכל המכשירים שמשויכים אל {userid}. יעבוד רק אם כל המכשירים מחוברים לאינטרנט.",
     "Remote wipe of devices" : "השמדת נתונים מרוחקת במכשירים",
@@ -274,9 +244,8 @@ OC.L10N.register(
     "Account deletion" : "מחיקת חשבון",
     "Delete {userid}'s account" : "מחיקת החשבון של {userid}",
     "Welcome mail sent!" : "נשלחה הודעת קבלת פנים בדוא״ל!",
-    "Toggle user actions menu" : "החלפת מצב תפריט פעולות משתמש",
+    "Done" : "הסתיים",
     "Edit" : "עריכה",
-    "Show user backend" : "הצגת צד אחורי למשתמש",
     "Show storage path" : "הצגת נתיב אחסון",
     "Show last login" : "הצגת כניסה אחרונה",
     "Send email" : "שליחת דואר אלקטרוני",
@@ -299,7 +268,7 @@ OC.L10N.register(
     "{license}-licensed" : "ברישיון {license}",
     "Changelog" : "יומן שינויים",
     "by {author}\n{license}" : "מאת {author}\n{license}",
-    "Active users" : "משתמשים פעילים",
+    "New account" : "חשבון חדש",
     "Admins" : "מנהלים",
     "Disabled users" : "משתמשים מושבתים",
     "Group name" : "שם קבוצה",
@@ -322,11 +291,16 @@ OC.L10N.register(
     "Download and enable" : "להוריד ולהפעיל",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "היישומון הזה לא מסומן כנתמך בגרסת ה־Nextcloud. עדיין יתאפשר לך להמשיך ולהתקין את היישומון. נא לשים לב שיכול להיות שהיישומון לא יעבוד כצפוי.",
     "Never" : "מעולם לא",
+    "Active users" : "משתמשים פעילים",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "היישומון הופעל אך יש לעדכן אותו. ההפניה לעמוד העדכון תחל בעוד 5 שניות.",
+    "Do you really want to wipe your data from this device?" : "להשמיד את הנתונים שלך במכשיר הזה?",
+    "Confirm wipe" : "אישור ההשמדה",
+    "Error while wiping the device with the token" : "שגיאה בעת השמדת נתוני המכשיר עם האסימון",
+    "Error while updating device token name" : "שגיאה בעת עדכון שם אסימון המכשיר",
+    "Error while updating device token scope" : "שגיאה בעדכון טווח אסימון מכשירים",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "היו יותר מדי בקשות מהרשת שלך. נסה שוב מאוחר יותר, או צור קשר עם מנהל המערכת שלך אם זו שגיאה.",
     "Documentation" : "תיעוד",
     "Forum" : "פורום",
-    "Login" : "התחברות",
     "SSL" : "SSL",
     "Open documentation" : "תיעוד פתוח",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "חשוב להגדיר את השרת הזה כדי שיתאפשר לשלוח דרכו הודעות דוא״ל, למשל כדי לאפס ססמה ולשלוח התרעות.",
@@ -339,7 +313,6 @@ OC.L10N.register(
     "Authentication" : "אימות",
     "Authentication required" : "נדרש אימות",
     "Credentials" : "פרטי גישה",
-    "SMTP Username" : "שם משתמש SMTP ",
     "SMTP Password" : "סיסמת SMTP",
     "Save" : "שמור",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "למטרות אבטחה וביצועים מיטביים עבור המערכת שלך חשוב שהכול יוגדר כראוי. כדי לסייע לך בכך אנו עורכים בדיקות אוטומטיות. נא לעיין בתיעוד המקושר לקבלת מידע נוסף.",
@@ -358,14 +331,45 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו",
     "Use a second factor besides your password to increase security for your account." : "ניתן להשתמש בגורם נוסף מלבד הססמה שלך כדי להגביר את אבטחת החשבון שלך.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "אם משמשים אותך יישומי צד־שלישי להתחברות אל Nextcloud, נא לוודא יצירת והגדרת ססמה ליישומון לכל אחד מהם בטרם הפעלת אימות דו־שלבי.",
+    "No user supplied" : "לא סופק שם משתמש",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "נא לספק ססמת שחזור של מנהלים, אחרת, כל נתוני המשתמשים ילכו לאיבוד.",
+    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL משתמש בגרסה של %1$s שתוקפה פג (%2$s). נא לעדכן את מערכת ההפעלה או שתכונות כמו %3$s לא תפעלנה בצורה אמינה.",
+    "Invalid user" : "משתמש שגוי",
+    "Your username is: %s" : "שם המשתמש שלך הוא: %s",
+    "Logged in user must be a subadmin" : "המשתמש שנכנס חייב להיות תת־מנהל",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "משימת רקע שבודקת את אישורי ה־SSL בייבוא המשתמש ממתינה. נא לדגום את הדף הזה שוב בהמשך.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "יש כמה אישורי SSL מיובאים קיימים שאינם בשימוש עוד ב־Nextcloud 21. אפשר לייבא אותם בשורת הפקודה עם הפקודה „occ security:certificates:import”. הנתיבים שלהם בתור תיקיית הנתונים מופיעים להלן.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "ניתן לאכוף אימות דו־שלבי על כל המשתמשים ועל קבוצות מסוימות. אם אין להם ספק אימות דו־שלבי מוגדר, לא תהיה להם אפשרות להיכנס למערכת.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "כאשר קבוצות נבחרות/מוחרגות, הן משתמשות בלוגיקה הבאה כדי להחליט האם נאכף על המשתמש אימות דו־שלבי: אם לא נבחרו קבוצות, אימות דו־שלבי פעיל עבור כולם למעט החברים בקבוצות שהוחרגו. אם נבחרו קבוצות, אימות דו־שלבי מופעל לכל החברים של הקבוצות האלו. אם משתמש נמצא גם בקבוצה נבחרת וגם בקבוצה מוחרגת, הנבחרת מקבלת עדיפות ואימות דו־שלבי נאכף.",
     "Enable all" : "הפעלת הכול",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Sync client - {os}" : "לקוח סנכרון - {os}",
+    "Error while deleting the token" : "שגיאה בזמן מחיקת המחרוזת",
+    "Use the credentials below to configure your app or device." : "יש להשתמש בפרטי הזיהוי שלהלן כדי להגדיר את היישומון או ההתקן שלך.",
+    "For security reasons this password will only be shown once." : "מטעמי אבטחה הססמה תופיע פעם אחת בלבד.",
+    "Copied!" : "הועתק!",
+    "Copy" : "העתקה",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "כדי להריץ זאת יש צורך בהרחבת POSIX ל־PHP. נא לעיין ב{linkstart}תיעוד של PHP{linkend} לפרטים נוספים.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "פעולה זו תסיר את הקבוצה {group}. המשתמשים ﬥﬡ יימחקו.",
     "Please confirm the group removal " : "נא לאשר את הסרת הקבוצה",
     "png or jpg, max. 20 MB" : "png או jpg, מקסימום 20 מגה-בייט",
     "Your email address" : "כתובת הדואר האלקטרוני שלך",
+    "You do not have permissions to see the details of this user" : "אין לך הרשאות לצפות בפירוט על המשתמש",
     "Add new password" : "הוספת ססמה חדשה",
     "Add new email address" : "הוספת כתובת דוא״ל חדשה",
+    "Set user as admin for" : "הגדרת משתמש כהנהלה של",
+    "Select user quota" : "בחירת מכסת משתמש",
+    "Toggle user actions menu" : "החלפת מצב תפריט פעולות משתמש",
+    "Delete user" : "מחיקת משתמש",
+    "Disable user" : "השבתת משתמש",
+    "Enable user" : "הפעלת משתמש",
     "Edit User" : "עריכת משתמש",
     "Will be autogenerated" : "ייווצר אוטומטית",
     "Add a new user" : "הוספת משתמש חדש",
@@ -374,13 +378,15 @@ OC.L10N.register(
     "Add group" : "הוספת קבוצה",
     "Default quota:" : "מכסת בררת מחדל:",
     "Show Languages" : "הצגת שפות",
+    "Show user backend" : "הצגת צד אחורי למשתמש",
     "Send email to new user" : "שליחת דואר אלקטרוני למשתמש חדש",
     "Not saved" : "לא נשמר",
     "Twitter" : "טוויטר",
     "Enable untested app" : "לאפשר יישומון שלא נבדק",
+    "SMTP Username" : "שם משתמש SMTP ",
     "day(s)" : "ימים",
     "Set default expiration date" : "הגדרת תאריך תפוגה ברירת מחדל",
     "Allow username autocompletion in share dialog" : "לאפשר השלמה אוטומטית של שם משתמש בחלונית השיתוף",
     "Allow username autocompletion to users within the same groups" : "לאפשר השלמה אוטומטית של שם משתמש למשתמשים בתוך אותן הקבוצות"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
