@@ -48,16 +48,11 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Udaljeno brisanje pokrenuto je %1$s",
     "Remote wipe has finished on %1$s" : "Udaljeno brisanje završilo je %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Izmijenjena je vaša <strong>zaporka</strong> ili <strong>adresa e-pošte</strong>",
-    "Apps" : "Aplikacije",
+    "Settings" : "Postavke",
     "Wrong password" : "Pogrešna zaporka",
     "Saved" : "Spremljeno",
-    "No user supplied" : "Nijedan korisnik nije podnesen",
     "Authentication error" : "Pogrešna autentifikacija",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Unesite administratorsku zaporku za oporavak; u protivnom će svi podaci korisnika biti izgubljeni.",
     "Wrong admin recovery password. Please check the password and try again." : "Pogrešna administratorska zaporka za oporavak. Provjerite zaporku i pokušajte ponovno.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instaliranje i ažuriranje aplikacija putem trgovine aplikacijama ili dijeljenja putem udruženog oblaka",
-    "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL upotrebljava zastarjelu inačicu %1$s (%2$s). Ažurirajte svoj operacijski sustav kako bi značajke, kao što je %3$s, pouzdano radile.",
     "Administrator documentation" : "Dokumentacija za administratora",
     "User documentation" : "Dokumentacija za korisnike",
     "Invalid SMTP password." : "Nevaljana zaporka za SMTP.",
@@ -66,8 +61,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Ako ste primili ovu poruku e-pošte, čini se da je e-pošta pravilno konfigurirana.",
     "Email could not be sent. Check your mail server log" : "Slanje poruke e-pošte nije uspjelo. Provjerite zapis poslužitelja e-pošte",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Došlo je do problema pri slanju poruke e-pošte. Pregledajte svoje postavke. (Pogreška: %s)",
-    "Users" : "Korisnici",
-    "Invalid user" : "Nevažeći korisnik",
+    "Invalid account" : "Nevažeći račun",
     "Invalid mail address" : "Nevažeća adresa e-pošte",
     "Settings saved" : "Postavke spremljene",
     "Unable to change full name" : "Nije moguće promijeniti puno ime",
@@ -93,14 +87,13 @@ OC.L10N.register(
     "Welcome aboard" : "Dobrodošli",
     "Welcome aboard %s" : "Dobrodošli u %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Dobrodošli u svoj račun %s, sada možete dodati, zaštititi i dijeliti svoje podatke.",
-    "Your username is: %s" : "Vaše korisničko ime je: %s",
     "Set your password" : "Postavite zaporku",
     "Go to %s" : "Idi na %s",
     "Install Client" : "Instaliraj klijenta",
-    "Logged in user must be a subadmin" : "Korisnik koji je prijavljen mora biti podadministrator",
-    "Settings" : "Postavke",
+    "Apps" : "Aplikacije",
     "Personal" : "Osobno",
     "Administration" : "Administracija",
+    "Users" : "Korisnici",
     "Additional settings" : "Dodatne postavke",
     "Administration privileges" : "Ovlasti za administriranje",
     "Groupware" : "Groupware",
@@ -114,21 +107,42 @@ OC.L10N.register(
     "Email server" : "Poslužitelj e-pošte",
     "Security & setup warnings" : "Upozorenja o sigurnosti i postavljanju",
     "Background jobs" : "Pozadinski zadaci",
-    "Create" : "Stvori",
-    "Change" : "Promijeni",
-    "Delete" : "Izbriši",
-    "Reshare" : "Dijeli ponovno",
     "Unlimited" : "Neograničeno",
     "Verifying" : "Provjeravanje",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Na čekanju je pozadinski zadatak za provjeravanje vjerodajnica SSL-a koje uvezu korisnici. Provjerite ponovno kasnije.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Prisutne su vjerodajnice SSL-a koje su uvezli korisnici i koje Nextcloud 21 ne upotrebljava. Mogu se uvesti putem naredbenog retka s pomoću naredbe „occ security:certificates:import”. U nastavku su prikazani njihovi putovi unutar podatkovnog direktorija.",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "U bazi podataka nedostaju određeni neobavezni stupci. Zbog činjenice da bi dodavanje stupaca u velikim tablicama moglo potrajati neko duže vrijeme, stupci se ne dodaju automatski, već je njihovo dodavanje neobavezno. Izvršenjem „occ db:add-missing-columns” ti se stupci mogu ručno dodati dok instanca radi. Nakon dodavanja stupaca može se poboljšati odaziv ili uporabljivost određenih značajki.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "U bazi podataka nedostaju određeni indeksi. Zbog činjenice da bi dodavanje indeksa u velikim tablicama moglo potrajati neko duže vrijeme, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-indices” se ti indeksi mogu ručno dodati dok instanca radi. Kada se indeksi dodaju, upiti u te tablice obično su mnogo brži.",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "U bazi podataka nedostaju određeni primarni ključevi. Zbog činjenice da bi dodavanje primarnih ključeva moglo potrajati neko duže vrijeme u velikim tablicama, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-primary-keys” ti se primarni ključevi mogu ručno dodati dok instanca radi.",
+    "Disabled" : "Onemogućeno",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Omogućen je stari format šifriranja na strani poslužitelja. Preporučujemo da ga onemogućite.",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcija PHP-a „set_time_limit” nije dostupna. To bi moglo dovesti do zaustavljanja skripti tijekom izvršenja i prekida instalacije. Preporučuje se uključivanje ove funkcije.",
+    "Supported" : "Podržano",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vaš PHP nema podršku za FreeType što može uzrokovati neispravan prikaz profilnih slika i sučelja postavki.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Čini se da PHP nije ispravno postavljen za slanje upita u vezi s varijablama okruženja sustava. Ispitivanje s getenv („PATH”) vraća samo prazan odgovor.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Omogućena je konfiguracija samo za čitanje. Time se sprječava postavljanje nekih konfiguracija putem web-sučelja. Nadalje, datoteku treba ručno prebaciti u način pisanja pri svakom ažuriranju.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaša se baza podataka ne pokreće s razinom izolacije transakcije „READ COMMITTED”. To može uzrokovati probleme kada se paralelno izvršava više radnji.",
     "Nextcloud settings" : "Postavke Nextclouda",
     "Here you can decide which group can access certain sections of the administration settings." : "Ovdje možete odlučiti koja grupa može pristupiti određenim dijelovima administratorskih postavki.",
     "None" : "Nema",
     "Unable to modify setting" : "Nije moguće izmijeniti postavku",
+    "Allow apps to use the Share API" : "Dopusti aplikacijama korištenje API-ja za dijeljenje",
+    "Allow resharing" : "Dopusti ponovno dijeljenje",
+    "Allow sharing with groups" : "Dopusti dijeljenje s grupama",
+    "Restrict users to only share with users in their groups" : "Ograniči korisnike na dijeljenje samo s korisnicima unutar svoje grupe",
+    "Allow users to share via link and emails" : "Dopusti korisnicima dijeljenje putem poveznice i e-pošte",
+    "Allow public uploads" : "Dopusti javne otpreme",
+    "Always ask for a password" : "Uvijek traži zaporku",
+    "Enforce password protection" : "Nametni zaštitu zaporkom",
+    "Exclude groups from sharing" : "Izuzmi grupe iz dijeljenja",
+    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene sadržaje, ali ih neće moći pokrenuti.",
+    "Set default expiration date for shares" : "Postavi zadani datum isteka dijeljenja",
+    "Enforce expiration date" : "Primijeni datum isteka",
+    "Set default expiration date for shares to other servers" : "Postavi zadani datum isteka dijeljenja na druge poslužitelje",
+    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ako je omogućeno automatsko dovršavanje „ista grupa” i „integracija telefonskog broja”, bilo koje od tih podudaranja dovoljno je za prikaz korisnika.",
+    "Allow username autocompletion to users based on phone number integration" : "Omogući korisnicima automatsko dovršavanje korisničkog imena na temelju integracije telefonskog broja",
+    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Prikaži tekst izjave o odricanju od odgovornosti na stranici za otpremanje javnih poveznica (prikazuje se samo kad je popis datoteka skriven)",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Ovaj će tekst biti prikazan na stranici za otpremanje javnih poveznica kad je popis datoteka skriven.",
+    "Default share permissions" : "Zadana dopuštenja za dijeljenje",
     "Two-Factor Authentication" : "Dvofaktorska autentifikacija",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvofaktorska autentifikacija može se primijeniti na sve korisnike i određene grupe. Ako nisu konfigurirali davatelje usluge dvofaktorske autentifikacije, neće se moći prijaviti u sustav.",
     "Enforce two-factor authentication" : "Primijeni dvofaktorsku autentifikaciju",
     "Limit to groups" : "Ograniči na grupe",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Primjena dvofaktorske autentifikacije može se postaviti samo za određene grupe.",
@@ -136,7 +150,6 @@ OC.L10N.register(
     "Enforced groups" : "Obuhvaćene grupe",
     "Two-factor authentication is not enforced for members of the following groups." : "Dvofaktorska autentifikacija ne primjenjuje se na članove sljedećih grupa.",
     "Excluded groups" : "Izuzete grupe",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Nakon odabira grupa koje će biti obuhvaćene/izuzete, primjenjuje se sljedeća logika za utvrđivanje je li 2FA omogućen za određenog korisnika: ako nije odabrana nijedna grupa, 2FA je omogućen za sve osim za članove izuzetih grupa. Ako su odabrane određene grupe, 2FA je omogućen samo za sve članove tih grupa. Ako je korisnik član odabrane i izuzete grupe, odabrana grupa ima prednost i 2FA se primjenjuje.",
     "Save changes" : "Spremi promjene",
     "All" : "Sve",
     "Limit app usage to groups" : "Ograničite primjenu aplikacije na grupe",
@@ -153,7 +166,6 @@ OC.L10N.register(
     "Admin documentation" : "Dokumentacija za administratore",
     "Developer documentation" : "Dokumentacija za razvojne programere",
     "This app is supported via your current Nextcloud subscription." : "Aplikacija je podržana unutar vaše trenutne pretplate na Nextcloud.",
-    "Supported" : "Podržano",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Istaknute aplikacije razvijaju članovi zajednice. One nude osnovnu funkcionalnost i spremne su za produkciju.",
     "Featured" : "Istaknuto",
     "Update to {update}" : "Ažuriraj na {update}",
@@ -172,41 +184,22 @@ OC.L10N.register(
     "Rename" : "Preimenuj",
     "Revoke" : "Opozovi",
     "Wipe device" : "Izbriši sve s uređaja",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome za Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
     "{productName} iOS app" : "{productName} aplikacija za iOS",
     "{productName} Android app" : "{productName} aplikacija za Android",
     "{productName} Talk for iOS" : "{productName} Talk za iOS",
     "{productName} Talk for Android" : "{productName} Talk za Android",
-    "Sync client - {os}" : "Sinkroniziraj klijenta – {os}",
     "This session" : "Ova sesija",
     "Device" : "Uređaj",
     "Last activity" : "Posljednja aktivnost",
     "Devices & sessions" : "Uređaji i sesije",
     "Web, desktop and mobile clients currently logged in to your account." : "Web, računalni i mobilni klijenti trenutno prijavljeni u vaš račun.",
-    "Do you really want to wipe your data from this device?" : "Želite li zaista izbrisati podatke s ovog uređaja?",
-    "Confirm wipe" : "Potvrdi brisanje",
-    "Error while creating device token" : "Pogreška pri stvaranju tokena za uređaj",
-    "Error while updating device token scope" : "Pogreška pri ažuriranju raspona tokena za uređaj",
-    "Error while updating device token name" : "Pogreška pri ažuriranju naziva tokena za uređaja",
-    "Error while deleting the token" : "Pogreška pri brisanju tokena",
-    "Error while wiping the device with the token" : "Pogreška pri brisanju sadržaja uređaja tokenom",
     "App name" : "Naziv aplikacije",
     "Create new app password" : "Stvori novu zaporku za aplikaciju",
-    "Use the credentials below to configure your app or device." : "Upotrijebite vjerodajnice navedene u nastavku za konfiguriranje aplikacije ili uređaja.",
-    "For security reasons this password will only be shown once." : "Iz sigurnosnih razloga ta će se zaporka prikazati samo jednom.",
-    "Username" : "Korisničko ime",
+    "Error while creating device token" : "Pogreška pri stvaranju tokena za uređaj",
+    "Login" : "Prijava",
     "Password" : "Zaporka",
-    "Done" : "Gotovo",
     "Show QR code for mobile apps" : "Prikaži QR kôd za mobilne aplikacije",
-    "Copied!" : "Kopirano!",
-    "Copy" : "Kopiraj",
     "Could not copy app password. Please copy it manually." : "Kopiranje zaporke aplikacije nije uspjelo. Kopirajte je ručno.",
     "Use system cron service to call the cron.php file every 5 minutes." : "Koristite se sistemskim servisom cron za pozivanje datoteke cron.php svakih 5 minuta.",
     "Profile" : "Profil",
@@ -221,27 +214,25 @@ OC.L10N.register(
     "This is the final warning: Do you really want to enable encryption?" : "Ovo je posljednje upozorenje: želite li zaista omogućiti šifriranje?",
     "No encryption module loaded, please enable an encryption module in the app menu." : "Nije učitan modul za šifriranje, omogućite modul za šifriranje u izborniku aplikacije.",
     "Select default encryption module:" : "Odaberi zadani modul za šifriranje:",
+    "Cancel" : "Odustani",
+    "Confirm" : "Potvrdi",
     "Submit" : "Šalji",
     "Remove group" : "Ukloni grupu",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Izbrisat ćete grupu {group}. Korisnici NEĆE biti izbrisani.",
-    "Please confirm the group removal " : "Potvrdite uklanjanje grupe ",
     "Current password" : "Trenutna zaporka",
     "New password" : "Nova zaporka",
     "Change password" : "Promijeni zaporku",
     "Picture provided by original account" : "Slika s izvornog računa",
-    "Cancel" : "Odustani",
     "Your biography" : "Vaša biografija",
     "Details" : "Pojedinosti",
     "You are a member of the following groups:" : "Član ste sljedećih grupa:",
     "Your full name" : "Vaše ime i prezime",
-    "Email options" : "Mogućnosti e-pošte",
+    "This address is not confirmed" : "Ova adresa nije potvrđena",
     "Primary email for password reset and notifications" : "Primarna e-pošta za resetiranje zaporke i primanje obavijesti",
+    "Email options" : "Mogućnosti e-pošte",
     "Remove primary email" : "Ukloni primarnu adresu e-pošte",
     "Delete email" : "Izbriši adresu e-pošte",
     "Unset as primary email" : "Poništi primarnu adresu e-pošte",
-    "This address is not confirmed" : "Ova adresa nije potvrđena",
     "Set as primary email" : "Postavi kao primarnu adresu e-pošte",
-    "Your email address" : "Vaša adresa e-pošte",
     "Additional email address {index}" : "Dodatne adrese e-pošte {index}",
     "Unable to delete primary email address" : "Nije moguće izbrisati primarnu adresu e-pošte",
     "Unable to update primary email address" : "Nije moguće ažurirati primarnu adresu e-pošte",
@@ -251,20 +242,21 @@ OC.L10N.register(
     "No email address set" : "Nije postavljena adresa e-pošte",
     "Additional emails" : "Dodatne adrese e-pošte",
     "Your headline" : "Vaš naslov",
-    "Language" : "Jezik",
     "Help translate" : "Pomozite prevesti",
     "Unable to update language" : "Nije moguće ažurirati jezik",
     "No language set" : "Nije postavljen jezik",
-    "Locale" : "Lokacija",
     "Your organisation" : "Vaša organizacija",
     "Your phone number" : "Vaš broj telefona",
     "Edit your Profile visibility" : "Uredite vidljivost profila",
-    "Enable Profile" : "Omogući profil",
     "Unable to update profile enabled state" : "Nije moguće ažurirati stanje omogućenog profila",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Na profilu se primjenjuje stroža postavka vidljivosti ili opsega. Na primjer, ako je vidljivost postavljena na „Prikaži svima”, a opseg je postavljen na „Privatno”, primjenjuje se „Privatno”.",
     "Unable to update visibility of {displayId}" : "Nije moguće ažurirati vidljivost za {displayId}",
     "Your role" : "Vaša uloga",
     "Add" : "Dodaj",
+    "Create" : "Stvori",
+    "Change" : "Promijeni",
+    "Delete" : "Izbriši",
+    "Reshare" : "Dijeli ponovno",
     "Default language" : "Zadani jezik",
     "Common languages" : "Česti jezici",
     "Other languages" : "Drugi jezici",
@@ -273,20 +265,17 @@ OC.L10N.register(
     "Display name" : "Ime za prikaz",
     "Email" : "E-pošta",
     "Quota" : "Kvota",
+    "Language" : "Jezik",
     "Avatar" : "Avatar",
+    "Username" : "Korisničko ime",
     "Group admin for" : "Administrator grupe za",
     "User backend" : "Korisnički pozadinski sustav",
     "Storage location" : "Mjesto pohrane",
     "Last login" : "Posljednja prijava",
-    "You do not have permissions to see the details of this user" : "Nemate dopuštenja za prikaz pojedinosti ovog korisnika",
     "Add user to group" : "Dodaj korisnika u grupu",
-    "Set user as admin for" : "Postavi korisnika kao administratora za",
-    "Select user quota" : "Odaberi kvotu korisnika",
     "{size} used" : "Iskorišteno {size}",
-    "Delete user" : "Izbriši korisnika",
+    "Delete account" : "Izbriši račun",
     "Wipe all devices" : "Izbriši podatke sa svih uređaja",
-    "Disable user" : "Onemogući korisnika",
-    "Enable user" : "Omogući korisnika",
     "Resend welcome email" : "Ponovno pošalji poruku dobrodošlice",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "U slučaju gubitka uređaja ili napuštanja organizacije, može daljinski izbrisati Nextcloudove podatke sa svih uređaja kojima se koristi {userid}. Brisanje je moguće samo ako su uređaji povezani na internet.",
     "Remote wipe of devices" : "Daljinsko brisanje podataka s uređaja",
@@ -295,9 +284,8 @@ OC.L10N.register(
     "Account deletion" : "Brisanje računa",
     "Delete {userid}'s account" : "Izbriši račun koji pripada {userid}",
     "Welcome mail sent!" : "Poslana poruka dobrodošlice!",
-    "Toggle user actions menu" : "Uklj./isklj. izbornik s radnjama korisnika",
+    "Done" : "Gotovo",
     "Edit" : "Uredi",
-    "Show user backend" : "Prikaži korisnički pozadinski sustav",
     "Show storage path" : "Prikaži put pohrane",
     "Show last login" : "Prikaži posljednju prijavu",
     "Send email" : "Pošalji poruku e-pošte",
@@ -316,16 +304,15 @@ OC.L10N.register(
     "No devices configured." : "Nema konfiguriranih uređaja.",
     "The following devices are configured for your account:" : "Sljedeći su uređaji konfigurirani za vaš račun:",
     "Your browser does not support WebAuthn." : "Vaš preglednik ne podržava WebAuthn.",
-    "Your apps" : "Vaše aplikacije",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administrator možete detaljnije podešavati dijeljenja. Pogledajte odgovarajuću dokumentaciju za više informacija.",
+    "You need to enable the File sharing App." : "Morate omogućiti aplikaciju za dijeljenje datoteka.",
     "{license}-licensed" : "Licencirano prema {license}",
     "Changelog" : "Zapis promjena",
     "by {author}\n{license}" : "{autor}\n{licenca}",
-    "Enter group name" : "Unesite naziv grupe",
-    "Add group" : "Dodaj grupu",
-    "Active users" : "Aktivni korisnici",
+    "New account" : "Novi račun",
     "Admins" : "Administratori",
     "Disabled users" : "Onemogućeni korisnici",
-    "Not saved" : "Nije spremljeno",
+    "Group name" : "Naziv grupe",
     "Sending…" : "Slanje…",
     "Email sent" : "E-pošta je poslana",
     "Location" : "Lokacija",
@@ -337,29 +324,33 @@ OC.L10N.register(
     "Organisation" : "Organizacija",
     "Phone number" : "Broj telefona",
     "Role" : "Uloga",
-    "Twitter" : "Twitter",
     "Website" : "Web-mjesto",
     "Profile visibility" : "Vidljivost profila",
+    "Locale" : "Lokacija",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Nije dostupno jer je ovo svojstvo potrebno za osnovnu funkcionalnost, uključujući dijeljenje datoteka i pozivnice za kalendar",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nije dostupno jer nije dopušteno objavljivanje korisničkih podataka na poslužitelju pretraživanja, obratite se administratoru sustava ako imate pitanja",
+    "Your apps" : "Vaše aplikacije",
     "Active apps" : "Aktivne aplikacije",
     "Disabled apps" : "Onemogućene aplikacije",
     "Updates" : "Ažuriranja",
     "App bundles" : "Paketi aplikacija",
     "Featured apps" : "Istaknute aplikacije",
     "Show to everyone" : "Prikaži svima",
-    "Show to logged in users only" : "Prikaži samo prijavljenim korisnicima",
     "Hide" : "Sakrij",
     "Download and enable" : "Preuzmi i omogući",
     "The app will be downloaded from the App Store" : "Aplikacija će se preuzeti iz trgovine aplikacijama",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ova aplikacija nije označena kao kompatibilna s vašom inačicom Nextclouda. Ako odlučite nastaviti, moći ćete instalirati aplikaciju. Imajte na umu da aplikacija možda neće raditi kako očekujete.",
     "Never" : "Nikad",
+    "Active users" : "Aktivni korisnici",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacija je omogućena, ali je treba ažurirati. Za 5 sekundi bit ćete preusmjereni na stranicu za ažuriranje.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Pogreška: ova aplikacija ne može biti omogućena jer čini poslužitelj nestabilnim",
+    "Do you really want to wipe your data from this device?" : "Želite li zaista izbrisati podatke s ovog uređaja?",
+    "Confirm wipe" : "Potvrdi brisanje",
+    "Error while wiping the device with the token" : "Pogreška pri brisanju sadržaja uređaja tokenom",
+    "Error while updating device token name" : "Pogreška pri ažuriranju naziva tokena za uređaja",
+    "Error while updating device token scope" : "Pogreška pri ažuriranju raspona tokena za uređaj",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Zaprimljeno je previše zahtjeva iz vaše mreže. Pokušajte kasnije ili se obratite administratoru ako se radi o pogrešci.",
     "Documentation" : "Dokumentacija",
     "Forum" : "Forum",
-    "Login" : "Prijava",
     "SSL" : "SSL",
     "Open documentation" : "Otvori dokumentaciju",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Važno je postaviti ovaj poslužitelj kako biste mogli slati poruke e-pošte u vezi s resetiranjem zaporke i obavijesti.",
@@ -372,7 +363,6 @@ OC.L10N.register(
     "Authentication" : "Autentifikacija",
     "Authentication required" : "Potrebna autentifikacija",
     "Credentials" : "Vjerodajnice",
-    "SMTP Username" : "Korisničko ime za SMTP",
     "SMTP Password" : "SMTP zaporka",
     "Save" : "Spremi",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Pravilna konfiguracija iznimno je važna za sigurnost i performanse vaše instance. Kako bismo vam pomogli pravilno konfigurirati sustav, provest ćemo neke automatske provjere. Za više informacija pogledajte navedenu dokumentaciju.",
@@ -382,30 +372,6 @@ OC.L10N.register(
     "Checking for system and security issues." : "Provjera sustava i sigurnosnih postavki.",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Pažljivo pročitajte <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">upute za instalaciju ↗</a> i potražite postoje li ikakve pogreške ili upozorenja u <a href=\"%2$s\">zapisima</a>.",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Provjerite sigurnost svojeg Nextclouda s pomoću <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">sigurnosnog skeniranja ↗</a>.",
-    "You need to enable the File sharing App." : "Morate omogućiti aplikaciju za dijeljenje datoteka.",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Administrator možete detaljnije podešavati dijeljenja. Pogledajte odgovarajuću dokumentaciju za više informacija.",
-    "Allow apps to use the Share API" : "Dopusti aplikacijama korištenje API-ja za dijeljenje",
-    "Set default expiration date for shares" : "Postavi zadani datum isteka dijeljenja",
-    "Expire after" : "Istek nakon",
-    "day(s)" : "dan/dana",
-    "Enforce expiration date" : "Primijeni datum isteka",
-    "Set default expiration date for shares to other servers" : "Postavi zadani datum isteka dijeljenja na druge poslužitelje",
-    "Allow users to share via link and emails" : "Dopusti korisnicima dijeljenje putem poveznice i e-pošte",
-    "Allow public uploads" : "Dopusti javne otpreme",
-    "Always ask for a password" : "Uvijek traži zaporku",
-    "Enforce password protection" : "Nametni zaštitu zaporkom",
-    "Set default expiration date" : "Postavi zadani datum isteka",
-    "Exclude groups from creating link shares:" : "Izuzmite grupe iz stvaranja dijeljenja poveznice:",
-    "Allow resharing" : "Dopusti ponovno dijeljenje",
-    "Allow sharing with groups" : "Dopusti dijeljenje s grupama",
-    "Restrict users to only share with users in their groups" : "Ograniči korisnike na dijeljenje samo s korisnicima unutar svoje grupe",
-    "Exclude groups from sharing" : "Izuzmi grupe iz dijeljenja",
-    "These groups will still be able to receive shares, but not to initiate them." : "Ove će grupe još uvijek moći primati dijeljene sadržaje, ali ih neće moći pokrenuti.",
-    "Allow username autocompletion to users based on phone number integration" : "Omogući korisnicima automatsko dovršavanje korisničkog imena na temelju integracije telefonskog broja",
-    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Ako je omogućeno automatsko dovršavanje „ista grupa” i „integracija telefonskog broja”, bilo koje od tih podudaranja dovoljno je za prikaz korisnika.",
-    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Prikaži tekst izjave o odricanju od odgovornosti na stranici za otpremanje javnih poveznica (prikazuje se samo kad je popis datoteka skriven)",
-    "This text will be shown on the public link upload page when the file list is hidden." : "Ovaj će tekst biti prikazan na stranici za otpremanje javnih poveznica kad je popis datoteka skriven.",
-    "Default share permissions" : "Zadana dopuštenja za dijeljenje",
     "Reasons to use Nextcloud in your organization" : "Razlozi za uporabu Nextclouda u vašoj organizaciji",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{githubopen}Izvorni kôd{linkclose} je razvila {communityopen}Nextcloudova zajednica korisnika{linkclose} i licenciran je sukladno {Licenseopen}AGPL-u{linkclose}.",
     "Like our Facebook page" : "Pratite našu Facebook stranicu",
@@ -416,25 +382,67 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Ovo izdanje Nextclouda nije podržano i nisu dostupne trenutne obavijesti.",
     "Use a second factor besides your password to increase security for your account." : "Koristite se i drugim faktorom pored zaporke kako biste povećali sigurnost svog računa.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ako se za povezivanje s Nextcloudom koristite aplikacijama treće strane, stvorite i konfigurirajte lozinku za svaku aplikaciju prije omogućavanja drugog faktora za provođenje autentifikacije.",
-    "You created app password \"{token}\"" : "Stvorili ste zaporku aplikacije „{token}”",
+    "No user supplied" : "Nijedan korisnik nije podnesen",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Unesite administratorsku zaporku za oporavak; u protivnom će svi podaci korisnika biti izgubljeni.",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instaliranje i ažuriranje aplikacija putem trgovine aplikacijama ili dijeljenja putem udruženog oblaka",
+    "Federated Cloud Sharing" : "Dijeljenje putem udruženog oblaka",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL upotrebljava zastarjelu inačicu %1$s (%2$s). Ažurirajte svoj operacijski sustav kako bi značajke, kao što je %3$s, pouzdano radile.",
+    "Invalid user" : "Nevažeći korisnik",
+    "Your username is: %s" : "Vaše korisničko ime je: %s",
+    "Logged in user must be a subadmin" : "Korisnik koji je prijavljen mora biti podadministrator",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Na čekanju je pozadinski zadatak za provjeravanje vjerodajnica SSL-a koje uvezu korisnici. Provjerite ponovno kasnije.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Prisutne su vjerodajnice SSL-a koje su uvezli korisnici i koje Nextcloud 21 ne upotrebljava. Mogu se uvesti putem naredbenog retka s pomoću naredbe „occ security:certificates:import”. U nastavku su prikazani njihovi putovi unutar podatkovnog direktorija.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvofaktorska autentifikacija može se primijeniti na sve korisnike i određene grupe. Ako nisu konfigurirali davatelje usluge dvofaktorske autentifikacije, neće se moći prijaviti u sustav.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Nakon odabira grupa koje će biti obuhvaćene/izuzete, primjenjuje se sljedeća logika za utvrđivanje je li 2FA omogućen za određenog korisnika: ako nije odabrana nijedna grupa, 2FA je omogućen za sve osim za članove izuzetih grupa. Ako su odabrane određene grupe, 2FA je omogućen samo za sve članove tih grupa. Ako je korisnik član odabrane i izuzete grupe, odabrana grupa ima prednost i 2FA se primjenjuje.",
     "Enable all" : "Omogući sve",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Sync client - {os}" : "Sinkroniziraj klijenta – {os}",
+    "Error while deleting the token" : "Pogreška pri brisanju tokena",
+    "Use the credentials below to configure your app or device." : "Upotrijebite vjerodajnice navedene u nastavku za konfiguriranje aplikacije ili uređaja.",
+    "For security reasons this password will only be shown once." : "Iz sigurnosnih razloga ta će se zaporka prikazati samo jednom.",
+    "Copied!" : "Kopirano!",
+    "Copy" : "Kopiraj",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Za izvršavanje navedenog postupka potrebno je proširenje PHP POSIX. Pogledajte {linkstart}dokumentaciju PHP-a{linkend} za više informacija.",
+    "You are about to remove the group {group}. The users will NOT be deleted." : "Izbrisat ćete grupu {group}. Korisnici NEĆE biti izbrisani.",
+    "Please confirm the group removal " : "Potvrdite uklanjanje grupe ",
     "png or jpg, max. 20 MB" : "png ili jpg, maks. 20 MB",
+    "Your email address" : "Vaša adresa e-pošte",
+    "Enable Profile" : "Omogući profil",
+    "You do not have permissions to see the details of this user" : "Nemate dopuštenja za prikaz pojedinosti ovog korisnika",
     "Add new password" : "Dodaj novu zaporku",
     "Add new email address" : "Dodaj novu adresu e-pošte",
+    "Set user as admin for" : "Postavi korisnika kao administratora za",
+    "Select user quota" : "Odaberi kvotu korisnika",
+    "Toggle user actions menu" : "Uklj./isklj. izbornik s radnjama korisnika",
+    "Delete user" : "Izbriši korisnika",
+    "Disable user" : "Onemogući korisnika",
+    "Enable user" : "Omogući korisnika",
     "Edit User" : "Uredi korisnika",
     "Will be autogenerated" : "Automatski će se generirati",
     "Add a new user" : "Dodaj novog korisnika",
     "No users in here" : "Ovdje nema korisnika",
+    "Enter group name" : "Unesite naziv grupe",
+    "Add group" : "Dodaj grupu",
     "Default quota:" : "Zadana kvota:",
     "Show Languages" : "Prikaži jezike",
+    "Show user backend" : "Prikaži korisnički pozadinski sustav",
     "Send email to new user" : "Pošalji poruku e-pošte novom korisniku",
+    "Not saved" : "Nije spremljeno",
+    "Twitter" : "Twitter",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Nije dostupno jer nije dopušteno objavljivanje korisničkih podataka na poslužitelju pretraživanja, obratite se administratoru sustava ako imate pitanja",
+    "Show to logged in users only" : "Prikaži samo prijavljenim korisnicima",
     "Enable untested app" : "Omogući neprovjerenu aplikaciju",
-    "Plain" : "Čisti tekst",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Način autentifikacije",
+    "SMTP Username" : "Korisničko ime za SMTP",
+    "Expire after" : "Istek nakon",
+    "day(s)" : "dan/dana",
+    "Set default expiration date" : "Postavi zadani datum isteka",
+    "Exclude groups from creating link shares:" : "Izuzmite grupe iz stvaranja dijeljenja poveznice:",
     "Allow username autocompletion in share dialog" : "Dopusti automatsko dovršavanje korisničkog imena u dijaloškom okviru za dijeljenje",
     "Allow username autocompletion to users within the same groups" : "Dopusti automatsko dovršavanje korisničkog imena na korisnike iz istih grupa"
 },
