@@ -48,23 +48,15 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Fjartengd útþurrkun var hafin á %1$s",
     "Remote wipe has finished on %1$s" : "Fjartengdri útþurrkun er lokið á %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Breyting hefur orðið á <strong>lykilorði</strong> eða <strong>tölvupóstfangi</strong> þínu",
-    "Apps" : "Forrit",
+    "Settings" : "Stillingar",
     "Could not remove app." : "Gat ekki fjarlægt forrit.",
     "Could not update app." : "Gat ekki uppfært forrit.",
     "Wrong password" : "Rangt lykilorð",
     "Unable to change personal password" : "Ekki tókst að breyta persónulegu lykilorði",
     "Saved" : "Vistað",
-    "No user supplied" : "Enginn notandi gefinn",
     "Unable to change password. Password too long." : "Ekki tókst að breyta lykilorði. Lykilorðið er of langt.",
     "Authentication error" : "Villa við auðkenningu",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast.",
     "Wrong admin recovery password. Please check the password and try again." : "Rangt endurheimtulykilorð kerfisstjóra, athugaðu lykilorðið og reyndu aftur.",
-    "Backend does not support password change, but the user's encryption key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "uppsetning eða uppfærsla forrita úr forritabúð eða með skýjasambandi",
-    "Federated Cloud Sharing" : "Deiling með skýjasambandi",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL er að nota úrelda útgáfu af %1$s (%2$s). Uppfærðu stýrikerfið þitt, annars er hætt við að eiginleikar á borð við %3$s virki ekki sem skyldi.",
-    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP Opcache er ekki hlaðið inn. Fyrir betri afköst mælum við með að því sé hlaðið inn í PHP-uppsetninguna þína.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "PHP Opcache er ekki virkt. Fyrir betri afköst mælum við með að setja <code>opcache.enable=1</code> inn í PHP-uppsetninguna þína.",
     "Administrator documentation" : "Hjálparskjöl stjórnanda",
     "User documentation" : "Hjálparskjöl notenda",
     "Nextcloud help overview" : "Efnisyfirlit Nextcloud-hjálpar",
@@ -74,9 +66,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Fyrst að þú fékkst þennan tölvupóst, þá lítur út fyrir að tölvupóstuppsetningin sé í lagi.",
     "Email could not be sent. Check your mail server log" : "Ekki var hægt að senda póst. Skoðaðu annál póstþjónsins",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Vandamál kom upp við að senda tölvupóst. Farðu yfir stillingarnar þínar. (Villa: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Þú verður að gefa upp tölvupóstfangið þitt svo að þú getir sent prófunarpósta. Farðu á %s til þess.",
-    "Users" : "Notendur",
-    "Invalid user" : "Ógildur notandi",
+    "Invalid account" : "Ógildur aðgangur",
     "Invalid mail address" : "Ógilt tölvupóstfang",
     "Settings saved" : "Stillingar vistaðar",
     "Unable to change full name" : "Get ekki breytt fullu nafni",
@@ -102,14 +92,13 @@ OC.L10N.register(
     "Welcome aboard" : "Velkomin um borð",
     "Welcome aboard %s" : "Velkomin um borð %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Velkomin(n) í %s aðganginn þinn; þú getur bætt við, varið og deilt gögnunum þínum.",
-    "Your username is: %s" : "Notandanafnið þitt er: %s",
     "Set your password" : "Stilltu lykilorðið þitt",
     "Go to %s" : "Farðu í %s",
     "Install Client" : "Setja upp biðlaraforrit",
-    "Logged in user must be a subadmin" : "Innskráður notandi verður að vera undirstjórnandi (subadmin)",
-    "Settings" : "Stillingar",
+    "Apps" : "Forrit",
     "Personal" : "Einka",
     "Administration" : "Stjórnun",
+    "Users" : "Notendur",
     "Additional settings" : "Valfrjálsar stillingar",
     "Artificial Intelligence" : "Gervigreind",
     "Administration privileges" : "Kerfisstjórnunarheimildir",
@@ -127,7 +116,6 @@ OC.L10N.register(
     "Unlimited" : "ótakmörkuðu",
     "Verifying" : "Sannreyni",
     "Your remote address could not be determined." : "Ekki var hægt að ákvarða fjartengda vistfangið þitt.",
-    "Old user imported certificates" : "Gömul skilríki sem notandi hefur flutt inn",
     "Database missing columns" : "Gagnagrunn vantar dálka",
     "Missing optional column \"%s\" in table \"%s\"." : "Vantar valkvæða dálkinn \"%s\" í töflunni \"%s\".",
     "Database missing indices" : "Gagnagrunn vantar vísa",
@@ -152,10 +140,11 @@ OC.L10N.register(
     "Disabled" : "Óvirkt",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Eldri gerð dulritunar á þjóni er virk. Við mælum með því að hún sé gerð óvirk.",
     "Memcache" : "Memcache",
-    "Configured" : "Stillt",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "Ekkert skyndiminni (cache) hefur verið stillt Til að auka afköst ættirðu að setja upp skyndiminni (með memcache) ef það er tiltækt.",
+    "Configured" : "Stillt",
     "PHP default charset" : "Sjálfgefin stafatafla PHP",
     "PHP configuration option \"default_charset\" should be UTF-8" : "PHP-stillingarofinn \"default_charset\" ætti að vera UTF-8",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-fallið \"set_time_limit\" er ekki tiltækt. Þetta gæti valdið því að skriftur stöðvist í miðri keyrslu og skemmi uppsetninguna þína. Við mælumst til þess að þetta fall sé gert virkt.",
     "Freetype" : "Freetype",
     "Supported" : "Stutt",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-uppsetningin er ekki með stuðning við Free Type. Þetta mun valda því að notendamyndir og stillingaviðmót virki ekki.",
@@ -165,7 +154,7 @@ OC.L10N.register(
     "The PHP memory limit is below the recommended value of %s." : "Minnismörk PHP eru lægri en gildið sem mælt er með; %s.",
     "PHP modules" : "PHP-einingar",
     "This instance is missing some required PHP modules. It is required to install them: %s." : "Í þetta kerfistilvik vantar ýmsar nauðsynlegar PHP-einingar. Mælt er eindregið með að setja þær upp: %s.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "Í þetta kerfistilvik vantar ýmsar PHP-einingar sem mælt er með. Til að bæta afköst og betri samhæfni er mælt eindregið með að setja þær upp: %s.",
+    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP Opcache er ekki hlaðið inn. Fyrir betri afköst mælum við með að því sé hlaðið inn í PHP-uppsetninguna þína.",
     "PHP version" : "PHP-útgáfa",
     "You are currently running PHP %s." : "Þú ert núna að keyra PHP %s.",
     "Random generator" : "Slembigjafi",
@@ -223,7 +212,6 @@ OC.L10N.register(
     "Deleted disclaimer text" : "Eyddi texta fyrirvara",
     "Could not set disclaimer text" : "Gat ekki stillt texta fyrirvara",
     "Two-Factor Authentication" : "Tveggja-þrepa auðkenning",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Hægt er að þvinga fram tveggja-þrepa auðkenningu fyrir alla notendur og/eða tiltekna hópa. Ef þeir eru ekki með tveggja-þrepa auðkenningarþjónustu uppsetta, munu þeir ekki geta skráð sig inn á kerfið.",
     "Enforce two-factor authentication" : "Þvinga fram tveggja-þrepa auðkenningu",
     "Limit to groups" : "Takmarka við hópa",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Hægt er að þvinga fram tveggja-þátta auðkenningu fyrir einungis ákveðna hópa.",
@@ -231,7 +219,6 @@ OC.L10N.register(
     "Enforced groups" : "Þvingaðir hópar",
     "Two-factor authentication is not enforced for members of the following groups." : "Tveggja-þrepa auðkenning er ekki þvinguð fram fyrir meðlimi eftirfarandi hópa.",
     "Excluded groups" : "Útilokaðir hópar",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Þegar hópar eru valdir/útilokaðir, styðjast þeir við eftirfarandi röksemdafærslu til að ákvarða hvort notandi sé með þvingaða/virka tveggja-þrepa auðkenningu: tveggja-þrepa auðkenning er virk fyrir alla nema meðlimi útilokaðra hópa. Ef hópar eru valdir, er tveggja-þrepa auðkenningvirk fyrir alla meðlimi þessara hópa. Ef notandi er bæði í völdum og í útilokuðum hópum, ræður valið og því er tveggja-þrepa auðkenning virk.",
     "Save changes" : "Vista breytingar",
     "All" : "Allt",
     "Limit app usage to groups" : "Takmarka notkun forrits við tiltekna hópa",
@@ -273,57 +260,34 @@ OC.L10N.register(
     "Revoke" : "Afturkalla",
     "Wipe device" : "Þurrka út af tæki",
     "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Afturköllun á þessu teikni gæti komið í veg fyrir útþurrkun af tækinu nema ef útþurrkunin sé þegar byrjuð.",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome fyrir Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
     "{productName} iOS app" : "{productName} iOS-forrit",
     "{productName} Android app" : "{productName} Android-forrit",
     "{productName} Talk for iOS" : "{productName} Talk fyrir iOS",
     "{productName} Talk for Android" : "{productName} Talk fyrir Android",
-    "Sync client - {os}" : "Samstilla biðlara - {os}",
     "This session" : "Þessa setu",
     "Device" : "Tæki",
     "Last activity" : "Síðasta virkni",
     "Devices & sessions" : "Tæki og setur",
     "Web, desktop and mobile clients currently logged in to your account." : "Veftól, tölvur og símar sem núna eru skráð inn á aðganginn þinn.",
-    "Do you really want to wipe your data from this device?" : "Viltu í alvörunni hreinsa gögnin þín af þessu tæki?",
-    "Confirm wipe" : "Staðfesta útþurrkun",
-    "Error while creating device token" : "Villa við að búa til teikn fyrir tækið",
-    "Error while updating device token scope" : "Villa við að uppfæra gildissvið fyrir teikn tækisins",
-    "Error while updating device token name" : "Villa við að uppfæra nafn fyrir teikn tækisins",
-    "Error while deleting the token" : "Villa kom upp við að eyða teikninu",
-    "Error while wiping the device with the token" : "Villa við að hreinsa tækið með teikninu",
     "App name" : "Heiti forrits",
     "Create new app password" : "Búa til nýtt lykilorð forrits",
-    "Use the credentials below to configure your app or device." : "Notaðu auðkennin hér fyrir neðan til að stilla forritið eða tækið.",
-    "For security reasons this password will only be shown once." : "Af öryggisástæðum er þetta lykilorð einungis birt einu sinni.",
-    "Username" : "Notandanafn",
+    "Error while creating device token" : "Villa við að búa til teikn fyrir tækið",
+    "Login" : "Innskráning",
     "Password" : "Lykilorð",
-    "Done" : "Lokið",
     "Show QR code for mobile apps" : "Birta QR-kóða fyrir snjallsímaforrit",
-    "Copied!" : "Afritað!",
-    "Copy" : "Afrita",
     "Could not copy app password. Please copy it manually." : "Tókst ekki að afrita lykilorð forritsins. Afritaðu það handvirkt.",
     "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "Til að þjónninn virki sem skyldi, er mikilvægt að stilla bakgrunnsverk rétt. Mælt er með því að nota 'cron' kerfisins. Skoðaðu hjálparskjölin til að sjá ítarlegar upplýsingar.",
     "Last job execution ran {time}. Something seems wrong." : "Síðasta verk var keyrt {time}. Eitthvað er ekki eins og það á að sér að vera.",
     "Last job ran {relativeTime}." : "Síðasta verk var keyrt {relativeTime}.",
     "Background job did not run yet!" : "Bakgrunnsverk hefur ekki ennþá verið keyrt!",
     "AJAX" : "AJAX",
-    "Execute one task with each page loaded. Use case: Single user instance." : "Framkvæma eitt verk með hverri innhlaðinni síðu. Dæmi um notkun: Tilvik fyrir einn notanda.",
     "Webcron" : "Webcron",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 5 mínútna fresti yfir HTTP. Dæmi um notkun: Mjög lítil tilvik (1–5 notendur eða eftir notkun).",
     "Cron (Recommended)" : "Cron (mælt með þessu)",
     "Use system cron service to call the cron.php file every 5 minutes." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 5 mínútna fresti.",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"{user}\".",
     "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Nauðsynlegt er að hafa PHP-POSIX-viðaukann. Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
     "Unable to update background job mode" : "Tókst ekki að uppfæra ham bakgrunnsverks",
     "Profile" : "Notandasnið",
-    "Enable or disable profile by default for new users." : "Virkja eða gera notandasnið óvirkt sjálfgefið fyrir nýja notendur.",
     "Enable" : "Virkja",
     "Unable to update profile default setting" : "Tókst ekki að uppfæra sjálfgefna stillingu notandasniðs",
     "Server-side encryption" : "Dulritun á þjóni",
@@ -340,7 +304,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "Þú verður að yfirfæra dulritunarlyklana þína úr gömlu dulrituninni (ownCloud <= 8.0) yfir í þá nýju. Virkjaðu \"Sjálfgefin dulritunareining\" og keyrðu {command}",
     "Unable to update server side encryption config" : " Get ekki uppfært uppsetningu fyrir dulritun á þjóni",
     "Please confirm the group removal" : "Staðfestu fjarlægingu hópsins",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn \"{group}\". Notendunum verður EKKI eytt.",
     "Cancel" : "Hætta við",
     "Confirm" : "Staðfesta",
     "Submit" : "Senda inn",
@@ -371,12 +334,13 @@ OC.L10N.register(
     "You are using <strong>{usage}</strong>" : "Þú ert að nota <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Þú ert að nota <strong>{usage}</strong> af <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Fullt nafn þitt",
-    "Email options" : "Tölvupóststillingar",
+    "Back" : "Til baka",
+    "This address is not confirmed" : "Þetta tölvupóstfang er ekki staðfest",
     "Primary email for password reset and notifications" : "Aðallykilorð fyrir tilkynningar og endurstillingu lykilorðs",
+    "Email options" : "Tölvupóststillingar",
     "Remove primary email" : "Fjarlægja aðaltölvupóstfang",
     "Delete email" : "Eyða tölvupósti",
     "Unset as primary email" : "Aftengja sem aðaltölvupóstfang",
-    "This address is not confirmed" : "Þetta tölvupóstfang er ekki staðfest",
     "Set as primary email" : "Gera að aðaltölvupóstfangi",
     "Additional email address {index}" : "Aukalegt tölvupóstfang {index}",
     "Unable to delete primary email address" : "Get ekki eytt aðaltölvupóstfangi",
@@ -388,6 +352,7 @@ OC.L10N.register(
     "Additional emails" : "Viðbótartölvupóstföng",
     "Your handle" : "Auðkennið þitt",
     "Your headline" : "Fyrirsögnin þín",
+    "Languages" : "Tungumál",
     "Help translate" : "Hjálpa við þýðingu",
     "Unable to update language" : "Tókst ekki að uppfæra tungumál",
     "No language set" : "Ekkert tungumál skilgreint",
@@ -398,7 +363,6 @@ OC.L10N.register(
     "Your organisation" : "Fyrirtækið þitt",
     "Your phone number" : "Símanúmerið þitt",
     "Edit your Profile visibility" : "Breyta sýnileika notandasniðsins þíns",
-    "Enable Profile" : "Virkja notandasnið",
     "Unable to update profile enabled state" : "Tókst ekki að uppfæra virka stöðu notandasniðs",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Sú stilling sem meira er takmarkandi, annað hvort sýnileiki eða dreifing, fær meira vægi í notandasniðinu þínu. Til dæmis ef sýnileiki er stilltur á \"Birta öllum\" og dreifing er stillt á \"Einka\", þá hefur \"Einka\" meira vægi.",
     "Unable to update visibility of {displayId}" : "Tókst ekki að uppfæra sýnileika á {displayId}",
@@ -416,9 +380,7 @@ OC.L10N.register(
     "Change" : "Breyta",
     "Delete" : "Eyða",
     "Reshare" : "Endurdeila",
-    "No users" : "Engir notendur",
-    "Loading users …" : "Hleð inn notendum …",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Listi yfir notendur. Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Notendur munu birtast eftir því sem farið er í gegnum listann.",
+    "Loading accounts …" : "Hleð inn notendaaðgöngum...",
     "Default language" : "Sjálfgefið tungumál",
     "Common languages" : "Algeng tungumál",
     "Other languages" : "Önnur tungumál",
@@ -443,36 +405,30 @@ OC.L10N.register(
     "Username will be autogenerated" : "Notandanafn verður útbúið sjálfvirkt",
     "Username (required)" : "Notandanafn (nauðsynlegt)",
     "Total rows summary" : "Samantek á fjölda raða",
+    "Loading users …" : "Hleð inn notendum …",
     "Scroll to load more rows" : "Skrunaðu til að hlaða inn fleiri röðum",
     "_{userCount} user …_::_{userCount} users …_" : ["{userCount} notandi …","{userCount} notendur …"],
     "_{userCount} user_::_{userCount} users_" : ["{userCount} notandi","{userCount} notendur"],
     "Avatar" : "Auðkennismynd",
+    "Username" : "Notandanafn",
     "Group admin for" : "Hópstjóri fyrir",
     "User backend" : "Bakendi notanda",
     "Storage location" : "Staðsetning gagnageymslu",
     "Last login" : "Síðasta innskráning",
     "User actions" : "Aðgerðir notanda",
     "Password or insufficient permissions message" : "Skilaboð um lykilorð eða ekki nægar heimildir",
-    "Loading user …" : "Hleð inn notanda...",
     "Change display name" : "Breyta birtingarnafni",
     "Set new password" : "Stilla nýtt lykilorð",
-    "You do not have permissions to see the details of this user" : "Þú hefur ekki réttindi til að skoða ítarupplýsingar um þennan notanda",
     "Set new email address" : "Stilla nýtt tölvupóstfang",
     "Add user to group" : "Bæta notanda í hóp",
-    "Set user as admin for" : "Setja notanda sem stjórnanda fyrir",
-    "Select user quota" : "Veldu kvóta notandans",
     "Set the language" : "Settu tungumálið",
     "{size} used" : "{size} notað",
-    "Delete user" : "Eyða notanda",
     "Wipe all devices" : "Þurrka út af öllum tækjum",
-    "Disable user" : "Gera notanda óvirkan",
-    "Enable user" : "Virkja notanda",
     "Resend welcome email" : "Endursenda kveðjupóst",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Týnist tæki eða hætti einhver hjá fyrirtæki/stofnun, þá getur þetta hreinsað fjartengt út öll Nextcloud-gögn af öllum tækjum sem tengd eru {userid}. Virkar bara ef tækin eru tengd internetinu.",
     "Remote wipe of devices" : "Fjartengd útþurrkun af tækjum",
     "Wipe {userid}'s devices" : "Þurrka út af tækjum {userid}",
     "Wiped {userid}'s devices" : "Þurrkaði út af tækjum {userid}",
-    "Failed to update user manager" : "Mistókst að uppfæra notendastýringu",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Eyða að fullu notandaaðgangnum {userid}, þar með talið öllum persónulegum skrám viðkomandi, forritsgögnum, o.s.frv.",
     "Account deletion" : "Eyðing á aðgangi",
     "Delete {userid}'s account" : "Eyða notandaaðgangi {userid}",
@@ -480,16 +436,13 @@ OC.L10N.register(
     "Password was successfully changed" : "Það tókst að breyta lykilorðinu",
     "Email was successfully changed" : "Það tókst að breyta tölvupóstfanginu",
     "Welcome mail sent!" : "Kveðjupóstur sendur!",
-    "Toggle user actions menu" : "Víxla af/á valmynd fyrir aðgerðir notanda",
+    "Done" : "Lokið",
     "Edit" : "Breyta",
-    "User management settings" : "Stillingar notendastýringar",
     "Visibility" : "Sýnileiki",
     "Show language" : "Birta tungumál",
-    "Show user backend" : "Birta bakenda notanda",
     "Show storage path" : "Birta slóð á gagnageymslu",
     "Show last login" : "Birta síðustu innskráningu",
     "Send email" : "Senda tölvupóst",
-    "Send welcome email to new users" : "Senda tölvupóst sem býður notanda velkominn",
     "Defaults" : "Sjálfgefin gildi",
     "Default quota" : "Sjálfgefinn kvóti",
     "Select default quota" : "Setja sjálfgefinn kvóta",
@@ -511,7 +464,6 @@ OC.L10N.register(
     "{license}-licensed" : "{license}-notkunarleyfi",
     "Changelog" : "Breytingaskrá",
     "by {author}\n{license}" : "frá {author}\n{license}",
-    "Active users" : "Virkir notendur",
     "Admins" : "Kerfisstjórar",
     "Disabled users" : "Óvirkir notendur",
     "Creating group …" : "Bý til hóp …",
@@ -536,8 +488,6 @@ OC.L10N.register(
     "Profile visibility" : "Sýnileiki notandasniðs",
     "Locale" : "Staðfærsla",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Er ekki tiltækt þar sem þessi eiginleiki er nauðsynlegur fyrir kjarnavirkni á borð við skráadeilingu og boð í dagatölum",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Er ekki tiltækt þar sem skýjasamband (federation) hefur verið gert óvirkt fyrir aðganginn þinn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Er ekki tiltækt þar sem ekki er leyfilegt að miðla sértækum gögnum notenda yfir á uppflettingaþjóninn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
     "Your apps" : "Forritin þín",
     "Active apps" : "Virk forrit",
     "Disabled apps" : "Óvirk forrit",
@@ -546,24 +496,28 @@ OC.L10N.register(
     "Featured apps" : "Forrit efst á baugi",
     "Supported apps" : "Studd forrit",
     "Show to everyone" : "Birta öllum",
-    "Show to logged in users only" : "Birta einungis innskráðum notendum",
     "Hide" : "Fela",
     "Download and enable" : "Sækja og virkja",
     "Allow untested app" : "Leyfa óprófuð forrit",
     "The app will be downloaded from the App Store" : "Forritið verður sótt úr forritabúðinni",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Þetta forrit er merkt sem ekki samhæft við þína útgáfu af Nextcloud. Ef þú heldur áfram er mögulegt að þú getir samt sett forritið upp. En athugaðu þá að ekki er víst að forritið virki eins og skyldi.",
     "Never" : "Aldrei",
+    "Active users" : "Virkir notendur",
     "An error occurred during the request. Unable to proceed." : "Villa kom upp við beiðnina. Get ekki haldið áfram.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Forritið hefur verið virkjað, en það þarf að uppfæra það. Þú verður áframsendur á uppfærslusíðuna eftir 5 sekúndur.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Villa: Ekki er hægt að virkja þetta forrit því það gerir þjóninn óstöðugan",
+    "Do you really want to wipe your data from this device?" : "Viltu í alvörunni hreinsa gögnin þín af þessu tæki?",
+    "Confirm wipe" : "Staðfesta útþurrkun",
+    "Error while wiping the device with the token" : "Villa við að hreinsa tækið með teikninu",
+    "Error while updating device token name" : "Villa við að uppfæra nafn fyrir teikn tækisins",
+    "Error while updating device token scope" : "Villa við að uppfæra gildissvið fyrir teikn tækisins",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Það komu of margar beiðnir frá netkerfinu þínu. Reyndu aftur eða hafðu samband við kerfisstjóra ef þetta er ekki rétt.",
+    "Account documentation" : "Hjálparskjöl fyrir notendaaðganga",
+    "Administration documentation" : "Hjálparskjöl fyrir stjórnendur",
     "Documentation" : "Hjálparskjöl",
     "Forum" : "Vefspjall",
     "Nextcloud help resources" : "Aðstoðartilföng Nextcloud",
-    "Account documentation" : "Hjálparskjöl fyrir notendaaðganga",
-    "Administration documentation" : "Hjálparskjöl fyrir stjórnendur",
     "General documentation" : "Almenn hjálparskjöl",
-    "Login" : "Innskráning",
     "None/STARTTLS" : "Ekkert/STARTTLS",
     "SSL" : "SSL",
     "Open documentation" : "Opna hjálparskjöl",
@@ -577,7 +531,6 @@ OC.L10N.register(
     "Authentication" : "Auðkenning",
     "Authentication required" : "Auðkenningar krafist",
     "Credentials" : "Auðkenni",
-    "SMTP Username" : "SMTP-notandanafn",
     "SMTP Password" : "SMTP-lykilorð",
     "Save" : "Vista",
     "Test and verify email settings" : "Prófa og staðfesta tölvupóststillingar",
@@ -598,19 +551,57 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Þessi samfélagsútgáfa Nextcloud kemur ekki með neinni opinberri aðstoð og rauntímatilkynningar eru ekki til taks.",
     "Use a second factor besides your password to increase security for your account." : "Notaðu annað þrep til viðbótar lykilorðinu þínu til að auka öryggi notandaaðgangsins þíns.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Ef þú notaðir utanaðkomandi forrit til að tengjast við Nextcloud, skaltu ganga úr skugga um að þú útbúir lykilorð fyrir hvert slíkt forrit áður en þú virkjar 2FA tveggja-þrepa auðkenningu.",
+    "No user supplied" : "Enginn notandi gefinn",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Settu inn endurheimtulykilorð kerfisstjóra, annars munu öll notandagögn tapast.",
+    "Backend does not support password change, but the user's encryption key was updated." : "Bakendi styður ekki breytingu á lykilorði, en það tókst að uppfæra dulritunarlykil notandans.",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "uppsetning eða uppfærsla forrita úr forritabúð eða með skýjasambandi",
+    "Federated Cloud Sharing" : "Deiling með skýjasambandi",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL er að nota úrelda útgáfu af %1$s (%2$s). Uppfærðu stýrikerfið þitt, annars er hætt við að eiginleikar á borð við %3$s virki ekki sem skyldi.",
+    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "PHP Opcache er ekki virkt. Fyrir betri afköst mælum við með að setja <code>opcache.enable=1</code> inn í PHP-uppsetninguna þína.",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "Þú verður að gefa upp tölvupóstfangið þitt svo að þú getir sent prófunarpósta. Farðu á %s til þess.",
+    "Invalid user" : "Ógildur notandi",
+    "Your username is: %s" : "Notandanafnið þitt er: %s",
+    "Logged in user must be a subadmin" : "Innskráður notandi verður að vera undirstjórnandi (subadmin)",
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Fann ógild UUIDs á LDAP-notendum eða hópum. Yfirfarðu stillingar í \"Override UUID detection\" í Sérfræðinga/Expert hluta LDAP-uppsetningarinnar og notaðu \"occ ldap:update-uuid\" til að uppfæra þær.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Hægt er að þvinga fram tveggja-þrepa auðkenningu fyrir alla notendur og/eða tiltekna hópa. Ef þeir eru ekki með tveggja-þrepa auðkenningarþjónustu uppsetta, munu þeir ekki geta skráð sig inn á kerfið.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Þegar hópar eru valdir/útilokaðir, styðjast þeir við eftirfarandi röksemdafærslu til að ákvarða hvort notandi sé með þvingaða/virka tveggja-þrepa auðkenningu: tveggja-þrepa auðkenning er virk fyrir alla nema meðlimi útilokaðra hópa. Ef hópar eru valdir, er tveggja-þrepa auðkenningvirk fyrir alla meðlimi þessara hópa. Ef notandi er bæði í völdum og í útilokuðum hópum, ræður valið og því er tveggja-þrepa auðkenning virk.",
     "Enable all" : "Virkja allt",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Sync client - {os}" : "Samstilla biðlara - {os}",
+    "Error while deleting the token" : "Villa kom upp við að eyða teikninu",
+    "Use the credentials below to configure your app or device." : "Notaðu auðkennin hér fyrir neðan til að stilla forritið eða tækið.",
+    "For security reasons this password will only be shown once." : "Af öryggisástæðum er þetta lykilorð einungis birt einu sinni.",
+    "Copied!" : "Afritað!",
+    "Copy" : "Afrita",
+    "Execute one task with each page loaded. Use case: Single user instance." : "Framkvæma eitt verk með hverri innhlaðinni síðu. Dæmi um notkun: Tilvik fyrir einn notanda.",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php er skráð á webcron-þjónustu til að kalla á cron.php á 5 mínútna fresti yfir HTTP. Dæmi um notkun: Mjög lítil tilvik (1–5 notendur eða eftir notkun).",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Til að keyra þetta þarftu að hafa PHP-POSIX-viðaukann (extension). Skoðaðu {linkstart}PHP-hjálparskjölin{linkend} fyrir nánari útlistun.",
     "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Nota cron-þjónustu kerfisins til að kalla á cron.php skrána á 5 mínútna fresti. Mælt með þessu á öllum tilvikum.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php verður að vera keyrt af kerfisnotandanum \"{user}\".",
+    "Enable or disable profile by default for new users." : "Virkja eða gera notandasnið óvirkt sjálfgefið fyrir nýja notendur.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn {group}. Notendunum verður EKKI eytt.",
     "Please confirm the group removal " : "Staðfestu fjarlægingu hópsins",
     "Choose profile picture from files" : "Veldu sem auðkennismynd úr skrám",
     "png or jpg, max. 20 MB" : "png eða jpg, hám. 20 MB",
     "Your email address" : "Netfangið þitt",
     "Your location" : "Staðsetning þín",
+    "Enable Profile" : "Virkja notandasnið",
     "Your Twitter handle" : "Twitter notandanafnið þitt",
+    "You do not have permissions to see the details of this user" : "Þú hefur ekki réttindi til að skoða ítarupplýsingar um þennan notanda",
     "Add new password" : "Bæta við nýju lykilorði",
     "Add new email address" : "Bæta við nýju tölvupóstfangi",
+    "Set user as admin for" : "Setja notanda sem stjórnanda fyrir",
+    "Select user quota" : "Veldu kvóta notandans",
+    "Toggle user actions menu" : "Víxla af/á valmynd fyrir aðgerðir notanda",
+    "Delete user" : "Eyða notanda",
+    "Disable user" : "Gera notanda óvirkan",
+    "Enable user" : "Virkja notanda",
     "Edit User" : "Breyta notanda",
     "Will be autogenerated" : "Verður útbúið sjálfvirkt",
     "Add a new user" : "Bæta við nýjum notanda",
@@ -619,10 +610,15 @@ OC.L10N.register(
     "Add group" : "Bæta við hópi",
     "Default quota:" : "Sjálfgefinn kvóti:",
     "Show Languages" : "Birta tungumál",
+    "Show user backend" : "Birta bakenda notanda",
     "Send email to new user" : "Senda tölvupóst til nýs notanda",
     "Not saved" : "Ekki vistað",
     "Twitter" : "Twitter",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Er ekki tiltækt þar sem skýjasamband (federation) hefur verið gert óvirkt fyrir aðganginn þinn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Er ekki tiltækt þar sem ekki er leyfilegt að miðla sértækum gögnum notenda yfir á uppflettingaþjóninn, hafðu samband við kerfisstjórann þinn ef þú ert með einhverjar spurningar",
+    "Show to logged in users only" : "Birta einungis innskráðum notendum",
     "Enable untested app" : "Virkja óprófað forrit",
+    "SMTP Username" : "SMTP-notandanafn",
     "Expire after" : "Rennur út eftir",
     "day(s)" : "dag(ar)",
     "Exclude groups from password requirements:" : "Undanskilja hópa frá kröfum um lykilorð:",
@@ -634,6 +630,15 @@ OC.L10N.register(
     "Edit display name" : "Breyta birtingarnafni",
     "Select manager" : "Veldu stýringu",
     "User's table" : "Tafla notandans",
-    "Select user manager" : "Veldu notendastýringu"
+    "Select user manager" : "Veldu notendastýringu",
+    "Old user imported certificates" : "Gömul skilríki sem notandi hefur flutt inn",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "Í þetta kerfistilvik vantar ýmsar PHP-einingar sem mælt er með. Til að bæta afköst og betri samhæfni er mælt eindregið með að setja þær upp: %s.",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "Þú er í þann mund að fara að fjarlægja hópinn \"{group}\". Notendunum verður EKKI eytt.",
+    "No users" : "Engir notendur",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Listi yfir notendur. Til að halda sem bestum afköstum er þessi listi ekki myndgerður að fullu. Notendur munu birtast eftir því sem farið er í gegnum listann.",
+    "Loading user …" : "Hleð inn notanda...",
+    "Failed to update user manager" : "Mistókst að uppfæra notendastýringu",
+    "User management settings" : "Stillingar notendastýringar",
+    "Send welcome email to new users" : "Senda tölvupóst sem býður notanda velkominn"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
