@@ -50,18 +50,15 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Remote wipe was started on %1$s",
     "Remote wipe has finished on %1$s" : "Remote wipe has finished on %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Your <strong>password</strong> or <strong>email</strong> was modified",
-    "Apps" : "Apps",
+    "Settings" : "Settings",
     "Could not remove app." : "Could not remove app.",
     "Could not update app." : "Could not update app.",
     "Wrong password" : "Wrong password",
     "Unable to change personal password" : "Unable to change personal password",
     "Saved" : "Saved",
-    "No user supplied" : "No user supplied",
     "Unable to change password. Password too long." : "Unable to change password. Password too long.",
     "Authentication error" : "Authentication error",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Please provide an admin recovery password; otherwise, all user data will be lost.",
     "Wrong admin recovery password. Please check the password and try again." : "Wrong admin recovery password. Please check the password and try again.",
-    "Backend does not support password change, but the user's encryption key was updated." : "Backend does not support password change, but the user's encryption key was updated.",
     "Administrator documentation" : "Administrator documentation",
     "User documentation" : "User documentation",
     "Nextcloud help overview" : "Nextcloud help overview",
@@ -71,9 +68,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "If you received this email, the email configuration seems to be correct.",
     "Email could not be sent. Check your mail server log" : "Email could not be sent. Check your mail server log",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "A problem occurred while sending the email. Please revise your settings. (Error: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "You need to set your user email before being able to send test emails. Go to %s for that.",
-    "Users" : "Users",
-    "Invalid user" : "Invalid user",
     "Invalid mail address" : "Invalid mail address",
     "Settings saved" : "Settings saved",
     "Unable to change full name" : "Unable to change full name",
@@ -99,14 +93,13 @@ OC.L10N.register(
     "Welcome aboard" : "Welcome aboard",
     "Welcome aboard %s" : "Welcome aboard %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Welcome to your %s account, you can add, protect, and share your data.",
-    "Your username is: %s" : "Your username is: %s",
     "Set your password" : "Set your password",
     "Go to %s" : "Go to %s",
     "Install Client" : "Install Client",
-    "Logged in user must be a subadmin" : "Logged in user must be a subadmin",
-    "Settings" : "Settings",
+    "Apps" : "Apps",
     "Personal" : "Personal",
     "Administration" : "Administration",
+    "Users" : "Users",
     "Additional settings" : "Additional settings",
     "Artificial Intelligence" : "Artificial Intelligence",
     "Administration privileges" : "Administration privileges",
@@ -127,9 +120,6 @@ OC.L10N.register(
     "Your remote address could not be determined." : "Your remote address could not be determined.",
     "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly.",
     "Your remote address \"%s\" is not brute-force throttled." : "Your remote address \"%s\" is not brute-force throttled.",
-    "Old user imported certificates" : "Old user imported certificates",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "A background job is pending that checks for user imported SSL certificates. Please check back later.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below.",
     "Database missing columns" : "Database missing columns",
     "Missing optional column \"%s\" in table \"%s\"." : "Missing optional column \"%s\" in table \"%s\".",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
@@ -141,6 +131,7 @@ OC.L10N.register(
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
     "Database pending bigint migrations" : "Database pending bigint migrations",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline.",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "This instance is running in debug mode. Only enable this for local development and not in production environments.",
     "Default phone region" : "Default phone region",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file.",
     "Email test" : "Email test",
@@ -257,7 +248,6 @@ OC.L10N.register(
     "Deleted disclaimer text" : "Deleted disclaimer text",
     "Could not set disclaimer text" : "Could not set disclaimer text",
     "Two-Factor Authentication" : "Two-Factor Authentication",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.",
     "Enforce two-factor authentication" : "Enforce two-factor authentication",
     "Limit to groups" : "Limit to groups",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Enforcement of two-factor authentication can be set for certain groups only.",
@@ -265,7 +255,6 @@ OC.L10N.register(
     "Enforced groups" : "Enforced groups",
     "Two-factor authentication is not enforced for members of the following groups." : "Two-factor authentication is not enforced for members of the following groups.",
     "Excluded groups" : "Excluded groups",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced.",
     "Save changes" : "Save changes",
     "All" : "All",
     "Limit app usage to groups" : "Limit app usage to groups",
@@ -327,7 +316,7 @@ OC.L10N.register(
     "Error while creating device token" : "Error while creating device token",
     "New app password" : "New app password",
     "Use the credentials below to configure your app or device. For security reasons this password will only be shown once." : "Use the credentials below to configure your app or device. For security reasons this password will only be shown once.",
-    "Username" : "Username",
+    "Login" : "Login",
     "Password" : "პაროლი",
     "Show QR code for mobile apps" : "Show QR code for mobile apps",
     "App password copied!" : "App password copied!",
@@ -341,16 +330,12 @@ OC.L10N.register(
     "Last job ran {relativeTime}." : "Last job ran {relativeTime}.",
     "Background job did not run yet!" : "Background job did not run yet!",
     "AJAX" : "AJAX",
-    "Execute one task with each page loaded. Use case: Single user instance." : "Execute one task with each page loaded. Use case: Single user instance.",
     "Webcron" : "Webcron",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage).",
     "Cron (Recommended)" : "Cron (Recommended)",
     "Use system cron service to call the cron.php file every 5 minutes." : "Use system cron service to call the cron.php file every 5 minutes.",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "The cron.php needs to be executed by the system user \"{user}\".",
     "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details.",
     "Unable to update background job mode" : "Unable to update background job mode",
     "Profile" : "Profile",
-    "Enable or disable profile by default for new users." : "Enable or disable profile by default for new users.",
     "Enable" : "Enable",
     "Unable to update profile default setting" : "Unable to update profile default setting",
     "Server-side encryption" : "Server-side encryption",
@@ -367,7 +352,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}",
     "Unable to update server side encryption config" : "Unable to update server side encryption config",
     "Please confirm the group removal" : "Please confirm the group removal",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "You are about to remove the group \"{group}\". The users will NOT be deleted.",
     "Cancel" : "Cancel",
     "Confirm" : "Confirm",
     "Submit" : "Submit",
@@ -398,12 +382,13 @@ OC.L10N.register(
     "You are using <strong>{usage}</strong>" : "You are using <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Your full name",
-    "Email options" : "Email options",
+    "Back" : "Back",
+    "This address is not confirmed" : "This address is not confirmed",
     "Primary email for password reset and notifications" : "Primary email for password reset and notifications",
+    "Email options" : "Email options",
     "Remove primary email" : "Remove primary email",
     "Delete email" : "Delete email",
     "Unset as primary email" : "Unset as primary email",
-    "This address is not confirmed" : "This address is not confirmed",
     "Set as primary email" : "Set as primary email",
     "Additional email address {index}" : "Additional email address {index}",
     "Unable to delete primary email address" : "Unable to delete primary email address",
@@ -425,7 +410,6 @@ OC.L10N.register(
     "Your organisation" : "Your organisation",
     "Your phone number" : "Your phone number",
     "Edit your Profile visibility" : "Edit your Profile visibility",
-    "Enable Profile" : "Enable Profile",
     "Unable to update profile enabled state" : "Unable to update profile enabled state",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected.",
     "Unable to update visibility of {displayId}" : "Unable to update visibility of {displayId}",
@@ -443,9 +427,6 @@ OC.L10N.register(
     "Change" : "Change",
     "Delete" : "Delete",
     "Reshare" : "Reshare",
-    "No users" : "No users",
-    "Loading users …" : "Loading users …",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list.",
     "Default language" : "Default language",
     "Common languages" : "Common languages",
     "Other languages" : "Other languages",
@@ -470,36 +451,31 @@ OC.L10N.register(
     "Username will be autogenerated" : "Username will be autogenerated",
     "Username (required)" : "Username (required)",
     "Total rows summary" : "Total rows summary",
+    "Loading users …" : "Loading users …",
     "Scroll to load more rows" : "Scroll to load more rows",
     "_{userCount} user …_::_{userCount} users …_" : ["{userCount} user …","{userCount} users …"],
     "_{userCount} user_::_{userCount} users_" : ["{userCount} user","{userCount} users"],
     "Avatar" : "Avatar",
+    "Username" : "Username",
     "Group admin for" : "Group admin for",
     "User backend" : "User backend",
     "Storage location" : "Storage location",
     "Last login" : "Last login",
     "User actions" : "User actions",
     "Password or insufficient permissions message" : "Password or insufficient permissions message",
-    "Loading user …" : "Loading user …",
     "Change display name" : "Change display name",
     "Set new password" : "Set new password",
-    "You do not have permissions to see the details of this user" : "You do not have permissions to see the details of this user",
     "Set new email address" : "Set new email address",
     "Add user to group" : "Add user to group",
-    "Set user as admin for" : "Set user as admin for",
-    "Select user quota" : "Select user quota",
     "Set the language" : "Set the language",
     "{size} used" : "{size} used",
-    "Delete user" : "Delete user",
+    "Delete account" : "Delete account",
     "Wipe all devices" : "Wipe all devices",
-    "Disable user" : "Disable user",
-    "Enable user" : "Enable user",
     "Resend welcome email" : "Resend welcome email",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet.",
     "Remote wipe of devices" : "Remote wipe of devices",
     "Wipe {userid}'s devices" : "Wipe {userid}'s devices",
     "Wiped {userid}'s devices" : "Wiped {userid}'s devices",
-    "Failed to update user manager" : "Failed to update user manager",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "Fully delete {userid}'s account including all their personal files, app data, etc.",
     "Account deletion" : "Account deletion",
     "Delete {userid}'s account" : "Delete {userid}'s account",
@@ -507,17 +483,13 @@ OC.L10N.register(
     "Password was successfully changed" : "Password was successfully changed",
     "Email was successfully changed" : "Email was successfully changed",
     "Welcome mail sent!" : "Welcome mail sent!",
-    "Toggle user actions menu" : "Toggle user actions menu",
     "Done" : "Done",
     "Edit" : "Edit",
-    "User management settings" : "User management settings",
     "Visibility" : "Visibility",
     "Show language" : "Show language",
-    "Show user backend" : "Show user backend",
     "Show storage path" : "Show storage path",
     "Show last login" : "Show last login",
     "Send email" : "Send email",
-    "Send welcome email to new users" : "Send welcome email to new users",
     "Defaults" : "Defaults",
     "Default quota" : "Default quota",
     "Select default quota" : "Select default quota",
@@ -539,15 +511,12 @@ OC.L10N.register(
     "{license}-licensed" : "{license}-licensed",
     "Changelog" : "Changelog",
     "by {author}\n{license}" : "by {author}\n{license}",
-    "User management" : "User management",
-    "Active users" : "Active users",
     "Admins" : "Admins",
     "Disabled users" : "Disabled users",
     "Creating group …" : "Creating group …",
     "Create group" : "Create group",
     "Group name" : "Group name",
     "Please enter a valid group name" : "Please enter a valid group name",
-    "User group: {group}" : "User group: {group}",
     "Failed to create group" : "Failed to create group",
     "Sending…" : "Sending…",
     "Email sent" : "Email sent",
@@ -566,8 +535,6 @@ OC.L10N.register(
     "Profile visibility" : "Profile visibility",
     "Locale" : "Locale",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Not available as this property is required for core functionality including file sharing and calendar invitations",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Not available as federation has been disabled for your account, contact your system administrator if you have any questions",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions",
     "Your apps" : "Your apps",
     "Active apps" : "Active apps",
     "Disabled apps" : "Disabled apps",
@@ -576,13 +543,13 @@ OC.L10N.register(
     "Featured apps" : "Featured apps",
     "Supported apps" : "Supported apps",
     "Show to everyone" : "Show to everyone",
-    "Show to logged in users only" : "Show to logged in users only",
     "Hide" : "Hide",
     "Download and enable" : "Download and enable",
     "Allow untested app" : "Allow untested app",
     "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected.",
     "Never" : "Never",
+    "Active users" : "Active users",
     "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Error: This app cannot be enabled because it makes the server unstable",
@@ -593,13 +560,12 @@ OC.L10N.register(
     "Error while updating device token name" : "Error while updating device token name",
     "Error while updating device token scope" : "Error while updating device token scope",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
+    "Account documentation" : "Account documentation",
+    "Administration documentation" : "Administration documentation",
     "Documentation" : "Documentation",
     "Forum" : "Forum",
     "Nextcloud help resources" : "Nextcloud help resources",
-    "Account documentation" : "Account documentation",
-    "Administration documentation" : "Administration documentation",
     "General documentation" : "General documentation",
-    "Login" : "Login",
     "None/STARTTLS" : "None/STARTTLS",
     "SSL" : "SSL",
     "Open documentation" : "Open documentation",
@@ -613,7 +579,6 @@ OC.L10N.register(
     "Authentication" : "Authentication",
     "Authentication required" : "Authentication required",
     "Credentials" : "Credentials",
-    "SMTP Username" : "SMTP Username",
     "SMTP Password" : "SMTP Password",
     "Save" : "Save",
     "Test and verify email settings" : "Test and verify email settings",
@@ -634,6 +599,9 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
     "Use a second factor besides your password to increase security for your account." : "Use a second factor besides your password to increase security for your account.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
+    "No user supplied" : "No user supplied",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Please provide an admin recovery password; otherwise, all user data will be lost.",
+    "Backend does not support password change, but the user's encryption key was updated." : "Backend does not support password change, but the user's encryption key was updated.",
     "installing and updating apps via the App Store or Federated Cloud Sharing" : "installing and updating apps via the App Store or Federated Cloud Sharing",
     "Federated Cloud Sharing" : "Federated Cloud Sharing",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably.",
@@ -646,7 +614,15 @@ OC.L10N.register(
     "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>.",
     "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>.",
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>.",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "You need to set your user email before being able to send test emails. Go to %s for that.",
+    "Invalid user" : "Invalid user",
+    "Your username is: %s" : "Your username is: %s",
+    "Logged in user must be a subadmin" : "Logged in user must be a subadmin",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "A background job is pending that checks for user imported SSL certificates. Please check back later.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below.",
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced.",
     "Enable all" : "Enable all",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
@@ -661,17 +637,29 @@ OC.L10N.register(
     "For security reasons this password will only be shown once." : "For security reasons this password will only be shown once.",
     "Copied!" : "Copied!",
     "Copy" : "Copy",
+    "Execute one task with each page loaded. Use case: Single user instance." : "Execute one task with each page loaded. Use case: Single user instance.",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage).",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details.",
     "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "The cron.php needs to be executed by the system user \"{user}\".",
+    "Enable or disable profile by default for new users." : "Enable or disable profile by default for new users.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "You are about to remove the group {group}. The users will NOT be deleted.",
     "Please confirm the group removal " : "Please confirm the group removal ",
     "Choose profile picture from files" : "Choose profile picture from files",
     "png or jpg, max. 20 MB" : "png or jpg, max. 20 MB",
     "Your email address" : "Your email address",
     "Your location" : "Your location",
+    "Enable Profile" : "Enable Profile",
     "Your Twitter handle" : "Your Twitter handle",
+    "You do not have permissions to see the details of this user" : "You do not have permissions to see the details of this user",
     "Add new password" : "Add new password",
     "Add new email address" : "Add new email address",
+    "Set user as admin for" : "Set user as admin for",
+    "Select user quota" : "Select user quota",
+    "Toggle user actions menu" : "Toggle user actions menu",
+    "Delete user" : "Delete user",
+    "Disable user" : "Disable user",
+    "Enable user" : "Enable user",
     "Edit User" : "Edit User",
     "Will be autogenerated" : "Will be autogenerated",
     "Add a new user" : "Add a new user",
@@ -680,10 +668,15 @@ OC.L10N.register(
     "Add group" : "Add group",
     "Default quota:" : "Default quota:",
     "Show Languages" : "Show Languages",
+    "Show user backend" : "Show user backend",
     "Send email to new user" : "Send email to new user",
     "Not saved" : "Not saved",
     "Twitter" : "Twitter",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Not available as federation has been disabled for your account, contact your system administrator if you have any questions",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions",
+    "Show to logged in users only" : "Show to logged in users only",
     "Enable untested app" : "Enable untested app",
+    "SMTP Username" : "SMTP Username",
     "Expire after" : "Expire after",
     "day(s)" : "day(s)",
     "Exclude groups from password requirements:" : "Exclude groups from password requirements:",
@@ -696,6 +689,16 @@ OC.L10N.register(
     "Select manager" : "Select manager",
     "User's table" : "User's table",
     "Select user manager" : "Select user manager",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s."
+    "Old user imported certificates" : "Old user imported certificates",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s.",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "You are about to remove the group \"{group}\". The users will NOT be deleted.",
+    "No users" : "No users",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list.",
+    "Loading user …" : "Loading user …",
+    "Failed to update user manager" : "Failed to update user manager",
+    "User management settings" : "User management settings",
+    "Send welcome email to new users" : "Send welcome email to new users",
+    "User management" : "User management",
+    "User group: {group}" : "User group: {group}"
 },
 "nplurals=2; plural=(n!=1);");
