@@ -23,14 +23,11 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "თქვენ ორ-ფაქტორიანი აუტენტიფიკაციით წარმატებით გაიარეთ ავტორიზაცია (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "ავტორიზაცია ორ-ფაქტორიანი აუტენტიფიკაციით ვერ მოხერხდა (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>თქვენი პაროლი</strong> ან <strong>ელ-ფოსტის მისამართი</strong> შეიცვალა",
-    "Apps" : "აპლიკაციები",
+    "Settings" : "პარამეტრები",
     "Wrong password" : "არასწორი პაროლი",
     "Saved" : "დამახსოვრდა",
-    "No user supplied" : "მომხმარებელი არ იქნა მოწოდებული",
     "Authentication error" : "აუტენტიფიკაციის შეცდომა",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
     "Wrong admin recovery password. Please check the password and try again." : "ადმინისტრატორის აღდგენის არასწორი პაროლი. გთხოვთ გადაამოწმოთ პაროლი და სცადოთ ახლიდან.",
-    "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
     "Administrator documentation" : "ადმინისტრატორის დოკუმენტაცია",
     "User documentation" : "მომხმარებლის დოკუმენტაცია",
     "Invalid SMTP password." : "არასწორი SMTP პაროლი.",
@@ -39,8 +36,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "იმ შემთხვევაში თუ მიიღეთ ეს ელ-წერილი, ელ-ფოსტის კონფიგურაცია კარგად უნდა იყოს.",
     "Email could not be sent. Check your mail server log" : "ელ-წერილი ვერ იგზავნება. გთხოვთ შეამოწმოთ მეილ-სერვერის ლოგი",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ელ-წერილის გაგზავნისას წარმოიშვა შეცდომა. გთხოვთ გადახედოთ თქვენს პარამეტრებს. (შეცდომა: %s)",
-    "Users" : "მომხმარებლები",
-    "Invalid user" : "არასწორი მომხმარებელი",
+    "Invalid account" : "არასწორი ანგარიში",
     "Invalid mail address" : "არასწორი საფოსტო მისამართი",
     "Settings saved" : "პარამეტრები შენახულია",
     "Unable to change full name" : "სრული სახელის ცვლილება ვერ ხერხდება",
@@ -62,14 +58,13 @@ OC.L10N.register(
     "Welcome aboard" : "კეთილი იყოს თქვენი ბორტზე მობრძანება",
     "Welcome aboard %s" : "%s, კეთილი იყოს თქვენი ბორტზე მობრძანება",
     "Welcome to your %s account, you can add, protect, and share your data." : "კეთილი იყოს თქვენი %s ანგარიშში მობრძანება, შეგიძლიათ დაამატოთ, დაიცვათ და გააზიაროთ თქვენი მონაცემები.",
-    "Your username is: %s" : "თქვენი მომხმარებლის სახელია: %s",
     "Set your password" : "დააყენეთ თქვენი პაროლი",
     "Go to %s" : "გადადით %s-ზე",
     "Install Client" : "დააყენეთ კლიენტი",
-    "Logged in user must be a subadmin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ქვე-ადმინისტრატორი",
-    "Settings" : "პარამეტრები",
+    "Apps" : "აპლიკაციები",
     "Personal" : "პირადი",
     "Administration" : "ადმინისტრაცია",
+    "Users" : "მომხმარებლები",
     "Additional settings" : "დამატებითი პარამეტრები",
     "Overview" : "ზოგადი მიმოხილვა",
     "Basic settings" : "ძირითადი პარამეტრები",
@@ -83,6 +78,7 @@ OC.L10N.register(
     "Unlimited" : "ულიმიტო",
     "Verifying" : "მოწმდება",
     "Disabled" : "არაა მოქმედი",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-ს ფუნქცია \"set_time_limit\" არაა ხელმისაწვდომი. ამან შეიძლება ქმედებისას გამოიწვიოს სკრიპტების შეჩერება, ინსტალაციის შეწყვეტა. რეკომენდირებულია ამ ფუნქციის ჩართვა.",
     "Supported" : "მხარდაჭერილია",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "თქვენს PHP-ს არ აქვს FreeType-ის მხარდაჭერა, რაც გამოწვევს დარღვეულ პროფილის სურათებს და პარამეტრების ინტერფეისს.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "როგორც ჩანს PHP სისტემის გარემოს ცვლადების მიღებისთვის არაა სწორად მოწყობილი. ეს ტესტი getenv(\"PATH\")-ით აბრუნებს მხოლოდ ცარიელ პასუხს.",
@@ -125,28 +121,16 @@ OC.L10N.register(
     "Allow filesystem access" : "ფაილ-სისტემაზე წვდომის მინიჭება",
     "Rename" : "სახელის შეცვლა",
     "Revoke" : "წვდომის გაუქმება",
-    "Internet Explorer" : "Internet Explorer-ი",
-    "Edge" : "Edge-ი",
-    "Firefox" : "Firefox-ი",
-    "Google Chrome" : "Google Chrome-ი",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome Android-ისთვის",
-    "Sync client - {os}" : "სინქ. კლიენტი - {os}",
     "This session" : "ეს სესია",
     "Device" : "მოწყობილობა",
     "Last activity" : "ბოლო აქტივობა",
     "Web, desktop and mobile clients currently logged in to your account." : "ვებ, დესკტოპ და მობილური კლიენტები ამჟამად ავტორიზირებული თქვენს ანგარიშზე.",
-    "Error while creating device token" : "მოწყობილობის ტოკენის ჩატვირთვისას წარმოიქმნა შეცდომა",
-    "Error while deleting the token" : "ტოკენის წაშლისას წარმოიქმნა შეცდომა",
     "App name" : "აპლიკაციის სახელი",
     "Create new app password" : "ახალი აპლიკაციის პაროლის შექმნა",
-    "Use the credentials below to configure your app or device." : "ქვემოთ მოცემული უფლებამოსილებანის გამოყენება აპლიკაციისა თუ მოწყობილობისთვის.",
-    "For security reasons this password will only be shown once." : "უსაფრთხოების მიზნით ეს პაროლი გამოჩნდება მხოლოდ ერთხელ.",
-    "Username" : "მომხმარებლის სახელი",
+    "Error while creating device token" : "მოწყობილობის ტოკენის ჩატვირთვისას წარმოიქმნა შეცდომა",
+    "Login" : "ლოგინი",
     "Password" : "პაროლი",
-    "Done" : "დასრულებულია",
-    "Copied!" : "კოპირებულია",
-    "Copy" : "კოპირება",
     "Enable" : "ჩართვა",
     "Server-side encryption" : "სერვერული-მხარის შიფრაცია",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "სერვერული-მხარის შიფრაცია იძლევა სერვერზე ატვირთული ფაილების შიფრაციის საშუალებას. ეს ფუნქცია ლიმიტს აწესებს მოქმედებაზე, ასე რომ გააქტიურედ მხოლოდ აუცილებლობისას.",
@@ -179,21 +163,21 @@ OC.L10N.register(
     "Quota" : "ქვოტა",
     "Language" : "ენა",
     "Avatar" : "ავატარი",
+    "Username" : "მომხმარებლის სახელი",
     "Group admin for" : "ადმინისტრატორის შეჯგუფება",
     "User backend" : "მომხმარებელის ბექენდი",
     "Storage location" : "საცავის ადგილმდებარეობა",
     "Last login" : "ბოლო ავტორიზაცია",
     "{size} used" : "მოხმარებულია {size}",
+    "Delete account" : "ანგარიშის გაუქმება",
+    "Done" : "დასრულებულია",
     "Edit" : "შეცვლა",
-    "Show user backend" : "მომხმარებლის ბექენდის ჩვენება",
     "Show last login" : "ბოლო ავტორიზაციის ჩვენება",
     "Send email" : "ელ-წერილის გაგზავნა",
     "Default quota" : "საწყისი კვოტა",
     "Unnamed device" : "უსახელო მოწყობილობა",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "როგორც ადმინისტრატორს შეგიძლიათ გაზიარების ქცევის კორექტირება. დამატებითი ინფორმაციისთვის იხილეთ დოკუმენტაცია.",
-    "Your apps" : "თქვენი აპლიკაციები",
     "Changelog" : "ცვლილებების ლოგი",
-    "Active users" : "აქტიური მომხმარებლები",
     "Admins" : "ადმინისტრატორები",
     "Group name" : "ჯგუფის სახელი",
     "Sending…" : "იგზავნება…",
@@ -204,15 +188,16 @@ OC.L10N.register(
     "Full name" : "სრული სახელი",
     "Phone number" : "ტელეფონის ნომერი",
     "Website" : "ვებ-საიტი",
+    "Your apps" : "თქვენი აპლიკაციები",
     "Disabled apps" : "არამოქმედი აპლიკაციები",
     "Updates" : "განახლებები",
     "App bundles" : "აპლიკაციის შეკვრები",
     "Hide" : "დამალვა",
     "Never" : "არასდროს",
+    "Active users" : "აქტიური მომხმარებლები",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "აპლიკაცია ამოქმედდა, თუმცა საჭიროებს განახლებას. 5 წამში გადამისამართდებით განახლების გვერდზე.",
     "Documentation" : "დოკუმენტაცია",
     "Forum" : "ფორუმი",
-    "Login" : "ლოგინი",
     "SSL" : "SSL",
     "Open documentation" : "ღია დოკუმენტაცია",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "ამ სერვერის მოწყობა ელ-წერილების გასაგზვნად მნიშვნელოვანია, მაგ. პაროლის აღსადგენად და შეტყობინებების მისაღებად.",
@@ -224,7 +209,6 @@ OC.L10N.register(
     "Authentication" : "აუტენტიფიკაცია",
     "Authentication required" : "აუტენტიფიკაცია საჭიროებს",
     "Credentials" : "უფლებამოსილებანი",
-    "SMTP Username" : "SMTP მოხმარებლის სახელი",
     "SMTP Password" : "SMTP მომხმარებლის პაროლი",
     "Save" : "შენახვა",
     "All checks passed." : "ყველა შემოწმებამ ჩაიარა დადებითად.",
@@ -233,20 +217,34 @@ OC.L10N.register(
     "Follow us on Twitter" : "გამოგვყევით Twitter-ზე",
     "Check out our blog" : "იხილეთ ჩვენი ბლოგი",
     "Subscribe to our newsletter" : "გამოიწერეთ ჩვენი სიახლეები",
+    "No user supplied" : "მომხმარებელი არ იქნა მოწოდებული",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "გთხოვთ მოგვაწოდოთ ადმინისტრატორის აღდგენის პაროლი; სხვა შემთხვევაში ყველა მონაცემი დაიკარგება.",
+    "Federated Cloud Sharing" : "ფედერალური ქლაუდ გაზიარება",
+    "Invalid user" : "არასწორი მომხმარებელი",
+    "Your username is: %s" : "თქვენი მომხმარებლის სახელია: %s",
+    "Logged in user must be a subadmin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ქვე-ადმინისტრატორი",
     "Enable all" : "ყველას ამოქმედება",
+    "Internet Explorer" : "Internet Explorer-ი",
+    "Edge" : "Edge-ი",
+    "Firefox" : "Firefox-ი",
+    "Google Chrome" : "Google Chrome-ი",
+    "Safari" : "Safari",
+    "Sync client - {os}" : "სინქ. კლიენტი - {os}",
+    "Error while deleting the token" : "ტოკენის წაშლისას წარმოიქმნა შეცდომა",
+    "Use the credentials below to configure your app or device." : "ქვემოთ მოცემული უფლებამოსილებანის გამოყენება აპლიკაციისა თუ მოწყობილობისთვის.",
+    "For security reasons this password will only be shown once." : "უსაფრთხოების მიზნით ეს პაროლი გამოჩნდება მხოლოდ ერთხელ.",
+    "Copied!" : "კოპირებულია",
+    "Copy" : "კოპირება",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "ამის გასაშვებად საჭიროა გქონდეთ PHP POSIX გაფართოება. მეტი დეტალებისთვის იხილეთ {linkstart}PHP დოკუმენტაცია{linkend}. ",
     "png or jpg, max. 20 MB" : "png ან jpg, მაქს. 20 მბ",
     "Your email address" : "თქვენი ელ-ფოსტის მისამართი",
     "Your Twitter handle" : "თქვენი Twitter-is @…",
     "Add group" : "ჯგუფის დამატება",
+    "Show user backend" : "მომხმარებლის ბექენდის ჩვენება",
     "Send email to new user" : "გაუგზავნეთ ელ-წერილი ახალ მომხმარებელს",
     "Not saved" : "არაა შენახული",
     "Twitter" : "Twitter-ი",
-    "Plain" : "ჩვეულებრივი",
-    "NT LAN Manager" : "NT LAN მენეჯერი",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "აუტენტიფიკაციის მეთოდი",
+    "SMTP Username" : "SMTP მოხმარებლის სახელი",
     "Set default expiration date" : "დააყენეთ საწყისი ვადის ამოწურვის თარიღი"
 },
 "nplurals=2; plural=(n!=1);");
