@@ -50,25 +50,15 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Далечинското бришење е започна на  %1$s",
     "Remote wipe has finished on %1$s" : "Далечинското бришење заврши на %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Вашата <strong>лозинка</strong> или <strong>е-пошта</strong> е променета",
-    "Apps" : "Аппликации",
+    "Settings" : "Параметри",
     "Could not remove app." : "Не може да ја се избрише апликацијата.",
     "Could not update app." : "Не може да ја се ажурира апликацијата.",
     "Wrong password" : "Погрешна лозинка",
     "Unable to change personal password" : "Неможе да се промени сопствената лозинката",
     "Saved" : "Зачувано",
-    "No user supplied" : "Нема корисничко име",
     "Unable to change password. Password too long." : "Неможе да се промени лозинката. Лозинката е премногу долга.",
     "Authentication error" : "Грешка во автентикација",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ве молам дадете лозинка за поврат на администраторот; во спротивно, сите кориснички податоци ќе бидат изгубени.",
     "Wrong admin recovery password. Please check the password and try again." : "Погрешна лозинка за поврат на администраторот. Ве молам проверете ја лозинката и пробајте повторно.",
-    "Backend does not support password change, but the user's encryption key was updated." : "Позадината не подржува промена на лозинката, но корисничкиот клуч за енкрипција е ажуриран.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "инсталирање и ажурирање на апликации преку продавницата за апликации или Федерално споделување",
-    "Federated Cloud Sharing" : "Федеретивно споделување",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL користи застарена %1$s верзија (%2$s). Ве молиме ажурирајте го вашиот оперативен систем или можностите како %3$s нема да работат безбедно.",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Неможе да се одреди TLS верзијата на cURL или не е ажурирана и затоа настанува грешка при HTTPS барањето до https://nextcloud.com. Проверете ги записите во nextcloud за повеќе детали.",
-    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP модулот OPcache не е вчитан. За да имате подобри перформанси е препорачливо да го вчитате во вашата PHP инсталација.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache модулот е оневозможен. За подобри перформанси препорачливо е да го овозможите <code>opcache.enable=1</code> во вашата PHP конфигурација.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache е конфигуриран за да ги брише коментарите во кодовите. Со овозможен OPcache, <code>opcache.save_comments=1</code> мора да се постави за да функционира Nextcloud.",
     "Administrator documentation" : "Документација за администратор",
     "User documentation" : "Документација за корисник",
     "Invalid SMTP password." : "Грешна SMTP лозинка.",
@@ -77,9 +67,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Ако ја примивте оваа порака, тоа значи дека конфигурацијата за е-пошта е правилно поставена.",
     "Email could not be sent. Check your mail server log" : "Порака преку Е-пошта неможе да се испрати. Проверете го записот во е-пошта серверот",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Се случи грешка при праќање на порака. Ве молам проверете ги вашите параметри. (Error: %s)",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "Треба да ја поставите вашата е-пошта адреса пред да можете да испратите тест пораки. Одете во %s за тоа.",
-    "Users" : "Корисници",
-    "Invalid user" : "Неправилен корисник",
     "Invalid mail address" : "Неправилна електронска адреса/пошта",
     "Settings saved" : "Параматрите се зачувани",
     "Unable to change full name" : "Не можам да го променам целото име",
@@ -105,14 +92,13 @@ OC.L10N.register(
     "Welcome aboard" : "Добредојдовте",
     "Welcome aboard %s" : "Добредојдовте %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Добредојдовте на вашата %s сметка, можете да додавате, чувате и да ги споделувате вашите податоци.",
-    "Your username is: %s" : "Вашето корисничко име е: %s",
     "Set your password" : "Поставете ваша лозинка",
     "Go to %s" : "Оди до %s",
     "Install Client" : "Инсталирај клиент",
-    "Logged in user must be a subadmin" : "Најавениот корисник мора да биде подадминистратор",
-    "Settings" : "Параметри",
+    "Apps" : "Аппликации",
     "Personal" : "Лично",
     "Administration" : "Администрација",
+    "Users" : "Корисници",
     "Additional settings" : "Дополнителни параметри",
     "Artificial Intelligence" : "Вештачка интелигенција",
     "Administration privileges" : "Административни привилегии",
@@ -129,16 +115,16 @@ OC.L10N.register(
     "Background jobs" : "Задачи кој се извршуваат во позадина",
     "Unlimited" : "Неограничено",
     "Verifying" : "Потврдување",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Позадинското извршување на процедурите се на чекање бидејќи се проверуваат некој SSL сертификати што се увезени од корисник. Вратете се подоцна.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Постојат некој увезени SSL сертификати, во наредната верзија на Nextcloud 21 нема да се користи. Истите можат да се увезат преку командната линија со внесување на командата \"occ security:certificates:import\". Нивните патеки во директориумот со податоци се прикажани подолу. ",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Во базата недостасуваат некој опционални колони. Поради фактот што додавањето колони во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-columns\" ќе бидат додадени оние колони што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени колоните, некој карактеристики ќе се подобрат и можат да ја подобрат употребата и безбедноста.",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Во базата недостасуваат некој индекси. Поради фактот што додавањето индекси во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-indices\" ќе бидат додадени оние индекси што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени индексите, барањата во табелите ќе биде многу побрзо.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Во базата недостасуваат некој примарни клучеви. Поради фактот што додавањето на примарни клучеви во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-primary-keys\" ќе бидат додадени оние примарни клучеви што недостасуваат и инстанцата непречено ќе работи.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Овој опслужувач нема работна Интернет врска. Ова значи дека некои опции како што е монтирање на надворешни складишта, известувања за ажурирање или инсталации на апликации од 3-ти лица нема да работат. Пристапот на датотеки од далечина и праќање на пораки за известувања може исто така да не работат. Ви советуваме да овозможите Интернет врска за овој опслужувач ако сакате да ги имате сите опции. ",
     "Disabled" : "Оневозможено",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Овозможен е стар формат за криптирање од страна на серверот. Препорачуваме да го оневозможите ова.",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функцијата \"set_time_limit\" не е достапна. Ова може да резултира со запирање на скриптите во извршувањето, и грешки во вашата инсталација. Овозможувањето на оваа функција е препорачлива.",
     "Supported" : "Поддржано",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP се чини дека не е правилно поставена за да испраќа барања до променливите на околината на системот. Тестот со getenv(\"PATH\") враќа само празен одговор.",
+    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "PHP модулот OPcache не е вчитан. За да имате подобри перформанси е препорачливо да го вчитате во вашата PHP инсталација.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Антивирана е конфигурација која е само за чирање. Ова спречува поставување на некои конфигурации преку веб-интерфејсот. Понатаму, датотеката треба да се пребрише рачно за секое ажурирање.",
     "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "Се користи MariaDB верзија\"%s\". Nextcloud 21 и поголемите верзии, повеќе нема да ја поддржува оваа верзија и потебно е да ја ажурирате на верзија 10.2 или понова.",
     "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "Се користи MySQL верзија\"%s\". Nextcloud 21 и поголемите верзии, повеќе нема да ја поддржува оваа верзија и потебно е да ја ажурирате на верзија 8.0 или MariaDB 10.2 или понова.",
@@ -180,7 +166,6 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "Овој текст ќе биде прикажан на страната со јавниот линк кога листата на датотеки е сокриена.",
     "Default share permissions" : "Стандардни дозволи за споделување",
     "Two-Factor Authentication" : "Двофакторна автентикација",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Двофакторна автентикација може да биде задолжителна за сите корисници и одредени групи. Доколку корисниците немаат поставено провајдер за двофакторна автентикација, нема да можат да се најават на системот.",
     "Enforce two-factor authentication" : "Задолжителна двофакторна автентикација",
     "Limit to groups" : "Ограничување на групи",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Задолжителна двофакторна автентикација може да се постави само за одредени групи.",
@@ -188,7 +173,6 @@ OC.L10N.register(
     "Enforced groups" : "Задолжителни групи",
     "Two-factor authentication is not enforced for members of the following groups." : "Двофакторна автентикација не е задолжителна за членови на следниве групи.",
     "Excluded groups" : "Исклучени групи",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Кога се избираат/исклучуваат групи, се користи следната постапка за утврдување дали корисникот задолжително ќе користи двофакторна автентификација: Ако нема избрано групи, двофакторна автентификација е овозможена за секој освен за членовите во исклучените групи. Ако еден корисник е член во две групи избрана и исклучена, тогаш тој корисник задолжително мора да користи двофакторна автентификација.",
     "Save changes" : "Зачувај ги промените",
     "All" : "Сите",
     "Limit app usage to groups" : "Ограничување за користење на апликации во групи",
@@ -228,57 +212,34 @@ OC.L10N.register(
     "Revoke" : "Одземи",
     "Wipe device" : "Избриши уред",
     "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Одземањето на овој токен може да спречи бришење на вашиот уред ако сè уште не е избришано.",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome за Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
     "{productName} iOS app" : "{productName} iOS апликација",
     "{productName} Android app" : "{productName} Android апликација",
     "{productName} Talk for iOS" : "{productName} Talk за iOS",
     "{productName} Talk for Android" : "{productName} Talk за Android",
-    "Sync client - {os}" : "Клиент за синхронизација - {os}",
     "This session" : "Оваа сесија",
     "Device" : "Уред",
     "Last activity" : "Последна активност",
     "Devices & sessions" : "Уреди и сесии",
     "Web, desktop and mobile clients currently logged in to your account." : "Клиенти за веб, компјутер и мобелен кој моментално се поврзани на твојата сметка.",
-    "Do you really want to wipe your data from this device?" : "Дали навистина сакате да ја избришете содржината од овој уред?",
-    "Confirm wipe" : "Потврди бришење",
-    "Error while creating device token" : "Грешка при креирање на токен за уред",
-    "Error while updating device token scope" : "Грешка при ажурирање на токен за уред",
-    "Error while updating device token name" : "Грешка при промена на името за токен на уред",
-    "Error while deleting the token" : "Грешка при бришење на токен",
-    "Error while wiping the device with the token" : "Грешка при бришење на уред со токен",
     "App name" : "Име на апликација",
     "Create new app password" : "Креирај нова лозинка за апликација",
-    "Use the credentials below to configure your app or device." : "Користи ги следните акредитиви за конфигурирање на апликацијата или уредот.",
-    "For security reasons this password will only be shown once." : "Поради безбедносни причини лозинката ќе биде прикажана само еднаш.",
-    "Username" : "Корисничко име",
+    "Error while creating device token" : "Грешка при креирање на токен за уред",
+    "Login" : "Најава",
     "Password" : "Лозинка",
-    "Done" : "Готово",
     "Show QR code for mobile apps" : "Прикажи QR код за апликација на мобилен телефон",
-    "Copied!" : "Копирано!",
-    "Copy" : "Копирај",
     "Could not copy app password. Please copy it manually." : "Неможе да се копира лозинката за апликација. Ве молиме копирајте ја рачно.",
     "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "За серверот да работи правилно, важно е да ги конфигурирате процедурите кој се извршуваат во позадина. За големи истанци 'Cron' е препорачаната поставка. Погледнете ја документацијата за повеќе информации.",
     "Last job execution ran {time}. Something seems wrong." : "Последно извршување на задачите: {time}. Нешто не е во ред.",
     "Last job ran {relativeTime}." : "Последната процедура се изврши пред {relativeTime}.",
     "Background job did not run yet!" : "Сеуште нема извршено ниедна задача!",
     "AJAX" : "AJAX",
-    "Execute one task with each page loaded. Use case: Single user instance." : "Извршува по една задача со секоја вчитана страница. Се користи за инстанца со еден корисник.",
     "Webcron" : "Webcron",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php треба да се регистрира на webcron сервис за да ја повикува процедурата секој 5 минути преку HTTP. Се користи за помали истанци (1-5 корисника во зависност на искористувањето).",
     "Cron (Recommended)" : "Cron (Препорачано)",
     "Use system cron service to call the cron.php file every 5 minutes." : "Го користи системскиот Cron сервис и го повикува cron.php секој 5 минути.",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php е потребно да биде извршен од системски корисник \"{user}\".",
     "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "Потребен е PHP POSIX додаток. Погледни во  {linkstart}PHP документацијата{linkend} за повеќе детали.",
     "Unable to update background job mode" : "Не може да се ажурира режимот на работа во позадина",
     "Profile" : "Профил",
-    "Enable or disable profile by default for new users." : "Стандардно овозможи или оневозможи профил за нови корисници.",
     "Enable" : "Овозможи",
     "Unable to update profile default setting" : "Неможе да се ажурираат стандардните параметри за профилот",
     "Server-side encryption" : "Енкрипција на страна на серверот",
@@ -323,12 +284,13 @@ OC.L10N.register(
     "You are using <strong>{usage}</strong>" : "Користите <strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Користите <strong>{usage}</strong> од <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Вашето целосно име",
-    "Email options" : "Е-пошта параметри",
+    "Back" : "Назад",
+    "This address is not confirmed" : "Оваа адреса не е потврдена",
     "Primary email for password reset and notifications" : "Примарна Е-пошта за ресетирање на лозинка и известувања",
+    "Email options" : "Е-пошта параметри",
     "Remove primary email" : "Избриши примарна е-пошта",
     "Delete email" : "Избриши е-пошта",
     "Unset as primary email" : "Острани од примарна е-пошта",
-    "This address is not confirmed" : "Оваа адреса не е потврдена",
     "Set as primary email" : "Постави како примарна е-пошта",
     "Additional email address {index}" : "Дополнителна е-пошта {index}",
     "Unable to delete primary email address" : "Неможе да се избрише примарната е-пошта",
@@ -349,7 +311,6 @@ OC.L10N.register(
     "Your organisation" : "Вашата организација",
     "Your phone number" : "Вашиот телефонски број",
     "Edit your Profile visibility" : "Уредете ја видливоста на вашиот профил",
-    "Enable Profile" : "Овозможи профил",
     "Unable to update profile enabled state" : "Неможе да се ажурира достапноста на профилот",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "Порестриктивни параметри за видливост или опсег се почитува на вашиот профил. На пример, ако видливоста е поставена на \"Прикажи на сите\", а опсегот е поставен на \"Приватно\", се почитува \"Приватно\".",
     "Unable to update visibility of {displayId}" : "Неможе да се ажурира видливоста на {displayId}",
@@ -366,9 +327,7 @@ OC.L10N.register(
     "Change" : "Измени",
     "Delete" : "Избриши",
     "Reshare" : "Пресподели",
-    "No users" : "Нема корисници",
-    "Loading users …" : "Вчитување корисници ...",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Листа на корисници. Оваа листа не е целосно прикажана поради заштеда на перформанси. Корисниците ќе се прикажуваат додека се движите низ листата.",
+    "No accounts" : "Нема сметки",
     "Default language" : "Стандарден јазик",
     "Common languages" : "Заеднички јазици",
     "Other languages" : "Други јазици",
@@ -393,27 +352,23 @@ OC.L10N.register(
     "Username will be autogenerated" : "Корисничкото име ќе биде автоматски генерирано",
     "Username (required)" : "Корисничко име (задолжително)",
     "Total rows summary" : "Резиме на вкупно редови",
+    "Loading users …" : "Вчитување корисници ...",
     "Scroll to load more rows" : "Одете надолу за да се вчитаат повеќе редови",
     "_{userCount} user …_::_{userCount} users …_" : ["{userCount} корисник …","{userCount} корисници …"],
     "_{userCount} user_::_{userCount} users_" : ["{userCount} корисник","{userCount} корисници"],
     "Avatar" : "Аватар",
+    "Username" : "Корисничко име",
     "Group admin for" : "Администратор на група",
     "User backend" : "Задна страна на корисник",
     "Storage location" : "Локација на складиште",
     "Last login" : "Последно најавување",
     "Password or insufficient permissions message" : "Порака за лозинка или недоволна дозвола",
-    "Loading user …" : "Вчитување корисник ...",
     "Change display name" : "Промена на името",
-    "You do not have permissions to see the details of this user" : "Немате дозвола за да ги гледате деталите на овој корисник",
     "Add user to group" : "Додади корисник во група",
-    "Set user as admin for" : "Назначи го корисникот како администратор за",
-    "Select user quota" : "Избери квота за корисник",
     "Set the language" : "Постави јазик",
     "{size} used" : "искористено {size}",
-    "Delete user" : "Избриши корисник",
+    "Delete account" : "Избриши сметка",
     "Wipe all devices" : "Избриши ги сите уреди",
-    "Disable user" : "Оневозможи корисник",
-    "Enable user" : "Овозможи корисник",
     "Resend welcome email" : "Повторно испрати е-пошта порака за добредојде",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Во случај да го изгубите уредот или да излезете од компанијата, можете далечински да ги избришете податоците од сите уреди кој се конектирани со корисникот {userid}. Ова работи само доколку уредот е поврзан на интернет.",
     "Remote wipe of devices" : "Далечинско бришење на уреди",
@@ -422,15 +377,13 @@ OC.L10N.register(
     "Account deletion" : "Бришење на сметката",
     "Delete {userid}'s account" : "Избриши го корисникот {userid}",
     "Welcome mail sent!" : "Испратена е-пошта порака за добредојде!",
-    "Toggle user actions menu" : "Вклучи го менито за активности",
+    "Done" : "Готово",
     "Edit" : "Уреди",
     "Visibility" : "Видливост",
     "Show language" : "Прикажи јазик",
-    "Show user backend" : "Прикажи задна страна на корисник",
     "Show storage path" : "Прикажи патека на складиште",
     "Show last login" : "Прикажи последно најавување",
     "Send email" : "Испрати пошта",
-    "Send welcome email to new users" : "Испрати е-пошта за добредојде до новите корисници",
     "Defaults" : "Стандарди",
     "Default quota" : "Стандардна квота",
     "Select default quota" : "Избери стандардна квота",
@@ -452,7 +405,6 @@ OC.L10N.register(
     "{license}-licensed" : "{license}-лиценца",
     "Changelog" : "Листа на промени",
     "by {author}\n{license}" : "од {author}\n{license}",
-    "Active users" : "Активни корисници",
     "Admins" : "Администратори",
     "Disabled users" : "Оневозможени корисници",
     "Group name" : "Име на група",
@@ -471,7 +423,6 @@ OC.L10N.register(
     "Profile visibility" : "Видливост на профилот",
     "Locale" : "Локација",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Не е достапно бидејќи ова својство е потребно за основна функционалност, вклучувајќи споделување датотеки и покани од календар",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Не е достапно бидејќи не е дозволено објавување специфични податоци за корисникот на серверот за пребарување, контактирајте со вашиот системски администратор ако имате какви било прашања",
     "Your apps" : "Ваши апликации",
     "Active apps" : "Активни апликации",
     "Disabled apps" : "Оневозможени апликации",
@@ -480,20 +431,24 @@ OC.L10N.register(
     "Featured apps" : "Истакнати апликации",
     "Supported apps" : "Поддржани апликации",
     "Show to everyone" : "Прикажи на сите",
-    "Show to logged in users only" : "Прикажи само на корисници",
     "Hide" : "Сокриј",
     "Download and enable" : "Преземи и овозможи",
     "Allow untested app" : "Дозволи не тестирана апликација",
     "The app will be downloaded from the App Store" : "Апликацијата ќе биде преземена преку продавницата за апликации",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Апликацијата не е означена дека е компатибилна со вашата верзија на Nextcloud. Доколку продолжите апликацијата ќе се инсталира. Имајте на ум дека апликацијата може да не работи како што очекувате.",
     "Never" : "Никогаш",
+    "Active users" : "Активни корисници",
     "An error occurred during the request. Unable to proceed." : "Настана грешка во процесот. Не може да продолжи.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Оваа апликација е овозможена но треба да биде надоградена. Ќе бидете пренасочени кон страната за надоградување за 5 секунди.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Грешка: Оваа апликација неможе да се овозможи бидејќи ќе го направи серверот нестабилен",
+    "Do you really want to wipe your data from this device?" : "Дали навистина сакате да ја избришете содржината од овој уред?",
+    "Confirm wipe" : "Потврди бришење",
+    "Error while wiping the device with the token" : "Грешка при бришење на уред со токен",
+    "Error while updating device token name" : "Грешка при промена на името за токен на уред",
+    "Error while updating device token scope" : "Грешка при ажурирање на токен за уред",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Има испратено премногу барање од вашата мрежа. Обидете се подоцна повторно или контактирајте го администраторот.",
     "Documentation" : "Документација",
     "Forum" : "Форум",
-    "Login" : "Најава",
     "None/STARTTLS" : "None/STARTTLS",
     "SSL" : "SSL",
     "Open documentation" : "Отвори ја документацијата",
@@ -507,7 +462,6 @@ OC.L10N.register(
     "Authentication" : "Автентикација",
     "Authentication required" : "Потребна е автентификација",
     "Credentials" : "Акредитиви",
-    "SMTP Username" : "SMTP корисничко име",
     "SMTP Password" : "SMTP лозинка",
     "Save" : "Зачувај",
     "Test and verify email settings" : "Тестирај и потврди ги параметрите за електронска пошта",
@@ -527,17 +481,59 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "Претплатете се на нашиот билтен",
     "Use a second factor besides your password to increase security for your account." : "Користете втор фактор и покрај вашата лозинка за да ја зголемите безбедноста на вашата сметка.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Доколку користите друга апликација за поврзување на Nextcloud, осигурајте се дека имате креирано лозинка за секоја апликација пред да овозможите втор фактор.",
+    "No user supplied" : "Нема корисничко име",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ве молам дадете лозинка за поврат на администраторот; во спротивно, сите кориснички податоци ќе бидат изгубени.",
+    "Backend does not support password change, but the user's encryption key was updated." : "Позадината не подржува промена на лозинката, но корисничкиот клуч за енкрипција е ажуриран.",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "инсталирање и ажурирање на апликации преку продавницата за апликации или Федерално споделување",
+    "Federated Cloud Sharing" : "Федеретивно споделување",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL користи застарена %1$s верзија (%2$s). Ве молиме ажурирајте го вашиот оперативен систем или можностите како %3$s нема да работат безбедно.",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "Неможе да се одреди TLS верзијата на cURL или не е ажурирана и затоа настанува грешка при HTTPS барањето до https://nextcloud.com. Проверете ги записите во nextcloud за повеќе детали.",
+    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache модулот е оневозможен. За подобри перформанси препорачливо е да го овозможите <code>opcache.enable=1</code> во вашата PHP конфигурација.",
+    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache е конфигуриран за да ги брише коментарите во кодовите. Со овозможен OPcache, <code>opcache.save_comments=1</code> мора да се постави за да функционира Nextcloud.",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "Треба да ја поставите вашата е-пошта адреса пред да можете да испратите тест пораки. Одете во %s за тоа.",
+    "Invalid user" : "Неправилен корисник",
+    "Your username is: %s" : "Вашето корисничко име е: %s",
+    "Logged in user must be a subadmin" : "Најавениот корисник мора да биде подадминистратор",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Позадинското извршување на процедурите се на чекање бидејќи се проверуваат некој SSL сертификати што се увезени од корисник. Вратете се подоцна.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Постојат некој увезени SSL сертификати, во наредната верзија на Nextcloud 21 нема да се користи. Истите можат да се увезат преку командната линија со внесување на командата \"occ security:certificates:import\". Нивните патеки во директориумот со податоци се прикажани подолу. ",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Двофакторна автентикација може да биде задолжителна за сите корисници и одредени групи. Доколку корисниците немаат поставено провајдер за двофакторна автентикација, нема да можат да се најават на системот.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Кога се избираат/исклучуваат групи, се користи следната постапка за утврдување дали корисникот задолжително ќе користи двофакторна автентификација: Ако нема избрано групи, двофакторна автентификација е овозможена за секој освен за членовите во исклучените групи. Ако еден корисник е член во две групи избрана и исклучена, тогаш тој корисник задолжително мора да користи двофакторна автентификација.",
     "Enable all" : "Овозможи ги сите",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Sync client - {os}" : "Клиент за синхронизација - {os}",
+    "Error while deleting the token" : "Грешка при бришење на токен",
+    "Use the credentials below to configure your app or device." : "Користи ги следните акредитиви за конфигурирање на апликацијата или уредот.",
+    "For security reasons this password will only be shown once." : "Поради безбедносни причини лозинката ќе биде прикажана само еднаш.",
+    "Copied!" : "Копирано!",
+    "Copy" : "Копирај",
+    "Execute one task with each page loaded. Use case: Single user instance." : "Извршува по една задача со секоја вчитана страница. Се користи за инстанца со еден корисник.",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php треба да се регистрира на webcron сервис за да ја повикува процедурата секој 5 минути преку HTTP. Се користи за помали истанци (1-5 корисника во зависност на искористувањето).",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "За да го извршите ова, треба PHP POSIX додаток. Погледни во  {linkstart}PHP документацијата{linkend} за повеќе детали.",
     "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Го користи системскиот Cron сервис и го повикува cron.php секој 5 минути. Препорачано за сите истанци.",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php е потребно да биде извршен од системски корисник \"{user}\".",
+    "Enable or disable profile by default for new users." : "Стандардно овозможи или оневозможи профил за нови корисници.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Ќе ја отстраните групата {group}. Корисниците во неа НЕМА да бидат избришани.",
     "Please confirm the group removal " : "Потврди отстранување на група",
     "Choose profile picture from files" : "Избери фотографија на профилот од датотеките",
     "png or jpg, max. 20 MB" : "png или jpg, максимум 20 MB",
     "Your email address" : "Вашата адреса за е-пошта",
     "Your location" : "Ваша локација",
+    "Enable Profile" : "Овозможи профил",
+    "You do not have permissions to see the details of this user" : "Немате дозвола за да ги гледате деталите на овој корисник",
     "Add new password" : "Додади нова лозинка",
     "Add new email address" : "Додади нова е-пошта адреса",
+    "Set user as admin for" : "Назначи го корисникот како администратор за",
+    "Select user quota" : "Избери квота за корисник",
+    "Toggle user actions menu" : "Вклучи го менито за активности",
+    "Delete user" : "Избриши корисник",
+    "Disable user" : "Оневозможи корисник",
+    "Enable user" : "Овозможи корисник",
     "Edit User" : "Уреди корисник",
     "Will be autogenerated" : "Ќе бидат автоматски генерирани",
     "Add a new user" : "Додади нов корисник",
@@ -546,10 +542,14 @@ OC.L10N.register(
     "Add group" : "Додади група",
     "Default quota:" : "Стандардна квота:",
     "Show Languages" : "Прикажи јазици",
+    "Show user backend" : "Прикажи задна страна на корисник",
     "Send email to new user" : "Испрати е-пошта до новите корисници",
     "Not saved" : "Не е зачувано",
     "Twitter" : "Twitter",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Не е достапно бидејќи не е дозволено објавување специфични податоци за корисникот на серверот за пребарување, контактирајте со вашиот системски администратор ако имате какви било прашања",
+    "Show to logged in users only" : "Прикажи само на корисници",
     "Enable untested app" : "Овозможи не тестирана апликација",
+    "SMTP Username" : "SMTP корисничко име",
     "Expire after" : "Истекува за",
     "day(s)" : "ден(а)",
     "Exclude groups from password requirements:" : "Исклучи групи од барање за лозинка:",
@@ -560,6 +560,10 @@ OC.L10N.register(
     "Edit display name" : "Иреди име",
     "Select manager" : "Избери менаџер",
     "User's table" : "Табела со корисници",
-    "Select user manager" : "Избери менаџер на корисници"
+    "Select user manager" : "Избери менаџер на корисници",
+    "No users" : "Нема корисници",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "Листа на корисници. Оваа листа не е целосно прикажана поради заштеда на перформанси. Корисниците ќе се прикажуваат додека се движите низ листата.",
+    "Loading user …" : "Вчитување корисник ...",
+    "Send welcome email to new users" : "Испрати е-пошта за добредојде до новите корисници"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
