@@ -38,7 +38,7 @@ OC.L10N.register(
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Avètz renommat lo senhal d’aplicacion « {token} » en « {newToken} »",
     "Security" : "Seguretat",
     "You successfully logged in using two-factor authentication (%1$s)" : "Vos sètz corrèctament connectat via l’autentificacion a dos factors (%1$s)",
-    "Apps" : "Aplicacions",
+    "Settings" : "Paramètres",
     "Wrong password" : "Wrong password",
     "Saved" : "Enregistrat",
     "Authentication error" : "Error d’autentificacion",
@@ -46,19 +46,17 @@ OC.L10N.register(
     "Invalid SMTP password." : "Senhal SMTP invalid.",
     "Email setting test" : "Paramètres email de pròva",
     "Well done, %s!" : "Felicitacion, %s !",
-    "Users" : "Utilizaires",
-    "Invalid user" : "Utilizaire invalid",
     "Invalid mail address" : "Adreça email invalida",
     "Settings saved" : "Paramètres enregistrats",
     "Welcome aboard" : "La benvenguda a bòrd",
     "Welcome aboard %s" : "La benvenguda a bòrd %s",
-    "Your username is: %s" : "Vòstre nom d’utilizaire : %s",
     "Set your password" : "Definir vòstre senhal",
     "Go to %s" : "Anar a %s",
     "Install Client" : "Installar client",
-    "Settings" : "Paramètres",
+    "Apps" : "Aplicacions",
     "Personal" : "Personal",
     "Administration" : "Administracion",
+    "Users" : "Utilizaires",
     "Additional settings" : "Paramètres addicionals",
     "Administration privileges" : "Privilègis d’administracion",
     "Overview" : "Apercebut",
@@ -73,6 +71,7 @@ OC.L10N.register(
     "Unlimited" : "Illimitat",
     "Verifying" : "Verificacion",
     "Disabled" : "Desactivat",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La foncion « set_time_limit\" » es pas disponibla. Aquò poiriá menar a una execucion copada al mièg camin, e a una copadura de l’installacion. L’activacion d’aquesta foncion es forçadament recomandada.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vòstre PHP prend pas en carga FreeType, çò que causa lo rompement dels imatges de perfil e de l’interfàcia de paramètres.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP sembla corrèctament configurat per interpretar las variablas d’environament del sistèma. La pròva amb getenv(\"PATH\") a pas tornar una responda voida.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuracion lectura-sola es estada activada. Aquò empacha de configurar d’unes paramètres via l’interfàcia web. Pasmens, òm deu far venir lo fichièr modificable manualament per cada mesa a jorn.",
@@ -105,14 +104,7 @@ OC.L10N.register(
     "Rename" : "Renomenar",
     "Revoke" : "Revocar",
     "Wipe device" : "Tirar periferic",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome per Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
     "{productName} iOS app" : "Aplicacion iOS {productName}",
     "{productName} Android app" : "Aplicacion Android {productName}",
     "{productName} Talk for iOS" : "Talk de {productName} per iOS",
@@ -122,17 +114,15 @@ OC.L10N.register(
     "Last activity" : "Darrièra activitat",
     "Devices & sessions" : "Periferics e sessions",
     "App name" : "Nom d’aplicacion",
-    "Username" : "Nom d'utilizaire",
+    "Login" : "Login",
     "Password" : "Senhal",
-    "Done" : "Done",
-    "Copied!" : "Copiat !",
-    "Copy" : "Copiar",
     "Profile" : "Perfil",
     "Enable" : "Activar",
     "Cancel" : "Anullar",
     "Confirm" : "Confirmar",
     "Submit" : "Transmetre",
-    "Remove group" : "Suprimir grop",
+    "Rename group" : "Renomenar lo grop",
+    "Remove group" : "Suprimir lo grop",
     "Current password" : "Senhal actual",
     "New password" : "Senhal novèl",
     "Change password" : "Cambiar de senhal",
@@ -141,8 +131,8 @@ OC.L10N.register(
     "Details" : "Detalhs",
     "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
     "Your full name" : "Vòstre nom complèt",
-    "Email options" : "Opcions d’email",
     "This address is not confirmed" : "Aquesta adreça es pas confirmada",
+    "Email options" : "Opcions d’email",
     "Set as primary email" : "Definir coma adreça principala",
     "No email address set" : "Cap d’adreça pas definida",
     "Additional emails" : "Emails suplementaris",
@@ -153,7 +143,6 @@ OC.L10N.register(
     "Your organisation" : "Vòstra organizacion",
     "Your phone number" : "Vòstre numèro de telefòn",
     "Edit your Profile visibility" : "Modificatz la visibilitat de vòstre perfil",
-    "Enable Profile" : "Activar Perfil",
     "Your role" : "Vòstre ròtle",
     "Add" : "Ajustar",
     "Create" : "Crear",
@@ -169,19 +158,16 @@ OC.L10N.register(
     "Quota" : "Quota",
     "Language" : "Lenga",
     "Avatar" : "Avatar",
+    "Username" : "Nom d'utilizaire",
     "Last login" : "Darrièra connexion",
     "Add user to group" : "Apondre utilizaire al grop",
-    "Set user as admin for" : "Definir l’utilizaire coma admin per",
-    "Select user quota" : "Seleccionar lo quota utilizaire",
     "{size} used" : "{size} utilizat",
-    "Delete user" : "Suprimir l’utilizaire",
     "Wipe all devices" : "Escafar totes los periferics",
-    "Disable user" : "Desactivar l’utilizaire",
-    "Enable user" : "Activar l’utilizaire",
     "Resend welcome email" : "Tornar enviar l’email de benvenguda",
     "Account deletion" : "Supression de compte",
     "Delete {userid}'s account" : "Suprimir lo compte de {userid}",
     "Welcome mail sent!" : "Email de benvenguda enviat !",
+    "Done" : "Done",
     "Edit" : "Modificar",
     "Visibility" : "Visibilitat",
     "Show last login" : "Afichar la darrièra connexion",
@@ -193,10 +179,8 @@ OC.L10N.register(
     "Passwordless Authentication" : "Autentificacion sens senhal",
     "No devices configured." : "Cap de periferic pas configurat.",
     "Your browser does not support WebAuthn." : "Vòstre navigador es pas compatible amb WebAuthn.",
-    "Your apps" : "Vòstras aplicacions",
     "Changelog" : "Nòta de version",
     "by {author}\n{license}" : "per {author}\n{license}",
-    "Active users" : "Utilizaires actius",
     "Admins" : "Admins",
     "Disabled users" : "Utilizaires desactivats",
     "Group name" : "Nom del grop",
@@ -214,16 +198,17 @@ OC.L10N.register(
     "Website" : "Site web",
     "Profile visibility" : "Visibilitat perfil",
     "Locale" : "Varianta lingüistica",
+    "Your apps" : "Vòstras aplicacions",
     "Active apps" : "Aplicacions activas",
     "Disabled apps" : "Aplicacions desactivadas",
     "Updates" : "Mesas a jorn",
     "Show to everyone" : "Afichar a tot lo monde",
     "Hide" : "Amagar",
     "Never" : "Pas jamais",
+    "Active users" : "Utilizaires actius",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "I a agut tròp de requèstas a partir de vòstre ret. Tornatz ensajar mai tard o contactatz vòstre administrator s’aquò es una error.",
     "Documentation" : "Documentacion",
     "Forum" : "Forum",
-    "Login" : "Login",
     "Open documentation" : "Dobrir la documentacion",
     "Send mode" : "Mòde de mandadís",
     "Encryption" : "Chiframent",
@@ -232,7 +217,6 @@ OC.L10N.register(
     "Authentication" : "Autentificacion",
     "Authentication required" : "Autentificacion requerida",
     "Credentials" : "Informacions d'identificacion",
-    "SMTP Username" : "Utilizaire SMTP",
     "SMTP Password" : "Senhal SMTP",
     "Save" : "Salvar",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desvolopat per la {communityopen}comunautat Nextcloud{linkclose}, lo {githubopen}còdi font{linkclose} es jos licéncia {licenseopen}AGPL{linkclose}.",
@@ -241,12 +225,28 @@ OC.L10N.register(
     "Follow us on Mastodon" : "Nos seguir sus Mastodon",
     "Check out our blog" : "Donar un còp d’uèlh a nòstre blòg",
     "Subscribe to our newsletter" : "S’abonar a l’infoletra",
-    "You created app password \"{token}\"" : "Avètz creat lo senhal d’aplicacion « {token} »",
+    "Invalid user" : "Utilizaire invalid",
+    "Your username is: %s" : "Vòstre nom d’utilizaire : %s",
     "Enable all" : "Activar tot",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Copied!" : "Copiat !",
+    "Copy" : "Copiar",
     "png or jpg, max. 20 MB" : "png or jpg, max. 20 Mo",
     "Your email address" : "Vòstra adreça electronica",
+    "Enable Profile" : "Activar Perfil",
     "Add new password" : "Apondre senhal novèl",
     "Add new email address" : "Apondre adreça electronica",
+    "Set user as admin for" : "Definir l’utilizaire coma admin per",
+    "Select user quota" : "Seleccionar lo quota utilizaire",
+    "Delete user" : "Suprimir l’utilizaire",
+    "Disable user" : "Desactivar l’utilizaire",
+    "Enable user" : "Activar l’utilizaire",
     "Edit User" : "Modificar l’utilizaire",
     "Add a new user" : "Apondre un utilizaire novè",
     "No users in here" : "Cap d’utilizaire aquí",
@@ -255,8 +255,7 @@ OC.L10N.register(
     "Show Languages" : "Veire las lengas",
     "Not saved" : "Pas enregistrat",
     "Twitter" : "Twitter",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
+    "SMTP Username" : "Utilizaire SMTP",
     "day(s)" : "jorn(s)",
     "Set default expiration date" : "Definir una data d’expiracion per defaut"
 },
