@@ -48,18 +48,12 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Ștergerea de la distanță a fost pornită pe %1$s",
     "Remote wipe has finished on %1$s" : "Ștergerea de la distanță s-a încheiat pe %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Parola </strong> sau <strong>mailul </strong>a fost modificat",
-    "Apps" : "Aplicații",
+    "Settings" : "Setări",
     "Wrong password" : "Parolă greșită",
     "Unable to change personal password" : "Nu se poate schimba parola personală",
     "Saved" : "Salvat",
-    "No user supplied" : "Nu a fost furnizat niciun utilizator",
     "Authentication error" : "Eroare la autentificare",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă administrativă de recuperare, altfel toate datele utilizatorilor vor fi pierdute",
     "Wrong admin recovery password. Please check the password and try again." : "Parolă administrativă de recuperare greșită. Verifică parola și încearcă din nou.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalarea și actualizarea aplicațiilor prin intermediul App Store sau Federated Cloud Sharing",
-    "Federated Cloud Sharing" : "Partajare federalizată cloud",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilizează o versiune %1$sneupdatată (%2$s). Vă rugăm să updatați sistemul de operare sau actualizați caracteristicile %3$scare nu funcționează în mod fiabil.",
-    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modulul PHP OPcache nu este încărcat. Pentru o performanță mai bună, se recomandă să îl încărcați în instalarea PHP.",
     "Administrator documentation" : "Documentație pentru administrare",
     "User documentation" : "Documentație utilizator",
     "Invalid SMTP password." : "Parolă SMTP invalidă.",
@@ -68,8 +62,6 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Daca primești acest mail, configurările de email au fost efectuate corect.",
     "Email could not be sent. Check your mail server log" : "Mesajul nu a putut fi trimis. Verifică logul serverului de mail.",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : " A apărut o problemă la trimiterea emailului. Verifică-ți setărie. (Eroare: %s)",
-    "Users" : "Utilizatori",
-    "Invalid user" : "Utilizator invalid",
     "Invalid mail address" : "Adresa mail invalidă",
     "Settings saved" : "Setările au fost salvate",
     "Unable to change full name" : "Nu s-a putut schimba numele complet",
@@ -90,14 +82,13 @@ OC.L10N.register(
     "Your %s account was created" : "Contul tău %s a fost creat",
     "Welcome aboard" : "Bun venit la bord",
     "Welcome aboard %s" : "Bun venit la bord %s",
-    "Your username is: %s" : "Utilizatorul tău este: %s",
     "Set your password" : "Setează parola",
     "Go to %s" : "Salt la %s",
     "Install Client" : "Instalează client",
-    "Logged in user must be a subadmin" : "Utilizatorul logat trebuie să fie un subadmin",
-    "Settings" : "Setări",
+    "Apps" : "Aplicații",
     "Personal" : "Personal",
     "Administration" : "Administrare",
+    "Users" : "Utilizatori",
     "Additional settings" : "Setări adiționale",
     "Administration privileges" : "Privilegii de administrare",
     "Groupware" : "Articole de grup",
@@ -112,16 +103,17 @@ OC.L10N.register(
     "Background jobs" : "Proces de fundal",
     "Unlimited" : "Nelimitată",
     "Verifying" : "Se verifică",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Este în așteptare o sarcină de lucru în fundal care verifică dacă există certificate SSL importate de utilizator. Vă rugăm să reveniți mai târziu.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Sunt prezente unele certificate SSL importate de utilizator, care nu mai sunt utilizate cu Nextcloud 21. Acestea pot fi importate în linia de comandă prin intermediul comenzii \"occ security:certificates:import\". Căile lor în interiorul directorului de date sunt prezentate mai jos.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Lipsesc coloane opționale din baza de date. Datorită faptului că adăugarea de coloane tabelelor mari durează mult, acestea nu au fost adăugate automat atunci când pot fi opționale. Rulând \"occ db:add-missing-columns\", aceste coloane lipsă pot fi adăugate manual în timp ce instanța este online. Odată ce aceste coloane opționale au fost adăugate, unele funcționalități pot îmbunătăți timpul de răspuns sau uzabilitatea. ",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Lipsesc indecși din baza de date. Datorită faptului că adăugarea indecșilor la tabelele mari durează mult, aceștia nu au fost adăugați automat. Rulând \"occ db:add-missing-indices\", indecși lipsă pot fi adăugați manual în timp ce instanța rulează în continuare. Odată ce indecșii au fost adăugați, interogările acelor tabele vor fi de obicei mai rapide.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Bazei de date îi lipsesc câteva chei primare. Datorită faptului că adăugarea cheilor primare la tabelele mari durează mult, acestea nu au fost adăugate automat. Rulând \"occ db:add-missing-primary-keys\", aceste chei primare lipsă pot fi adăugate manual în timp ce instanța rulează. ",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Instanța este în modul debug. Folosiți aceasta doar pentru dezvoltare și nu în producție.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Acest server nu are o conexiune funcțională la Internet. Mai multe puncte finale nu pot fi contactate. Aceasta înseamnă că unele funcționalități precum montarea unui spațiu extern de stocare, notificări despre actualizări sau instalarea aplicațiilor din sursă terță nu vor fi accesibile. De asemenea, ar putea să nu funcționeze nici accesarea fișierelor la distanță și transmiterea emailurilor de notificare .",
     "Disabled" : "Dezactivați",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Este activat vechiul format de criptare din partea serverului. Vă recomandăm să dezactivați acest lucru.",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funcția PHP \"set_time_limit\" nu este disponibilă. Aceasta ar putea avea ca efect ca scripturile să fie oprite în timpul execuției, compromițând instalarea. Se recomandă puternic activarea acestei funcții.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Instalarea PHP nu are suport pentru FreeType, introducând incompatibilități cu imaginile de profil și cu interfața de configurare.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nu pare să fie configurat corespunzător pentru a interoga variabilele de mediu ale sistemului. Testul cu getenv(\"PATH\") returnează doar un răspuns gol.",
+    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "Modulul PHP OPcache nu este încărcat. Pentru o performanță mai bună, se recomandă să îl încărcați în instalarea PHP.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A fost activată configurația doar pentru citire. Acest lucru împiedică setarea unor configurații prin intermediul interfeței web. În plus, fișierul trebuie să fie făcut scriere manual la fiecare actualizare.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza dumneavoastră de date nu rulează cu nivelul de izolare a tranzacției \"READ COMMITTED\". Acest lucru poate cauza probleme atunci când mai multe acțiuni sunt executate în paralel.",
     "Profile information" : "Informații de profil",
@@ -139,7 +131,6 @@ OC.L10N.register(
     "These groups will still be able to receive shares, but not to initiate them." : "Aceste grupuri vor putea în continuare să primească partajări, dar nu să le inițieze.",
     "Enforce expiration date" : "Impune data de expirare",
     "Two-Factor Authentication" : " Autentificare în doi pași",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Autentificarea cu doi factori poate fi impusă pentru toți utilizatorii și pentru grupuri specifice. Dacă aceștia nu au configurat un furnizor cu doi factori, nu se vor putea conecta la sistem.",
     "Enforce two-factor authentication" : "Forțează autentificarea cu doi factori",
     "Limit to groups" : "Limitează pentru grupuri",
     "Enforcement of two-factor authentication can be set for certain groups only." : "Forțarea autentificării cu doi factori poate fi setată doar pentru anumite grupuri.",
@@ -169,35 +160,17 @@ OC.L10N.register(
     "Allow filesystem access" : "Permite accesul la fișierele de sistem",
     "Rename" : "Redenumește",
     "Revoke" : "Revocă",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome for Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
     "This session" : "Această sesiune",
     "Device" : "Dispozitiv",
     "Last activity" : "Ultima activitate",
     "Devices & sessions" : "Dispozitive și sesiuni",
     "Web, desktop and mobile clients currently logged in to your account." : "Clienții web, desktop și mobil conectați în prezent la contul dvs.",
-    "Do you really want to wipe your data from this device?" : "Chiar doriți să vă ștergeți datele de pe acest dispozitiv?",
-    "Confirm wipe" : "Confirmați ștergerea",
-    "Error while creating device token" : "Eroare la crearea token-ului de dispozitiv",
-    "Error while updating device token scope" : "Eroare la actualizarea domeniului de aplicare a token-ului de dispozitiv",
-    "Error while updating device token name" : "Eroare la actualizarea numelui token-ului dispozitivului",
-    "Error while deleting the token" : "Eroare de ștergere token",
-    "Error while wiping the device with the token" : "Eroare la ștergerea dispozitivului cu token-ul",
     "App name" : "Numele aplicației",
     "Create new app password" : "Crează o nouă parolă pentru aplicație",
-    "Use the credentials below to configure your app or device." : "Utilizați acreditările de mai jos pentru a vă configura aplicația sau dispozitivul.",
-    "For security reasons this password will only be shown once." : "Din motive de securitate, această parolă va fi afișată doar o singură dată.",
-    "Username" : "Nume utilizator",
+    "Error while creating device token" : "Eroare la crearea token-ului de dispozitiv",
+    "Login" : "Autentificare",
     "Password" : "Parolă",
-    "Done" : "Realizat",
-    "Copied!" : "S-a copiat!",
-    "Copy" : "Copiază",
     "Enable" : "Activare",
     "Server-side encryption" : "Criptare la nivel de server",
     "Enable server-side encryption" : "Activează criptarea pe server",
@@ -212,6 +185,7 @@ OC.L10N.register(
     "New password" : "Noua parolă",
     "Change password" : "Schimbă parola",
     "Details" : "Detalii",
+    "Back" : "Înapoi",
     "No email address set" : "Fără adresă de email setată",
     "Help translate" : "Ajută la traducere",
     "Your phone number" : "Numărul tău de telefon",
@@ -227,12 +201,12 @@ OC.L10N.register(
     "Language" : "Limba",
     "Total rows summary" : "Rezumat total rânduri",
     "Avatar" : "Avatar",
+    "Username" : "Nume utilizator",
     "Last login" : "Ultima autentificare",
-    "You do not have permissions to see the details of this user" : "Nu aveți permisiuni pentru a vedea detaliile acestui utilizator",
     "{size} used" : "{size} folosită",
+    "Done" : "Realizat",
     "Edit" : "Editează",
     "Visibility" : "Vizibil",
-    "Show user backend" : "Arată administrare utilizator",
     "Show last login" : "Arată ultima autentificare",
     "Send email" : "Expediază mesajul",
     "Add WebAuthn device" : "Adăugați dispozitivul WebAuthn",
@@ -259,13 +233,16 @@ OC.L10N.register(
     "Disabled apps" : "Aplicații inactive",
     "Updates" : "Actualizări",
     "Featured apps" : "Aplicații recomandate",
-    "Show to logged in users only" : "Afișează doar pentru utilizatorii autentificați",
     "Hide" : "Ascunde",
     "Never" : "Niciodată",
+    "Do you really want to wipe your data from this device?" : "Chiar doriți să vă ștergeți datele de pe acest dispozitiv?",
+    "Confirm wipe" : "Confirmați ștergerea",
+    "Error while wiping the device with the token" : "Eroare la ștergerea dispozitivului cu token-ul",
+    "Error while updating device token name" : "Eroare la actualizarea numelui token-ului dispozitivului",
+    "Error while updating device token scope" : "Eroare la actualizarea domeniului de aplicare a token-ului de dispozitiv",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Prea multe cereri din această rețea. Încercați mai târziu sau contactați administratorul.",
     "Documentation" : "Documentație",
     "Forum" : "Forum",
-    "Login" : "Autentificare",
     "SSL" : "SSL",
     "Open documentation" : "Deschide documentația",
     "Send mode" : "Modul de expediere",
@@ -276,18 +253,44 @@ OC.L10N.register(
     "Authentication" : "Autentificare",
     "Authentication required" : "Autentificare necesară",
     "Credentials" : "Detalii de autentificare",
-    "SMTP Username" : "Nume utilizator SMTP",
     "SMTP Password" : "Parolă SMTP",
     "Save" : "Salvează",
     "All checks passed." : "Toate verificările s-au terminat fără erori.",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Această versiune comunitară a Nextcloud nu este suportată, iar notificările instantanee nu sunt disponibile.",
+    "No user supplied" : "Nu a fost furnizat niciun utilizator",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Furnizează o parolă administrativă de recuperare, altfel toate datele utilizatorilor vor fi pierdute",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "instalarea și actualizarea aplicațiilor prin intermediul App Store sau Federated Cloud Sharing",
+    "Federated Cloud Sharing" : "Partajare federalizată cloud",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL utilizează o versiune %1$sneupdatată (%2$s). Vă rugăm să updatați sistemul de operare sau actualizați caracteristicile %3$scare nu funcționează în mod fiabil.",
+    "Invalid user" : "Utilizator invalid",
+    "Your username is: %s" : "Utilizatorul tău este: %s",
+    "Logged in user must be a subadmin" : "Utilizatorul logat trebuie să fie un subadmin",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Este în așteptare o sarcină de lucru în fundal care verifică dacă există certificate SSL importate de utilizator. Vă rugăm să reveniți mai târziu.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Sunt prezente unele certificate SSL importate de utilizator, care nu mai sunt utilizate cu Nextcloud 21. Acestea pot fi importate în linia de comandă prin intermediul comenzii \"occ security:certificates:import\". Căile lor în interiorul directorului de date sunt prezentate mai jos.",
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Au fost găsite UUID-uri nevalabile ale utilizatorilor sau grupurilor LDAP. Vă rugăm să revizuiți setările \"Override UUID detection\" din partea Expert a configurației LDAP și să utilizați \"occ ldap:update-uuid\" pentru a le actualiza.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Autentificarea cu doi factori poate fi impusă pentru toți utilizatorii și pentru grupuri specifice. Dacă aceștia nu au configurat un furnizor cu doi factori, nu se vor putea conecta la sistem.",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Error while deleting the token" : "Eroare de ștergere token",
+    "Use the credentials below to configure your app or device." : "Utilizați acreditările de mai jos pentru a vă configura aplicația sau dispozitivul.",
+    "For security reasons this password will only be shown once." : "Din motive de securitate, această parolă va fi afișată doar o singură dată.",
+    "Copied!" : "S-a copiat!",
+    "Copy" : "Copiază",
     "png or jpg, max. 20 MB" : "png sau jpg, max. 20 MB",
     "Your email address" : "Adresa ta de email",
+    "You do not have permissions to see the details of this user" : "Nu aveți permisiuni pentru a vedea detaliile acestui utilizator",
     "Add group" : "Adaugă grup",
+    "Show user backend" : "Arată administrare utilizator",
     "Send email to new user" : "Trimite email către noul utilizator",
     "Not saved" : "Nu a fost salvat",
     "Twitter" : "Twitter",
+    "Show to logged in users only" : "Afișează doar pentru utilizatorii autentificați",
+    "SMTP Username" : "Nume utilizator SMTP",
     "Set default expiration date" : "Setează data implicită de expirare",
     "Allow username autocompletion in share dialog" : "Permite autocompletarea numelor în dialogul de partajare"
 },
