@@ -48,28 +48,21 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "Cantzelladura remota aviada in %1$s",
     "Remote wipe has finished on %1$s" : "Cantzelladura remota acabbada in %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "S'at modificadu sa <strong>crae</strong> o s'<strong>indiritzu de posta</strong> tuo",
-    "Apps" : "Aplicatziones",
+    "Settings" : "Cunfiguratziones",
     "Wrong password" : "Crae isballiada",
     "Saved" : "Sarvadu",
-    "No user supplied" : "Peruna utèntzia frunida",
     "Authentication error" : "Errore de autenticatzione",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Fruni una crae amministrativa de riprìstinu; si nono, s'ant a perdere totu is datos de utente.",
     "Wrong admin recovery password. Please check the password and try again." : "Crae amministrativa de riprìstinu isballiada. Controlla·dda e torra a proare.",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installatzione e agiornamentu de is aplicatziones tràmite sa butega de is aplicatziones o sa cumpartzidura in sa nue federada",
-    "Federated Cloud Sharing" : "Cumpartzidura in sa nue federada",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL est impreende una versione %1$sagiornada (%2$s). Agiorna su sistema operativu tuo, si nono funtzionalidades comente %3$s no ant a funtzionare.",
     "Administrator documentation" : "Documentatzione amministratzione",
     "User documentation" : "Documentatzione utente",
     "Invalid SMTP password." : "Crae SMTP non bàlida.",
-    "Email setting test" : "Proa de impostatziones de sa posta eletrònica",
+    "Email setting test" : "Proa de cunfiguratzione de posta eletrònica",
     "Well done, %s!" : "Bene fatu, %s!",
     "If you received this email, the email configuration seems to be correct." : "Si as retzidu custu messàgiu de posta, sa cunfiguratzione de sa posta eletrònica est andada bene.",
     "Email could not be sent. Check your mail server log" : "Impossìbile a imbiare su messàgiu. Controlla s'informe de su serbidore tuo de posta",
-    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ddoe at àpidu unu problema in s'imbiu de su messàgiu. Controlla is impostatziones. (Errore: %s)",
-    "Users" : "Utentes",
-    "Invalid user" : "Utèntzia non bàlida",
+    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ddoe at àpidu unu problema in s'imbiu de su messàgiu. Controlla sa cunfiguratzione. (Errore: %s)",
     "Invalid mail address" : "Indiritzu de posta non bàlidu",
-    "Settings saved" : "Impostatziones sarvadas",
+    "Settings saved" : "Cunfiguratziones sarvadas",
     "Unable to change full name" : "Impossìbile a cambiare su nùmene",
     "Unable to change email address" : "Non faghet a cambiare s'indiritzu de posta eletrònica",
     "Unable to set invalid phone number" : "Non faghet a impostare nùmeru de telèfonu non bàlidu",
@@ -93,37 +86,39 @@ OC.L10N.register(
     "Welcome aboard" : "Ti donamus sa benebènnida",
     "Welcome aboard %s" : "Ti donamus sa benebènnida %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Ti donamus sa benebènnida a su contu %s, podes agiùnghere, amparare e cumpartzire is datos tuos.",
-    "Your username is: %s" : "Su nùmene utente tuo est: %s",
     "Set your password" : "Imposta sa crae tua",
     "Go to %s" : "Bae a %s",
     "Install Client" : "Installa aplicatzione",
-    "Logged in user must be a subadmin" : "S'utente devet essere de sa suta-amministratzione ",
-    "Settings" : "Impostatziones",
+    "Apps" : "Aplicatziones",
     "Personal" : "Personale",
     "Administration" : "Amministratzione",
-    "Additional settings" : "Impostatziones in agiunta",
+    "Users" : "Utentes",
+    "Additional settings" : "Cunfiguratziones in agiunta",
     "Groupware" : "Groupware",
     "Overview" : "Panoràmica",
-    "Basic settings" : "Impostatziones de base",
+    "Basic settings" : "Cunfiguratzione de base",
     "Sharing" : "Cumpartzidura",
     "Calendar" : "Calendàriu",
     "Personal info" : "Informatziones personales",
     "Mobile & desktop" : "Mòbile e de iscrivania",
     "Email server" : "Serbidore posta eletrònica",
-    "Security & setup warnings" : "Avisos de seguresa e impostatziones",
+    "Security & setup warnings" : "Avisos de seguresa e cunfiguratzione",
     "Background jobs" : "Atividades de background",
     "Unlimited" : "Chene lìmites",
     "Verifying" : "Averguende",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Un'atividade in segundu pianu est in isetu pro controllare is tzertificados SSL importados dae s'utente. Torra a controllare prus a tardu.",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "B'at tzertificados SSL importados dae utentes chi non s'impreant prus cun Nextcloud 21. Si podent importare in sa lìnia de cumandu tràmite su cumandu \"occ security:certificates:import\". Is percursos issoro in sa cartella de is datos sunt mustrados in fatu.",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "In sa base de datos mancat calicuna colunna optzionale. Agiùnghere is colunnas optzionale a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-columns\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is colunnas sunt agiuntas unas cantas funtzionalidades diant pòdere resurtare prus reativos o prus bellu a impreare. ",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "In sa base de datos mancat calicunu ìnditze. Agiùnghere is ìnditzes a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende  \"occ db:add-missing-indices\" si podent agiùnghere a manu is ìnditzes chi mancant in s'interis chi s'istàntzia est in funtzione. Cando is ìnditzes sunt agiuntos is rechestas a custas tàulas andant giai semper prus a lestru meda.",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "In sa base de datos mancat calicuna crae primària. Agiùnghere is craes primàrias a tàulas mannas podet pigare unu pagu de tempus, tando no s'agiunghent de manera automàtica. Impreende \"occ db:add-missing-primary-keys\". Si podent agiùnghere a manu is craes primàrias chi mancant in s'interis chi s'istàntzia est in funtzione.",
     "Disabled" : "Disativadu",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "Su formadu betzu de tzifradura ladu serbidore est ativu. Racumandamus de ddu disativare. ",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Sa funtzione PHP \"set_time_limit\" no est disponìbile. Custu podet essire in programmas firmados in cursu de esecutzione, trunchende s'installatzione. Est cussigiadu meda a ativare custa funtzione.",
     "Supported" : "Suportadu",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Su PHP tuo no tenet su suportu FreeType, e custu càusat dannos in is immàgines de profilu e in s'interfache de is impostatziones.",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Su PHP tuo no tenet su suportu FreeType, e custu càusat dannos in is immàgines de profilu e in s'interfache de sa cunfiguratzione.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Paret chi PHP no est cunfigradu comente si depet pro rechèrrere variàbiles de ambiente de sistema. Sa proa cun getenv(\"PATH\") at torradu isceti una isceda bòida.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Sa cunfinguratzione de letura isceti est istètia ativada. Custu evitat de pònere cunfiguratziones cun sa interfache-web. In prus, s'archìviu depet èssere produidu pro èssere iscritu a manu a cada agiornamentu.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Sa base de datos tua non funtzionat cun su livellu de isulamentu de sa transatzione \"READ COMMITTED\". Custu podet causare problemas cando si faghent prus atziones in parallelu.",
-    "Nextcloud settings" : "Impostatziones de Nextcloud",
+    "Nextcloud settings" : "Cunfiguratzione de Nextcloud",
+    "Image generation" : "Generatzione de immàgines",
     "None" : "Perunu",
     "Allow apps to use the Share API" : "Permite a is aplicatzione de impreare is API de cumpartzidura",
     "Allow resharing" : "Permite de torrare a cumpartzire",
@@ -144,7 +139,6 @@ OC.L10N.register(
     "This text will be shown on the public link upload page when the file list is hidden." : "Custu testu s'at a mustrare in sa pàgina de carrigamentu de su ligòngiu pùblicu cando s'archìviu de sa lista est cuadu.",
     "Default share permissions" : "Permissos de cumpartzidura predefinidos",
     "Two-Factor Authentication" : "Autenticatzione a duos fatores",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "S'autenticatzione a duos fatores si podet aplicare a totu is utentes e grupos ispetzìficos. Si non tenent unu frunidore a duos fatores cunfiguradu, no ant a pòdere intrare in su sistema.",
     "Enforce two-factor authentication" : "Àplica s'autenticatzione a duos fatores",
     "Limit to groups" : "Lìmita a grupos",
     "Enforcement of two-factor authentication can be set for certain groups only." : "S'aplicatzione de s'autenticatzione a duos fatores si podet impostare isceti pro tzertos grupos.",
@@ -152,7 +146,6 @@ OC.L10N.register(
     "Enforced groups" : "Grupos impostos",
     "Two-factor authentication is not enforced for members of the following groups." : "S'autenticatzione a duos fatores no est imposta pro cumponentes de is grupos in fatu.",
     "Excluded groups" : "Grupos esclùdidos",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cando si seletzionant/escludent grupos, pro determinare si un'utente at aplicadu 2FA, s'impreat sa lògica in fatu: si non si seletzionat perunu grupu, 2FA est ativu pro chie chi siat, francu pro cumponentes de grupos esclùdidos. Si un'utente est siat in unu grupu seletzionadu siat in unu esclùdidu, cussu seletzionadu passat in antis e 2FA est aplicadu.",
     "Save changes" : "Sarva càmbios",
     "All" : "Totu",
     "Limit app usage to groups" : "Lìmita s'impreu de s'aplicatzione a grupos",
@@ -182,46 +175,27 @@ OC.L10N.register(
     "Disable all" : "Disativa totu",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n aplicatzione tenet un'agiornamentu a disponimentu","%n aplicatziones tenent un'agiornamentu a disponimentu"],
     "Marked for remote wipe" : "Marcadu pro cantzelladura remota",
-    "Device settings" : "Impostatziones de su dispositivu",
+    "Device settings" : "Cunfiguratzione de su dispositivu",
     "Allow filesystem access" : "Permite s'intrada a su sistema de is archìvios",
     "Rename" : "Torra a numenare",
     "Revoke" : "Rèvoca",
     "Wipe device" : "Cantzella dispositivu",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome pro Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
     "{productName} iOS app" : "{productName} aplicatzione iOS ",
     "{productName} Android app" : "{productName} aplicatzione Android",
     "{productName} Talk for iOS" : "{productName} Talk pro iOS",
     "{productName} Talk for Android" : "{productName} Talk pro Android",
-    "Sync client - {os}" : "Cliente de sincronizatzione - {os}",
     "This session" : "Custa sessione",
     "Device" : "Dispositivu",
     "Last activity" : "Ùrtima atividade",
     "Devices & sessions" : "Dispositivos & sessiones",
     "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de iscrivania e mòbiles collegados immoe in su contu tuo.",
-    "Do you really want to wipe your data from this device?" : "A beru boles cantzellare is datos dae custu dispositivu?",
-    "Confirm wipe" : "Cunfirma cantzelladura",
-    "Error while creating device token" : "Errore creende su token de su dispositivu",
-    "Error while updating device token scope" : "Errore agiornende s'àmbitu de su token de su dispositivu",
-    "Error while updating device token name" : "Errore agiornende si nùmene de su token de su dispositivu",
-    "Error while deleting the token" : "Errore in sa cantzelladura de su token",
-    "Error while wiping the device with the token" : "Errore in sa cantzelladura de su dispositivu cun su token",
     "App name" : "Nùmene de s'aplicatzione",
     "Create new app password" : "Crea una crae noa de aplicatzione",
-    "Use the credentials below to configure your app or device." : "Imprea is credentziales in suta pro cunfigurare s'aplicatzione o su dispositivu.",
-    "For security reasons this password will only be shown once." : "Pro resones de seguresa, custa crae s'at a mustrare una borta isceti.",
-    "Username" : "Nùmene utente",
+    "Error while creating device token" : "Errore creende su token de su dispositivu",
+    "Login" : "Atzessu",
     "Password" : "Crae",
-    "Done" : "Fatu",
     "Show QR code for mobile apps" : "Mustra su còdighe QR pro aplicatziones mòbiles",
-    "Copied!" : "Copiadu!",
-    "Copy" : "Còpia",
     "Could not copy app password. Please copy it manually." : "No at fatu a copiare sa crae. Copia·dda a manu.",
     "Use system cron service to call the cron.php file every 5 minutes." : "Imprea su servìtziu cron de sistema pro cramare s'archìviu cron.php cada 5 minutos.",
     "Profile" : "Profilu",
@@ -229,7 +203,7 @@ OC.L10N.register(
     "Server-side encryption" : "Tzifradura ladu serbidore",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Sa tzifradura ladu serbidore permitit de tzifrare is archìvios chi sunt carrigados in custu serbidore. Bi sunt limitatziones comente prestatziones prus bàscias, tando ativa•ddu isceti chi est netzessàriu.",
     "Enable server-side encryption" : "Ativa  tzifradura ladu serbidore",
-    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una borta chi sa tzifradura est ativada, totu is archìvios carrigados in su serbidore dae cussu momentu ant a èssere tzifrados in su serbidore. S'at a pòdere disativare sa tzifradura a pustis, si su mòdulu de tzifradura ativu ddu permitit, e totu is pre-cunditziones (comente s'impostatzione de una crae de recùperu) sunt cumproadas.",
+    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una borta chi sa tzifradura est ativada, totu is archìvios carrigados in su serbidore dae cussu momentu ant a èssere tzifrados in su serbidore. S'at a pòdere disativare sa tzifradura a pustis, si su mòdulu de tzifradura ativu ddu permitit, e totu is pre-cunditziones (comente sa cunfiguratzione de una crae de recùperu) sunt cumproadas.",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Sa tzifradura a sa sola no assegurat sa seguresa de su sistema. Càstia sa documentatzione pro àteras informatziones subra su funtzionamentu de s'aplicatzione pro sa tzifradura, e is genias de impreu suportadas.",
     "Be aware that encryption always increases the file size." : "Regorda ca sa tzifradura creschet semper sa mannària de s'archìviu.",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Benit semper a bene a creare còpias de seguresa regulares de is datos tuos, in casu de tzifradura assegura•ti de creare còpia de is craes de tzfradura paris cun is datos tuos.",
@@ -243,11 +217,12 @@ OC.L10N.register(
     "Current password" : "Crae currente",
     "New password" : "Crae noa",
     "Change password" : "Càmbia crae",
-    "Picture provided by original account" : "Imàgine frunida dae su contu originale",
+    "Picture provided by original account" : "Immàgine frunida dae su contu originale",
     "Details" : "Detàllios",
     "You are a member of the following groups:" : "Faghes parte de custos grupos:",
-    "Email options" : "Optziones de posta eletrònica",
+    "Back" : "In segus",
     "Primary email for password reset and notifications" : "Indiritzu de posta eletrònica printzipale pro torrare a impostare sa crae e retzire notìficas",
+    "Email options" : "Optziones de posta eletrònica",
     "Remove primary email" : "Boga•nche s'indiritzu de posta eletrònica printzipale",
     "Delete email" : "Cantzella indiritzu de posta eletrònica",
     "Additional email address {index}" : "Segundu indiritzu de posta eletrònica {index}",
@@ -269,19 +244,15 @@ OC.L10N.register(
     "Quota" : "Cuota",
     "Language" : "Limba",
     "Avatar" : "Avatar",
+    "Username" : "Nùmene utente",
     "Group admin for" : "In amministratzione pro su grupu",
     "User backend" : "Motore utente",
     "Storage location" : "Positzione de s'archiviatzione",
     "Last login" : "Ùrtimu atzessu",
-    "You do not have permissions to see the details of this user" : "Non tenes is permissos pro bìdere is detàllios de s'utente",
     "Add user to group" : "Agiunghe un'utente a unu grupu",
-    "Set user as admin for" : "Include a un'utente in s'amministratzione pro",
-    "Select user quota" : "Seletziona cuota utente",
     "{size} used" : "{size} impreadu",
-    "Delete user" : "Cantzella utente",
+    "Delete account" : "Cantzella contu",
     "Wipe all devices" : "Cantzella totu is dispositivos",
-    "Disable user" : "Disativa utente",
-    "Enable user" : "Ativa utente",
     "Resend welcome email" : "Torra a imbiare su messàgiu de benebènnida",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In casu de pèrdida de su dispositivu o de essida dae s'organizatzione, custu podet cantzellare dae remotu is datos de Nextcloud dae totu is dispositivos assotziados cun {userid}. Funtzionat isceti si is dispositivos sunt collegados a internet. ",
     "Remote wipe of devices" : "Cantzelladura remota de is dispositivos",
@@ -290,9 +261,8 @@ OC.L10N.register(
     "Account deletion" : "Cantzelladura de su contu",
     "Delete {userid}'s account" : "Cantzella su contu de {userid}",
     "Welcome mail sent!" : "Messàgiu de benebènnida imbiadu!",
-    "Toggle user actions menu" : "Càmbia su menu de is atziones de s'utente",
+    "Done" : "Fatu",
     "Edit" : "Modìfica",
-    "Show user backend" : "Mustra su motore utente",
     "Show storage path" : "Mustra su percursu de archiviatzione",
     "Show last login" : "Mustra s'ùrtimu atzessu",
     "Send email" : "Imbia messàgiu de posta eletrònica",
@@ -312,17 +282,15 @@ OC.L10N.register(
     "The following devices are configured for your account:" : "Is dispositivos in fatu sunt cunfigurados pro su contu tuo:",
     "Your browser does not support WebAuthn." : "Su serbidore tuo non suportat WebAuthn.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Comente parte de s'amministratzione podes afinigare su cumportamentu de cumpartzidura. Càstia sa documentatzione pro àteras informatziones.",
-    "Your apps" : "Is aplicatziones tuas",
     "{license}-licensed" : "suta lissèntzia {license}",
     "Changelog" : "Registru de is càmbios",
     "by {author}\n{license}" : "de {author}\n{license}",
-    "Active users" : "Utèntzias ativas",
     "Admins" : "Amministratzione",
     "Disabled users" : "Disativa utentes",
     "Sending…" : "Imbiende...",
     "Email sent" : "Messàgiu de posta imbiadu",
     "Location" : "Positzione",
-    "Profile picture" : "Imàgine de profilu",
+    "Profile picture" : "Immàgine de profilu",
     "About" : "In contu de",
     "Full name" : "Nùmene cumpletu",
     "Headline" : "Tìtulos",
@@ -330,6 +298,7 @@ OC.L10N.register(
     "Role" : "Faina",
     "Website" : "Situ ìnternet",
     "Locale" : "Localizatzione",
+    "Your apps" : "Is aplicatziones tuas",
     "Active apps" : "Aplicatziones ativas",
     "Disabled apps" : "Aplicatziones disativadas",
     "Updates" : "Agiornamentos",
@@ -340,12 +309,17 @@ OC.L10N.register(
     "The app will be downloaded from the App Store" : "S'aplicatzione s'at a iscarrigare dae sa butega de is aplicatziones",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Custa aplicatzione no est marcada comente cumpatìbile cun sa versione tua de Nextcloud. Si sighis, as a pòdere installare s'aplicatzione. Càstia ca podet èssere chi non funtzionet comente prevìdidu.",
     "Never" : "Mai",
+    "Active users" : "Utèntzias ativas",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "S'aplicatzione est istada ativada ma tenet bisòngiu de un'agiornamentu. T'amus a deretare a sa pàgina de agiornamentu tra 5 segundos.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Errore: Custa aplicatzione non si podet ativare ca faghet su serbidore no istàbile",
+    "Do you really want to wipe your data from this device?" : "A beru boles cantzellare is datos dae custu dispositivu?",
+    "Confirm wipe" : "Cunfirma cantzelladura",
+    "Error while wiping the device with the token" : "Errore in sa cantzelladura de su dispositivu cun su token",
+    "Error while updating device token name" : "Errore agiornende si nùmene de su token de su dispositivu",
+    "Error while updating device token scope" : "Errore agiornende s'àmbitu de su token de su dispositivu",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tropu rechestas sunt arribadas dae sa rete tua. Torra a proare prus a tardu o cuntata s'amministradore tuo chi ddoe at un'errore.",
     "Documentation" : "Documentatzione",
     "Forum" : "Forum",
-    "Login" : "Atzessu",
     "Open documentation" : "Aberi documentatzione",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Est importante a impostare custu serbidore pro imbiare messàgios de posta eletrònica, pro re-impostare sa crae e pro is notìficas. ",
     "Send mode" : "Modalidade de imbiu",
@@ -357,7 +331,6 @@ OC.L10N.register(
     "Authentication" : "Autenticatzione",
     "Authentication required" : "Autenticatzione recherta",
     "Credentials" : "Credentziales",
-    "SMTP Username" : "Nùmene utente SMTP ",
     "SMTP Password" : "Crae SMTP",
     "Save" : "Sarva",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Est importante pro sa seguresa e s'esecutzione de s'istàntzia tua chi totu siat cunfiguradu bene. Pro t'agiudare, semus faghende controllos automàticos. Càstia sa documentatzione in ligòngiu pro àteras informatziones.",
@@ -376,15 +349,46 @@ OC.L10N.register(
     "Subscribe to our newsletter" : "Iscrie·ti a sa lista de messàgios nostra",
     "Use a second factor besides your password to increase security for your account." : "Imprea unu segundu fatore a parte sa crae tua pro crèschere sa seguresa de su contu tuo.",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Si impreas aplicatziones de sa de tres partes pro ti connètere a Nextcloud, assegura•ti de creare e cunfigurare una crae pro cada aplicatzione antis de ativare su segundu fatore de autenticatzione.",
-    "You created app password \"{token}\"" : "As creadu sa crae de s'aplicatzione \"{token}\"",
+    "No user supplied" : "Peruna utèntzia frunida",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Fruni una crae amministrativa de riprìstinu; si nono, s'ant a perdere totu is datos de utente.",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installatzione e agiornamentu de is aplicatziones tràmite sa butega de is aplicatziones o sa cumpartzidura in sa nue federada",
+    "Federated Cloud Sharing" : "Cumpartzidura in sa nue federada",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL est impreende una versione %1$sagiornada (%2$s). Agiorna su sistema operativu tuo, si nono funtzionalidades comente %3$s no ant a funtzionare.",
+    "Invalid user" : "Utèntzia non bàlida",
+    "Your username is: %s" : "Su nùmene utente tuo est: %s",
+    "Logged in user must be a subadmin" : "S'utente devet essere de sa suta-amministratzione ",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Un'atividade in segundu pianu est in isetu pro controllare is tzertificados SSL importados dae s'utente. Torra a controllare prus a tardu.",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "B'at tzertificados SSL importados dae utentes chi non s'impreant prus cun Nextcloud 21. Si podent importare in sa lìnia de cumandu tràmite su cumandu \"occ security:certificates:import\". Is percursos issoro in sa cartella de is datos sunt mustrados in fatu.",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "S'autenticatzione a duos fatores si podet aplicare a totu is utentes e grupos ispetzìficos. Si non tenent unu frunidore a duos fatores cunfiguradu, no ant a pòdere intrare in su sistema.",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Cando si seletzionant/escludent grupos, pro determinare si un'utente at aplicadu 2FA, s'impreat sa lògica in fatu: si non si seletzionat perunu grupu, 2FA est ativu pro chie chi siat, francu pro cumponentes de grupos esclùdidos. Si un'utente est siat in unu grupu seletzionadu siat in unu esclùdidu, cussu seletzionadu passat in antis e 2FA est aplicadu.",
     "Enable all" : "Ativa totu",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Sync client - {os}" : "Cliente de sincronizatzione - {os}",
+    "Error while deleting the token" : "Errore in sa cantzelladura de su token",
+    "Use the credentials below to configure your app or device." : "Imprea is credentziales in suta pro cunfigurare s'aplicatzione o su dispositivu.",
+    "For security reasons this password will only be shown once." : "Pro resones de seguresa, custa crae s'at a mustrare una borta isceti.",
+    "Copied!" : "Copiadu!",
+    "Copy" : "Còpia",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Pro esecutare custu, serbit s'estensione PHP POSIX. Càstia {linkstart}documentatzione PHP{linkend} pro àteros detàllios.",
     "You are about to remove the group {group}. The users will NOT be deleted." : "Ses acanta de nche bogare su grupu {group}. Is utèntzias NO s'ant a cantzellare.",
     "Please confirm the group removal " : "Cunfirma de bogare su grupu",
     "png or jpg, max. 20 MB" : "png o jpg, max. 20 MB",
     "Your email address" : "Indiritzu tuo de posta eletrònica",
+    "You do not have permissions to see the details of this user" : "Non tenes is permissos pro bìdere is detàllios de s'utente",
     "Add new password" : "Agiunghe una crae noa",
     "Add new email address" : "Agiunghe un'indiritzu nou de posta eletrònica",
+    "Set user as admin for" : "Include a un'utente in s'amministratzione pro",
+    "Select user quota" : "Seletziona cuota utente",
+    "Toggle user actions menu" : "Càmbia su menu de is atziones de s'utente",
+    "Delete user" : "Cantzella utente",
+    "Disable user" : "Disativa utente",
+    "Enable user" : "Ativa utente",
     "Edit User" : "Modìfica utente",
     "Will be autogenerated" : "At a èssere auto-generadu",
     "Add a new user" : "Agiunghe un'utèntzia noa",
@@ -393,15 +397,12 @@ OC.L10N.register(
     "Add group" : "Agiunghe grupu",
     "Default quota:" : "Cuota predefinida:",
     "Show Languages" : "Mustra limbas",
+    "Show user backend" : "Mustra su motore utente",
     "Send email to new user" : "Imbia messàgiu de posta a utèntzia noa",
     "Not saved" : "Non sarvadu",
     "Twitter" : "Twitter",
     "Enable untested app" : "Ativa aplicatzione non verificada",
-    "Plain" : "Simpre",
-    "NT LAN Manager" : "NT LAN Manager",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "Mètodu de autenticatzione",
+    "SMTP Username" : "Nùmene utente SMTP ",
     "Expire after" : "Iscadit pustis de",
     "day(s)" : "die(s)",
     "Set default expiration date" : "Imposta sa data de iscadèntzia predefinida ",
