@@ -23,14 +23,11 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Ju keni hyrë me sukses duke përdorur autentifikimin me dy faktorë ( %1$s )",
     "A login attempt using two-factor authentication failed (%1$s)" : "Një përpjekje e identifikimit me anë të autentifikimit me dy faktorë dështoi ( %1$s )",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>fjalëkalimi</strong> ose <strong>emaili</strong> juaj është modifikuar",
-    "Apps" : "Aplikacione",
+    "Settings" : "Rregullimet",
     "Wrong password" : "Fjalëkalim i gabuar",
     "Saved" : "U ruajt",
-    "No user supplied" : "S’u dha përdorues",
     "Authentication error" : "Gabim mirëfilltësimi",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ju lutemi siguro një fjalëkalim të rikuperueshëm admini; përndryshe, të gjithë të dhënat e përdoruesit do të humbasin ",
     "Wrong admin recovery password. Please check the password and try again." : "Fjalëkalim i gabuar rikthimesh për përgjegjësin. Ju lutemi, kontrolloni fjalëkalimin dhe provoni përsëri.",
-    "Federated Cloud Sharing" : "Ndarje Në Re të Federuar ",
     "Administrator documentation" : "Dokumentim për përgjegjës",
     "User documentation" : "Dokumentim për përdoruesit",
     "Invalid SMTP password." : "Fjalëkalim SMTP i pavlefshëm",
@@ -39,8 +36,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "Nëse keni marrë këtë email, konfigurimi i email-it duket të jetë i saktë.",
     "Email could not be sent. Check your mail server log" : "Email nuk mund të dërgohej. Kontrolloni logun e serverit tuaj të postës",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ndodhi një gabim gjatë dërgimit të email-it. Ju lutemi, rishikoni rregullimet tuaja. (Error: %s)",
-    "Users" : "Përdoruesit",
-    "Invalid user" : "Përdorues i pavlefshëm",
+    "Invalid account" : "Llogari e pavlefshme",
     "Invalid mail address" : "Adresë email e pavlefshme",
     "Settings saved" : "Konfigurimet u ruajtën",
     "Unable to change full name" : "S’arrin të ndryshojë emrin e plotë",
@@ -61,12 +57,12 @@ OC.L10N.register(
     "Your %s account was created" : "Llogaria juaj %s u krijua",
     "Welcome aboard" : "Mirë se vini në bord",
     "Welcome aboard %s" : "Mirë se vini në bord %s",
-    "Your username is: %s" : "Emri juaj i përdoruesit është: %s",
     "Set your password" : "Vendos fjalëkalimin tënd",
     "Go to %s" : "Shko tek %s",
     "Install Client" : "Instalo Klient",
-    "Settings" : "Rregullimet",
+    "Apps" : "Aplikacione",
     "Personal" : "Personale",
+    "Users" : "Përdoruesit",
     "Additional settings" : "Konfigurime shtesë",
     "Basic settings" : "Konfigurime bazike",
     "Sharing" : "Ndarje me të tjerët",
@@ -117,29 +113,16 @@ OC.L10N.register(
     "Allow filesystem access" : "Lejo aksesin e sistemit të skedarëve",
     "Rename" : "Rename",
     "Revoke" : "Anulo",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome për Android",
-    "iPhone" : "iPhone",
-    "Sync client - {os}" : "Sinkronizo klientin - {os}",
     "This session" : "Ky sesion",
     "Device" : "Pajisje",
     "Last activity" : "Aktiviteti i fundit",
     "Web, desktop and mobile clients currently logged in to your account." : "Klientë në rrjet, desktop dhe celular kanë hyrë aktualisht në  llogarinë tuaj.",
-    "Error while creating device token" : "Gabim gjatë krijimit të token-ëve të pajisjejeve",
-    "Error while deleting the token" : "Gabim gjatë fshirjes së token-it",
     "App name" : "Emër aplikacioni",
     "Create new app password" : "Krijoni fjalëkalim aplikacioni të ri",
-    "Use the credentials below to configure your app or device." : "Përdorni kredencialet e mëposhtme për të konfiguruar aplikacionin apo pajisjen tuaj.",
-    "For security reasons this password will only be shown once." : "Për arsye siguri ky fjalëkalim do të shofaqet vetëm një herv.",
-    "Username" : "Emër përdoruesi",
+    "Error while creating device token" : "Gabim gjatë krijimit të token-ëve të pajisjejeve",
+    "Login" : "Hyrje",
     "Password" : "Fjalëkalim",
-    "Done" : "U bë",
-    "Copied!" : "U kopjua!",
-    "Copy" : "Kopjo",
     "Enable" : "Aktivizoje",
     "Server-side encryption" : "Fshehtëzim më anë shërbyesi",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Enkriptimi nga ana e serverit bën të mundur enkriptimin e skedarëve të ngarkuar në këtë server. Kjo vjen me kufizime si një ndëshkim për performancën, prandaj e lejoni këtë vetëm nëse është e nevojshme.",
@@ -160,6 +143,7 @@ OC.L10N.register(
     "Change password" : "Ndrysho fjalëkalimin",
     "Picture provided by original account" : "Foto e prurë nga llogaria origjinale",
     "Details" : "Detaje",
+    "Back" : "Mbrapsht",
     "No email address set" : "S’është caktuar adresë email",
     "Help translate" : "Ndihmoni në përkthim",
     "Your phone number" : "Numri juaj i telefonit",
@@ -174,13 +158,15 @@ OC.L10N.register(
     "Quota" : "Kuota",
     "Language" : "Gjuhë",
     "Avatar" : "Avatari",
+    "Username" : "Emër përdoruesi",
     "Group admin for" : "Administratori i  grupit për",
     "User backend" : "Program klient i përdoruesit",
     "Storage location" : "Vendndodhje Depozite",
     "Last login" : "Hyrja e fundit",
     "{size} used" : "{madhësia} e përdorur",
+    "Delete account" : "Fshij llogarinë",
+    "Done" : "U bë",
     "Edit" : "Përpuno",
-    "Show user backend" : "Shfaq programin klient të përdoruesit",
     "Show last login" : "Shfaq hyrjen e fundit",
     "Send email" : "Dërgo email",
     "Default quota" : "Kuota Parazgjedhje",
@@ -189,7 +175,6 @@ OC.L10N.register(
     "Unnamed device" : "Paisje pa emër",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Si admin ju mund të rregulloni mirë sjelljen e ndarjes. Ju lutem shih dokumentacionin për më shumë informacion.",
     "Changelog" : "Katalogu i ndryshimeve",
-    "Active users" : "Përdoruesit aktivë",
     "Admins" : "Administratorë",
     "Disabled users" : "Përdoruesit të çaktivizuar",
     "Group name" : "Emër grupi",
@@ -208,10 +193,10 @@ OC.L10N.register(
     "App bundles" : "Pako e aplikacionit ",
     "Hide" : "Fshihe",
     "Never" : "Kurrë",
+    "Active users" : "Përdoruesit aktivë",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacioni është aktivizuar, por lyp të përditësohet. Do të ridrejtoheni te faqja e përditësimeve brenda 5 sekondash.",
     "Documentation" : "Dokumentacioni",
     "Forum" : "Forum",
-    "Login" : "Hyrje",
     "SSL" : "SSL",
     "Open documentation" : "Hapni dokumentimin",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Është e rëndësishme të ngrini këtë server për të qenë në gjendje të dërgoni email, si për rivendosjen e fjalëkalimeve dhe për njoftimet.",
@@ -223,7 +208,6 @@ OC.L10N.register(
     "Authentication" : "Mirëfilltësim",
     "Authentication required" : "Lypset mirëfilltësim",
     "Credentials" : "Kredenciale",
-    "SMTP Username" : "Emër përdoruesi SMTP",
     "SMTP Password" : "Fjalëkalim SMTP",
     "Save" : "Ruaj",
     "All checks passed." : "I kaloi krejt kontrollet.",
@@ -232,15 +216,34 @@ OC.L10N.register(
     "Follow us on Twitter" : "Na ndiqni në Twitter",
     "Check out our blog" : "Shikoni blogun tonë",
     "Subscribe to our newsletter" : "Abonohu në gazeten tonë",
+    "No user supplied" : "S’u dha përdorues",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Ju lutemi siguro një fjalëkalim të rikuperueshëm admini; përndryshe, të gjithë të dhënat e përdoruesit do të humbasin ",
+    "Federated Cloud Sharing" : "Ndarje Në Re të Federuar ",
+    "Invalid user" : "Përdorues i pavlefshëm",
+    "Your username is: %s" : "Emri juaj i përdoruesit është: %s",
     "Enable all" : "Aktivizoi të gjitha",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "Sync client - {os}" : "Sinkronizo klientin - {os}",
+    "Error while deleting the token" : "Gabim gjatë fshirjes së token-it",
+    "Use the credentials below to configure your app or device." : "Përdorni kredencialet e mëposhtme për të konfiguruar aplikacionin apo pajisjen tuaj.",
+    "For security reasons this password will only be shown once." : "Për arsye siguri ky fjalëkalim do të shofaqet vetëm një herv.",
+    "Copied!" : "U kopjua!",
+    "Copy" : "Kopjo",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Për të bërë këtë ekzekutim ju duhet shtesa PHP POSIX. Shikoni {linkstart} dokumentacionin e PHP {linkend} pë më shumë detaje.",
     "png or jpg, max. 20 MB" : "png ose jpg, maks. 20 MB",
     "Your email address" : "Adresa juaj email",
     "Your Twitter handle" : "Emri i përdoruesit tuaj në Twitter",
     "Add group" : "Shto grup",
+    "Show user backend" : "Shfaq programin klient të përdoruesit",
     "Send email to new user" : "Dërgo email përdoruesi të ri",
     "Not saved" : "Nuk u ruajt",
     "Twitter" : "Twitter",
+    "SMTP Username" : "Emër përdoruesi SMTP",
     "Set default expiration date" : "Caktoni datë parazgjedhje skadimi"
 },
 "nplurals=2; plural=(n != 1);");
