@@ -40,45 +40,53 @@ OC.L10N.register(
     "You deleted app password \"{token}\"" : "คุณลบรหัสผ่านแอป \"{token}\" แล้ว",
     "Security" : "ความปลอดภัย",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "มีการเปลี่ยนแปลง<strong>รหัสผ่าน</strong>หรือ<strong>อีเมล</strong>ของคุณ",
-    "Apps" : "แอป",
+    "Settings" : "การตั้งค่า",
     "Wrong password" : "รหัสผ่านไม่ถูกต้อง",
     "Saved" : "บันทึกแล้ว",
-    "No user supplied" : "ไม่ได้ระบุผู้ใช้",
     "Authentication error" : "เกิดข้อผิดพลาดในการตรวจสอบสิทธิ์",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "โปรดใส่รหัสผ่านกู้คืนของผู้ดูแลระบบ มิฉะนั้น ข้อมูลของผู้ใช้ทั้งหมดจะหายไป",
     "Wrong admin recovery password. Please check the password and try again." : "รหัสผ่านกู้คืนของผู้ดูแลระบบไม่ถูกต้อง กรุณาตรวจสอบรหัสผ่านและลองอีกครั้ง",
-    "Federated Cloud Sharing" : "คลาวด์แชร์กับสหพันธ์",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL กำลังใช้ %1$s รุ่นเก่า (%2$s) โปรดอัปเดตระบบปฏิบัติการ ไม่เช่นนั้นคุณสมบัติเช่น %3$s จะไม่สามารถทำงานอย่างมีประสิทธิภาพ",
     "Administrator documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
     "User documentation" : "เอกสารประกอบสำหรับผู้ใช้",
     "Email setting test" : "ทดสอบการตั้งค่าอีเมล",
     "Well done, %s!" : "เยี่ยมยอด คุณ %s!",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "เกิดปัญหาขณะส่งอีเมล กรุณาแก้ไขการตั้งค่าของคุณ (ข้อผิดพลาด: %s)",
-    "Users" : "ผู้ใช้",
-    "Invalid user" : "ผู้ใช้ไม่ถูกต้อง",
+    "Invalid account" : "บัญชีไม่ถูกต้อง",
     "Invalid mail address" : "ที่อยู่อีเมลไม่ถูกต้อง",
     "Settings saved" : "บันทึกการตั้งค่าแล้ว",
     "Unable to change full name" : "ไม่สามารถเปลี่ยนชื่อเต็ม",
     "Your %s account was created" : "สร้างบัญชี %s ของคุณแล้ว",
     "Welcome to your %s account, you can add, protect, and share your data." : "ยินดีต้อนรับสู่บัญชี %s ของคุณ คุณสามารถเพิ่ม ป้องกัน และแชร์ข้อมูลของคุณ",
-    "Your username is: %s" : "ชื่อผู้ใช้ของคุณคือ: %s",
     "Set your password" : "ตั้งรหัสผ่านของคุณ",
     "Go to %s" : "ไปที่ %s",
     "Install Client" : "ติดตั้งไคลเอ็นต์",
-    "Settings" : "การตั้งค่า",
+    "Apps" : "แอป",
     "Personal" : "ส่วนตัว",
+    "Users" : "ผู้ใช้",
     "Additional settings" : "การตั้งค่าเพิ่มเติม",
     "Sharing" : "การแชร์",
     "Calendar" : "ปฏิทิน",
     "Personal info" : "ข้อมูลส่วนบุคคล",
     "Email server" : "เซิร์ฟเวอร์อีเมล",
     "Security & setup warnings" : "คำเตือนความปลอดภัยและการติดตั้ง",
-    "Create" : "สร้าง",
-    "Change" : "เปลี่ยนแปลง",
-    "Delete" : "ลบ",
     "Unlimited" : "ไม่จำกัด",
+    "Disabled" : "ปิดใช้งาน",
+    "Supported" : "รองรับ",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP ของคุณไม่รองรับ FreeType ส่งผลให้รูปภาพโปรไฟล์และส่วนติดต่อการตั้งค่าไม่สมบูรณ์",
     "Nextcloud settings" : "การตั้งค่า Nextcloud",
     "None" : "ไม่มี",
+    "Allow apps to use the Share API" : "อนุญาตให้แอปสามารถใช้ API แชร์",
+    "Allow resharing" : "อนุญาตให้แชร์ซ้ำ",
+    "Allow sharing with groups" : "อนุญาตให้แชร์กับกลุ่ม",
+    "Restrict users to only share with users in their groups" : "จำกัดให้ผู้ใช้สามารถแชร์กับผู้ใช้ในกลุ่มของพวกเขาเท่านั้น",
+    "Allow users to share via link and emails" : "อนุญาตให้ผู้ใช้สามารถแชร์ผ่านลิงก์และอีเมล",
+    "Allow public uploads" : "อนุญาตให้อัปโหลดสาธารณะ",
+    "Always ask for a password" : "ถามรหัสผ่านเสมอ",
+    "Enforce password protection" : "บังคับใช้การป้องกันรหัสผ่าน",
+    "Exclude groups from sharing" : "ยกเว้นกลุ่มจากการแชร์",
+    "These groups will still be able to receive shares, but not to initiate them." : "กลุ่มนี้จะยังคงสามารถรับการแชร์ แต่ไม่สามารถสร้างแชร์ใหม่",
+    "Set default expiration date for shares" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์",
+    "Enforce expiration date" : "บังคับให้มีวันหมดอายุ",
+    "Set default expiration date for shares to other servers" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์ไปยังเซิร์ฟเวอร์อื่น",
     "Two-Factor Authentication" : "การยืนยันสองปัจจัย",
     "Save changes" : "บันทึกการเปลี่ยนแปลง",
     "All" : "ทั้งหมด",
@@ -96,7 +104,6 @@ OC.L10N.register(
     "Admin documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
     "Developer documentation" : "เอกสารประกอบสำหรับนักพัฒนา",
     "This app is supported via your current Nextcloud subscription." : "แอปนี้รองรับผ่านการเป็นสมาชิก Nextcloud ปัจจุบันของคุณ",
-    "Supported" : "รองรับ",
     "Featured" : "แนะนำ",
     "Update to {update}" : "อัปเดตเป็น {update}",
     "Icon" : "ไอคอน",
@@ -113,41 +120,22 @@ OC.L10N.register(
     "Rename" : "เปลี่ยนชื่อ",
     "Revoke" : "เพิกถอน",
     "Wipe device" : "ล้างอุปกรณ์",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome สำหรับ Android",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
     "{productName} iOS app" : "แอป {productName} สำหรับ iOS",
     "{productName} Android app" : "แอป {productName} สำหรับ Android",
     "{productName} Talk for iOS" : "{productName} Talk สำหรับ iOS",
     "{productName} Talk for Android" : "{productName} Talk สำหรับ Android",
-    "Sync client - {os}" : "ไคลเอ็นต์ซิงค์ - {os}",
     "This session" : "เซสชันนี้",
     "Device" : "อุปกรณ์",
     "Last activity" : "กิจกรรมล่าสุด",
     "Devices & sessions" : "อุปกรณ์และเซสซัน",
     "Web, desktop and mobile clients currently logged in to your account." : "ไคลเอ็นต์เว็บ เดสก์ท็อป และมือถือที่เข้าสู่ระบบบัญชีของคุณอยู่",
-    "Do you really want to wipe your data from this device?" : "คุณแน่ใจว่าต้องการล้างข้อมูลจากอุปกรณ์นี้จริง ๆ หรือไม่?",
-    "Confirm wipe" : "ยืนยันการล้าง",
-    "Error while creating device token" : "ข้อผิดพลาดขณะสร้างโทเค็นอุปกรณ์",
-    "Error while updating device token scope" : "ข้อผิดพลาดขณะอัปเดตขอบเขตโทเค็นอุปกรณ์",
-    "Error while updating device token name" : "ข้อผิดพลาดขณะอัปเดตชื่อโทเค็นอุปกรณ์",
-    "Error while deleting the token" : "ข้อผิดพลาดขณะลบโทเค็น",
-    "Error while wiping the device with the token" : "ข้อผิดพลาดขณะล้างอุปกรณ์ที่มีโทเค็น",
     "App name" : "ชื่อแอป",
     "Create new app password" : "สร้างรหัสผ่านแอปใหม่",
-    "Use the credentials below to configure your app or device." : "ใช้ข้อมูลประจำตัวด้านล่างเพื่อกำหนดค่าแอปหรืออุปกรณ์ของคุณ",
-    "For security reasons this password will only be shown once." : "เนื่องด้วยเหตุผลด้านความปลอดภัย รหัสผ่านนี้จะแสดงครั้งเดียว",
-    "Username" : "ชื่อผู้ใช้",
+    "Error while creating device token" : "ข้อผิดพลาดขณะสร้างโทเค็นอุปกรณ์",
+    "Login" : "เข้าสู่ระบบ",
     "Password" : "รหัสผ่าน",
-    "Done" : "เสร็จสิ้น",
     "Show QR code for mobile apps" : "แสดงคิวอาร์โค้ดสำหรับแอปมือถือ",
-    "Copied!" : "คัดลอกแล้ว!",
-    "Copy" : "คัดลอก",
     "Could not copy app password. Please copy it manually." : "ไม่สามารถคัดลอกรหัสผ่านแอป โปรดคัดลอกด้วยตนเอง",
     "Enable" : "เปิดใช้งาน",
     "Server-side encryption" : "การเข้ารหัสฝั่งเซิร์ฟเวอร์",
@@ -168,8 +156,8 @@ OC.L10N.register(
     "Change password" : "เปลี่ยนรหัสผ่าน",
     "Picture provided by original account" : "ใช้รูปภาพจากบัญชีเดิม",
     "Details" : "รายละเอียด",
-    "Email options" : "ตัวเลือกอีเมล",
     "Primary email for password reset and notifications" : "อีเมลหลักสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน",
+    "Email options" : "ตัวเลือกอีเมล",
     "Remove primary email" : "ลบอีเมลหลักออก",
     "Delete email" : "ลบอีเมล",
     "Additional email address {index}" : "ที่อยู่อีเมลเพิ่มเติม {index}",
@@ -177,6 +165,9 @@ OC.L10N.register(
     "Help translate" : "ช่วยแปล",
     "No language set" : "ไม่ได้ตั้งภาษา",
     "Add" : "เพิ่ม",
+    "Create" : "สร้าง",
+    "Change" : "เปลี่ยนแปลง",
+    "Delete" : "ลบ",
     "Default language" : "ภาษาค่าเริ่มต้น",
     "Common languages" : "ภาษาที่นิยม",
     "Password change is disabled because the master key is disabled" : "การเปลี่ยนรหัสผ่านถูกปิดการใช้งาน เนื่องจากคีย์หลักถูกปิดการใช้งาน",
@@ -186,19 +177,15 @@ OC.L10N.register(
     "Quota" : "โควต้า",
     "Language" : "ภาษา",
     "Avatar" : "ภาพแทนตัว",
+    "Username" : "ชื่อผู้ใช้",
     "Group admin for" : "ผู้ดูแลกลุ่มสำหรับ",
     "User backend" : "แบ็กเอนด์ของผู้ใช้",
     "Storage location" : "สถานที่จัดเก็บข้อมูล",
     "Last login" : "เข้าสู่ระบบล่าสุด",
-    "You do not have permissions to see the details of this user" : "คุณไม่มีสิทธิ์ที่จะดูรายละเอียดของผู้ใช้นี้",
     "Add user to group" : "เพิ่มผู้ใช้เข้ากลุ่ม",
-    "Set user as admin for" : "ตั้งผู้ใช้เป็นผู้ดูแลระบบสำหรับ",
-    "Select user quota" : "เลือกโควต้าผู้ใช้",
     "{size} used" : "ใช้ไป {size}",
-    "Delete user" : "ลบผู้ใช้",
+    "Delete account" : "ลบบัญชี",
     "Wipe all devices" : "ล้างอุปกรณ์ทั้งหมด",
-    "Disable user" : "ปิดใช้งานผู้ใช้",
-    "Enable user" : "เปิดใช้งานผู้ใช้",
     "Resend welcome email" : "ส่งอีเมลยินดีต้อนรับซ้ำ",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "ในกรณีที่อุปกรณ์สูญหายหรือออกจากองค์กร ตัวเลือกนี้สามารถล้างข้อมูล Nextcloud จากทุกอุปกรณ์ที่เชื่อมโยงกับ {userid} จากระยะไกล การล้างข้อมูลจะทำงานเฉพาะเมื่ออุปกรณ์เชื่อมต่อกับอินเทอร์เน็ตเท่านั้น",
     "Remote wipe of devices" : "ล้างอุปกรณ์จากระยะไกล",
@@ -207,8 +194,8 @@ OC.L10N.register(
     "Account deletion" : "การลบบัญชี",
     "Delete {userid}'s account" : "ลบบัญชีของ {userid}",
     "Welcome mail sent!" : "ส่งอีเมลยินดีต้อนรับแล้ว!",
-    "Toggle user actions menu" : "เปิด-ปิด เมนูการกระทำผู้ใช้",
-    "Show user backend" : "แสดงแบ็กเอนด์ของผู้ใช้",
+    "Done" : "เสร็จสิ้น",
+    "Edit" : "แก้ไข",
     "Show storage path" : "แสดงเส้นทางจัดเก็บข้อมูล",
     "Show last login" : "แสดงการเข้าสู่ระบบล่าสุด",
     "Send email" : "ส่งอีเมล",
@@ -227,15 +214,12 @@ OC.L10N.register(
     "No devices configured." : "ไม่มีอุปกรณ์ที่กำหนดค่า",
     "The following devices are configured for your account:" : "อุปกรณ์เหล่านี้มีการกำหนดค่าสำหรับบัญชีของคุณแล้ว:",
     "Your browser does not support WebAuthn." : "เบราว์เซอร์ของคุณไม่รองรับ WebAuthn",
-    "Your apps" : "แอปของคุณ",
     "{license}-licensed" : "สัญญาอนุญาต {license}",
     "Changelog" : "บันทึกการเปลี่ยนแปลง",
     "by {author}\n{license}" : "โดย {author}\n{license}",
-    "Active users" : "ผู้ใช้ที่ใช้งานอยู่",
     "Admins" : "ผู้ดูแลระบบ",
     "Disabled users" : "ผู้ใช้ที่ปิดใช้งาน",
     "Group name" : "ชื่อกลุ่ม",
-    "Not saved" : "ไม่ได้บันทึก",
     "Sending…" : "กำลังส่ง....",
     "Email sent" : "ส่งอีเมลแล้ว",
     "Location" : "ตำแหน่ง",
@@ -243,9 +227,9 @@ OC.L10N.register(
     "About" : "เกี่ยวกับ",
     "Full name" : "ชื่อเต็ม",
     "Phone number" : "หมายเลขโทรศัพท์",
-    "Twitter" : "ทวิตเตอร์",
     "Website" : "เว็บไซต์",
     "Locale" : "ตำแหน่งที่ตั้ง",
+    "Your apps" : "แอปของคุณ",
     "Active apps" : "แอปที่เปิดใช้งานอยู่",
     "Disabled apps" : "แอปที่ปิดใช้งาน",
     "Updates" : "อัปเดต",
@@ -256,12 +240,17 @@ OC.L10N.register(
     "The app will be downloaded from the App Store" : "แอปจะถูกดาวน์โหลดจากร้านค้าแอป",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "แอปนี้ยังไม่ถูกระบุว่ารองรับกับรุ่น Nextcloud ของคุณ หากคุณดำเนินการต่อ คุณจะสามารถติดตั้งแอปได้ แต่แอปอาจไม่ทำงานอย่างที่คาดหวังไว้",
     "Never" : "ไม่เคย",
+    "Active users" : "ผู้ใช้ที่ใช้งานอยู่",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "แอปเปิดใช้งานแล้ว แต่ต้องทำการอัปเดต คุณจะถูกนำไปยังหน้าอัปเดตใน 5 วินาที",
     "Error: This app cannot be enabled because it makes the server unstable" : "ข้อผิดพลาด: ไม่สามารถเปิดใช้งานแอปนี้เพราะทำให้เซิร์ฟเวอร์ไม่เสถียร",
+    "Do you really want to wipe your data from this device?" : "คุณแน่ใจว่าต้องการล้างข้อมูลจากอุปกรณ์นี้จริง ๆ หรือไม่?",
+    "Confirm wipe" : "ยืนยันการล้าง",
+    "Error while wiping the device with the token" : "ข้อผิดพลาดขณะล้างอุปกรณ์ที่มีโทเค็น",
+    "Error while updating device token name" : "ข้อผิดพลาดขณะอัปเดตชื่อโทเค็นอุปกรณ์",
+    "Error while updating device token scope" : "ข้อผิดพลาดขณะอัปเดตขอบเขตโทเค็นอุปกรณ์",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "มีการส่งคำขอจากเครือข่ายของคุณมากเกินไป กรุณาลองอีกครั้งในภายหลัง หรือติดต่อผู้ดูแลระบบหากเป็นข้อผิดพลาด",
     "Documentation" : "เอกสารประกอบ",
     "Forum" : "ฟอรัม",
-    "Login" : "เข้าสู่ระบบ",
     "SSL" : "SSL",
     "Open documentation" : "เปิดเอกสารประกอบ",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "การตั้งค่าให้เซิร์ฟเวอร์นี้ส่งอีเมลได้ เช่น อีเมลสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน เป็นสิ่งสำคัญ",
@@ -274,7 +263,6 @@ OC.L10N.register(
     "Authentication" : "การตรวจสอบสิทธิ์",
     "Authentication required" : "จำเป็นต้องตรวจสอบความถูกต้อง",
     "Credentials" : "ข้อมูลส่วนตัวสำหรับเข้าระบบ",
-    "SMTP Username" : "ชื่อผู้ใช้ SMTP",
     "SMTP Password" : "รหัสผ่าน SMTP",
     "Save" : "บันทึก",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "การกำหนดค่าทุกอย่างให้ถูกต้องเป็นสิ่งสำคัญสำหรับความปลอดภัยและประสิทธิภาพของเซิร์ฟเวอร์ของคุณ เพื่อช่วยคุณในเรื่องนี้ เรากำลังทำการตรวจสอบอัตโนมัติ โปรดดูเอกสารประกอบที่ลิงก์มาสำหรับข้อมูลเพิ่มเติม",
@@ -284,33 +272,41 @@ OC.L10N.register(
     "Checking for system and security issues." : "กำลังตรวจสอบปัญหาระบบและความปลอดภัย",
     "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "โปรดตรวจสอบ<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">คู่มือการติดตั้ง ↗</a>ซ้ำ และตรวจสอบข้อผิดพลาดหรือคำเตือนใน<a href=\"%2$s\">บันทึก</a>",
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "ตรวจสอบความปลอดภัยของ Nextcloud ของคุณผ่าน<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">การสแกนความปลอดภัยของเรา ↗</a>",
-    "Allow apps to use the Share API" : "อนุญาตให้แอปสามารถใช้ API แชร์",
-    "Set default expiration date for shares" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์",
-    "Expire after" : "หมดอายุหลังจาก",
-    "day(s)" : "วัน",
-    "Enforce expiration date" : "บังคับให้มีวันหมดอายุ",
-    "Set default expiration date for shares to other servers" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์ไปยังเซิร์ฟเวอร์อื่น",
-    "Allow users to share via link and emails" : "อนุญาตให้ผู้ใช้สามารถแชร์ผ่านลิงก์และอีเมล",
-    "Allow public uploads" : "อนุญาตให้อัปโหลดสาธารณะ",
-    "Always ask for a password" : "ถามรหัสผ่านเสมอ",
-    "Enforce password protection" : "บังคับใช้การป้องกันรหัสผ่าน",
-    "Set default expiration date" : "ตั้งวันหมดอายุค่าเริ่มต้น",
-    "Exclude groups from creating link shares:" : "ยกเว้นกลุ่มจากการสร้างลิงก์แชร์:",
-    "Allow resharing" : "อนุญาตให้แชร์ซ้ำ",
-    "Allow sharing with groups" : "อนุญาตให้แชร์กับกลุ่ม",
-    "Restrict users to only share with users in their groups" : "จำกัดให้ผู้ใช้สามารถแชร์กับผู้ใช้ในกลุ่มของพวกเขาเท่านั้น",
-    "Exclude groups from sharing" : "ยกเว้นกลุ่มจากการแชร์",
-    "These groups will still be able to receive shares, but not to initiate them." : "กลุ่มนี้จะยังคงสามารถรับการแชร์ แต่ไม่สามารถสร้างแชร์ใหม่",
     "Reasons to use Nextcloud in your organization" : "เหตุผลที่ควรใช้ Nextcloud ในองค์กรของคุณ",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "รุ่นที่ออกโดยชุมชนของ Nextcloud นี้ไม่ได้รับการสนับสนุน และไม่สามารถใช้งานการแจ้งเตือนทันทีได้",
-    "You created app password \"{token}\"" : "คุณสร้างรหัสผ่านแอป \"{token}\" แล้ว",
+    "No user supplied" : "ไม่ได้ระบุผู้ใช้",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "โปรดใส่รหัสผ่านกู้คืนของผู้ดูแลระบบ มิฉะนั้น ข้อมูลของผู้ใช้ทั้งหมดจะหายไป",
+    "Federated Cloud Sharing" : "คลาวด์แชร์กับสหพันธ์",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL กำลังใช้ %1$s รุ่นเก่า (%2$s) โปรดอัปเดตระบบปฏิบัติการ ไม่เช่นนั้นคุณสมบัติเช่น %3$s จะไม่สามารถทำงานอย่างมีประสิทธิภาพ",
+    "Invalid user" : "ผู้ใช้ไม่ถูกต้อง",
+    "Your username is: %s" : "ชื่อผู้ใช้ของคุณคือ: %s",
     "Enable all" : "เปิดใช้งานทั้งหมด",
+    "Internet Explorer" : "Internet Explorer",
+    "Edge" : "Edge",
+    "Firefox" : "Firefox",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Sync client - {os}" : "ไคลเอ็นต์ซิงค์ - {os}",
+    "Error while deleting the token" : "ข้อผิดพลาดขณะลบโทเค็น",
+    "Use the credentials below to configure your app or device." : "ใช้ข้อมูลประจำตัวด้านล่างเพื่อกำหนดค่าแอปหรืออุปกรณ์ของคุณ",
+    "For security reasons this password will only be shown once." : "เนื่องด้วยเหตุผลด้านความปลอดภัย รหัสผ่านนี้จะแสดงครั้งเดียว",
+    "Copied!" : "คัดลอกแล้ว!",
+    "Copy" : "คัดลอก",
     "You are about to remove the group {group}. The users will NOT be deleted." : "คุณกำลังจะลบกลุ่ม {group} ผู้ใช้ที่อยู่ในกลุ่มจะไม่ถูกลบไปด้วย",
     "Please confirm the group removal " : "กรุณายืนยันการลบกลุ่ม",
     "png or jpg, max. 20 MB" : "png หรือ jpg สูงสุดไม่เกิน 20 MB",
     "Your email address" : "ที่อยู่อีเมลของคุณ",
+    "You do not have permissions to see the details of this user" : "คุณไม่มีสิทธิ์ที่จะดูรายละเอียดของผู้ใช้นี้",
     "Add new password" : "เพิ่มรหัสผ่านใหม่",
     "Add new email address" : "เพิ่มที่อยู่อีเมลใหม่",
+    "Set user as admin for" : "ตั้งผู้ใช้เป็นผู้ดูแลระบบสำหรับ",
+    "Select user quota" : "เลือกโควต้าผู้ใช้",
+    "Toggle user actions menu" : "เปิด-ปิด เมนูการกระทำผู้ใช้",
+    "Delete user" : "ลบผู้ใช้",
+    "Disable user" : "ปิดใช้งานผู้ใช้",
+    "Enable user" : "เปิดใช้งานผู้ใช้",
     "Edit User" : "แก้ไขผู้ใช้",
     "Will be autogenerated" : "จะถูกสร้างขึ้นโดยอัตโนมัติ",
     "Add a new user" : "เพิ่มผู้ใช้ใหม่",
@@ -319,12 +315,15 @@ OC.L10N.register(
     "Add group" : "เพิ่มกลุ่ม",
     "Default quota:" : "ค่าโควต้าเริ่มต้น:",
     "Show Languages" : "แสดงภาษา",
+    "Show user backend" : "แสดงแบ็กเอนด์ของผู้ใช้",
     "Send email to new user" : "ส่งอีเมลไปยังผู้ใช้ใหม่",
+    "Not saved" : "ไม่ได้บันทึก",
+    "Twitter" : "ทวิตเตอร์",
     "Enable untested app" : "เปิดใช้งานแอปที่ไม่ได้ทดสอบ",
-    "Plain" : "ธรรมดา",
-    "NT LAN Manager" : "ตัวจัดการ NT LAN",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Authentication method" : "วิธีการตรวจสอบความถูกต้อง"
+    "SMTP Username" : "ชื่อผู้ใช้ SMTP",
+    "Expire after" : "หมดอายุหลังจาก",
+    "day(s)" : "วัน",
+    "Set default expiration date" : "ตั้งวันหมดอายุค่าเริ่มต้น",
+    "Exclude groups from creating link shares:" : "ยกเว้นกลุ่มจากการสร้างลิงก์แชร์:"
 },
 "nplurals=1; plural=0;");
