@@ -50,31 +50,15 @@ OC.L10N.register(
     "Remote wipe was started on %1$s" : "%1$s上的远程擦除已开始",
     "Remote wipe has finished on %1$s" : "%1$s上的远程擦除已完成",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "您的 <strong>密码</strong> 或 <strong>邮箱</strong> 已被更改",
-    "Apps" : "应用",
+    "Settings" : "设置",
     "Could not remove app." : "无法移除应用。",
     "Could not update app." : "无法更新应用。",
     "Wrong password" : "密码错误",
     "Unable to change personal password" : "无法更改个人密码",
     "Saved" : "已保存",
-    "No user supplied" : "未提供用户",
     "Unable to change password. Password too long." : "无法更改密码。密码太长。",
     "Authentication error" : "认证错误",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "请提供管理员恢复密码，否则所有用户的数据都将丢失。",
     "Wrong admin recovery password. Please check the password and try again." : "错误的管理员恢复密码。请检查密码并重试。",
-    "Backend does not support password change, but the user's encryption key was updated." : "后端不支持密码修改，但用户的加密密钥已经更新。",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "通过应用商店或联合云共享安装和更新应用",
-    "Federated Cloud Sharing" : "联合云共享",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL 正使用一个过时的%1$s 版本 (%2$s)。请升级您的操作系统，否则像 %3$s 这样的特性将无法可靠地工作。",
-    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "不能确定 cURL 的 TLS 版本是否已过时，因为在 HTTPS 请求 https://nextcloud.com 时发生了错误。请检查 Nextcloud 日志文件以获取更多信息。",
-    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "未加载 PHP OPcache 模块。为了更好的性能，建议将其加载到您的 PHP 安装中。",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache 已经禁用。为了更好的性能，建议在您的 PHP 设置中应用 <code>opcache.enable=1</code>。",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache 被设置为移除代码注释。当启用 OPcache 后，必须设置 <code>opcache.save_comments=1</code>，才能让 Nextcloud 工作。",
-    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允许使用 OPcache API。启用 OPcache 后，强烈建议使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目录，或取消该设置以禁用 OPcache API 限制，以避免 Nextcloud 核心或应用程序升级期间发生错误。",
-    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允许使用 OPcache API。强烈建议使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目录，或取消该设置以禁用 OPcache API 限制，以避免 Nextcloud 核心或应用程序升级期间发生错误。",
-    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "基于共享内存的 OPcache 已禁用。为了更好的性能，建议在您的 PHP 配置中应用 <code>opcache.file_cache_only=0</code>，并仅使用文件作为二级缓存。",
-    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "几乎超过了 OPcache 键的最大数量。为确保所有脚本可以保留在缓存中，建议在您的 PHP 设置中 <code>opcache.max_accelerated_files</code> 设置一个高于 <code>%s</code> 的值。",
-    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 缓存几乎已满。为确保所有脚本可以保留在缓存中，建议在您的 PHP 设置中 <code>opcache.memory_consumption</code> 设置一个高于 <code>%s</code> 的值。",
-    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 内部字符串缓存几乎已满。为确保重复的字符串可以被有效地缓存，建议在您的 PHP 设置中 <code>opcache.interned_strings_buffer</code> 设置一个高于 <code>%s</code> 的值。",
     "Administrator documentation" : "管理员文档",
     "User documentation" : "用户文档",
     "Nextcloud help overview" : "Nextcloud 帮助文件预览",
@@ -84,9 +68,7 @@ OC.L10N.register(
     "If you received this email, the email configuration seems to be correct." : "如果您收到了这封邮件，电子邮件配置应该就是正确的。",
     "Email could not be sent. Check your mail server log" : "邮件无法发送。检查您的邮件服务器日志",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "在发送电子邮件时出现问题。请修正您的设置。（错误：%s）",
-    "You need to set your user email before being able to send test emails. Go to %s for that." : "您需要先前往%s设置电子邮箱，才能发送测试邮件。",
-    "Users" : "用户",
-    "Invalid user" : "无效用户",
+    "Invalid account" : "无效的账户。",
     "Invalid mail address" : "无效的电子邮件地址",
     "Settings saved" : "设置已保存",
     "Unable to change full name" : "无法修改全名",
@@ -112,14 +94,13 @@ OC.L10N.register(
     "Welcome aboard" : "欢迎使用",
     "Welcome aboard %s" : "%s，欢迎使用",
     "Welcome to your %s account, you can add, protect, and share your data." : "欢迎使用您的账号 %s ，您可以添加、保护和共享您的数据。",
-    "Your username is: %s" : "您的用户名是：%s",
     "Set your password" : "设置您的密码",
     "Go to %s" : "访问 %s",
     "Install Client" : "安装客户端",
-    "Logged in user must be a subadmin" : "当前登录用户必须为子管理员",
-    "Settings" : "设置",
+    "Apps" : "应用",
     "Personal" : "个人",
     "Administration" : "管理",
+    "Users" : "用户",
     "Additional settings" : "其他设置",
     "Artificial Intelligence" : "人工智能",
     "Administration privileges" : "管理权限",
@@ -140,12 +121,10 @@ OC.L10N.register(
     "Your remote address could not be determined." : "无法确定您的远程地址",
     "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "您的地址 %s 因疑似暴力攻击已被限制，您可能在各种请求中遇到性能缓慢的问题。若前述地址与您的实际地址存在出入，则您可能错误配置了代理服务器。",
     "Your remote address \"%s\" is not brute-force throttled." : "您的地址 %s 未受暴力攻击限制",
-    "Old user imported certificates" : "旧用户导入的证书",
-    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "一个检查用户导入的 SSL 证书的后台工作正在进行中。请稍后再来检查。",
-    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "目前存在一些用户导入的 SSL 证书，这在 Nextcloud 21 中已经不使用了。它们可以通过“occ security:certificates:import”命令在命令行导入。它们在数据目录下的路径如下所示。",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "数据库缺少一些可选列。 由于在大表上添加列可能会花费一些时间，因此在可以选择时不会自动添加列。 通过运行“occ db:add-missing-columns”，可以在实例继续运行时手动添加那些缺少的列。 添加列后，某些功能可能会提高响应速度或可用性。",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "数据库丢失了一些索引。由于给大的数据表添加索引会耗费一些时间，因此程序没有自动对其进行修复。您可以在 Nextcloud 运行时通过命令行手动执行“occ db:add-missing-indices”命令修复丢失的索引。索引修复后会大大提高相应表的查询速度。",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "数据库缺少一些主键。由于在大型数据表上添加主键可能需要一些时间，因此程序没有自动添加。通过运行“occ db:add-missing-primary-keys”，这些缺失的主键可以在实例持续运行时手动添加。",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "此实例正在调试模式下运行。仅在本地开发而非生产环境时启用该模式。",
     "Default phone region" : "默认电话区域",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective ISO 3166-1 code of the region to your config file." : "您在安装过程中未设置默认的国际区号。缺失国际区号的电话号码时将使用默认的国际区号进行验证。要允许无国际区号的电话，请在您的配置文件中添加 “default_phone_region” 设置选项并依照 ISO 3166-1 进行设置。",
     "Email test" : "电子邮件测试",
@@ -166,10 +145,11 @@ OC.L10N.register(
     "Disabled" : "已禁用",
     "The old server-side-encryption format is enabled. We recommend disabling this." : "旧的服务器端加密格式已启用。我们建议禁用此功能。",
     "Memcache" : "内存缓存",
-    "Configured" : "已配置",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "未配置内存缓存。若有内存缓存可用，请进行配置以提升性能。",
+    "Configured" : "已配置",
     "PHP default charset" : "PHP默认字符集",
     "PHP configuration option \"default_charset\" should be UTF-8" : "PHP 设置选项 default_chatset 应该为 UTF-8",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP函数“set_time_limit”不可用。 这可能会导致脚本在执行过程中暂停，从而导致安装中断。 我们强烈建议启用此功能。",
     "Freetype" : "Freetype字体",
     "Supported" : "受支持",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "您的 PHP 没有 FreeType 支持，这会导致个人资料图片和设置界面出现故障。",
@@ -179,7 +159,7 @@ OC.L10N.register(
     "The PHP memory limit is below the recommended value of %s." : "PHP 内存限制低于建议值 %s。",
     "PHP modules" : "PHP模块",
     "This instance is missing some required PHP modules. It is required to install them: %s." : "该实例缺少一些必须的PHP模块。必须安装以下模块：%s",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "该实例缺少一些推荐的PHP模块。强烈建议您安装以下模块以提升性能和兼容性：%s",
+    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "未加载 PHP OPcache 模块。为了更好的性能，建议将其加载到您的 PHP 安装中。",
     "PHP version" : "PHP版本",
     "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "您当前正在使用 PHP %s。在 Nextcloud 27 中 PHP 8.0 已过时，而在 Nextcloud 28 中可能最低需要 PHP 8.1。请尽快升级 PHP 至官方支持的最新版本。",
     "You are currently running PHP %s." : "您当前正在使用 PHP %s。",
@@ -257,7 +237,6 @@ OC.L10N.register(
     "Deleted disclaimer text" : "免责声明文本已删除",
     "Could not set disclaimer text" : "未能设置免责声明文本",
     "Two-Factor Authentication" : "两步验证",
-    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "两步验证可以对于所有用户和特定分组启用。如果没有设置两步验证提供者，他们则不能登录到系统。",
     "Enforce two-factor authentication" : "强制启用两步验证",
     "Limit to groups" : "限制于组",
     "Enforcement of two-factor authentication can be set for certain groups only." : "可以仅为某些组设置两步验证的强制执行。",
@@ -265,7 +244,6 @@ OC.L10N.register(
     "Enforced groups" : "强制群组",
     "Two-factor authentication is not enforced for members of the following groups." : "两步验证不对以下分组的成员强制启用。",
     "Excluded groups" : "排除群组",
-    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "当分组被选择/排除时，将使用以下逻辑来确定一个用户是否强制启用两步验证：如果没有选择分组，两步验证将对被排除分组成员外的所有用户启用。如果选择了分组，两步验证将对被选择分组的成员启用。如果一个用户同时属于被选择和被排除分组，被选择分组将拥有优先权，两步验证将对该用户强制启用。",
     "Save changes" : "保存修改",
     "All" : "全部",
     "Limit app usage to groups" : "限制可使用应用的分组",
@@ -307,57 +285,34 @@ OC.L10N.register(
     "Revoke" : "撤销",
     "Wipe device" : "擦除设备",
     "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "如果您的设备还没有开始擦除，撤销这个令牌可能会阻止擦除它。",
-    "Internet Explorer" : "IE 浏览器",
-    "Edge" : "Edge 浏览器",
-    "Firefox" : "火狐浏览器",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari 浏览器",
     "Google Chrome for Android" : "Android 版 Google Chrome",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
     "{productName} iOS app" : "{productName} iOS 应用",
     "{productName} Android app" : "{productName} 安卓应用",
     "{productName} Talk for iOS" : "{productName} iOS 版通话应用",
     "{productName} Talk for Android" : "{productName} Android 版通话应用",
-    "Sync client - {os}" : "同步客户端 - {os}",
     "This session" : "当前会话",
     "Device" : "设备",
     "Last activity" : "最后活跃",
     "Devices & sessions" : "设备和活动链接",
     "Web, desktop and mobile clients currently logged in to your account." : "您账号当前登录的网页版，桌面和移动客户端。",
-    "Do you really want to wipe your data from this device?" : "您真的要从此设备擦除您的数据吗？",
-    "Confirm wipe" : "确认擦除",
-    "Error while creating device token" : "创建设备令牌时出错",
-    "Error while updating device token scope" : "更新设备令牌范围时出错",
-    "Error while updating device token name" : "更新设备令牌名称时出错",
-    "Error while deleting the token" : "删除令牌时出错",
-    "Error while wiping the device with the token" : "使用令牌擦除设备时出错",
     "App name" : "应用名",
     "Create new app password" : "创建新应用密码",
-    "Use the credentials below to configure your app or device." : "使用下述证书配置您的应用或设备。",
-    "For security reasons this password will only be shown once." : "由于安全原因，密码仅会显示一次。",
-    "Username" : "用户名",
+    "Error while creating device token" : "创建设备令牌时出错",
+    "Login" : "登录",
     "Password" : "密码",
-    "Done" : "完成",
     "Show QR code for mobile apps" : "为移动应用展示二维码",
-    "Copied!" : "已复制！",
-    "Copy" : "复制",
     "Could not copy app password. Please copy it manually." : "无法复制应用密码。请手动复制。",
     "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "为了使服务器正常工作，正确配置后台作业是很重要的。Cron 是推荐的设置。更多信息请参见文档。",
     "Last job execution ran {time}. Something seems wrong." : "上次任务执行于 {time}。但似乎有些问题。",
     "Last job ran {relativeTime}." : "上次任务执行于 {relativeTime}。",
     "Background job did not run yet!" : "后台任务从未执行！",
     "AJAX" : "AJAX",
-    "Execute one task with each page loaded. Use case: Single user instance." : "每加载一个页面就执行一个任务。使用场景：单一用户实例。",
     "Webcron" : "Webcron",
-    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php 注册在一个 webcron 服务上，每 5 分钟通过 HTTP 调用 cron.php。使用场景：非常小的实例（1-5 个用户，取决于使用情况）。",
     "Cron (Recommended)" : "Cron（推荐）",
     "Use system cron service to call the cron.php file every 5 minutes." : "使用系统定时任务服务每 5 分钟执行一次 cron.php 文件。",
-    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php 需要由系统用户“{user}”执行。",
     "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "您需要安装 PHP POSIX 拓展，详情请见 {linkstart}PHP 文档{linkend}。",
     "Unable to update background job mode" : "无法更新后台任务模式",
     "Profile" : "个人资料",
-    "Enable or disable profile by default for new users." : "对新用户默认启用或禁用简介。",
     "Enable" : "启用",
     "Unable to update profile default setting" : "无法更新个人资料默认设置",
     "Server-side encryption" : "服务器端加密",
@@ -374,7 +329,6 @@ OC.L10N.register(
     "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "您需要从旧版本（ownCloud <= 8.0）迁移您的加密密钥。请在应用中启用“Default encryption module”并运行 {command}",
     "Unable to update server side encryption config" : "无法更新服务端加密设置",
     "Please confirm the group removal" : "请确认移除该群组",
-    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "你将移除群组 “{group}”。群组内的用户不会被删除。",
     "Cancel" : "取消",
     "Confirm" : "确认",
     "Submit" : "提交",
@@ -405,12 +359,13 @@ OC.L10N.register(
     "You are using <strong>{usage}</strong>" : "您已使用<strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "您已使用 <strong>{totalSpace}</strong> 中的 <strong>{usage}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "您的全名",
-    "Email options" : "电子邮件选项",
+    "Back" : "返回",
+    "This address is not confirmed" : "此地址未经确认",
     "Primary email for password reset and notifications" : "用于重设密码和通知的主邮件",
+    "Email options" : "电子邮件选项",
     "Remove primary email" : "删除主邮件地址",
     "Delete email" : "删除电子邮件",
     "Unset as primary email" : "取消设为主邮件地址",
-    "This address is not confirmed" : "此地址未经确认",
     "Set as primary email" : "设为主电子邮件地址",
     "Additional email address {index}" : "附加邮件地址 {index}",
     "Unable to delete primary email address" : "无法删除主电邮地址",
@@ -432,7 +387,6 @@ OC.L10N.register(
     "Your organisation" : "您的组织",
     "Your phone number" : "您的电话号码",
     "Edit your Profile visibility" : "编辑个人资料可见性",
-    "Enable Profile" : "编辑个人资料",
     "Unable to update profile enabled state" : "无法更新个人资料启用状态",
     "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "系统将遵循个人资料的 “可见性” 和 “范围” 设置中限制更严格那个。例如，当 “可见性” 设置为 “显示给所有人”，而 “范围” 设置为 “私密” 时，系统将按照 “私密” 来设置您个人资料",
     "Unable to update visibility of {displayId}" : "无法更新 {displayId} 的可见性",
@@ -450,9 +404,8 @@ OC.L10N.register(
     "Change" : "修改",
     "Delete" : "删除",
     "Reshare" : "重新共享",
-    "No users" : "无用户",
-    "Loading users …" : "正在加载用户 ...",
-    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "列出所有用户。考虑性能原因该列表可能不会全部显示，而是在你浏览列表时按需显示。",
+    "No accounts" : "没有账目",
+    "Loading accounts …" : "正在加载账户...",
     "Default language" : "默认语言",
     "Common languages" : "常用语言",
     "Other languages" : "其他语言",
@@ -477,36 +430,31 @@ OC.L10N.register(
     "Username will be autogenerated" : "用户名将自动生成",
     "Username (required)" : "用户名（必填）",
     "Total rows summary" : "总行摘要",
+    "Loading users …" : "正在加载用户 ...",
     "Scroll to load more rows" : "滚动以加载更多列。",
     "_{userCount} user …_::_{userCount} users …_" : ["{userCount} 个用户 ..."],
     "_{userCount} user_::_{userCount} users_" : ["{userCount} 个用户"],
     "Avatar" : "头像",
+    "Username" : "用户名",
     "Group admin for" : "分组管理员",
     "User backend" : "用户来源",
     "Storage location" : "存储位置",
     "Last login" : "最后登录",
     "User actions" : "用户操作",
     "Password or insufficient permissions message" : "密码错误或权限不足的提示消息",
-    "Loading user …" : "正在加载用户 ...",
     "Change display name" : "修改显示名称",
     "Set new password" : "设置新密码",
-    "You do not have permissions to see the details of this user" : "您没有权限查看该用户的详细信息",
     "Set new email address" : "设置新邮箱地址",
     "Add user to group" : "添加用户到组",
-    "Set user as admin for" : "设置用户为管理员",
-    "Select user quota" : "选择用户容量限额",
     "Set the language" : "设置语言",
     "{size} used" : "已使用 {size}",
-    "Delete user" : "删除用户",
+    "Delete account" : "删除账号",
     "Wipe all devices" : "擦除所有设备",
-    "Disable user" : "禁用用户",
-    "Enable user" : "启用用户",
     "Resend welcome email" : "重新发送欢迎邮件",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "如果设备丢失或退出组织，这可以从与 {userid} 关联的所有设备中远程擦除 Nextcloud 数据。 仅当设备连接到互联网时才有效。",
     "Remote wipe of devices" : "远程擦除设备",
     "Wipe {userid}'s devices" : "擦除 {userid} 的设备",
     "Wiped {userid}'s devices" : "已抹除 {userid} 的设备",
-    "Failed to update user manager" : "更新用户管理员失败",
     "Fully delete {userid}'s account including all their personal files, app data, etc." : "完全删除 {userid} 的账号，包括其所有个人文件，应用程序数据等。",
     "Account deletion" : "帐号删除",
     "Delete {userid}'s account" : "删除 {userid} 的账号",
@@ -514,16 +462,13 @@ OC.L10N.register(
     "Password was successfully changed" : "密码更改成功",
     "Email was successfully changed" : "邮箱更改成功",
     "Welcome mail sent!" : "欢迎邮件已经发送！",
-    "Toggle user actions menu" : "切换用户行动菜单",
+    "Done" : "完成",
     "Edit" : "编辑",
-    "User management settings" : "用户管理设置",
     "Visibility" : "可见性",
     "Show language" : "显示语言",
-    "Show user backend" : "显示用户来源",
     "Show storage path" : "显示存储路径",
     "Show last login" : "显示最后登录",
     "Send email" : "发送电子邮件",
-    "Send welcome email to new users" : "向新用户发送欢迎邮件",
     "Defaults" : "默认",
     "Default quota" : "默认配额",
     "Select default quota" : "选择默认存储限额",
@@ -545,7 +490,7 @@ OC.L10N.register(
     "{license}-licensed" : "{license}-许可协议",
     "Changelog" : "更改日志",
     "by {author}\n{license}" : "按照 {author}\n{license}",
-    "Active users" : "活跃用户",
+    "New account" : "新建帐号",
     "Admins" : "管理员",
     "Disabled users" : "已禁用的用户",
     "Creating group …" : "正在创建群组 ...",
@@ -570,8 +515,6 @@ OC.L10N.register(
     "Profile visibility" : "个人资料可见性",
     "Locale" : "地区语系",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "不可用，因为包括文件共享和日历邀请在内的核心功能需要此属性",
-    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "您的账号上的联合云功能已被停用，如有疑问，请咨询系统管理员。",
-    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "不可用，因为不允许将特定于用户的数据发布到查找服务器，如果有任何问题，请与系统管理员联系",
     "Your apps" : "您的应用",
     "Active apps" : "已启用的应用",
     "Disabled apps" : "已禁用的应用",
@@ -580,24 +523,28 @@ OC.L10N.register(
     "Featured apps" : "精选应用",
     "Supported apps" : "支持的应用",
     "Show to everyone" : "显示给所有人",
-    "Show to logged in users only" : "仅显示给登录用户",
     "Hide" : "隐藏",
     "Download and enable" : "下载并启用",
     "Allow untested app" : "允许未经测试的应用",
     "The app will be downloaded from the App Store" : "将从应用商店下载应用",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的 Nextcloud 版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
     "Never" : "从不",
+    "Active users" : "活跃用户",
     "An error occurred during the request. Unable to proceed." : "请求期间发生错误。无法继续。",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。将在 5 秒后跳转到更新页面。",
     "Error: This app cannot be enabled because it makes the server unstable" : "错误:这个应用程序不能被启用，因为它使服务器不稳定 ",
+    "Do you really want to wipe your data from this device?" : "您真的要从此设备擦除您的数据吗？",
+    "Confirm wipe" : "确认擦除",
+    "Error while wiping the device with the token" : "使用令牌擦除设备时出错",
+    "Error while updating device token name" : "更新设备令牌名称时出错",
+    "Error while updating device token scope" : "更新设备令牌范围时出错",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "您的网络请求过多。如果出现错误，请稍后重试或与您的管理员联系。",
+    "Account documentation" : "账号文档",
+    "Administration documentation" : "管理文档",
     "Documentation" : "文档",
     "Forum" : "论坛",
     "Nextcloud help resources" : "Nextcloud 帮助资源",
-    "Account documentation" : "账号文档",
-    "Administration documentation" : "管理文档",
     "General documentation" : "一般文档",
-    "Login" : "登录",
     "None/STARTTLS" : "无/STARTTLS",
     "SSL" : "SSL",
     "Open documentation" : "打开文档",
@@ -611,7 +558,6 @@ OC.L10N.register(
     "Authentication" : "身份认证",
     "Authentication required" : "需要认证",
     "Credentials" : "证书",
-    "SMTP Username" : "SMTP 用户名",
     "SMTP Password" : "SMTP 密码",
     "Save" : "保存",
     "Test and verify email settings" : "测试并验证电子邮箱设置",
@@ -632,19 +578,67 @@ OC.L10N.register(
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Nextcloud 的此社区版本不受支持，即时通知不可用。",
     "Use a second factor besides your password to increase security for your account." : "使用除您密码之外的第二种方法来增强您账号的安全性。",
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "如果您使用第三方应用程序连接到 Nextcloud，请确保在启用双因素身份验证之前为每个应用程序创建和配置应用程序密码。",
+    "No user supplied" : "未提供用户",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "请提供管理员恢复密码，否则所有用户的数据都将丢失。",
+    "Backend does not support password change, but the user's encryption key was updated." : "后端不支持密码修改，但用户的加密密钥已经更新。",
+    "installing and updating apps via the App Store or Federated Cloud Sharing" : "通过应用商店或联合云共享安装和更新应用",
+    "Federated Cloud Sharing" : "联合云共享",
+    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL 正使用一个过时的%1$s 版本 (%2$s)。请升级您的操作系统，否则像 %3$s 这样的特性将无法可靠地工作。",
+    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the Nextcloud log file for more details." : "不能确定 cURL 的 TLS 版本是否已过时，因为在 HTTPS 请求 https://nextcloud.com 时发生了错误。请检查 Nextcloud 日志文件以获取更多信息。",
+    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache 已经禁用。为了更好的性能，建议在您的 PHP 设置中应用 <code>opcache.enable=1</code>。",
+    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache 被设置为移除代码注释。当启用 OPcache 后，必须设置 <code>opcache.save_comments=1</code>，才能让 Nextcloud 工作。",
+    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允许使用 OPcache API。启用 OPcache 后，强烈建议使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目录，或取消该设置以禁用 OPcache API 限制，以避免 Nextcloud 核心或应用程序升级期间发生错误。",
+    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不被允许使用 OPcache API。强烈建议使用 <code>opcache.restrict_api</code> 包含所有 Nextcloud 目录，或取消该设置以禁用 OPcache API 限制，以避免 Nextcloud 核心或应用程序升级期间发生错误。",
+    "The shared memory based OPcache is disabled. For better performance, it is recommended to apply <code>opcache.file_cache_only=0</code> to your PHP configuration and use the file cache as second level cache only." : "基于共享内存的 OPcache 已禁用。为了更好的性能，建议在您的 PHP 配置中应用 <code>opcache.file_cache_only=0</code>，并仅使用文件作为二级缓存。",
+    "The maximum number of OPcache keys is nearly exceeded. To assure that all scripts can be kept in the cache, it is recommended to apply <code>opcache.max_accelerated_files</code> to your PHP configuration with a value higher than <code>%s</code>." : "几乎超过了 OPcache 键的最大数量。为确保所有脚本可以保留在缓存中，建议在您的 PHP 设置中 <code>opcache.max_accelerated_files</code> 设置一个高于 <code>%s</code> 的值。",
+    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 缓存几乎已满。为确保所有脚本可以保留在缓存中，建议在您的 PHP 设置中 <code>opcache.memory_consumption</code> 设置一个高于 <code>%s</code> 的值。",
+    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "OPcache 内部字符串缓存几乎已满。为确保重复的字符串可以被有效地缓存，建议在您的 PHP 设置中 <code>opcache.interned_strings_buffer</code> 设置一个高于 <code>%s</code> 的值。",
+    "You need to set your user email before being able to send test emails. Go to %s for that." : "您需要先前往%s设置电子邮箱，才能发送测试邮件。",
+    "Invalid user" : "无效用户",
+    "Your username is: %s" : "您的用户名是：%s",
+    "Logged in user must be a subadmin" : "当前登录用户必须为子管理员",
+    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "一个检查用户导入的 SSL 证书的后台工作正在进行中。请稍后再来检查。",
+    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "目前存在一些用户导入的 SSL 证书，这在 Nextcloud 21 中已经不使用了。它们可以通过“occ security:certificates:import”命令在命令行导入。它们在数据目录下的路径如下所示。",
     "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "LDAP 用户或组的 UUID 无效。请审查你在 LDAP 配置的专家部分的 \"覆盖 UUID 检测 \"设置，并使用 \"occ ldap:update-uuid\" 来更新它们。",
+    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "两步验证可以对于所有用户和特定分组启用。如果没有设置两步验证提供者，他们则不能登录到系统。",
+    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "当分组被选择/排除时，将使用以下逻辑来确定一个用户是否强制启用两步验证：如果没有选择分组，两步验证将对被排除分组成员外的所有用户启用。如果选择了分组，两步验证将对被选择分组的成员启用。如果一个用户同时属于被选择和被排除分组，被选择分组将拥有优先权，两步验证将对该用户强制启用。",
     "Enable all" : "启用所有",
+    "Internet Explorer" : "IE 浏览器",
+    "Edge" : "Edge 浏览器",
+    "Firefox" : "火狐浏览器",
+    "Google Chrome" : "Google Chrome",
+    "Safari" : "Safari 浏览器",
+    "iPhone" : "iPhone",
+    "iPad" : "iPad",
+    "Sync client - {os}" : "同步客户端 - {os}",
+    "Error while deleting the token" : "删除令牌时出错",
+    "Use the credentials below to configure your app or device." : "使用下述证书配置您的应用或设备。",
+    "For security reasons this password will only be shown once." : "由于安全原因，密码仅会显示一次。",
+    "Copied!" : "已复制！",
+    "Copy" : "复制",
+    "Execute one task with each page loaded. Use case: Single user instance." : "每加载一个页面就执行一个任务。使用场景：单一用户实例。",
+    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "cron.php 注册在一个 webcron 服务上，每 5 分钟通过 HTTP 调用 cron.php。使用场景：非常小的实例（1-5 个用户，取决于使用情况）。",
     "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "为了运行该功能，您需要 PHP POSIX 扩展。请参考 {linkstart}PHP 文档{linkend} 获取更多信息。",
     "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "使用系统 cron 服务，每 5 分钟调用 cron.php 文件。建议在所有实例中使用。",
+    "The cron.php needs to be executed by the system user \"{user}\"." : "cron.php 需要由系统用户“{user}”执行。",
+    "Enable or disable profile by default for new users." : "对新用户默认启用或禁用简介。",
     "You are about to remove the group {group}. The users will NOT be deleted." : "您将要移除群组 {group}。组中的用户不会被删除。",
     "Please confirm the group removal " : "请确认移除群组",
     "Choose profile picture from files" : "从文件中选择个人资料图片",
     "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
     "Your email address" : "您的电子邮件",
     "Your location" : "您的位置",
+    "Enable Profile" : "编辑个人资料",
     "Your Twitter handle" : "您的 Twitter 账号",
+    "You do not have permissions to see the details of this user" : "您没有权限查看该用户的详细信息",
     "Add new password" : "添加新的密码",
     "Add new email address" : "添加新的电子邮件地址",
+    "Set user as admin for" : "设置用户为管理员",
+    "Select user quota" : "选择用户容量限额",
+    "Toggle user actions menu" : "切换用户行动菜单",
+    "Delete user" : "删除用户",
+    "Disable user" : "禁用用户",
+    "Enable user" : "启用用户",
     "Edit User" : "编辑用户",
     "Will be autogenerated" : "将自动生成",
     "Add a new user" : "添加新用户",
@@ -653,10 +647,15 @@ OC.L10N.register(
     "Add group" : "添加分组",
     "Default quota:" : "默认配额：",
     "Show Languages" : "显示语言",
+    "Show user backend" : "显示用户来源",
     "Send email to new user" : "发送电子邮件给新用户",
     "Not saved" : "未保存",
     "Twitter" : "Twitter",
+    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "您的账号上的联合云功能已被停用，如有疑问，请咨询系统管理员。",
+    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "不可用，因为不允许将特定于用户的数据发布到查找服务器，如果有任何问题，请与系统管理员联系",
+    "Show to logged in users only" : "仅显示给登录用户",
     "Enable untested app" : "启用未经测试的应用",
+    "SMTP Username" : "SMTP 用户名",
     "Expire after" : "过期于下列日期后",
     "day(s)" : "天",
     "Exclude groups from password requirements:" : "从密码要求中排除指定组：",
@@ -668,6 +667,15 @@ OC.L10N.register(
     "Edit display name" : "编辑显示名称",
     "Select manager" : "选择管理者",
     "User's table" : "用户的表格",
-    "Select user manager" : "选择用户管理者"
+    "Select user manager" : "选择用户管理者",
+    "Old user imported certificates" : "旧用户导入的证书",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them: %s." : "该实例缺少一些推荐的PHP模块。强烈建议您安装以下模块以提升性能和兼容性：%s",
+    "You are about to remove the group \"{group}\". The users will NOT be deleted." : "你将移除群组 “{group}”。群组内的用户不会被删除。",
+    "No users" : "无用户",
+    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "列出所有用户。考虑性能原因该列表可能不会全部显示，而是在你浏览列表时按需显示。",
+    "Loading user …" : "正在加载用户 ...",
+    "Failed to update user manager" : "更新用户管理员失败",
+    "User management settings" : "用户管理设置",
+    "Send welcome email to new users" : "向新用户发送欢迎邮件"
 },
 "nplurals=1; plural=0;");
