@@ -10,7 +10,6 @@ OC.L10N.register(
     "Password to access {file} was sent to {email}" : "Password for adgang {file} blev sendt til {email}",
     "Password to access {file} was sent to you" : "Password for adgang {file} blev sendt til dig.",
     "Share by mail" : "Delt med mail",
-    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deling af %1$s mislykkedes, fordi dette element allerede er delt med bruger%2$s",
     "Failed to send share by email" : "Kunne ikke sende deling via e-mail",
     "%1$s shared »%2$s« with you" : "%1$s delte \"%2$s\" med dig",
     "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med dig",
@@ -25,14 +24,8 @@ OC.L10N.register(
     "»%s« added a note to a file shared with you" : "»%s« har tilføjet en note til en fil delt med dig",
     "You can choose a different password at any time in the share dialog." : "Du kan til enhver tid vælge et andet password i delings dialogen.",
     "Could not find share" : "Kan ikke finde deling",
-    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Tillad brugere at dele et personligt link til en fil eller folder ved at skrive en email ind.",
     "Send password by mail" : "Send kodeord på mail",
-    "Shared with %1$s" : "Delt med %1$s",
-    "Shared with %1$s by %2$s" : "Delt med %1$s af %2$s",
-    "Password for mail share sent to %1$s" : "Password for mail deling er sendt til %1$s",
-    "You shared %1$s with %2$s by mail" : "Du delte %1$s med %2$s via e-mail",
-    "%3$s shared %1$s with %2$s by mail" : "%3$s delte %1$s med %2$s via e-mail",
-    "Password to access %1$s was sent to %2s" : "Password for adgang %1$s blev sendt til %2s",
-    "Password to access %1$s was sent to you" : "Password for adgang %1$s blev sendt til dig."
+    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deling af %1$s mislykkedes, fordi dette element allerede er delt med bruger%2$s",
+    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Tillad brugere at dele et personligt link til en fil eller folder ved at skrive en email ind."
 },
 "nplurals=2; plural=(n != 1);");
