@@ -14,7 +14,6 @@ OC.L10N.register(
     "Your Nextcloud Subscription has expired!" : "La tua sottoscrizione di Nextcloud è scaduta!",
     "Your server has no Nextcloud Subscription" : "Il tuo server non ha una sottoscrizione di Nextcloud",
     "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Il tuo server Nextcloud non è supportato da una sottoscrizione aziendale di Nextcloud.",
-    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Una sottoscrizione Enterprise di Nextcloud significa che gli sviluppatori originali dietro il tuo server di cloud privato sono dedicati al 100% al tuo successo: la sicurezza, la scalabilità, le prestazioni e la funzionalità del tuo servizio!",
     "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Se il tuo server non funziona più e i tuoi impiegati non posso più lavorare, non devi affidarti alle ricerche sui forum per una soluzione. Hai accesso diretto ai nostri ingegneri esperti!",
     "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Hai un contratto con il venditore che fornisce informazioni di sicurezza confidenziali, mitigazioni, patch e aggiornamenti.",
     "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Se vuoi rimanere per un po' con la tua versione attuale senza interruzioni, non devi eseguire software senza aggiornamenti di sicurezza.",
@@ -50,14 +49,14 @@ OC.L10N.register(
     "Expired subscription" : "Sottoscrizione scaduta",
     "Subscription key:" : "Chiave di sottoscrizione:",
     "Expires in: " : "Scade tra:",
-    "_%n year_::_%n years_" : ["%n anno","%n anni"],
-    "_%n month_::_%n months_" : ["%n mese","%n mesi"],
-    "_%n week_::_%n weeks_" : ["%n settimana","%n settimane"],
-    "_%n day_::_%n days_" : ["%n giorno","%n giorni"],
+    "_%n year_::_%n years_" : ["%n anno","%n anni","%n anni"],
+    "_%n month_::_%n months_" : ["%n mese","%n mesi","%n mesi"],
+    "_%n week_::_%n weeks_" : ["%n settimana","%n settimane","%n settimane"],
+    "_%n day_::_%n days_" : ["%n giorno","%n giorni","%n giorni"],
     "For an unlimited amount of users" : "Per una quantità illimitata di utenti",
-    "_For %n active users_::_For %n active users_" : ["Per %n utenti attivi","Per %n utenti attivi"],
-    "_For %n users_::_For %n users_" : ["Per %n utenti","Per %n utenti"],
-    "_currently at %n user_::_currently at %n users_" : ["attualmente a %n utente","attualmente a %n utenti"],
+    "_For %n active users_::_For %n active users_" : ["Per %n utenti attivi","Per %n utenti attivi","Per %n utenti attivi"],
+    "_For %n users_::_For %n users_" : ["Per %n utenti","Per %n utenti","Per %n utenti"],
+    "_currently at %n user_::_currently at %n users_" : ["attualmente a %n utente","attualmente a %n utenti","attualmente a %n utenti"],
     "Includes support for %s" : "Include il supporto per %s",
     "Includes support for %1$s & %2$s" : "Include il supporto per %1$s e %2$s",
     "Includes support for %1$s, %2$s & %3$s" : "Include il supporto per %1$s, %2$s e %3$s",
@@ -88,13 +87,10 @@ OC.L10N.register(
     "Community support" : "Supporto della comunità",
     "Forum" : "Forum",
     "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud è un software libero che è supportato da una comunità molto attiva. Registrati al forum per porre domande e discutere con altre persone.",
+    "Nextcloud forum" : "Forum di Nextcloud",
     "GitHub" : "GitHub",
     "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud utilizza GitHub come piattaforma per lavorare in modo collaborativo. Puoi segnalare i bug direttamente lì.",
-    "Chat" : "Chat",
-    "Chat with us on our IRC channel #nextcloud on Freenode." : "Comunica in chat con noi sul nostro canale IRC #nextcloud su Freenode.",
-    "Nextcloud forum" : "Forum di Nextcloud",
     "Nextcloud at GitHub" : "Nextcloud su GitHub",
-    "Open chat" : "Apri chat",
     "Subscription key" : "Chiave di sottoscrizione",
     "If you have an active Nextcloud Subscription please enter your subscription key here." : "Sei hai una sottoscrizione di Nextcloud attiva, digita qui la tua chiave di sottoscrizione.",
     "Learn more about an enterprise subscription." : "Scopri altro sulla sottoscrizione aziendale.",
@@ -112,4 +108,4 @@ OC.L10N.register(
     "Check out our blog" : "Leggi il nostro blog",
     "Subscribe to our newsletter" : "Iscriviti alla nostra newsletter"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
