@@ -1,10 +1,6 @@
 OC.L10N.register(
     "systemtags",
     {
-    "Tag name is empty" : "El nombre de la etiqueta está vacío",
-    "Update" : "Actualizar",
-    "Create" : "Crear",
-    "Select tag …" : "Selecciona etiqueta...",
     "System tag %1$s added by the system" : "Etiqueta de sistema %1$s añadida por el sistema",
     "Added system tag {systemtag}" : "Se añadió la etiqueta de sistema {systemtag}",
     "Added system tag %1$s" : "Se añadió la etiqueta del sistema %1$s",
@@ -46,17 +42,33 @@ OC.L10N.register(
     "All tagged %s …" : "Todos etiquetados %s …",
     "tagged %s" : "Etiquetados %s",
     "Collaborative tags" : "Etiquetas colaborativas",
-    "Collaborative tagging functionality which shares tags among users." : "Funcionalidad de etiquetado colaborativo que comparte las etiquetas entre usuarios.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetado colaborativo que comparte las etiquetas entre usuarios. Adecuado para equipos.\n\n(Si eres un proveedor con una instalación en multitenencia), se aconseja desactivar esta app pues las etiquetas se comparten).",
+    "Create or edit tags" : "Crear o editar etiquetas",
+    "Search for a tag to edit" : "Buscar la etiqueta a editar",
+    "Collaborative tags …" : "Etiquetas colaborativas ...",
+    "No tags to select" : "No hay etiquetas para seleccionar",
+    "Tag name" : "Nombre de la etiqueta",
+    "Tag level" : "Nivel de la etiqueta",
+    "Create" : "Crear",
+    "Update" : "Actualizar",
+    "Delete" : "Borrar",
+    "Reset" : "Restablecer",
+    "Loading …" : "Cargando …",
+    "Public" : "Público",
+    "Restricted" : "Restringido",
+    "Invisible" : "Invisible",
+    "Created tag" : "Etiqueta creada",
+    "Failed to create tag" : "Fallo al crear etiqueta",
+    "Updated tag" : "Etiqueta actualizada",
+    "Failed to update tag" : "Fallo al actualizar la etiqueta",
+    "Deleted tag" : "Etiqueta eliminada",
+    "Failed to delete tag" : "Fallo al borrar etiqueta",
     "Loading collaborative tags …" : "Cargando etiquetas colaborativas …",
     "Search or create collaborative tags" : "Buscar o crear etiquetas colaborativas",
-    "Collaborative tags …" : "Etiquetas colaborativas ...",
     "No tags to select, type to create a new tag" : "No hay etiquetas para seleccionar, escriba para crear una etiqueta nueva",
     "Failed to load tags" : "Fallo al cargar etiquetas",
     "Failed to load selected tags" : "Fallo al cargar las etiquetas seleccionadas",
     "Failed to select tag" : "Fallo al seleccionar etiqueta",
-    "Failed to create tag" : "Fallo al crear etiqueta",
-    "Failed to delete tag" : "Fallo al borrar etiqueta",
+    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Las etiquetas colaborativas están disponibles para todos los usuarios. Las etiquetas restringidas son visibles para los usuarios, pero no pueden ser asignadas por ellos. Las etiquetas invisibles son para uso interno, pues los usuarios no pueden verlas ni asignarlas.",
     "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}",
     "List of tags and their associated files and folders." : "Lista de etiquetas y sus carpetas y archivos asociados.",
@@ -64,23 +76,22 @@ OC.L10N.register(
     "Tags you have created will show up here." : "Las etiquetas que haya creado aparecerán aquí.",
     "Failed to load last used tags" : "Fallo al cargar las etiquetas recientemente utilizadas",
     "Missing \"Content-Location\" header" : "No existe la cabecera \"Content-Location\"",
-    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Las etiquetas colaborativas están disponibles para todos los usuarios. Las etiquetas restringidas son visibles para los usuarios, pero no pueden ser asignadas por ellos. Las etiquetas invisibles son para uso interno, pues los usuarios no pueden verlas ni asignarlas.",
-    "Create a new tag" : "Crear una etiqueta nueva",
-    "Tag name" : "Nombre de la etiqueta",
-    "Name" : "Nombre",
-    "Tag level" : "Nivel de la etiqueta",
-    "Public" : "Público",
-    "Restricted" : "Restringido",
-    "Invisible" : "Invisible",
-    "Delete" : "Borrar",
-    "Reset" : "Restablecer",
-    "No files in here" : "Aquí no hay archivos",
-    "No entries found in this folder" : "No hay entradas en esta carpeta",
-    "Size" : "Tamaño",
-    "Modified" : "Modificado",
+    "Failed to load tags for file" : "Fallo al cargar las etiquetas del archivo",
+    "Failed to set tag for file" : "Fallo al asignar la etiqueta al archivo",
+    "Failed to delete tag for file" : "Fallo al borrar la etiqueta del archivo",
+    "Tag name is empty" : "El nombre de la etiqueta está vacío",
+    "Select tag …" : "Selecciona etiqueta...",
+    "Collaborative tagging functionality which shares tags among users." : "Funcionalidad de etiquetado colaborativo que comparte las etiquetas entre usuarios.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetado colaborativo que comparte las etiquetas entre usuarios. Adecuado para equipos.\n\n(Si eres un proveedor con una instalación en multitenencia), se aconseja desactivar esta app pues las etiquetas se comparten).",
     "Tagged files" : "Archivos etiquetados",
     "Select tags to filter by" : "Seleccionar etiquetas por las que filtrar",
     "Please select tags to filter by" : "Por favor, seleccione las etiquetas por las que desea filtrar",
-    "No files found for the selected tags" : "No se han encontrado archivos para las etiquetas seleccionadas"
+    "No files found for the selected tags" : "No se han encontrado archivos para las etiquetas seleccionadas",
+    "Create a new tag" : "Crear una etiqueta nueva",
+    "Name" : "Nombre",
+    "No files in here" : "Aquí no hay archivos",
+    "No entries found in this folder" : "No hay entradas en esta carpeta",
+    "Size" : "Tamaño",
+    "Modified" : "Modificado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
