@@ -34,8 +34,6 @@ OC.L10N.register(
     "<strong>System tags</strong> for a file have been modified" : "Las <strong>etiquetas del sistema</strong> para un archivo han sido modificadas",
     "Tags" : "Etiquetas",
     "Collaborative tags" : "Etiquetas colaborativas",
-    "Collaborative tagging functionality which shares tags among users." : "Funcionalidad de etiquetas colaborativas que comparte las etiquetas entre usuarios.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetear collaborativamente que comparte las etiquetas entre usuarios. Grandioso para equipos.\n\t(Si eres un proveedor con una instalación multi subarrendada, se recomienda desactivar esta aplicación ya que las etiquetas son compartidas.)",
     "Create" : "Crear",
     "Update" : "Actualizar",
     "Delete" : "Borrar",
@@ -43,17 +41,21 @@ OC.L10N.register(
     "Public" : "Público",
     "Restricted" : "Restringido",
     "Invisible" : "Invisible",
+    "This file has the tag {tag}" : "Este archivo tiene la etiqueta {tag}",
+    "This file has the tags {firstTags} and {lastTag}" : "Este archivo tiene las etiquetas {firstTags} y {lastTag}",
     "No tags found" : "No se encontraron etiquetas",
-    "No files in here" : "No hay archivos aquí",
-    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
-    "Name" : "Nombre",
-    "Size" : "Tamaño",
-    "Modified" : "Modificado",
     "Select tag …" : "Seleccionar etiqueta ...",
+    "Collaborative tagging functionality which shares tags among users." : "Funcionalidad de etiquetas colaborativas que comparte las etiquetas entre usuarios.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidad de etiquetear collaborativamente que comparte las etiquetas entre usuarios. Grandioso para equipos.\n\t(Si eres un proveedor con una instalación multi subarrendada, se recomienda desactivar esta aplicación ya que las etiquetas son compartidas.)",
     "Tagged files" : "Archivos etiquetados",
     "Select tags to filter by" : "Selecciona las etiquetas del filtro",
     "Please select tags to filter by" : "Por favor selecciona las etiquetas del filtro",
     "No files found for the selected tags" : "No se encontraron archivos para las etiquetas seleccionadas",
-    "Create a new tag" : "Crear una nueva etiqueta"
+    "Create a new tag" : "Crear una nueva etiqueta",
+    "Name" : "Nombre",
+    "No files in here" : "No hay archivos aquí",
+    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
+    "Size" : "Tamaño",
+    "Modified" : "Modificado"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
