@@ -42,9 +42,10 @@ OC.L10N.register(
     "All tagged %s …" : "%sguztiak etiketatuta …",
     "tagged %s" : "%setiketatuta",
     "Collaborative tags" : "Elkarlaneko etiketak",
-    "Collaborative tagging functionality which shares tags among users." : "Etiketak erabiltzaileen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Etiketak erabiltzaileen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea. Bikaina taldeentzat.\n\t(Maizter anitzeko instalazioa duen hornitzailea bazara, gomendatzen da aplikazio hau desaktibatzea etiketak partekatzen dira eta.)",
+    "Create or edit tags" : "Sortu edo editatu etiketak",
+    "Search for a tag to edit" : "Bilatu editatzeko etiketa",
     "Collaborative tags …" : "Elkarlaneko etiketak ...",
+    "No tags to select" : "Ez da etiketarik hautatu",
     "Tag name" : "Etiketaren izena",
     "Tag level" : "Etiketaren maila",
     "Create" : "Sortu",
@@ -55,7 +56,11 @@ OC.L10N.register(
     "Public" : "Publikoa",
     "Restricted" : "Mugatua",
     "Invisible" : "Ikusezina",
+    "Created tag" : "Etiketa sortu da",
     "Failed to create tag" : "Etiketa sortzeak huts egin du",
+    "Updated tag" : "Etiketa eguneratu da",
+    "Failed to update tag" : "Etiketa eguneratzeak huts egin du",
+    "Deleted tag" : "Etiketa ezabatu da",
     "Failed to delete tag" : "Etiketa ezabatzeak huts egin du",
     "Loading collaborative tags …" : "Elkarlaneko etiketak kargatzen ...",
     "Search or create collaborative tags" : "Bilatu edo sortu elkarlaneko etiketak",
@@ -71,17 +76,22 @@ OC.L10N.register(
     "Tags you have created will show up here." : "Sortu dituzun etiketak hemen agertuko dira.",
     "Failed to load last used tags" : "Ezin izan dira azken erabilitako etiketak kargatu",
     "Missing \"Content-Location\" header" : "\"Content-Location\" goiburua falta",
-    "No files in here" : "Ez dago fitxategirik hemen",
-    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
-    "Name" : "Izena",
-    "Size" : "Tamaina",
-    "Modified" : "Aldatuta",
+    "Failed to load tags for file" : "Fitxategiarentzako etiketak kargatzeak huts egin du",
+    "Failed to set tag for file" : "Fitxategiarentzako etiketa ezartzeak huts egin du",
+    "Failed to delete tag for file" : "Fitxategiaren etiketa ezabatzeak huts egin du",
     "Tag name is empty" : "Etiketaren izena hutsik dago",
     "Select tag …" : "Hautatu etiketa ...",
+    "Collaborative tagging functionality which shares tags among users." : "Etiketak erabiltzaileen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Etiketak erabiltzaileen artean partekatzen dituen lankidetzazko etiketatze funtzionalitatea. Bikaina taldeentzat.\n\t(Maizter anitzeko instalazioa duen hornitzailea bazara, gomendatzen da aplikazio hau desaktibatzea etiketak partekatzen dira eta.)",
     "Tagged files" : "Etiketatutako fitxategiak",
     "Select tags to filter by" : "Hautatu etiketak iragazteko",
     "Please select tags to filter by" : "Hautatu etiketak iragazteko",
     "No files found for the selected tags" : "Ez da fitxategirik aurkitu hautatutako etiketetarako",
-    "Create a new tag" : "Sortu etiketa berria"
+    "Create a new tag" : "Sortu etiketa berria",
+    "Name" : "Izena",
+    "No files in here" : "Ez dago fitxategirik hemen",
+    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
+    "Size" : "Tamaina",
+    "Modified" : "Aldatuta"
 },
 "nplurals=2; plural=(n != 1);");
