@@ -42,8 +42,6 @@ OC.L10N.register(
     "All tagged %s …" : "Összes ezzel címkézett: %s…",
     "tagged %s" : "ezzel címkézett: %s",
     "Collaborative tags" : "Együttműködési címkék",
-    "Collaborative tagging functionality which shares tags among users." : "Együttműködő címkézési funkció, amely megosztja a címkéket a felhasználók között.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Együttműködő címkézési funkció, amely megosztja a címkéket a felhasználók között. Nagyszerű a csapatok számára.\n\t(Ha Ön több szervezet számára szolgáltatást nyújtó szolgáltató, akkor ajánlott deaktiválni ezt az alkalmazást, mivel a címkék meg vannak osztva.)",
     "Collaborative tags …" : "Együttműködési címkék…",
     "Tag name" : "Címke név",
     "Tag level" : "Címke szint",
@@ -71,17 +69,19 @@ OC.L10N.register(
     "Tags you have created will show up here." : "A saját címkék itt jelennek meg.",
     "Failed to load last used tags" : "A legutóbb használt címkék betöltése sikertelen",
     "Missing \"Content-Location\" header" : "Hiányzó „Content-Location” fejléc",
-    "No files in here" : "Itt nincsenek fájlok",
-    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
-    "Name" : "Név",
-    "Size" : "Méret",
-    "Modified" : "Módosítva",
     "Tag name is empty" : "A címke neve üres",
     "Select tag …" : "Válasszon címkét…",
+    "Collaborative tagging functionality which shares tags among users." : "Együttműködő címkézési funkció, amely megosztja a címkéket a felhasználók között.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Együttműködő címkézési funkció, amely megosztja a címkéket a felhasználók között. Nagyszerű a csapatok számára.\n\t(Ha Ön több szervezet számára szolgáltatást nyújtó szolgáltató, akkor ajánlott deaktiválni ezt az alkalmazást, mivel a címkék meg vannak osztva.)",
     "Tagged files" : "Címkézett fájlok",
     "Select tags to filter by" : "Válasszon címkéket a szűréshez:",
     "Please select tags to filter by" : "Válasszon címkéket a szűréshez:",
     "No files found for the selected tags" : "Nem található fájl a kiválasztott címkéhez",
-    "Create a new tag" : "Új címke létrehozása"
+    "Create a new tag" : "Új címke létrehozása",
+    "Name" : "Név",
+    "No files in here" : "Itt nincsenek fájlok",
+    "No entries found in this folder" : "Nincsenek bejegyzések ebben a mappában",
+    "Size" : "Méret",
+    "Modified" : "Módosítva"
 },
 "nplurals=2; plural=(n != 1);");
