@@ -1,10 +1,6 @@
 OC.L10N.register(
     "systemtags",
     {
-    "Tag name is empty" : "O nome da etiqueta está vazia",
-    "Update" : "Atualizar",
-    "Create" : "Criar",
-    "Select tag …" : "Selecionar etiqueta...",
     "System tag %1$s added by the system" : "A tag de sistema %1$s foi adicionado pelo sistema",
     "Added system tag {systemtag}" : "Adicionada a etiqueta de sistema {systemtag}",
     "Added system tag %1$s" : "Adicionada a etiqueta de sistema %1$s",
@@ -46,17 +42,33 @@ OC.L10N.register(
     "All tagged %s …" : "Todos os %s marcados …",
     "tagged %s" : "marcado %s",
     "Collaborative tags" : "Etiquetas colaborativas",
-    "Collaborative tagging functionality which shares tags among users." : "Funcionalidade de marcação colaborativa que compartilha rótulos entre usuários.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha rótulos entre usuários. Ótimo para equipes.\n\t(Se você for um provedor de uma instalação de multilocação, é aconselhável desativar isso, pois os rótulos são compartilhados.)",
+    "Create or edit tags" : "Criar ou editar etiquetas",
+    "Search for a tag to edit" : "Procure uma etiqueta para editar",
+    "Collaborative tags …" : "Etiquetas colaborativas…",
+    "No tags to select" : "Nenhuma etiqueta para selecionar",
+    "Tag name" : "Nome da etiqueta",
+    "Tag level" : "Nível de etiqueta",
+    "Create" : "Criar",
+    "Update" : "Atualizar",
+    "Delete" : "Excluir",
+    "Reset" : "Redefinir",
+    "Loading …" : "Carregando …",
+    "Public" : "Público",
+    "Restricted" : "Restrito",
+    "Invisible" : "Invisível",
+    "Created tag" : "Etiqueta criada",
+    "Failed to create tag" : "Falha ao criar etiqueta",
+    "Updated tag" : "Etiqueta atualizada",
+    "Failed to update tag" : "Falha ao atualizar a etiqueta",
+    "Deleted tag" : "Etiqueta excluída",
+    "Failed to delete tag" : "Falha ao excluir etiqueta",
     "Loading collaborative tags …" : "Carregando etiquetas,s colaborativas…",
     "Search or create collaborative tags" : "Pesquise ou crie etiquetas colaborativas",
-    "Collaborative tags …" : "Etiquetas colaborativas…",
     "No tags to select, type to create a new tag" : "Nenhuma etiqueta para selecionar, digite para criar uma nova etiqueta",
     "Failed to load tags" : "Erro ao carregar rótulos",
     "Failed to load selected tags" : "Falha ao carregar as etiquetas selecionadas",
     "Failed to select tag" : "Falha ao selecionar etiqueta",
-    "Failed to create tag" : "Falha ao criar etiqueta",
-    "Failed to delete tag" : "Falha ao excluir etiqueta",
+    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Etiquetas colaborativas estão disponíveis para todos os usuários. As etiquetas restritas são visíveis para os usuários, mas não podem ser atribuídas por eles. Etiquetas invisíveis são para uso interno, já que os usuários não podem vê-las ou atribuí-las.",
     "This file has the tag {tag}" : "Este arquivo tem a tag {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Este arquivo tem as etiquetas {firstTags} e {lastTag}",
     "List of tags and their associated files and folders." : "Lista de etiquetas e seus arquivos e pastas associados.",
@@ -64,23 +76,22 @@ OC.L10N.register(
     "Tags you have created will show up here." : "Asetiquetas que você criou aparecerão aqui.",
     "Failed to load last used tags" : "Falha ao carregar as últimas etiquetas usadas",
     "Missing \"Content-Location\" header" : "Cabeçalho \"Conteúdo-Localização\" ausente",
-    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Etiquetas colaborativas estão disponíveis para todos os usuários. As etiquetas restritas são visíveis para os usuários, mas não podem ser atribuídas por eles. Etiquetas invisíveis são para uso interno, já que os usuários não podem vê-las ou atribuí-las.",
-    "Create a new tag" : "Criar uma nova etiqueta",
-    "Tag name" : "Nome da etiqueta",
-    "Name" : "Nome",
-    "Tag level" : "Nível de etiqueta",
-    "Public" : "Público",
-    "Restricted" : "Restrito",
-    "Invisible" : "Invisível",
-    "Delete" : "Excluir",
-    "Reset" : "Redefinir",
-    "No files in here" : "Nenhum arquivo aqui",
-    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
-    "Size" : "Tamanho",
-    "Modified" : "Modificado",
+    "Failed to load tags for file" : "Falha ao carregar etiquetas para arquivo",
+    "Failed to set tag for file" : "Falha ao definir etiqueta para arquivo",
+    "Failed to delete tag for file" : "Falha ao excluir etiqueta do arquivo",
+    "Tag name is empty" : "O nome da etiqueta está vazia",
+    "Select tag …" : "Selecionar etiqueta...",
+    "Collaborative tagging functionality which shares tags among users." : "Funcionalidade de marcação colaborativa que compartilha rótulos entre usuários.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funcionalidade de marcação colaborativa que compartilha rótulos entre usuários. Ótimo para equipes.\n\t(Se você for um provedor de uma instalação de multilocação, é aconselhável desativar isso, pois os rótulos são compartilhados.)",
     "Tagged files" : "Arquivos etiquetados",
     "Select tags to filter by" : "Selecione etiquetas a filtrar",
     "Please select tags to filter by" : "Por favor selecione etiquetas a filtrar",
-    "No files found for the selected tags" : "Nenhum arquivo encontrado para as etiquetas selecionadas"
+    "No files found for the selected tags" : "Nenhum arquivo encontrado para as etiquetas selecionadas",
+    "Create a new tag" : "Criar uma nova etiqueta",
+    "Name" : "Nome",
+    "No files in here" : "Nenhum arquivo aqui",
+    "No entries found in this folder" : "Nenhuma entrada foi encontrada nesta pasta",
+    "Size" : "Tamanho",
+    "Modified" : "Modificado"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
