@@ -1,10 +1,6 @@
 OC.L10N.register(
     "systemtags",
     {
-    "Tag name is empty" : "Имя метки пусто",
-    "Update" : "Обновить",
-    "Create" : "Создать",
-    "Select tag …" : "Выберите метку…",
     "System tag %1$s added by the system" : "Системная метка «%1$s» создана",
     "Added system tag {systemtag}" : "Создана системная метка «{systemtag}»",
     "Added system tag %1$s" : "Создана системная метка «%1$s»",
@@ -46,17 +42,34 @@ OC.L10N.register(
     "All tagged %s …" : "Все помеченные %s ...",
     "tagged %s" : "помеченные %s",
     "Collaborative tags" : "Метки совместной работы",
-    "Collaborative tagging functionality which shares tags among users." : "Совместная работа с метками файлов.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Совместная работа с метками файлов, предназначенная для групп пользователей. (Провайдерам с большим количеством клиентов рекомендуется отключить это приложение, так как метки являются общими).",
+    "Collaborative tagging functionality which shares tags among people." : "Функционал совместных меток, который публикует метки среди пользователей.",
+    "Create or edit tags" : "Создание или изменение меток",
+    "Search for a tag to edit" : "Поиск метки для изменения",
+    "Collaborative tags …" : "Совместные теги ...",
+    "No tags to select" : "Нет меток для выбора",
+    "Tag name" : "Название метки",
+    "Tag level" : "Уровень тега",
+    "Create" : "Создать",
+    "Update" : "Обновить",
+    "Delete" : "Удалить",
+    "Reset" : "Сбросить",
+    "Loading …" : "Загрузка…",
+    "Public" : "Общая",
+    "Restricted" : "Ограниченная",
+    "Invisible" : "Невидимая",
+    "Created tag" : "Метка создана",
+    "Failed to create tag" : "Не удалось создать тег",
+    "Updated tag" : "Метка обновлена",
+    "Failed to update tag" : "Не удалось обновить метку",
+    "Deleted tag" : "Метка удалена",
+    "Failed to delete tag" : "Не удалось удалить тег",
     "Loading collaborative tags …" : "Загрузка совместных тегов ...",
     "Search or create collaborative tags" : "Поиск или создание совместных тегов",
-    "Collaborative tags …" : "Совместные теги ...",
     "No tags to select, type to create a new tag" : "Нет тегов для выбора. Введите что-нибудь для создания нового тега",
     "Failed to load tags" : "Не удалось загрузить метки",
     "Failed to load selected tags" : "Не удалось загрузить выбранный тег",
     "Failed to select tag" : "Не удалось выбрать тег",
-    "Failed to create tag" : "Не удалось создать тег",
-    "Failed to delete tag" : "Не удалось удалить тег",
+    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Совместные теги доступны для всех пользователей. Ограниченные теги видны пользователям, но не могут быть назначены ими. Невидимые теги предназначены для внутреннего использования, поскольку пользователи не могут их видеть или назначать.",
     "This file has the tag {tag}" : "У этого файла есть тэг: {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "У этого файла есть тэги: {firstTags} и {lastTag}",
     "List of tags and their associated files and folders." : "Список тегов и связанных с ними файлов и папок.",
@@ -64,23 +77,22 @@ OC.L10N.register(
     "Tags you have created will show up here." : "Здесь будут отображаться созданные вами теги.",
     "Failed to load last used tags" : "Не удалось загрузить последние использованные метки",
     "Missing \"Content-Location\" header" : "Отсутствует заголовок «Content-Location»",
-    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Совместные теги доступны для всех пользователей. Ограниченные теги видны пользователям, но не могут быть назначены ими. Невидимые теги предназначены для внутреннего использования, поскольку пользователи не могут их видеть или назначать.",
-    "Create a new tag" : "Создать метку",
-    "Tag name" : "Название тэга",
-    "Name" : "Имя",
-    "Tag level" : "Уровень тега",
-    "Public" : "Общая",
-    "Restricted" : "Ограниченная",
-    "Invisible" : "Невидимая",
-    "Delete" : "Удалить",
-    "Reset" : "Сбросить",
-    "No files in here" : "Здесь нет файлов",
-    "No entries found in this folder" : "В этой папке не найдено ни одной записи",
-    "Size" : "Размер",
-    "Modified" : "Изменён",
+    "Failed to load tags for file" : "Не удалось загрузить метки для файла",
+    "Failed to set tag for file" : "Не удалось поставить метку файлу",
+    "Failed to delete tag for file" : "Не удалось удалить метку у файла",
+    "Tag name is empty" : "Имя метки пусто",
+    "Select tag …" : "Выберите метку…",
+    "Collaborative tagging functionality which shares tags among users." : "Совместная работа с метками файлов.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Совместная работа с метками файлов, предназначенная для групп пользователей. (Провайдерам с большим количеством клиентов рекомендуется отключить это приложение, так как метки являются общими).",
     "Tagged files" : "Помеченные файлы",
     "Select tags to filter by" : "Выберите метки для отбора",
     "Please select tags to filter by" : "Выберите метки для отбора",
-    "No files found for the selected tags" : "Не найдено файлов с выбранными метками"
+    "No files found for the selected tags" : "Не найдено файлов с выбранными метками",
+    "Create a new tag" : "Создать метку",
+    "Name" : "Имя",
+    "No files in here" : "Здесь нет файлов",
+    "No entries found in this folder" : "В этой папке не найдено ни одной записи",
+    "Size" : "Размер",
+    "Modified" : "Изменён"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
