@@ -1,10 +1,6 @@
 OC.L10N.register(
     "systemtags",
     {
-    "Tag name is empty" : "Názov štítku je prázdny",
-    "Update" : "Aktualizovať",
-    "Create" : "Vytvoriť",
-    "Select tag …" : "Vybrať štítok ...",
     "System tag %1$s added by the system" : "Systémový štítok %1$s bol pridaný systémom",
     "Added system tag {systemtag}" : "Pridaný systémový štítok {systemtag}",
     "Added system tag %1$s" : "Pridaný systémový štítok %1$s",
@@ -45,36 +41,42 @@ OC.L10N.register(
     "Tags" : "Štítky",
     "All tagged %s …" : "Všetky označené %s …",
     "tagged %s" : "označené %s",
-    "Collaborative tags" : "Značky pre spoluprácu",
-    "Collaborative tagging functionality which shares tags among users." : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi používateľmi.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi používateľmi. Skvelé pre tímy.\n\t (Ak ste poskytovateľom inštalácie pre viacero subjektov, odporúča sa túto aplikáciu deaktivovať, pretože štítky sú zdieľané.)",
+    "Collaborative tags" : "Štítky pre spoluprácu",
+    "Create" : "Vytvoriť",
+    "Update" : "Aktualizovať",
+    "Delete" : "Zmazať",
+    "Reset" : "Vynulovať",
+    "Loading …" : "Načítavam …",
+    "Public" : "Verejné",
+    "Restricted" : "Obmedzené",
+    "Invisible" : "Neviditeľné",
+    "Failed to create tag" : "Nepodarilo sa vytvoriť štítok",
+    "Failed to delete tag" : "Nepodarilo sa vymazať štítok",
+    "Search or create collaborative tags" : "Hľadajte alebo vytvorte  štítky pre spoluprácu",
     "No tags to select, type to create a new tag" : "Žiadne štítky neboli vybraté, začnite písať pre vytvorenie ďalších.",
     "Failed to load tags" : "Nepodarilo sa načítať štítky",
     "Failed to load selected tags" : "Nepodarilo sa načítať vytvorený štítok",
     "Failed to select tag" : "Nepodarilo sa vybrať štítok",
-    "Failed to create tag" : "Nepodarilo sa vytvoriť štítok",
-    "Failed to delete tag" : "Nepodarilo sa vymazať štítok",
+    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pre spoluprácu sú k dispozícii pre všetkých používateľov. Obmedzené štítky sú viditeľné pre používateľov, ale nedajú sa priradiť. Neviditeľné značky sú určené na interné použitie, pretože používatelia ich nemôžu vidieť ani priradiť.",
     "This file has the tag {tag}" : "Tento súbor má štítok {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Tento súbor má štítky {firstTags} a {lastTag}",
-    "List of tags and their associated files and folders." : "Zoznam štítkov a ich priradené súbory a adresáre",
+    "List of tags and their associated files and folders." : "Zoznam štítkov a ich priradené súbory a priečinky.",
     "No tags found" : "Štítky sa nenašli",
     "Tags you have created will show up here." : "Štítky, ktoré ste vytvorili sa zobrazia tu.",
     "Failed to load last used tags" : "Nepodarilo sa načítať posledné použité štítky",
-    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Štítky pre spoluprácu sú k dispozícii pre všetkých používateľov. Obmedzené značky sú viditeľné pre používateľov, ale nedajú sa priradiť. Neviditeľné značky sú určené na interné použitie, pretože používatelia ich nemôžu vidieť ani priradiť.",
+    "Tag name is empty" : "Názov štítku je prázdny",
+    "Select tag …" : "Vybrať štítok ...",
+    "Collaborative tagging functionality which shares tags among users." : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi používateľmi.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Funkcie spoločného označovania, ktoré zdieľajú štítky medzi používateľmi. Skvelé pre tímy.\n\t (Ak ste poskytovateľom inštalácie pre viacero subjektov, odporúča sa túto aplikáciu deaktivovať, pretože štítky sú zdieľané.)",
+    "Tagged files" : "Súbory so štítkom",
+    "Select tags to filter by" : "Vybrať štítky na filtrovanie",
+    "Please select tags to filter by" : "Vyberte štítky pre filtrovanie",
+    "No files found for the selected tags" : "Neboli nájdené žiadne súbory označené vybranými štítkami",
     "Create a new tag" : "Vytvoriť nový štítok",
     "Name" : "Názov",
-    "Public" : "Verejné",
-    "Restricted" : "Obmedzené",
-    "Invisible" : "Neviditeľné",
-    "Delete" : "Zmazať",
-    "Reset" : "Vynulovať",
     "No files in here" : "Žiadne súbory",
     "No entries found in this folder" : "V tomto priečinku sa nič nenašlo",
     "Size" : "Veľkosť",
-    "Modified" : "Upravené",
-    "Tagged files" : "Súbory so štítkom",
-    "Select tags to filter by" : "Vybrať štítky pre filter",
-    "Please select tags to filter by" : "Vyberte štítky pre filtrovanie",
-    "No files found for the selected tags" : "Neboli nájdené žiadne súbory označené vybranými štítkami"
+    "Modified" : "Upravené"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
