@@ -1,10 +1,6 @@
 OC.L10N.register(
     "systemtags",
     {
-    "Tag name is empty" : "Име ознаке је празно",
-    "Update" : "Ажурирај",
-    "Create" : "Направи",
-    "Select tag …" : "Одаберите ознаку …",
     "System tag %1$s added by the system" : "Систем додао системску ознаку %1$s",
     "Added system tag {systemtag}" : "Додата системска ознака {systemtag}",
     "Added system tag %1$s" : "Додата системска ознака %1$s",
@@ -46,17 +42,35 @@ OC.L10N.register(
     "All tagged %s …" : "Све означено %s …",
     "tagged %s" : "означено %s",
     "Collaborative tags" : "Тимске ознаке",
-    "Collaborative tagging functionality which shares tags among users." : "Могућност заједничког означавања којим се деле ознаке међу корисницима.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Могућност заједничког означавања којим се деле ознаке међу корисницима. Сјајно за тимове.\n\t(ако сте провајдер инсталације за одвојене кориснике/предузећа, саветује се да иксључите ову апликацију пошто су ознаке дељене.)",
+    "Collaborative tagging functionality which shares tags among people." : "Могућност заједничког означавања којим се деле ознаке међу људима.",
+    "Collaborative tagging functionality which shares tags among people. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функција заједничког означавања којом се ознаке деле међу људима. Одлично за тимове.\n\t(ако сте пружалац услуге са инсталацијом на више различитих локација, саветује се да искључите ову апликацију пошто се ознаке свакако деле.)",
+    "Create or edit tags" : "Креирај или уреди ознаке",
+    "Search for a tag to edit" : "Претрага ознаке за уређивање",
+    "Collaborative tags …" : "Ознаке сарадње...",
+    "No tags to select" : "Нема ниједне ознаке која може да се изабере",
+    "Tag name" : "Назив ознаке",
+    "Tag level" : "Ниво ознаке",
+    "Create" : "Направи",
+    "Update" : "Ажурирај",
+    "Delete" : "Обриши",
+    "Reset" : "Ресетуј",
+    "Loading …" : "Учитавање…",
+    "Public" : "Јавна",
+    "Restricted" : "Ограничена",
+    "Invisible" : "Невидљива",
+    "Created tag" : "Креирана ознака",
+    "Failed to create tag" : "Ознака није могла да се креира",
+    "Updated tag" : "Ажурирана ознака",
+    "Failed to update tag" : "Није успело ажурирање ознаке",
+    "Deleted tag" : "Обрисана ознака",
+    "Failed to delete tag" : "Ознака није могла да се обрише",
     "Loading collaborative tags …" : "Учитавају се ознаке сарадње…",
     "Search or create collaborative tags" : "Претражите или креирајте ознаке за сарадњу",
-    "Collaborative tags …" : "Ознаке сарадње...",
     "No tags to select, type to create a new tag" : "Није изабрана ниједна ознака, куцајте да креирате нову ознаку",
     "Failed to load tags" : "Грешка при учитавању ознака",
     "Failed to load selected tags" : "Изабрана ознака није могла да се учита",
     "Failed to select tag" : "Ознака није могла да се изабере",
-    "Failed to create tag" : "Ознака није могла да се креира",
-    "Failed to delete tag" : "Ознака није могла да се обрише",
+    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Заједниче ознаке су доступне свим корисницима. Заштићене ознаке су доступне свим корисницима, али их они не могу додељивати. Невидљиве ознаке су за интерну употребу, пошто их корисници не могу ни видети ни додељивати.",
     "This file has the tag {tag}" : "Овај фајл има ознаку {tag}",
     "This file has the tags {firstTags} and {lastTag}" : "Овај фајл има ознаке {firstTags} и {lastTag}",
     "List of tags and their associated files and folders." : "Листа ознака и њима придружени фајлови и директоријуми.",
@@ -64,23 +78,22 @@ OC.L10N.register(
     "Tags you have created will show up here." : "Овде ће се појавити ознаке које сте креирали.",
     "Failed to load last used tags" : "Последње коришћена ознака није могла да се учита",
     "Missing \"Content-Location\" header" : "Недостаје Content-Location” заглавље",
-    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Заједниче ознаке су доступне свим корисницима. Заштићене ознаке су доступне свим корисницима, али их они не могу додељивати. Невидљиве ознаке су за интерну употребу, пошто их корисници не могу ни видети ни додељивати.",
-    "Create a new tag" : "Направи нову ознаку",
-    "Tag name" : "Назив ознаке",
-    "Name" : "Назив",
-    "Tag level" : "Ниво ознаке",
-    "Public" : "Јавна",
-    "Restricted" : "Ограничена",
-    "Invisible" : "Невидљива",
-    "Delete" : "Обриши",
-    "Reset" : "Ресетуј",
-    "No files in here" : "Овде нема фајлова",
-    "No entries found in this folder" : "Нема ничега у овој фасцикли",
-    "Size" : "Величина",
-    "Modified" : "Измењен",
+    "Failed to load tags for file" : "Није успело учитавање ознака за фајл",
+    "Failed to set tag for file" : "Није успело постављање ознака за фајл",
+    "Failed to delete tag for file" : "Није успело брисање ознака за фајл",
+    "Tag name is empty" : "Име ознаке је празно",
+    "Select tag …" : "Одаберите ознаку …",
+    "Collaborative tagging functionality which shares tags among users." : "Могућност заједничког означавања којим се деле ознаке међу корисницима.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Могућност заједничког означавања којим се деле ознаке међу корисницима. Сјајно за тимове.\n\t(ако сте провајдер инсталације за одвојене кориснике/предузећа, саветује се да иксључите ову апликацију пошто су ознаке дељене.)",
     "Tagged files" : "Означени фајлови",
     "Select tags to filter by" : "Одаберите ознаке по којима да се филтрира",
     "Please select tags to filter by" : "Одаберите ознаке по којима да се филтрира",
-    "No files found for the selected tags" : "Ниједан фајл није нађен за одабране ознаке"
+    "No files found for the selected tags" : "Ниједан фајл није нађен за одабране ознаке",
+    "Create a new tag" : "Направи нову ознаку",
+    "Name" : "Назив",
+    "No files in here" : "Овде нема фајлова",
+    "No entries found in this folder" : "Нема ничега у овој фасцикли",
+    "Size" : "Величина",
+    "Modified" : "Измењен"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
