@@ -4,10 +4,13 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "আপলোড করা ফাইলটি  HTML  ফর্মে উল্লিখিত MAX_FILE_SIZE নির্ধারিত ফাইলের সর্বোচ্চ আকার  অতিক্রম করতে চলেছে ",
     "No file was uploaded" : "কোন ফাইল আপলোড করা হয় নি",
     "Missing a temporary folder" : "অস্থায়ী ফোল্ডারটি হারানো গিয়েছে",
+    "Translate" : "Translate",
     "guest" : "অতিথি",
     "Saved" : "সংরক্ষণ করা হলো",
     "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
-    "Translate" : "Translate",
+    "Cancel" : "বাতিল করুন",
+    "URL" : "URL",
+    "to" : "প্রতি",
     "Info" : "Info",
     "Warning" : "সতর্কবাণী",
     "Edit" : "সম্পাদনা"
