@@ -4,10 +4,14 @@ OC.L10N.register(
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Mae'r ffeil lwythwyd i fyny'n fwy na chyfarwyddeb MAX_FILE_SIZE bennwyd yn y ffurflen HTML",
     "No file was uploaded" : "Ni lwythwyd ffeil i fyny",
     "Missing a temporary folder" : "Plygell dros dro yn eisiau",
+    "Translate" : "Cyfieithu",
     "Saved" : "Wedi'u cadw",
     "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
     "Bold" : "Trwm",
     "Italic" : "Italig",
+    "URL" : "URL",
+    "to" : "at",
+    "Source code" : "Cod ffynhonnell",
     "Undo" : "Dadwneud",
     "Info" : "Info",
     "Warning" : "Rhybudd",
