@@ -10,7 +10,9 @@ OC.L10N.register(
     "Could not write file to disk" : "Cha b’ urrainn dhuinn am faidhle a sgrìobhadh dhan diosg",
     "A PHP extension stopped the file upload" : "Chur leudachan PHP stad air luchdadh suas an fhaidhle",
     "Translate" : "Eadar-theangaich",
+    "Cancel" : "Sguir dheth",
     "Replace" : "Cuir ’na àite",
+    "Source code" : "Bun-tùs",
     "Undo" : "Neo-dhèan",
     "Edit" : "Deasaich"
 },
