@@ -87,9 +87,13 @@ OC.L10N.register(
     "Quoted text" : "Tilvitnaður texti",
     "Code block" : "Kóðablokk",
     "Some code" : "Einhver kóði",
+    "Remove link" : "Fjarlægja tengil",
+    "Cancel" : "Hætta við",
+    "URL" : "Slóð",
+    "Cannot copy, please copy the link manually" : "Mistókst að afrita, afritaðu tengilinn handvirkt",
+    "Copy link to clipboard" : "Afrita tengil á klippispjald",
     "Upload from computer" : "Senda inn úr tölvunni",
     "Insert from Files" : "Setja inn úr skrám",
-    "Remove link" : "Fjarlægja tengil",
     "Link to file or folder" : "Tengill á skrá eða möppu",
     "Link to website" : "Tengill á vefsvæði",
     "Update link" : "Uppfæra tengil",
