@@ -16,6 +16,7 @@ OC.L10N.register(
     "text document" : "テキストドキュメント",
     "{user} has mentioned you in the text document {node}" : "{user} が、テキストファイル {} であなたに言及しました",
     "This file cannot be displayed as download is disabled by the share" : "このファイルは共有者によってダウンロードが制限されており、表示できません",
+    "No permission to access this file." : "権限がないため、このファイルにアクセスできません。",
     "Readme" : "Readme",
     "Text" : "テキスト",
     "📝 Collaborative document editing" : "📝 共同文書編集",
@@ -91,14 +92,21 @@ OC.L10N.register(
     "Quoted text" : "引用された文字",
     "Code block" : "コードブロック",
     "Some code" : "何かコード",
+    "Edit link" : "リンクを編集",
+    "Save changes" : "変更を保存",
+    "Remove link" : "リンクを削除",
+    "Cancel" : "キャンセル",
+    "URL" : "URL",
+    "Cannot copy, please copy the link manually" : "コピーできませんでした。手動でリンクをコピーしてください。",
+    "Copy link to clipboard" : "リンクをクリップボードにコピーする",
     "Upload from computer" : "コンピュータからアップロード",
     "Insert from Files" : "アップロード済のファイルを挿入",
-    "Remove link" : "リンクを削除",
     "Link to file or folder" : "ファイルやフォルダーへのリンク",
     "Link to website" : "ウェブサイトへのリンク",
     "Update link" : "リンクの更新",
     "Open the Smart Picker" : "スマートピッカーを開く",
     "Select file or folder to link to" : "リンク先のファイルまたはフォルダを選択",
+    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\" が選択されました",
     "_%n word_::_%n words_" : ["%n語"],
     "_%n char_::_%n chars_" : ["%n文字"],
     "Editor actions" : "編集者のアクション",
@@ -108,6 +116,7 @@ OC.L10N.register(
     "Translate from" : "原文の言語",
     "Select language" : "言語を選択する",
     "to" : "訳文の言語",
+    "Translated text result" : "テキスト翻訳の結果",
     "Replace" : "入れ替え",
     "Insert" : "挿入する",
     "Detect language" : "言語を検出する",
@@ -118,6 +127,8 @@ OC.L10N.register(
     "No command found" : "コマンドが見つかりません",
     "No user found" : "ユーザーが見つかりません",
     "No suggestion found" : "提案が見つかりません",
+    "Copy code block" : "コードブロックをコピー",
+    "Copy code" : "コピーコード",
     "Code block options" : "コードブロックの選択",
     "Code block language" : "コードブロックの言語",
     "e.g. php, javascript, json…" : "例えば php, javascript, json等･･･",
@@ -170,6 +181,8 @@ OC.L10N.register(
     "Add description" : "説明を追加",
     "\"{name}\" already exist!" : "\"{name}\" は既に存在します",
     "Created \"{name}\"" : "\"{name}\" を作成しました",
+    "Copied to the clipboard" : "クリップボードにコピーされました",
+    "Could not copy to the clipboard" : "クリップボードにコピーできませんでした",
     "Front matter" : "Front matter",
     "Source language" : "原文の言語",
     "Target language" : "訳文の言語",
