@@ -14,6 +14,9 @@ OC.L10N.register(
     "Unsaved changes" : "შეუნახავი ცვლილებები",
     "Formatting help" : "დახმარება ფორმატირებაზე",
     "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
+    "Save changes" : "ცვილებების შენახვა",
+    "Cancel" : "გაუქმება",
+    "URL" : "URL",
     "Select language" : "აირჩიეთ ენა",
     "to" : "ვის",
     "Replace" : "ჩანაცვლება",
