@@ -49,6 +49,13 @@ OC.L10N.register(
     "Heading level 1" : "제목 단계 1",
     "Heading 6" : "제목 6",
     "Heading level 6" : "제목 단계 6",
+    "Quoted text" : "인용문",
+    "Edit link" : "링크 수정",
+    "Save changes" : "설정 저장",
+    "Cancel" : "취소",
+    "URL" : "URL",
+    "Cannot copy, please copy the link manually" : "복사할 수 없습니다, 링크를 수동으로 복사하세요.",
+    "Open the Smart Picker" : "스마트 피커 열기",
     "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
     "_%n word_::_%n words_" : ["%n개 단어"],
     "_%n char_::_%n chars_" : ["%n개 글자"],
@@ -56,6 +63,10 @@ OC.L10N.register(
     "Select language" : "언어 선택",
     "to" : "에서",
     "Replace" : "바꾸기",
+    "Insert" : "삽입",
+    "Detect language" : "언어 감지",
+    "Translation failed" : "번역 실패",
+    "Copy code block" : "코드 블록 복사",
     "Source code" : "소스 코드",
     "Hide outline" : "개요 숨기기",
     "Show outline" : "개요 보이기",
@@ -72,6 +83,7 @@ OC.L10N.register(
     "Command" : "명령",
     "Control" : "제어:",
     "Formatting" : "서식",
+    "Smart picker" : "스마트 피커",
     "Edit" : "편집",
     "Unsupported image type" : "지원하지 않는 사진 형식"
 },
