@@ -23,6 +23,9 @@ OC.L10N.register(
     "Formatting help" : "Ajutor pentru formatare",
     "Keyboard shortcuts" : "Scurtături din tastatură",
     "Quoted text" : "Text citat",
+    "Edit link" : "Editare link",
+    "Cancel" : "Anulare",
+    "URL" : "URL",
     "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
     "to" : "către",
     "Replace" : "Înlocuiește",
