@@ -16,6 +16,7 @@ OC.L10N.register(
     "text document" : "文字文件",
     "{user} has mentioned you in the text document {node}" : "{user} 在  {node} 的文字文件中提到了您",
     "This file cannot be displayed as download is disabled by the share" : "此檔案無法顯示，因為共享已禁用下載",
+    "No permission to access this file." : "無權存取此檔案。",
     "Readme" : "說明",
     "Text" : "文字編輯器",
     "📝 Collaborative document editing" : "📝 協作文件編輯",
@@ -91,14 +92,21 @@ OC.L10N.register(
     "Quoted text" : "引用文字",
     "Code block" : "程式碼區塊",
     "Some code" : "一些代碼",
+    "Edit link" : "編輯連結",
+    "Save changes" : "保存更改",
+    "Remove link" : "移除連結",
+    "Cancel" : "取消",
+    "URL" : "URL",
+    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
+    "Copy link to clipboard" : "複製連結到剪貼板",
     "Upload from computer" : "從電腦上傳",
     "Insert from Files" : "從檔案插入",
-    "Remove link" : "移除連結",
     "Link to file or folder" : "連結至檔案或資料夾",
     "Link to website" : "連結至網站",
     "Update link" : "更新鏈接",
     "Open the Smart Picker" : "打開智能選擇器",
     "Select file or folder to link to" : "選擇要連結的檔案或資料夾",
+    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}，已選取「{selectedSubMenuItemName}」",
     "_%n word_::_%n words_" : ["%n 個單詞"],
     "_%n char_::_%n chars_" : ["%n 個字母"],
     "Editor actions" : "編輯器操作",
@@ -107,7 +115,9 @@ OC.L10N.register(
     "To translate individual parts of the text, select it before using the translate function." : "要翻譯部份文字，請在使用翻譯功能前選取該部份。",
     "Translate from" : "翻譯從",
     "Select language" : "選擇語言",
+    "Text to translate from" : "要翻譯的文字",
     "to" : "至",
+    "Translated text result" : "翻譯文字結果",
     "Replace" : "取代",
     "Insert" : "插入",
     "Detect language" : "檢測語言",
@@ -118,6 +128,8 @@ OC.L10N.register(
     "No command found" : "找不到命令",
     "No user found" : "找不到用戶",
     "No suggestion found" : "找不到建議",
+    "Copy code block" : "複製程式碼區塊",
+    "Copy code" : "複製代碼",
     "Code block options" : "程式碼區塊選項",
     "Code block language" : "程式碼區塊語言",
     "e.g. php, javascript, json…" : "例如 php、javascript、json ...",
@@ -129,7 +141,7 @@ OC.L10N.register(
     "Delete this attachment" : "刪除此附件",
     "Delete this image" : "刪除此圖像",
     "Failed to load" : "加載失敗",
-    "Unsupported image type" : "不支援的圖片類型",
+    "Could not find image in attachments list." : "在附件清單中找不到影像。",
     "Add row before" : "在前面添加行",
     "Add row after" : "在後面添加行",
     "Delete this row" : "刪除此行",
@@ -168,16 +180,15 @@ OC.L10N.register(
     "Add notes, lists or links …" : "加入筆記、清單或連結…",
     "Edit" : "編輯",
     "Add description" : "添加描述",
+    "\"{name}\" already exist!" : "「{name}」已存在！",
+    "Created \"{name}\"" : "已建立「{name}」",
+    "Copied to the clipboard" : "已複製到剪貼板",
+    "Could not copy to the clipboard" : "無法複製到剪貼簿",
     "Front matter" : "前言",
-    "Document save status" : "文件保存狀態",
-    "Update Link" : "更新連結",
-    "Add Link" : "添加連結",
-    "Link file" : "連結檔案",
-    "Remove Link" : "移除連結",
-    "Select file to link to" : "選擇要連結的檔案",
-    "Show rich workspaces" : "顯示較多功能的工作區",
     "Source language" : "本源語言",
     "Target language" : "目標語言",
+    "Unsupported image type" : "不支援的圖片類型",
+    "Show rich workspaces" : "顯示較多功能的工作區",
     "e.g. php, javascript, json, ..." : "例如：php、javascript、json 等"
 },
 "nplurals=1; plural=0;");
