@@ -91,8 +91,9 @@ class ApiService {
 			} elseif ($fileId) {
 				try {
 					$file = $this->documentService->getFileById($fileId);
-				} catch (NotFoundException $e) {
-					return new DataResponse([], Http::STATUS_NOT_FOUND);
+				} catch (NotFoundException|NotPermittedException $e) {
+					$this->logger->error('No permission to access this file', [ 'exception' => $e ]);
+					return new DataResponse($this->l10n->t('No permission to access this file.'), Http::STATUS_NOT_FOUND);
 				}
 			} else {
 				return new DataResponse('No valid file argument provided', Http::STATUS_PRECONDITION_FAILED);
