@@ -24,8 +24,6 @@ OC.L10N.register(
     "Could not write file to disk" : "لم يستطع كتابة ملف للقرص",
     "A PHP extension stopped the file upload" : "اضافة البي اچ بي PHP اوقفت رفع الملف",
     "No file uploaded" : "لم يتم رفع الملف",
-    "Failed to clean up the old administration theming images folder" : "إخفاق في تنظيف مجلد صور ثيمات الإدارة القديمة",
-    "Failed to clean up the old administration image folder" : "إخفاق في تنظيف مجلد صور الإدارة القديمة",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "أنت تستخدم الآن ثيمة مُخصّصة. إعدادات تطبيق الثيمات يُمكن أن يتم الكتابة عليها بسبب ذلك. ",
     "Theming" : "تخصيص القالب",
     "Appearance and accessibility" : "المظهر appearance، و سهولة الوصول accessibility",
@@ -109,9 +107,11 @@ OC.L10N.register(
     "Default app priority" : "أسبقية التطبيق التلقائي",
     "If an app is not enabled for a user, the next app with lower priority is used." : "إذا لم يكن التطبيق مخوَّلاً للمستخدِم، فإن التطبيق التالي في الأسبقية سيقع استعماله.",
     "Could not set global default apps" : "تعذّر تعيين التطبيقات التلقائية العامة",
-    "Select a custom color" : "إختر لوناً مُخصّصاً",
     "Reset to default" : "اعادة تعيين الافتراضيات",
     "Upload" : "تحميل",
-    "Remove background image" : "إزالة صورة الخلفية"
+    "Remove background image" : "إزالة صورة الخلفية",
+    "Failed to clean up the old administration theming images folder" : "إخفاق في تنظيف مجلد صور ثيمات الإدارة القديمة",
+    "Failed to clean up the old administration image folder" : "إخفاق في تنظيف مجلد صور الإدارة القديمة",
+    "Select a custom color" : "إختر لوناً مُخصّصاً"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
