@@ -21,11 +21,10 @@ OC.L10N.register(
     "Could not write file to disk" : " Файлът не можа да бъде записан на диск",
     "A PHP extension stopped the file upload" : "PHP разширение спря качването на файла",
     "No file uploaded" : "Няма качен файл",
-    "Failed to clean up the old administration theming images folder" : "Неуспешно почистване на папка със стари изображения на администраторски теми",
-    "Failed to clean up the old administration image folder" : "Неуспешно почистване на старата папка с изображения на администратора",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Вече използвате персонализирана тема. Настройките на приложението за теми могат да бъдат презаписани от това.",
     "Theming" : "Теми",
     "Appearance and accessibility" : "Изглед и достъпност",
+    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP модулът \"imagick\" не е активиран, въпреки че приложението за теми е активирано. За да работи правилно генерирането на аватари тип favicon, трябва да инсталирате и активирате този модул.",
     "Dark theme with high contrast mode" : "Тъмна тема с режим на висок контраст",
     "Enable dark high contrast mode" : "Активиране на тъмен режим с висок контраст",
     "Similar to the high contrast mode, but with dark colours." : "Подобно на режима с висок контраст, но с тъмни цветове.",
@@ -84,9 +83,11 @@ OC.L10N.register(
     "No background" : "Без фон",
     "Select a background from your files" : "Избор на фон от вашите файлове",
     "Theme selection is enforced" : "Изборът на тема е приложен",
-    "Select a custom color" : "Избор на персонализиран цвят",
     "Reset to default" : "Настройки по подразбиране",
     "Upload" : "Качване",
-    "Remove background image" : "Премахни фоновото изображение"
+    "Remove background image" : "Премахни фоновото изображение",
+    "Failed to clean up the old administration theming images folder" : "Неуспешно почистване на папка със стари изображения на администраторски теми",
+    "Failed to clean up the old administration image folder" : "Неуспешно почистване на старата папка с изображения на администратора",
+    "Select a custom color" : "Избор на персонализиран цвят"
 },
 "nplurals=2; plural=(n != 1);");
