@@ -24,11 +24,12 @@ OC.L10N.register(
     "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
     "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
     "No file uploaded" : "Keine Datei hochgeladen",
-    "Failed to clean up the old administration theming images folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
-    "Failed to clean up the old administration image folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sie benutzen bereits ein benutzerdefiniertes Design. Die App \"Theming\" würde dies überschreiben.",
     "Theming" : "Design",
     "Appearance and accessibility" : "Aussehen und Barrierefreiheit",
+    "PHP Imagick module" : "PHP Imagick-Modul",
+    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Das PHP-Modul \"imagick\" ist nicht aktiviert, die Theming-App hingegen schon. Damit die Favicon-Generierung korrekt funktioniert, müssen Sie dieses Modul installieren und aktivieren.",
+    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Das PHP-Modul \"imagick\" in dieser Instanz hat keine SVG-Unterstützung. Für eine bessere Kompatibilität empfiehlt es sich, es zu installieren.",
     "Dark theme with high contrast mode" : "Dunkles Design mit hohem Kontrastmodus",
     "Enable dark high contrast mode" : "Kontrastreichen Modus aktivieren",
     "Similar to the high contrast mode, but with dark colours." : "Ähnlich wie der Hochkontrastmodus, aber mit dunklen Farben.",
@@ -71,6 +72,7 @@ OC.L10N.register(
     "User settings" : "Benutzer-Einstellungen",
     "Disable user theming" : "Benutzer-Design deaktivieren",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Trotz der von Ihnen vorgenommenen Auswahl und Anpassung, können Benutzer ihren Hintergrund und ihre Farben ändern. Wenn Sie Ihre Anpassung erzwingen möchten, können Sie dies hier aktivieren.",
+    "Appearance and accessibility settings" : "Aussehen- und Barrierefreiheitseinstellungen",
     "Background" : "Hintergrund",
     "Customization has been disabled by your administrator" : "Diese Anpassungsmöglichkeit wurde von Ihrer Administration deaktiviert",
     "Set a custom background" : "Einen benutzerdefinierten Hintergrund setzen",
@@ -105,9 +107,11 @@ OC.L10N.register(
     "Default app priority" : "Standard-App-Priorität",
     "If an app is not enabled for a user, the next app with lower priority is used." : "Wenn eine App für einen Benutzer nicht aktiviert ist, wird die nächste App mit niedrigerer Priorität verwendet.",
     "Could not set global default apps" : "Globale Standard-Apps konnten nicht festgelegt werden",
-    "Select a custom color" : "Eine benutzerdefinierte Farbe auswählen",
     "Reset to default" : " Auf Standard zurücksetzen ",
     "Upload" : "Hochladen",
-    "Remove background image" : "Hintergrundbild entfernen"
+    "Remove background image" : "Hintergrundbild entfernen",
+    "Failed to clean up the old administration theming images folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
+    "Failed to clean up the old administration image folder" : "Fehler beim Bereinigen des alten Admin-Design-Bilderordners",
+    "Select a custom color" : "Eine benutzerdefinierte Farbe auswählen"
 },
 "nplurals=2; plural=(n != 1);");
