@@ -21,11 +21,10 @@ OC.L10N.register(
     "Could not write file to disk" : "نتوانست پرونده را روی دیسک بنویسد",
     "A PHP extension stopped the file upload" : "یک افزونهٔ پی‌اچ‌پی بارگذاری پرونده را متوقّف کرد",
     "No file uploaded" : "هیچ پرونده‌ای بارگذاری نشد",
-    "Failed to clean up the old administration theming images folder" : "Failed to clean up the old administration theming images folder",
-    "Failed to clean up the old administration image folder" : "Failed to clean up the old administration image folder",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "هم‌اکنون در حال استفاده از یک زمینهٔ شخصی هستید. ممکن است تنظمیات کارهٔ زمینش به دستش پایکال شوند.",
     "Theming" : "زمینش",
     "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
+    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
     "Dark theme with high contrast mode" : "زمینهٔ تیره با حالت سایه‌روشن بالا",
     "Enable dark high contrast mode" : "به کار انداختن حالت سایه‌روشن تاریک",
     "Similar to the high contrast mode, but with dark colours." : "شبیه حالت سایه‌روشن بالا، ولی با رنگ‌های تیره",
@@ -76,32 +75,19 @@ OC.L10N.register(
     "Disable all keyboard shortcuts" : "از کار انداختن تمامی میان‌برهای صفحه‌کلید",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "دسترسی جهانی برای ما بسیار مهم است. ما از استانداردهای وب پیروی می‌کنیم و دقیت می‌کنیم تا همه چیز بدون موش‌واره و نرم‌افزارهای کمکی مانند صفحه‌خوان‌ها نیز قابل استفاده باشند. هدف ما این است که مطابق با دستورالعمل {guidelines}راهنماهای دسترس‌پذیری محتوا تحت وب{linkend} نسخه 2.1 در سطح AA، و حتی با زمینه کنتراست بالا در سطح AAA باشیم.",
     "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!",
+    "Move up" : "Move up",
+    "Move down" : "حرکت به پایین",
     "Custom background" : "Custom background",
     "Default background" : "Default background",
     "Change color" : "تغییر رنگ",
     "No background" : "No background",
     "Select a background from your files" : "Select a background from your files",
     "Theme selection is enforced" : "گزینش زمینه اجباری است",
-    "Select a custom color" : "گزینش رنگی شخصی",
     "Reset to default" : "بازنشانی به پیش‌گزیده",
     "Upload" : "بارگذاری",
     "Remove background image" : "برداشتن تصویر پس‌زمینه",
-    "Loading preview…" : "بار کردن پیش‌نمایش…",
-    "Admin" : "مدیر",
-    "Error uploading the file" : "خطا در بارگذاری پرونده",
-    "Name cannot be empty" : "نام نمی‌تواند خالی باشد",
-    "Migrate and clean up admin theming images" : "Migrate and clean up admin theming images",
-    "Failed to clean up the old admin theming images folder" : "Failed to clean up the old admin theming images folder",
-    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps.",
-    "Pick from Files" : "گزینش از پرونده‌ها",
-    "Default image" : "تصویر پیش‌گزیده",
-    "Custom color" : "رنگ سفارشی",
-    "Plain background" : "پس‌زمینهٔ ساده",
-    "Insert from {productName}" : "درج از {productName}",
-    "Open documentation" : "گشودن مستندات",
-    "https://…" : "https://…",
-    "Upload new login background" : "بارگذاری تصویر ورود جدید",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box.",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color."
+    "Failed to clean up the old administration theming images folder" : "Failed to clean up the old administration theming images folder",
+    "Failed to clean up the old administration image folder" : "Failed to clean up the old administration image folder",
+    "Select a custom color" : "گزینش رنگی شخصی"
 },
 "nplurals=2; plural=(n > 1);");
