@@ -24,11 +24,12 @@ OC.L10N.register(
     "Could not write file to disk" : "Impossible d'écrire le fichier sur le disque",
     "A PHP extension stopped the file upload" : "Une extension PHP a arrêté le téléversement du fichier",
     "No file uploaded" : "Aucun fichier téléversé",
-    "Failed to clean up the old administration theming images folder" : "Échec du nettoyage du dossier d'images de l'ancien thème d'administration",
-    "Failed to clean up the old administration image folder" : "Échec du nettoyage de l'ancien dossier d'images d'administration",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Vous utilisez déjà un thème personnalisé. Les paramètres de l'application Theming peuvent être remplacés par ceux-ci.",
     "Theming" : "Personnaliser l'apparence",
     "Appearance and accessibility" : "Apparence et accessibilité",
+    "PHP Imagick module" : "Module PHP Imagick",
+    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Le module PHP \"imagick\" n'est pas actif mais l'application Theming est activée. Pour que la génération du Favicon fonctionne correctement, ce module doit être installé et actif.",
+    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Le module PHP « imagick » n’a aucun support SVG dans cette instance. Pour une meilleure compatibilité, il est recommandé de l’installer.",
     "Dark theme with high contrast mode" : "Thème sombre avec mode de contraste élevé",
     "Enable dark high contrast mode" : "Activer le mode sombre à contraste élevé",
     "Similar to the high contrast mode, but with dark colours." : "Similaire au mode de contraste élevé, mais avec des couleurs sombres.",
@@ -71,6 +72,7 @@ OC.L10N.register(
     "User settings" : "Paramètres utilisateurs",
     "Disable user theming" : "Désactiver la gestion du thème par l'utilisateur",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Bien que vous puissiez sélectionner et personnaliser votre instance, les utilisateurs peuvent modifier leur arrière-plan et leurs couleurs. Si vous voulez imposer votre personnalisation, vous pouvez activer cette option.",
+    "Appearance and accessibility settings" : "Paramètres d'apparence et d'accessibilité",
     "Background" : "Arrière-plan",
     "Customization has been disabled by your administrator" : "La personnalisation a été désactivée par votre administrateur",
     "Set a custom background" : "Définir un arrière-plan personnalisé",
@@ -105,9 +107,11 @@ OC.L10N.register(
     "Default app priority" : "Priorité de l'application par défaut",
     "If an app is not enabled for a user, the next app with lower priority is used." : "Si une application n'est pas activée pour un utilisateur, l'application suivante avec une priorité plus basse sera utilisée.",
     "Could not set global default apps" : "Impossible de définir les applications globales par défaut",
-    "Select a custom color" : "Sélectionnez une couleur personnalisée",
     "Reset to default" : "Restaurer les valeurs par défaut",
     "Upload" : "Téléverser",
-    "Remove background image" : "Retirer l'image d'arrière-plan"
+    "Remove background image" : "Retirer l'image d'arrière-plan",
+    "Failed to clean up the old administration theming images folder" : "Échec du nettoyage du dossier d'images de l'ancien thème d'administration",
+    "Failed to clean up the old administration image folder" : "Échec du nettoyage de l'ancien dossier d'images d'administration",
+    "Select a custom color" : "Sélectionnez une couleur personnalisée"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
