@@ -12,6 +12,8 @@ OC.L10N.register(
     "The given color is invalid" : "無効な色です",
     "Disable-user-theming should be true or false" : "Disable-user-themingは、trueまたはfalseで指定してください",
     "Saved" : "保存済み",
+    "Invalid app given" : "無効なアプリが指定されました",
+    "Invalid setting key" : "無効な設定キー",
     "The file was uploaded" : "ファイルがアップロードされました",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "アップロードファイルサイズが、php.ini の upload_max_filesize を超過しています",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "アップロードファイルはHTMLフォームで指定された MAX_FILE_SIZE の制限を超えています",
@@ -24,6 +26,7 @@ OC.L10N.register(
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "あなたはすでにカスタムテーマを使用しています。 テーマ設定の設定が上書きされる可能性があります。",
     "Theming" : "テーマ",
     "Appearance and accessibility" : "外観とアクセシビリティ",
+    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "テーマ別アプリは有効ですが、PHPモジュール「imagick」が有効ではありません。ファビコン生成を正しく行うには、このモジュールをインストールし、有効化する必要があります。",
     "Dark theme with high contrast mode" : "ハイコントラストモードのダークテーマ",
     "Enable dark high contrast mode" : "ハイコントラストモードのダークテーマを有効化",
     "Similar to the high contrast mode, but with dark colours." : "暗い色調でのハイコントラストモード",
@@ -74,28 +77,37 @@ OC.L10N.register(
     "Disable all keyboard shortcuts" : "全てのキーボードショートカットを無効化",
     "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "ユニバーサルアクセスは私たちにとって非常に重要なことです。そのためウェブ標準に従い、マウスやスクリーンリーダーなどの支援ソフトウェアが無くても全ての機能をご利用いただけるようにチェックしています。AAAレベルのハイコントラストのテーマを採用することで、{guidelines} Webコンテンツアクセシビリティガイドライン2.1  {linkend} のAAAレベルに準拠することを目指しています。",
     "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "何か問題を見つけた場合は、{issuetracker}私たちの問題トラッカー{linkend}で遠慮なく報告してください。参加したい場合は、{designteam}私たちのデザイン チーム{linkend}に参加してください!",
+    "Current selected app: {app}, position {position} of {total}" : "現在の選択済みアプリ: {app}、{total} の {position} 番目",
     "Move up" : "上に移動",
     "Move down" : "下に移動",
+    "Custom background" : "カスタム背景",
+    "Default background" : "デフォルト背景",
     "Change color" : "色を変える",
+    "No background" : "背景なし",
+    "Select a background from your files" : "あなたのファイルから背景を選択する",
+    "Select background" : "背景を選択する",
+    "No background has been selected" : "選択済みの背景はありません",
     "Theme selection is enforced" : "テーマ選択を強制",
-    "Select a custom color" : "カスタムカラーを選択",
+    "Navigation bar settings" : "ナビゲーションバーの設定",
+    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "アプリのナビゲーションバーで使用されるアプリの順序を設定できます。最初のエントリは、ログイン後またはロゴをクリックしたときに開かれるデフォルトのアプリになります。",
+    "The default app can not be changed because it was configured by the administrator." : "デフォルトのアプリは、管理者によって設定されたため変更できません。",
+    "The app order was changed, to see it in action you have to reload the page." : "アプリの順番が変更されました。それを実際に見るには、ページをリロードする必要があります。",
+    "Reset default app order" : "デフォルトのアプリの順序をリセットする",
+    "Could not set the app order" : "アプリの順番を設定できませんでした",
+    "Could not reset the app order" : "アプリの順番をリセットできませんでした",
+    "Default app" : "デフォルトアプリ",
+    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "デフォルトのアプリは、ログイン後やメニューのロゴをクリックした後に開かれるアプリです。",
+    "Use custom default app" : "カスタムデフォルトアプリを使用する",
+    "Global default app" : "Global default app",
+    "Global default apps" : "Global default apps",
+    "Default app priority" : "デフォルトアプリの優先順位",
+    "If an app is not enabled for a user, the next app with lower priority is used." : "あるアプリがユーザーに対して有効になっていない場合、次の優先順位のアプリが使用されます。",
+    "Could not set global default apps" : "グローバルなデフォルトアプリを設定できなかった",
     "Reset to default" : "デフォルトに戻す",
     "Upload" : "アップロード",
     "Remove background image" : "背景画像を削除",
-    "Loading preview…" : "プレビューを読み込み中...",
-    "Admin" : "管理者",
-    "Error uploading the file" : "ファイルのアップロードエラー",
-    "Name cannot be empty" : "名前は空にできません",
-    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "場合によっては、キーボードショートカットがアクセシビリティツールに干渉することがあります。ツールに正しくフォーカスできるようにするために、ここですべてのキーボード ショートカットを無効にできます。この場合、アプリで使用可能なすべてのショートカットも無効になります。",
-    "Pick from Files" : "ファイルから選択",
-    "Default image" : "デフォルト背景",
-    "Custom color" : "カスタム色",
-    "Plain background" : "シンプルな背景",
-    "Insert from {productName}" : "{productName} から挿入",
-    "Open documentation" : "ドキュメントを開く",
-    "https://…" : "https://…",
-    "Upload new login background" : "新しいログイン背景画像をアップロード",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "このサーバーの外観のカスタマイズと画像を変更を変更できますが、さらにユーザーは背景と色を変更できます。外観のカスタマイズを強制する場合は以下のチェック設定をオンにしてください。",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "アップロードしたロゴと色に基づいてfaviconを自動的に生成するには、SVG画像をサポートしているimagemagick PHP拡張をインストールしてください。"
+    "Failed to clean up the old administration theming images folder" : "古い管理テーマ画像フォルダのクリーンアップに失敗しました",
+    "Failed to clean up the old administration image folder" : "古い管理画像フォルダのクリーンアップに失敗しました",
+    "Select a custom color" : "カスタムカラーを選択"
 },
 "nplurals=1; plural=0;");
