@@ -21,11 +21,11 @@ OC.L10N.register(
     "Could not write file to disk" : "Невозможно записать файл на диск",
     "A PHP extension stopped the file upload" : "Расширение PHP прервало загрузку файла",
     "No file uploaded" : "Нет загруженных файлов",
-    "Failed to clean up the old administration theming images folder" : "Не удалось очистить старую папку с изображениями для администрирования тем",
-    "Failed to clean up the old administration image folder" : "Не удалось очистить старую папку с изображением для администрирования",
     "You are already using a custom theme. Theming app settings might be overwritten by that." : "Вы уже используете настраиваемое оформление, которое может быть перезаписано этим приложением.",
     "Theming" : "Внешний вид",
     "Appearance and accessibility" : "Внешний вид и доступность",
+    "PHP Imagick module" : "PHP модуль Imagick",
+    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "Для создания значка favicon приложением «Оформления» необходимо установить и активировать модуль «imagic» подсистемы PHP. ",
     "Dark theme with high contrast mode" : "Темная тема с режимом высокой контрастности",
     "Enable dark high contrast mode" : "Включить темную тему в режиме высокой контрастности",
     "Similar to the high contrast mode, but with dark colours." : "Аналогично режиму высокой контрастности, но с использованием темных цветов.",
@@ -68,6 +68,7 @@ OC.L10N.register(
     "User settings" : "Параметры пользователя",
     "Disable user theming" : "Отключить выбор темы для пользователей",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Хотя вы можете выбрать и настроить свой экземпляр, пользователи могут изменять свой фон и цвета. Если вы хотите принудительно применить свои настройки для всех, вы можете включить это.",
+    "Appearance and accessibility settings" : "Внешний вид и доступность",
     "Background" : "Фон",
     "Customization has been disabled by your administrator" : "Настройка тем была отключена вашим администратором",
     "Set a custom background" : "Установить пользовательский фон",
@@ -86,26 +87,19 @@ OC.L10N.register(
     "Select background" : "Выбрать фоновое изображение",
     "No background has been selected" : "Фоновое изображение не было выбрано",
     "Theme selection is enforced" : "Выбор темы принудительно",
-    "Select a custom color" : "Выберать собственный цвет",
+    "Navigation bar settings" : "Параметры панели навигации",
+    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Вы можете настроить порядок приложений в панели навигации. Первая запись будет приложением по умолчанию, и будет открываться после авторизации или при нажатии на логотип.",
+    "The default app can not be changed because it was configured by the administrator." : "Приложение по умолчанию не может быть изменено, поскольку оно настроено администратором.",
+    "The app order was changed, to see it in action you have to reload the page." : "Порядок приложений изменен, чтобы увидеть изменения необходимо перезагрузить страницу.",
+    "Reset default app order" : "Восстановить порядок приложений",
+    "Could not set the app order" : "Не удалось изменить порядок приложений",
+    "Could not reset the app order" : "Не удалось восстановить порядок приложений",
+    "Default app" : "Приложение по умолчанию",
     "Reset to default" : "Сбросить изменения",
     "Upload" : "Отправить",
     "Remove background image" : "Убрать фоновое изображение ",
-    "Loading preview…" : "Загружается предпросмотр…",
-    "Admin" : "Администратор",
-    "Error uploading the file" : "Ошибка при загрузке файла",
-    "Name cannot be empty" : "Имя не может быть пустым",
-    "Migrate and clean up admin theming images" : "Перенос и очистка изображений темы администратора",
-    "Failed to clean up the old admin theming images folder" : "Не удалось очистить старую папку с изображением для администрирования",
-    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "В некоторых случаях сочетания клавиш могут мешать работе инструментов специальных возможностей. Чтобы правильно сфокусироваться на вашем инструменте, вы можете отключить здесь все сочетания клавиш. Это также отключит все доступные ярлыки в приложениях.",
-    "Pick from Files" : "Выбрать из файлов",
-    "Default image" : "Изображение по умолчанию",
-    "Custom color" : "Свой цвет",
-    "Plain background" : "Обычный фон",
-    "Insert from {productName}" : "Вставить из {productName}",
-    "Open documentation" : "Открыть документацию",
-    "https://…" : "https://",
-    "Upload new login background" : "Загрузить новый фон для экрана входа в систему",
-    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Хотя вы можете выбрать и настроить свой экземпляр, пользователи могут изменять свой фон и цвета. Если вы хотите принудительно применить свою настройку для всех, вы можете включить это.",
-    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Для автоматической генерации favicon на основе загруженного логотипа и цвета нужно установить PHP расширение Imagemagick  с поддержкой изображений SVG "
+    "Failed to clean up the old administration theming images folder" : "Не удалось очистить старую папку с изображениями для администрирования тем",
+    "Failed to clean up the old administration image folder" : "Не удалось очистить старую папку с изображением для администрирования",
+    "Select a custom color" : "Выберать собственный цвет"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
