@@ -15,4 +15,4 @@ OC.L10N.register(
     "An error occurred while generating your backup codes" : "Se presentó un error al generar sus códigos de respaldo. ",
     "Submit" : "Enviar"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
