@@ -17,7 +17,7 @@ OC.L10N.register(
     "Apps missing compatible version" : "تفتقد التطبيقات إلى إصدار متوافق",
     "View in store" : "العرض على المتجر",
     "Apps with compatible version" : "تطبيقات بإصدار متوافق",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "لاحظ رجاءً أن مُحدّث الوب لا يُنصح به في حالة كان عدد مستخدميك أكثر من 100 شخص! استخدم المُحدّث عن طريق سطر الأوامر بدلاً عنه!",
+    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "يرجى ملاحظة أنه لا يوصى باستخدام أداة تحديث الويب مع أكثر من 100 حساب! الرجاء استخدام الأمر السطري للتحديث command line updater بدلاً من ذلك!",
     "Open updater" : "فتح المحدِّث",
     "Download now" : "حمل الآن",
     "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "مُحدِّث الوِب Web updater تمّ تعطيله. رجاءً، استعمل للتحديث الأمر السطري updater أو آلية تحديث مناسبة لطريقتك في التثبيت (مثل Docker pull).",
@@ -36,7 +36,7 @@ OC.L10N.register(
     "The selected update channel makes dedicated notifications for the server obsolete." : "قناة التحديث المحددة تجعل الإشعارات المخصصة للخادم قديمة.",
     "The selected update channel does not support updates of the server." : "قناة التحديث المحددة لا تدعم تحديثات الخادم.",
     "A new version is available: <strong>{newVersionString}</strong>" : "توجد نسخة جديدة: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "لاحظ أنه بعد الإصدار الجديد، لا يظهر التحديث إلاّ مع الإصدار الثانوي الأول أو بعده. بالرغ من من أنه يتم دوريّاً طرح إصدارات جديدة متعاقبة للنظام، فإنه يتم إحياناً إسقاط بعض الإصدارات إذا ما ظهرت فيها بعض الإشكالات. للمزيد حول التحديثات و قنوات الإصدار updates and release channels، أنظر: {link}",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "لاحظ أنه بعد كل إصدار جديد، لا يظهر التحديث إلا بعد الإصدار الثانوي الأول أو الأحدث. نحن نطرح إصدارات جديدة موزعة على مدار الوقت، و أحيانًا نتخطى إصدارًا عند اكتشاف مشكلات فيه. تعرّف على المزيد حول التحديثات وقنوات الإصدار على {link}",
     "Checked on {lastCheckedDate} - Open changelog" : "تمّ الفحص في {lastCheckedDate} - إفتَح سجل التغيير",
     "Checking apps for compatible versions" : "فحص التطبيقات من ناحية توافر أي إصدارات متوافقة",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "الرجاء التأكد أن ملف الconfig.php الخاص بك لا يعين قيمة <samp>appstoreenabled</samp> إلى false.",
@@ -49,9 +49,11 @@ OC.L10N.register(
     "Beta" : "تجريبي",
     "A pre-release version only for testing new features, not for production environments." : "نسخة تجريبية فقط لاختبار الميزات الجديدة ، وليس لبيئات الإنتاجية.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong>تطبيق  ليس له إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح.","<strong>%n</strong> من التطبيقات ليس لها إصدار متوافق مع إصدار نكست كلود المتاح."],
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "لاحظ رجاءً أن مُحدّث الوب لا يُنصح به في حالة كان عدد مستخدميك أكثر من 100 شخص! استخدم المُحدّث عن طريق سطر الأوامر بدلاً عنه!",
     "Please use the command line updater to update." : "رجاءً، للتحديث استخدم المُحدّث عن طريق سطر الأوامر.",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "يُمكنك تغيير قناة التحديث أدناه. و لاحظ أنها بدورها ستوثر في صفحة إدارة التطبيقات. مثال: بعد التحوّل إلى القناة باء، ستُعرض عليك تحديثات القناة باء في صفحة تحديث التطبيقات.",
     "Update channel:" : "قناة التحديث:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "لاحظ أنه بعد الإصدار الجديد، لا يظهر التحديث إلاّ مع الإصدار الثانوي الأول أو بعده. بالرغ من من أنه يتم دوريّاً طرح إصدارات جديدة متعاقبة للنظام، فإنه يتم إحياناً إسقاط بعض الإصدارات إذا ما ظهرت فيها بعض الإشكالات. للمزيد حول التحديثات و قنوات الإصدار updates and release channels، أنظر: {link}",
     "Checked on {lastCheckedDate}" : "فحص في {lastCheckedDate}"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
