@@ -17,7 +17,6 @@ OC.L10N.register(
     "Apps missing compatible version" : "Липсва съвместима версия на приложенията",
     "View in store" : "Преглед в магазина",
     "Apps with compatible version" : "Приложения със съвместима версия",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Моля, имайте предвид, че уеб актуализатора не се препоръчва за използване от повече от 100 потребители! Моля, вместо това използвайте програмата за актуализиране на командния ред!",
     "Open updater" : "Отвори актуализиращата програма",
     "Download now" : "Свали сега",
     "What's new?" : "Какви са промените?",
@@ -32,8 +31,6 @@ OC.L10N.register(
     "The selected update channel makes dedicated notifications for the server obsolete." : "Избрания канал за актуализации прави известията за този сървър остарели.",
     "The selected update channel does not support updates of the server." : "Избрания канал за актуализации не поддържа сървърни актуализации.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Налична е нова версия: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Забележете, че след нова версия, актуализацията се показва само след първата второстепенна версия или по-късно. Ние въвеждаме нови версии, разпределени във времето за нашите потребители и понякога пропускаме версия, когато бъдат открити проблеми. Научете повече за актуализациите и каналите за пускане на адрес {link}",
-    "Checked on {lastCheckedDate}" : "Проверено на {lastCheckedDate}",
     "Checking apps for compatible versions" : "Проверка на приложенията за съвместими версии",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Моля, уверете се, че в config.php не е зададено <samp>appstoreenabled</samp> на false.",
     "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Свързването с магазина за приложения App Store не е възможно или изобщо не са върнати актуализации. Търсете ръчно за актуализации или се уверете, че вашият сървър има достъп до интернет и може да се свърже с App Store.",
@@ -45,8 +42,11 @@ OC.L10N.register(
     "Beta" : "Бета",
     "A pre-release version only for testing new features, not for production environments." : "Версия само за тестване на нови функционалности, която не е подходяща за ползване в производствена среда.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> приложения нямат налична съвместима версия за тази версия на Nextcloud.","<strong>%n</strong> от приложенията нямат налична съвместима версия за тази версия на Nextcloud."],
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Моля, имайте предвид, че уеб актуализатора не се препоръчва за използване от повече от 100 потребители! Моля, вместо това използвайте програмата за актуализиране на командния ред!",
     "Please use the command line updater to update." : "Моля, използвайте програмата за актуализиране на командния ред, за да актуализирате.",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Можете да промените канала за актуализиране по-долу, който също засяга страницата за управление на приложения. Например, след като преминете към бета канала, актуализациите на бета приложенията ще ви бъдат предложени в страницата за управление на приложенията.",
-    "Update channel:" : "Канал за актуализиране:"
+    "Update channel:" : "Канал за актуализиране:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Забележете, че след нова версия, актуализацията се показва само след първата второстепенна версия или по-късно. Ние въвеждаме нови версии, разпределени във времето за нашите потребители и понякога пропускаме версия, когато бъдат открити проблеми. Научете повече за актуализациите и каналите за пускане на адрес {link}",
+    "Checked on {lastCheckedDate}" : "Проверено на {lastCheckedDate}"
 },
 "nplurals=2; plural=(n != 1);");
