@@ -17,10 +17,9 @@ OC.L10N.register(
     "Apps missing compatible version" : "Für diese Apps fehlen kompatible Versionen",
     "View in store" : "Im Store anzeigen",
     "Apps with compatible version" : "Für diese Apps gibt es kompatible Versionen",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Bitte beachte, dass der Web Updater bei mehr als 100 Benutzern nicht empfohlen wird! Bitte verwende stattdessen den Befehlszeilen-Updater!",
     "Open updater" : "Updater öffnen",
     "Download now" : "Jetzt herunterladen",
-    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Der Web-Updater ist deaktiviert. Bitte verwenden Sie zum Aktualisieren den Befehlszeilen-Updater oder den entsprechenden Update-Mechanismus für Ihre Installationsmethode (z. B. Docker pull).",
+    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Der Web-Updater ist deaktiviert. Bitte verwende zum Aktualisieren den Befehlszeilen-Updater oder den entsprechenden Update-Mechanismus für deine Installationsmethode (z. B. Docker pull).",
     "What's new?" : "Was ist neu?",
     "View changelog" : "Liste der Änderungen anschauen",
     "The update check is not yet finished. Please refresh the page." : "Die Aktualisierungsprüfung ist noch nicht abgeschlossen. Bitte die Seite neu laden.",
@@ -36,8 +35,6 @@ OC.L10N.register(
     "The selected update channel makes dedicated notifications for the server obsolete." : "Der gewählte Aktualisierungskanal macht dedizierte Benachrichtigungen für Server Aktualisierungen obsolet.",
     "The selected update channel does not support updates of the server." : "Der gewählte Aktualisierungskanal unterstützt keine Aktualisierungen für Server.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Eine neue Version ist verfügbar: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Beachte, dass das Update nach einer neuen Version erst nach der ersten Hauptversion oder später angezeigt wird. Die Nextcloud GmbH stellt den Benutzern im Laufe der Zeit neue Versionen zur Verfügung und überspringt manchmal eine Version, wenn Probleme auftreten. Weitere Informationen zu Updates und Release-Kanälen findest du unter {link}",
-    "Checked on {lastCheckedDate}" : "Geprüft am {lastCheckedDate}",
     "Checking apps for compatible versions" : "Es werden alle Apps auf kompatible Versionen geprüft",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bitte stelle sicher, dass in der \"config.php\"-Datei die Variable <samp>appstoreenabled</samp> nicht auf \"false\" steht.",
     "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Die Verbindung zum App-Store konnte nicht aufgebaut werden oder der App-Store hat keine Apps zurück geliefert. Suche selbst nach Updates oder stelle sicher, dass dein Server Zugriff auf das Internet hat und eine Verbindung zum App-Store aufbauen kann. ",
@@ -49,8 +46,11 @@ OC.L10N.register(
     "Beta" : "Beta",
     "A pre-release version only for testing new features, not for production environments." : "Eine Vorabversion die einzig zum Testen neuer Funktionen dient, nicht aber für den Einsatz in Produktivumgebungen geeignet ist.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Für <strong>%n</strong> App steht keine kompatible Version zur Verfügung.","Für <strong>%n</strong> Apps stehen keine kompatible Versionen zur Verfügung."],
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Bitte beachte, dass der Web Updater bei mehr als 100 Benutzern nicht empfohlen wird! Bitte verwende stattdessen den Befehlszeilen-Updater!",
     "Please use the command line updater to update." : "Verwende zum Aktualisieren den Befehlszeilen-Updater.",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Du kannst den Aktualisierungskanal unten ändern, was sich auch auf die Verwaltungsseite der Apps auswirkt. Z. B. werden nach dem Wechsel zum Beta-Kanal dir Beta-App-Updates auf der App-Verwaltungsseite angeboten.",
-    "Update channel:" : "Update-Kanal:"
+    "Update channel:" : "Update-Kanal:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Beachte, dass das Update nach einer neuen Version erst nach der ersten Hauptversion oder später angezeigt wird. Die Nextcloud GmbH stellt den Benutzern im Laufe der Zeit neue Versionen zur Verfügung und überspringt manchmal eine Version, wenn Probleme auftreten. Weitere Informationen zu Updates und Release-Kanälen findest du unter {link}",
+    "Checked on {lastCheckedDate}" : "Geprüft am {lastCheckedDate}"
 },
 "nplurals=2; plural=(n != 1);");
