@@ -17,7 +17,7 @@ OC.L10N.register(
     "Apps missing compatible version" : "Für diese Apps fehlen kompatible Versionen",
     "View in store" : "Im Store anzeigen",
     "Apps with compatible version" : "Für diese Apps gibt es kompatible Versionen",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Bitte beachten Sie, dass der Web Updater bei mehr als 100 Benutzern nicht empfohlen wird! Bitte verwenden Sie stattdessen den Befehlszeilen-Updater!",
+    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Bitte beachten Sie, dass der Web Updater bei mehr als 100 Konten nicht empfohlen wird! Bitte verwenden Sie stattdessen den Befehlszeilen-Updater!",
     "Open updater" : "Updater öffnen",
     "Download now" : "Jetzt herunterladen",
     "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "Der Web-Updater ist deaktiviert. Bitte verwenden Sie zum Aktualisieren den Befehlszeilen-Updater oder den entsprechenden Update-Mechanismus für Ihre Installationsmethode (z. B. Docker pull).",
@@ -33,11 +33,11 @@ OC.L10N.register(
     "Notify members of the following groups about available updates:" : "Informieren Sie die Mitglieder der folgenden Gruppen über verfügbare Updates:",
     "No groups" : "Keine Gruppen",
     "Only notifications for app updates are available." : "Benachrichtigungen sind nur für Aktualisierungen von Apps verfügbar.",
-    "The selected update channel makes dedicated notifications for the server obsolete." : "Der gewählte Aktualisierungskanal macht dedizierte Benachrichtigungen für Server Aktualisierungen obsolet.",
-    "The selected update channel does not support updates of the server." : "Der gewählte Aktualisierungskanal unterstützt keine Aktualisierungen für Server.",
+    "The selected update channel makes dedicated notifications for the server obsolete." : "Der gewählte Update-Kanal macht dedizierte Benachrichtigungen für Serveraktualisierungen obsolet.",
+    "The selected update channel does not support updates of the server." : "Der gewählte Update-Kanal unterstützt keine Aktualisierungen für Server.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Eine neue Version ist verfügbar: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Beachten Sie, dass die Aktualisierung nach einer neuen Version erst nach der ersten Unterversion (minor release) oder später angezeigt wird. Wir stellen unseren Benutzern im Laufe der Zeit neue Versionen zur Verfügung und überspringen manchmal eine Version, wenn Probleme auftreten. Weitere Informationen zu Aktualisierungen und Release-Kanälen finden Sie unter {link}",
-    "Checked on {lastCheckedDate}" : "Geprüft am {lastCheckedDate}",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Beachten Sie, dass die Aktualisierung für eine neue Version erst nach der ersten Unterversion (minor release) oder später angezeigt wird. Wir stellen im Laufe der Zeit neue Versionen zur Verfügung und überspringen manchmal eine Version, wenn Probleme auftreten. Weitere Informationen zu Update- und Release-Kanälen finden Sie unter {link}",
+    "Checked on {lastCheckedDate} - Open changelog" : "Geprüft am {lastCheckedDate} - Änderungsübersicht öffnen",
     "Checking apps for compatible versions" : "Es werden alle Apps auf kompatible Versionen geprüft",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bitte stellen Sie sicher, dass in der \"config.php\"-Datei die Variable <samp>appstoreenabled</samp>nicht auf \"false\" steht.",
     "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Es konnte keine Verbindung zum App-Store hergestellt werden oder es wurden keine Updates zurückgegeben. Suchen Sie manuell nach Updates oder stellen Sie sicher, dass Ihr Server Zugang zum Internet hat und eine Verbindung zum App-Store herstellen kann.",
@@ -49,8 +49,11 @@ OC.L10N.register(
     "Beta" : "Beta",
     "A pre-release version only for testing new features, not for production environments." : "Eine Vorabversion, die einzig zum Testen neuer Funktionen dient, nicht aber für den Einsatz in Produktivumgebungen geeignet ist.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Für <strong>%n</strong> App steht keine kompatible Version zur Verfügung.","Für <strong>%n</strong> Apps steht keine kompatible Version zur Verfügung."],
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Bitte beachten Sie, dass der Web Updater bei mehr als 100 Benutzern nicht empfohlen wird! Bitte verwenden Sie stattdessen den Befehlszeilen-Updater!",
     "Please use the command line updater to update." : "Verwenden Sie zum Aktualisieren den Befehlszeilen-Updater.",
-    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Sie können den Aktualisierungskanal unten ändern, was sich auch auf die Verwaltungsseite der Apps auswirkt. Z.B. Nach dem Wechsel zum Beta-Kanal werden Ihnen Beta-App-Updates auf der App-Verwaltungsseite angeboten.",
-    "Update channel:" : "Update-Kanal:"
+    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Sie können den Update-Kanal unten ändern, was sich auch auf die Verwaltungsseite der Apps auswirkt. Wenn Sie z. B. zum Beta-Kanal wechseln, werden Ihnen Beta-App-Updates auf der App-Verwaltungsseite angeboten.",
+    "Update channel:" : "Update-Kanal:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Beachten Sie, dass die Aktualisierung nach einer neuen Version erst nach der ersten Unterversion (minor release) oder später angezeigt wird. Wir stellen unseren Benutzern im Laufe der Zeit neue Versionen zur Verfügung und überspringen manchmal eine Version, wenn Probleme auftreten. Weitere Informationen zu Update- und Release-Kanälen finden Sie unter {link}",
+    "Checked on {lastCheckedDate}" : "Geprüft am {lastCheckedDate}"
 },
 "nplurals=2; plural=(n != 1);");
