@@ -17,10 +17,8 @@ OC.L10N.register(
     "Apps missing compatible version" : "Bertsio bateragarria falta duten aplikazioak",
     "View in store" : "Dendan ikusi",
     "Apps with compatible version" : "Bertsio bateragarria duten aplikazioak",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Kontuan izan web eguneratzailea ez dela gomendatzen 100 erabiltzaile baino gehiagorekin! Mesedez, erabili komando-lerroko eguneratzailea horren ordez!",
     "Open updater" : "Ireki eguneratzailea",
     "Download now" : "Deskargatu orain",
-    "Please use the command line updater to update." : "Mesedez, erabili komando-lerroko eguneratzailea eguneratzeko.",
     "What's new?" : "Zer berri?",
     "View changelog" : "Ikusi aldaketen egunkaria",
     "The update check is not yet finished. Please refresh the page." : "Egunareketen egiaztapena ez da oraindik bukatu. Mesedez freskatu orria.",
@@ -36,8 +34,6 @@ OC.L10N.register(
     "The selected update channel makes dedicated notifications for the server obsolete." : "Aukeratutako eguneraketa kanala zerbitzariaren jakinarazpen dedikatuak zaharkitzen ditu.",
     "The selected update channel does not support updates of the server." : "Hautatutako eguneraketa kanalak ez ditu zerbitzariaren eguneraketak onartzen.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Bertsio berri bat dago eskuragarri: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Kontuan izan bertsio berri baten ondoren eguneratzea lehen bertsio txikia edo geroago bakarrik agertzen dela. Denboran zehar tartekatuta zabaltzen ditugu bertsio berriak gure erabiltzaileentzat eta batzuetan bertsio bat saltatu egiten dugu, arazoak aurkitzen direnean. Lortu informazio gehiago eguneratzeei eta kanalak askatzeari buruz {link} helbidean ",
-    "Checked on {lastCheckedDate}" : "{lastCheckedDate}-n egiaztatuta",
     "Checking apps for compatible versions" : "Bertsio bateragarrientzat aplikaziorik dagoen egiaztatzen",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Ziurtatu config.php-k ez duela <samp> app store gaitua </samp>faltsu gisa ezartzen.",
     "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Ezin izan da appstore-arekin konektatu edo honek ez du eguneratzerik itzuli. Bilatu eskuz eguneratzeak edo ziurtatu zure zerbitzariak internet konexioa duela eta aplikazio biltegiarekin konektatu daitekeela.",
@@ -49,8 +45,11 @@ OC.L10N.register(
     "Beta" : "Beta",
     "A pre-release version only for testing new features, not for production environments." : "Argitaratu aurreko bertsioa funtzionalitate berriak probatzeko soilik da, ez ekoizpen inguruneetarako.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["Aplikazio <strong>%n</strong>ek ez du Nextcloud bertsio honetarako bertsio bateragarririk erabilgarri.","<strong>%n</strong>palikaziok ez dute Nextcloud bertsio honetarako bertsio bateragarririk erabilgarri."],
-    "Update for %1$s to version %2$s is available." : "%1$s(r)entzako %2$s bertsiora eguneratzea eskuragarri dago.",
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Kontuan izan web eguneratzailea ez dela gomendatzen 100 erabiltzaile baino gehiagorekin! Mesedez, erabili komando-lerroko eguneratzailea horren ordez!",
+    "Please use the command line updater to update." : "Mesedez, erabili komando-lerroko eguneratzailea eguneratzeko.",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Behean eguneratze-kanala alda dezakezu eta horrek aplikazioen kudeaketa-orrian ere eragiten du. Adib. beta kanalera aldatu ondoren, beta aplikazioen eguneraketak aplikazioen kudeaketa orrian eskainiko zaizkizu.",
-    "Update channel:" : "Eguneraketa kanala:"
+    "Update channel:" : "Eguneraketa kanala:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Kontuan izan bertsio berri baten ondoren eguneratzea lehen bertsio txikia edo geroago bakarrik agertzen dela. Denboran zehar tartekatuta zabaltzen ditugu bertsio berriak gure erabiltzaileentzat eta batzuetan bertsio bat saltatu egiten dugu, arazoak aurkitzen direnean. Lortu informazio gehiago eguneratzeei eta kanalak askatzeari buruz {link} helbidean ",
+    "Checked on {lastCheckedDate}" : "{lastCheckedDate}-n egiaztatuta"
 },
 "nplurals=2; plural=(n != 1);");
