@@ -17,10 +17,8 @@ OC.L10N.register(
     "Apps missing compatible version" : "Sovellukset, joista ei ole yhteensopivaa versiota",
     "View in store" : "Näytä kaupassa",
     "Apps with compatible version" : "Sovellukset, joista on yhteensopiva versio",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Huomioi, ettei päivitys selaimen kautta ole suositeltu yli 100 käyttäjän instansseissa! Tee sen sijaan päivitys komentoriviltä.",
     "Open updater" : "Avaa päivittäjä",
     "Download now" : "Lataa heti",
-    "Please use the command line updater to update." : "Käytä komentorivipäivitintä päivittääksesi.",
     "What's new?" : "Mitä uutta?",
     "View changelog" : "Näytä muutosloki",
     "The update check is not yet finished. Please refresh the page." : "Päivitystarkistus ei ole vielä valmis. Päivitä sivu.",
@@ -35,8 +33,6 @@ OC.L10N.register(
     "The selected update channel makes dedicated notifications for the server obsolete." : "Valittu päivityskanava tekee palvelimen omat ilmoitukset tarpeettomiksi.",
     "The selected update channel does not support updates of the server." : "Valittu päivityskanava ei tue palvelimen päivityksiä.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Uusi versio on saatavilla: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Huomaa, että uuden julkaisun jälkeen päivitys näkyy vasta ensimmäisen pienemmän julkaisun jälkeen tai myöhemmin. Julkaisemme uusia versioita käyttäjillemme ajallisesti hajautetusti, ja joskus jätämme jonkin version väliin, jos ongelmia ilmenee. Lisätietoja päivityksistä ja julkaisukanavista osoitteessa {link}",
-    "Checked on {lastCheckedDate}" : "Tarkistettu {lastCheckedDate}",
     "Checking apps for compatible versions" : "Tarkistetaan sovellusten yhteensopivat versiot ",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Varmista, ettei config.php-tiedosto aseta valintaa <samp>appstoreenabled</samp> arvoon false.",
     "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Kaikilla</strong> sovelluksilla on yhteensopiva versio saatavilla tälle Nextcloud-versiolle.",
@@ -47,8 +43,11 @@ OC.L10N.register(
     "Beta" : "Beta",
     "A pre-release version only for testing new features, not for production environments." : "Esijulkaisuversio uusien toimintojen testaukseen, ei tuotantoympäristöille.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> sovelluksella on yhteensopiva versio saatavilla tälle Nextcloud-versiolle.","<strong>%n</strong> sovelluksella on yhteensopiva versio saatavilla tälle Nextcloud-versiolle."],
-    "Update for %1$s to version %2$s is available." : "Kohteen %1$s päivitys versioon %2$s on saatavilla.",
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Huomioi, ettei päivitys selaimen kautta ole suositeltu yli 100 käyttäjän instansseissa! Tee sen sijaan päivitys komentoriviltä.",
+    "Please use the command line updater to update." : "Käytä komentorivipäivitintä päivittääksesi.",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Voit vaihtaa päivityskanavan alapuolelta, se vaikuttaa myös sovellushallinnan sivuun. Jos vaihdat esimerkiksi beetakanavaan, sovellusten beetapäivityksiä tarjotaan sovellushallinnan sivun kautta.",
-    "Update channel:" : "Päivityskanava:"
+    "Update channel:" : "Päivityskanava:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Huomaa, että uuden julkaisun jälkeen päivitys näkyy vasta ensimmäisen pienemmän julkaisun jälkeen tai myöhemmin. Julkaisemme uusia versioita käyttäjillemme ajallisesti hajautetusti, ja joskus jätämme jonkin version väliin, jos ongelmia ilmenee. Lisätietoja päivityksistä ja julkaisukanavista osoitteessa {link}",
+    "Checked on {lastCheckedDate}" : "Tarkistettu {lastCheckedDate}"
 },
 "nplurals=2; plural=(n != 1);");
