@@ -3,37 +3,55 @@ OC.L10N.register(
     {
     "{version} is available. Get more information on how to update." : "{version}을(를) 사용할 수 있습니다. 업데이트하는 방법에 대해서 알아보십시오.",
     "Channel updated" : "채널 업데이트됨",
+    "Web updater is disabled" : "웹 업데이트가 비활성화 되었습니다",
     "Update notifications" : "업데이트 알림",
     "The update server could not be reached since %d days to check for new updates." : "업데이트 서버에 %d일 동안 접근할 수 없어서 새 업데이트를 확인할 수 없습니다.",
     "Please check the Nextcloud and server log files for errors." : "Nextcloud 및 서버 로그에서 오류 정보를 확인하십시오.",
     "Update to %1$s is available." : "%1$s(으)로 업데이트할 수 있습니다.",
+    "Update to {serverAndVersion} is available." : "{serverAndVersion}(으)로 업데이트할 수 있습니다.",
     "Update for {app} to version %s is available." : "{app}을(를) 버전 %s(으)로 업데이트할 수 있습니다.",
     "Update notification" : "업데이트 알림",
     "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloud 업데이트 알림을 표시하고 업데이터에 SSO를 지원합니다.",
     "Update" : "업데이트",
     "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "실행 중인 버전이 더 이상 지원되지 않습니다. 빠른 시일 내에 지원되는 버전으로 업데이트하십시오.",
+    "Apps missing compatible version" : "호환되지 않는 앱",
     "View in store" : "스토어에서 보기",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "100명 이상의 사용자 수를 보유하고 있는 경우 웹 업데이터 사용을 권장하지 않습니다. 대신 명령행 업데이터를 사용하십시오. ",
+    "Apps with compatible version" : "호환되는 앱",
+    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "계정이 100개 이상 존재하는 경우 웹 업데이터 사용을 권장하지 않습니다. 대신 명령행 업데이터를 사용하십시오. ",
     "Open updater" : "업데이터 열기",
     "Download now" : "지금 다운로드",
+    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "웹 업데이터가 비활성화 되었습니다. 명령행 업데이터 또는 이 인스턴스의 설치 방식(예: Docker)에 적합한 업데이트 방법을 이용하십시오.",
     "What's new?" : "새로운 항목",
     "View changelog" : "변경 기록 확인",
     "The update check is not yet finished. Please refresh the page." : "업데이트 확인이 아직 끝나지 않았습니다. 페이지를 새로 고치십시오.",
     "Your version is up to date." : "최신 버전을 사용하고 있습니다.",
     "A non-default update server is in use to be checked for updates:" : "기본 업데이트 서버가 아닌 곳에서 업데이트를 확인하고 있음:",
+    "Update channel" : "업데이트 채널",
+    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "이곳에서 변경한 업데이트 채널은 앱 업데이트에도 동일하게 적용됩니다. 예) 예를 들어 이곳에서 베타 채널로 변경할 경우, 앱 관리 페이지에서 각 앱에 대한 베타 업데이트가 제공됩니다.",
+    "Current update channel:" : "현재 업데이트 채널:",
     "You can always update to a newer version. But you can never downgrade to a more stable version." : "항상 새 버전으로 업그레이드할 수 있지만, 더 안정적인 버전으로 다운그레이드할 수는 없습니다.",
     "Notify members of the following groups about available updates:" : "다음 그룹 구성원에게 업데이트 알림 전달:",
+    "No groups" : "그룹 없음",
+    "Only notifications for app updates are available." : "앱 업데이트에 대한 알림만 사용할 수 있습니다.",
     "The selected update channel makes dedicated notifications for the server obsolete." : "선택한 업데이트 채널은 서버 알림을 사용하지 않습니다.",
     "The selected update channel does not support updates of the server." : "선택한 업데이트 채널은 서버 업데이트를 지원하지 않습니다.",
     "A new version is available: <strong>{newVersionString}</strong>" : "새 버전을 사용할 수 있음: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "메이저 업그레이드는 해당 버전의 첫 마이너 업데이트 혹은 그 후의 업데이트에 대해 제공됩니다. 새로운 버전은 단계적으로 적용되며, 문제가 발생할 경우 배포를 중단하고 다음 업데이트로 건너뛸 수 있습니다. 업데이트와 릴리즈 채널에 대한 자세한 정보는 다음의 링크를 참고하십시오. {link}",
-    "Checked on {lastCheckedDate}" : "{lastCheckedDate}에 확인함",
+    "Checked on {lastCheckedDate} - Open changelog" : "{lastCheckedDate}에 확인함 - 변경내역 열기",
+    "Checking apps for compatible versions" : "호환되는 앱 업데이트 확인 중",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "config.php에서 <samp>appstoreenabled</samp> 설정이 false가 아닌지 확인하십시오.",
+    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "App Store에 연결할 수 없거나 반환된 업데이트 정보가 없습니다. 업데이트를 직접 검색하거나 App Store와의 인터넷 연결을 확인하십시오.",
+    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>모든</strong> 앱에 이 Nextcloud와 호환되는 버전이 있습니다.",
+    "Enterprise" : "엔터프라이즈",
     "Stable" : "안정판",
     "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "최신 안정 버전입니다. 일반 사용에 적합하며 항상 최신 주 버전으로 업데이트됩니다.",
     "Beta" : "베타",
     "A pre-release version only for testing new features, not for production environments." : "새로운 기능을 테스트하는 출시 이전 버전이며, 프로덕션 환경에 적합하지 않습니다.",
+    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong>개의 앱에 이 Nextcloud와 호환되는 버전이 없습니다."],
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "100명 이상의 사용자 수를 보유하고 있는 경우 웹 업데이터 사용을 권장하지 않습니다. 대신 명령행 업데이터를 사용하십시오. ",
+    "Please use the command line updater to update." : "명령행 업데이터를 사용하십시오.",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "아래에서 업데이트 채널을 번경할 수 있으며, 이는 앱 관리 페이지에도 적용됩니다. 예를 들어 베타 채널로 변경할 경우, 앱 관리 페이지에서 각 앱에 대한 베타 업데이트가 제공됩니다.",
-    "Update channel:" : "업데이트 채널:"
+    "Update channel:" : "업데이트 채널:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "메이저 업그레이드는 해당 버전의 첫 마이너 업데이트 혹은 그 후의 업데이트에 대해 제공됩니다. 새로운 버전은 단계적으로 적용되며, 문제가 발생할 경우 배포를 중단하고 다음 업데이트로 건너뛸 수 있습니다. 업데이트와 릴리즈 채널에 대한 자세한 정보는 다음의 링크를 참고하십시오. {link}",
+    "Checked on {lastCheckedDate}" : "{lastCheckedDate}에 확인함"
 },
 "nplurals=1; plural=0;");
