@@ -17,7 +17,6 @@ OC.L10N.register(
     "Apps missing compatible version" : "Апликации на кој им недостасува компатибилност",
     "View in store" : "Преглед во продавницата за апликации",
     "Apps with compatible version" : "Апликации со компатибилни верзии",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Имајте на ум дека веб ажурирачот не го препорачуваат повеќе од 100 корисници! Наместо тоа, користете го ажурирачот на командната линија!",
     "Open updater" : "Стартувај го надградувачот",
     "Download now" : "Преземи",
     "What's new?" : "Што е ново",
@@ -31,8 +30,6 @@ OC.L10N.register(
     "The selected update channel makes dedicated notifications for the server obsolete." : "Избраниот канал за ажурирање ќе овозможи известувања за застарениот сервер.",
     "The selected update channel does not support updates of the server." : "Избраниот канал за ажурирање не поддржува ажурирање за серверот.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Достапна е нова верзија: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Можно е да треба некое време додека новата верзија се прикаже овде. Ние испорачуваме нови до нашите корисници но од време на време некој верзии ги прескокнуваме поради пројандени проблеми во истите. Повеќе информации може да се пронајдат на {link}",
-    "Checked on {lastCheckedDate}" : "Проверено на {lastCheckedDate}",
     "Checking apps for compatible versions" : "Проверка за компатибилност на апликациите со новата верзија",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Бидете сигурни дека во config.php датотеката параматарот <samp>appstoreenabled</samp> е поставен на false.",
     "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Неможе да се поврзе со appstore или одговорот е дека нема ажурирање. Пребарајте рачно за ажурирање или бидете сигурни дека серверот има пристап до интернет и може да се поврзе со продавницата.",
@@ -44,8 +41,11 @@ OC.L10N.register(
     "Beta" : "Бета",
     "A pre-release version only for testing new features, not for production environments." : "Неиздадена верзија само за тестирање на новите можности, не е за редовна употреба.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["1 апликација нема компатибилност со оваа веријза","<strong>%n</strong> апликации немаат компатибилност со оваа веријза"],
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Имајте на ум дека веб ажурирачот не го препорачуваат повеќе од 100 корисници! Наместо тоа, користете го ажурирачот на командната линија!",
     "Please use the command line updater to update." : "Користете ја командната линија за ажурирање.",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Може да го промените каналот за ажурирање подолу, што исто така влијае на страницата за управување со апликации. На пр. откако ќе се префрлите на бета каналот, ќе ви бидат понудени ажурирања на бета апликации на страницата за управување со апликации.",
-    "Update channel:" : "Канал за ажурирање:"
+    "Update channel:" : "Канал за ажурирање:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Можно е да треба некое време додека новата верзија се прикаже овде. Ние испорачуваме нови до нашите корисници но од време на време некој верзии ги прескокнуваме поради пројандени проблеми во истите. Повеќе информации може да се пронајдат на {link}",
+    "Checked on {lastCheckedDate}" : "Проверено на {lastCheckedDate}"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
