@@ -17,7 +17,6 @@ OC.L10N.register(
     "Apps missing compatible version" : "Aplikácie s chýbajúcou kompatibilnou verziou",
     "View in store" : "Zobraziť v obchode",
     "Apps with compatible version" : "Aplikácie s kompatibilnou verziou",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Upozorňujeme, že webový aktualizátor sa neodporúča pre viac ako 100 používateľov! Namiesto toho použite nástroj na aktualizáciu príkazového riadku!",
     "Open updater" : "Otvoriť aktualizátor",
     "Download now" : "Stiahnuť teraz",
     "What's new?" : "Čo je nové?",
@@ -31,8 +30,6 @@ OC.L10N.register(
     "The selected update channel makes dedicated notifications for the server obsolete." : "Pre vybraný aktualizačný kanál budú priradené upozornenia pre server zastarané.",
     "The selected update channel does not support updates of the server." : "Vybraný aktualizačný kanál nepodporuje aktualizácie servera.",
     "A new version is available: <strong>{newVersionString}</strong>" : "Je dostupná nová verzia: <strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Upozorňujeme, že po oficiálnom vydaní novej verzie môže chvíľu trvať, než sa tu objaví. Nové verzie medzi našich používateľov distribuujeme priebežne rozložené v čase a ak sa nájdu chyby, niekedy danú verziu preskočíme. Viac informácií o kanáloch aktualizácií a vydaní sa dozviete na {link}",
-    "Checked on {lastCheckedDate}" : "Skontrolované {lastCheckedDate}",
     "Checking apps for compatible versions" : "Kontrolujú sa aplikácie na kompatibilné verzie",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Prosím uistite sa, že Váš config.php nemá nastavené <samp>appstoreenabled</samp>na false.",
     "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Nepodarilo sa pripojiť k obchodu s aplikáciami alebo obchod nemá žiadne aktualizácie. Aktualizácie hľadajte manuálne alebo sa uistite, že Váš server má prístup na internet a že sa môže pripojiť k obchodu.",
@@ -44,8 +41,11 @@ OC.L10N.register(
     "Beta" : "Beta",
     "A pre-release version only for testing new features, not for production environments." : "Verzia pred vydaním iba na testovanie nových funkcií, nevhodné pre ostrú prevádzku.",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> aplikácia nemá dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom","<strong>%n</strong> aplikácie nemajú dostupnú kompatibilnú verziu s týmto Nextcloudom"],
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Upozorňujeme, že webový aktualizátor sa neodporúča pre viac ako 100 používateľov! Namiesto toho použite nástroj na aktualizáciu príkazového riadku!",
     "Please use the command line updater to update." : "Použite prosím aktualizáciu cez príkazový riadok.",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Nižšie môžete zmeniť aktualizačný kanál, ktorý ovplyvní aj stránku správy aplikácií. Napr. po prepnutí na beta kanál vám budú na stránke správy aplikácií ponúknuté aktualizácie na beta verzie aplikácií.",
-    "Update channel:" : "Aktualizačný kanál:"
+    "Update channel:" : "Aktualizačný kanál:",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Upozorňujeme, že po oficiálnom vydaní novej verzie môže chvíľu trvať, než sa tu objaví. Nové verzie medzi našich používateľov distribuujeme priebežne rozložené v čase a ak sa nájdu chyby, niekedy danú verziu preskočíme. Viac informácií o kanáloch aktualizácií a vydaní sa dozviete na {link}",
+    "Checked on {lastCheckedDate}" : "Skontrolované {lastCheckedDate}"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
