@@ -17,7 +17,7 @@ OC.L10N.register(
     "Apps missing compatible version" : "應用程式缺少兼容版本",
     "View in store" : "在商店中檢視",
     "Apps with compatible version" : "具有兼容版本的應用程式",
-    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "請注意，不建議使用超過 100 個用戶的網絡更新程序！ 請改用命令行更新程序！",
+    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "請注意，不建議使用超過 100 個賬戶的網絡更新程序！ 請改用命令行更新程序！",
     "Open updater" : "打開更新程式",
     "Download now" : "立即下載",
     "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "網頁更新程式已停用。請使用命令列更新程式或適合您安裝方式的適當更新機制（例如 Docker pull）進行更新。",
@@ -36,7 +36,7 @@ OC.L10N.register(
     "The selected update channel makes dedicated notifications for the server obsolete." : "所選的更新頻道導致伺服器的專用通知過時。",
     "The selected update channel does not support updates of the server." : "選定的更新頻道不支援伺服器更新。",
     "A new version is available: <strong>{newVersionString}</strong>" : "有新版本可用：<strong>{newVersionString}</strong>",
-    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "請注意，新版本推出後，僅會在有第一個次要版本或更新的版本時顯示。我們會逐步向用戶推送新版本，並在發現問題時跳過特定版本。在 {link} 取得關於更新與推出頻道的更多資訊",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "請注意，新版本釋出後，僅會在有第一個次要版本或更新的版本時顯示。我們會逐步推送新版本，並在發現問題時跳過特定版本。在 {link} 取得關於更新與釋出頻道的更多資訊",
     "Checked on {lastCheckedDate} - Open changelog" : "檢查於 {lastCheckedDate} - 開啟變更紀錄",
     "Checking apps for compatible versions" : "檢查應用程式的兼容版本",
     "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "請確定您的 config.php 中並沒有將 <samp>appstoreenabled</samp> 的值設定為 false。",
@@ -49,9 +49,11 @@ OC.L10N.register(
     "Beta" : "Beta 測試版",
     "A pre-release version only for testing new features, not for production environments." : "預發佈版本僅用於測試新功能，不適用於生產環境。",
     "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["有 <strong>%n</strong> 個應用程式沒有與此 Nextcloud 版本相容的版本。"],
+    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "請注意，不建議使用超過 100 個用戶的網絡更新程序！ 請改用命令行更新程序！",
     "Please use the command line updater to update." : "請使用命令行更新程序進行更新。",
     "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "您可以變更下方的更新頻道，這也會影響應用程式管理頁面。例如，切換到測試版頻道後，在應用程式管理頁更新應用程式時也會提供測試版。",
     "Update channel:" : "更新頻道：",
+    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "請注意，新版本推出後，僅會在有第一個次要版本或更新的版本時顯示。我們會逐步向用戶推送新版本，並在發現問題時跳過特定版本。在 {link} 取得關於更新與推出頻道的更多資訊",
     "Checked on {lastCheckedDate}" : "上次檢查日期：{lastCheckedDate}"
 },
 "nplurals=1; plural=0;");
