@@ -10,6 +10,8 @@ OC.L10N.register(
     "Error saving image" : "Error guardando imágen",
     "Unsaved changes" : "Cambios sin guardar",
     "Drop changes" : "Descartar cambios",
+    "Play the live photo" : "Reproducir la fotografía en vivo",
+    "LIVE" : "EN VIVO",
     "Your browser does not support videos." : "Tu navegador no soporta videos.",
     "Edit" : "Editar",
     "Exit full screen" : "Salir de pantalla completa",
