@@ -10,6 +10,8 @@ OC.L10N.register(
     "Error saving image" : "Помилка збереження зображення",
     "Unsaved changes" : "Незбережені зміни",
     "Drop changes" : "Відкинути зміни",
+    "Play the live photo" : "Відтворити живе фото",
+    "LIVE" : "НАЖИВО",
     "Your browser does not support videos." : "Ваш браузер не підтримує відтворення відео.",
     "Edit" : "Редагувати",
     "Exit full screen" : "Вийти з повноекранного режиму",
@@ -108,6 +110,7 @@ OC.L10N.register(
     "Saved image size (width x height)" : "Розмір збереженого зображення (ширина x висота)",
     "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Зауважте, що вибрана область кадрування нижча за застосований розмір, що може спричинити погіршення якості",
     "Actual size (100%)" : "Фактичний розмір (100%)",
-    "Fit size" : "Припасувати за розміром"
+    "Fit size" : "Припасувати за розміром",
+    "\"{fileName}\"" : "\"{fileName}\""
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
