@@ -7,7 +7,6 @@ OC.L10N.register(
     "Error" : "Hiba",
     "Weather status" : "Időjárás állapota",
     "Weather status in your dashboard" : "Időjárás állapota az irányítópulton",
-    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Irányítópultba integrált időjárási állapot. A felhasználó helyzete meghatározható automatikusan vagy egyénileg beállítható. Ezután egy 6 órás előrejelzés lesz megjelenítve. Ez az információ máshol is megjeleníthető, például a Naptár alkalmazásban.",
     "Detect location" : "Helymeghatározás",
     "Set custom address" : "Egyéni cím beállítása",
     "Favorites" : "Kedvencek",
@@ -46,17 +45,6 @@ OC.L10N.register(
     "There was an error saving the mode." : "Hiba történt a mód mentése során.",
     "There was an error using personal address." : "Hiba történt a személyes cím használata során.",
     "Set location for weather" : "Tartózkodási hely beállítása az időjáráshoz",
-    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Tiszta égbolt {time}-kor",
-    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Felhős égbolt {time}-kor",
-    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Kellemes nap {time}-kor",
-    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Kellemes éjszaka {time}-kor",
-    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Részben felhős {time}-kor",
-    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Ködös {time}-kor",
-    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Enyhe eső {time}-kor",
-    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Eső {time}-kor",
-    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Kiadós eső {time}-kor",
-    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Zápor {time}-kor",
-    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Enyhe zápor {time}-kor",
-    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Kiadós zápor {time}-kor"
+    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Irányítópultba integrált időjárási állapot. A felhasználó helyzete meghatározható automatikusan vagy egyénileg beállítható. Ezután egy 6 órás előrejelzés lesz megjelenítve. Ez az információ máshol is megjeleníthető, például a Naptár alkalmazásban."
 },
 "nplurals=2; plural=(n != 1);");
