@@ -113,10 +113,9 @@ OC.L10N.register(
     "between" : "بين",
     "not between" : "ليس بين",
     "Request user agent" : "وكيل المستخدم الخاص بالطلب",
-    "User group membership" : "عضوية مجموعة المستخدمين",
+    "Group membership" : "عضوية المجموعة",
     "is member of" : "عضو فى",
     "is not member of" : "ليس عضو فى",
-    "Predefined URLs" : "عناوين URLs المحددة مسبقا",
-    "Others" : "آخرون"
+    "User group membership" : "عضوية مجموعة المستخدمين"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
