@@ -104,8 +104,8 @@ OC.L10N.register(
     "between" : "entre",
     "not between" : "no entre",
     "Request user agent" : "Sol·licita agent d'usuari",
-    "User group membership" : "Pertinença a grup d'usuaris",
     "is member of" : "és membre de",
-    "is not member of" : "no és membre de"
+    "is not member of" : "no és membre de",
+    "User group membership" : "Pertinença a grup d'usuaris"
 },
 "nplurals=2; plural=(n != 1);");
