@@ -84,10 +84,8 @@ OC.L10N.register(
     "between" : "inter",
     "not between" : "ne inter",
     "Request user agent" : "Retumil-identigilo („user-agent“)",
-    "User group membership" : "Grupano",
     "is member of" : "estas membro de",
     "is not member of" : "ne estas membro de",
-    "Predefined URLs" : "Antaŭdifinitaj retadresoj",
-    "Others" : "Aliaj"
+    "User group membership" : "Grupano"
 },
 "nplurals=2; plural=(n != 1);");
