@@ -106,14 +106,8 @@ OC.L10N.register(
     "between" : "između",
     "not between" : "nije između",
     "Request user agent" : "Zatraži korisničkog agenta",
-    "User group membership" : "Članstvo u grupi korisnika",
     "is member of" : "je član",
     "is not member of" : "nije član",
-    "Select a tag" : "Odaberi oznaku",
-    "No results" : "Nema rezultata",
-    "%s (invisible)" : "%s (nevidljivo)",
-    "%s (restricted)" : "%s (ograničeno)",
-    "Predefined URLs" : "Unaprijed definirani URL-ovi",
-    "Others" : "Ostalo"
+    "User group membership" : "Članstvo u grupi korisnika"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
