@@ -110,8 +110,8 @@ OC.L10N.register(
     "between" : "közötte",
     "not between" : "nincs közötte",
     "Request user agent" : "Kérés felhasználói ügynöke",
-    "User group membership" : "Felhasználói csoporttagság",
     "is member of" : "tagja ennek",
-    "is not member of" : "nem tagja ennek"
+    "is not member of" : "nem tagja ennek",
+    "User group membership" : "Felhasználói csoporttagság"
 },
 "nplurals=2; plural=(n != 1);");
