@@ -31,7 +31,7 @@ OC.L10N.register(
     "Operation #%s does not exist" : "Bewerking #%s bestaat niet",
     "Entity %s does not exist" : "Entiteit %s bestaat niet",
     "Entity %s is invalid" : "Entiteit %s is ongeldig",
-    "No events are chosen." : "Nog geen afspraken gekozen.",
+    "No events are chosen." : "Nog geen gebeurtenissen gekozen.",
     "Entity %s has no event %s" : "Entiteit %s heeft geen gebeurtenis %s",
     "Operation %s does not exist" : "Bewerking %s bestaat niet",
     "Operation %s is invalid" : "Bewerking %s is ongeldig",
@@ -48,12 +48,14 @@ OC.L10N.register(
     "Nextcloud workflow engine" : "Nextcloud workflow engine",
     "Select a filter" : "Selecteer een filter",
     "Select a comparator" : "Selecteer een comparator",
+    "Remove filter" : "Verwijder filter",
     "Select a file type" : "Selecteer een bestandstype",
     "e.g. httpd/unix-directory" : "bijv. httpd/unix-directory",
     "Folder" : "Map",
     "Images" : "Afbeeldingen",
     "Office documents" : "Office documenten",
     "PDF documents" : "PDF documenten",
+    "Custom MIME type" : "Maatwerk mimetype",
     "Custom mimetype" : "Maatwerk mimetype",
     "Please enter a valid time span" : "Geef een geldige tijdsinterval op",
     "Select a request URL" : "Selecteer een aanvraag URL",
@@ -65,10 +67,12 @@ OC.L10N.register(
     "Desktop client" : "Desktop client",
     "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
     "Custom user agent" : "Aangepaste 'user agent'",
-    "At least one event must be selected" : "Er moet minimaal één afspraak worden geselecteerd",
+    "Select a trigger" : "Selecteer een trigger",
+    "At least one event must be selected" : "Er moet minimaal één gebeurtenis worden geselecteerd",
     "Add new flow" : "Nieuwe flow toevoegen",
     "When" : "Wanneer",
     "and" : "en",
+    "Add a new filter" : "Nieuw filter toevoegen",
     "Cancel" : "Annuleren",
     "Delete" : "Verwijderen",
     "The configuration is invalid" : "De configuratie is ongeldig",
@@ -106,14 +110,8 @@ OC.L10N.register(
     "between" : "tussen",
     "not between" : "niet tussen",
     "Request user agent" : "Useragent aanvraag",
-    "User group membership" : "Gebruikersgroep lidmaatschap",
     "is member of" : "is lid van",
     "is not member of" : "is geen lid van",
-    "Select a tag" : "Selecteer een markering",
-    "No results" : "Geen resultaten",
-    "%s (invisible)" : "%s (onzichtbaar)",
-    "%s (restricted)" : "%s (beperkt)",
-    "Predefined URLs" : "Voorgedefinieerde URL's",
-    "Others" : "Anderen"
+    "User group membership" : "Gebruikersgroep lidmaatschap"
 },
 "nplurals=2; plural=(n != 1);");
