@@ -107,14 +107,8 @@ OC.L10N.register(
     "between" : "pomiędzy",
     "not between" : "nie pomiędzy",
     "Request user agent" : "Żądanie agenta użytkownika",
-    "User group membership" : "Członkostwo grupy użytkownika",
     "is member of" : "jest członkiem w",
     "is not member of" : "nie jest członkiem w",
-    "Select a tag" : "Wybierz etykietę",
-    "No results" : "Brak wyników",
-    "%s (invisible)" : "%s (niewidoczny)",
-    "%s (restricted)" : "%s (ograniczony)",
-    "Predefined URLs" : "Przedefiniowanie URLs",
-    "Others" : "Inne"
+    "User group membership" : "Członkostwo grupy użytkownika"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
