@@ -113,8 +113,8 @@ OC.L10N.register(
     "between" : "між",
     "not between" : "не між",
     "Request user agent" : "Запит агента користувача",
-    "User group membership" : "Участь користувача в групі",
     "is member of" : "є учасником",
-    "is not member of" : "не є учасником"
+    "is not member of" : "не є учасником",
+    "User group membership" : "Участь користувача в групі"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
