@@ -36,11 +36,13 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan butonon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Alklaku la jenan ligilon por restarigi vian pasvorton. Si vi ne petis restarigon de via pasvorto, simple ignoru tiun ĉi retmesaĝon.",
     "Reset your password" : "Restarigi vian pasvorton ",
+    "Task not found" : "Tasko ne trovita",
     "Internal error" : "Interna eraro",
+    "Image not found" : "Bildo ne trovita",
+    "Unable to translate" : "Ne eblas traduki",
     "Nextcloud Server" : "Nextcloud-servilo",
     "Some of your link shares have been removed" : "Kelkaj el viaj kunhavigaj ligiloj estis forigitaj",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Pro sekuriga problemo, ni forigu kelkajn el viaj kunhavigaj ligiloj. Bv. vidi la ligilon por plia informo.",
-    "The user limit of this instance is reached." : "La maksimuma nombro de uzantoj estis atingita en tiu ĉi servilo.",
     "Learn more ↗" : "Scii pli ↗",
     "Preparing update" : "Preparo de  la ĝisdatigo",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -65,21 +67,6 @@ OC.L10N.register(
     "Already up to date" : "Jam aktuala",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Via retservilo ankoraŭ ne estas agordita por permesi sinkronigon de dosieroj, ĉar la WebDAV-interfaco ŝajne difektiĝas.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Via retservilo ne estas bone agordita por trovi la adreson „{url}“. Pli da informo troveblas en la {linkstart}dokumentaro ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Via retservilo ne estas bone agordita por trovi la adreson „{url}“. Tio plej verŝajne estas kaŭzita de servilo ne ĝisdatigita por rekte liveri tiun ĉi dosierujon. Bv. kompari vian agordon al transformreguloj en „.htaccess“ por Apache, aŭ la reguloj por Nginx en la {linkstart}dokumentaro ↗{linkend}. Ĉe Nginx, tio, kio devas ĝisdatiĝi estas kutime linioj komencantaj per „location ~“.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Via retservilo ne estas bone agordita por sendi .woff2-dosierojn. Tio estas tipe problemo kun la agordo de Nginx. Nextcloud 15 bezonas adapton por ankaŭ sendi .woff2-dosierojn. Komparu vian Nginx-agordon kun la rekomendita agordo en nia {linkstart}dokumentaro ↗{linkend}.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ne eblis ruli la cron-taskon per komandlinia interfaco. La jenaj eraroj okazis:",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La PHP-funkcio „set_time_limit“ (angle „difini tempolimo“) ne disponeblas. Pro tio, skriptoj povus halti mezvoje, eble difektante vian instalaĵon. Ebligi tiun funkcion estas tre rekomendita.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Mankanta indekso „{indexName}“ en tabelo „{tableName}“.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankas kelkaj indeksoj en la datumbazo. Pro la ebla malrapideco aldoni indeksojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-indices“, dum la servilo estas funkcianta. Kiam la indeksoj ekzistos, la uzo de tiuj tabelojn estos kutime pli rapida.",
-    "Missing primary key on table \"{tableName}\"." : "Mankas ĉefŝlosilo ĉe la tablo „{tableName}“.",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Mankas kelkaj ĉefŝlosiloj en la datumbazo. Pro la ebla malrapideco aldoni ĉefŝlosilojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-primary-keys“, dum la servilo estas funkcianta.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Mankas malnepra kolumno ĉe la tablo „{tableName}“.",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankas kelkaj malnepraj kolumnoj en la datumbazo. Pro la ebla malrapideco aldoni kolumnojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-columns“, dum la servilo estas funkcianta. Kiam la kolumnoj aldoniĝos, la uzo de tiuj tabelojn estos kutime pli rapida.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "En tiu servilo, la PHP-modulo „php-imagick“ ne subtenas SVG. Por pli bona kongrueco, instalu ĝin.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite estas la nuna datumbazo uzita de la servilo. Por grandaj instalaĵoj, ni rekomendas uzi alian tipon de datumbazo.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Tio estas precipe rekomendinda, kiam oni uzas la surtablan programon por sinkronigi la dosierojn.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Kelkaj aplikaĵ-dosierujoj apartenas al malsama uzanto ol tiu de la retservilo. Tio povas okazi, kiam aplikaĵoj estis instalita mane. Kontrolu la permesojn de la jenaj dosierujoj:",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Tiu Nextcloud-servilo uzas objektokonservejon bazitan sur S3 kiel ĉefkonservejo. La alŝutitaj dosieroj provizore konserviĝas en la servilo, kaj pro tio oni rekomendas havi liberan spacon je 50 GB en la PHP-a provizora dosierujo. Kontrolu la protokolojn por ĉiuj detaloj pri la dosiervojo kaj la libera spaco. Do, aŭ ŝanĝu la provizoran dosierujon en „php.ini“, aŭ liberigu spacon en tiu loko.",
     "Error occurred while checking server setup" : "Eraro dum kontrolo de servila agordo",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Por pliaj detaloj, vidu la {linkstart}dokumentaron ↗{linkend}.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "La HTTP-kapo „{header}“ ne egalas al „{expected}“. Tio estas eventuala risko pri sekureco aŭ privateco. Bv. ĝustigi tiun agordon laŭe.",
@@ -98,21 +85,23 @@ OC.L10N.register(
     "Please reload the page." : "Bonvolu reŝargi la paĝon.",
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La ĝisdatigo malsukcesis. Por pli da informoj, <a href=\"{url}\">vidu la forumafisôn</a> pri tio.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La ĝisdatigo malsukcesis. Bonvolu raporti tiun problemon al la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-komunumo</a>.",
+    "Applications menu" : "Aplikaĵa menuo",
     "More apps" : "Pli da aplikaĵoj",
     "Currently open" : "Aktuale malfermita",
+    "_{count} notification_::_{count} notifications_" : ["{count} sciigoj","{count} sciigoj"],
+    "Custom date range" : "Propra data periodo",
+    "Pick start date" : "Elekti komencan daton",
+    "Pick end date" : "Elekti finan daton",
+    "Search in date range" : "Serĉi en data periodo",
     "Log in" : "Ensaluti",
     "Logging in …" : "Ensaluti...",
     "Server side authentication failed!" : "Ĉeservila aŭtentigo malsukcesis!",
     "Please contact your administrator." : "Bonvolu kontakti vian administranton.",
     "An internal error occurred." : "Interna servileraro okazis.",
     "Please try again or contact your administrator." : "Bonvolu provi ree aŭ kontakti vian administranton.",
-    "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
     "Password" : "Pasvorto",
     "Log in to {productName}" : "Saluti al {productName}",
-    "Wrong username or password." : "Neĝusta uzantnomo aŭ pasvorto.",
-    "User disabled" : "Uzanto malvalidigita",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Ni eltrovis plurajn nevalidajn provojn ensaluti el via IP-adreso. Do, oni prokrastis vian sekvantan ensaluton dum ĝis 30 sekundoj.",
-    "Username or email" : "Uzantnomo aŭ retpoŝtadreso",
     "Your account is not setup for passwordless login." : "Via konto ne estas agordita por uzi senpasvortan ensaluton.",
     "Passwordless authentication is not supported in your browser." : "Senpasvorta aŭtentigo ne eblas per via retumilo.",
     "Your connection is not secure" : "La konekto ne sekuras",
@@ -138,21 +127,39 @@ OC.L10N.register(
     "Install the Contacts app" : "Instali la Kontakto-aplikaĵon",
     "Loading your contacts …" : "Ŝargo de viaj kontaktoj...",
     "Looking for {term} …" : "Serĉo de {term}…",
-    "Modified" : "Modifita",
-    "Today" : "Hodiaŭ",
-    "Not found" : "Ne trovita",
-    "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
-    "Back" : "Antaŭen",
-    "Edit Profile" : "Modifi profilon",
     "Start typing to search" : "Ektajpu por serĉi",
     "Search" : "Serĉi",
     "No results for {query}" : "Neniu rezulto pri {query}",
+    "Forgot password?" : "Ĉu vi forgesis vian pasvorton?",
+    "Back" : "Antaŭen",
+    "Edit Profile" : "Modifi profilon",
+    "Date" : "Dato",
+    "Today" : "Hodiaŭ",
+    "Last 7 days" : "Lastaj 7 tagoj",
+    "Last 30 days" : "Lastaj 30 tagoj",
+    "This year" : "Ĉi jaro",
+    "Last year" : "Lasta jaro",
+    "Search people" : "Serĉi homojn",
+    "Not found" : "Ne trovita",
+    "People" : "Homoj",
+    "Filter in current view" : "Filtrilo en ĉi vido",
+    "Search in" : "Serĉi en",
+    "Searching …" : "Serĉado ...",
+    "No matching results" : "Neniuj kongruaj rezultoj",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Inter ${this.dateFilter.startFrom.toLocaleDateString()} kaj ${this.dateFilter.endAt.toLocaleDateString()}",
+    "This browser is not supported" : "La retumilo ne estas subtenata",
+    "Continue with this unsupported browser" : "Daŭrigi per tiu ne subtenata retumilo",
     "Supported versions" : "Subtenataj versioj",
+    "{name} version {version} and above" : "{name} versio {version} kaj supre",
     "Settings menu" : "Menuo de agordo",
+    "Avatar of {displayName}" : "Avataro de {displayName}",
     "No" : "Ne",
     "Yes" : "Jes",
+    "Choose {file}" : "Elekti {file}",
     "Choose" : "Elekti",
+    "Copy to {target}" : "Kopii al {target}",
     "Copy" : "Kopii",
+    "Move to {target}" : "Movi al {target}",
     "Move" : "Movi",
     "OK" : "Akcepti",
     "Error loading message template: {error}" : "Eraro dum ŝargo de mesaĝa ŝablono: {eraro}",
@@ -190,6 +197,7 @@ OC.L10N.register(
     "Strong password" : "Forta pasvorto",
     "No action available" : "Neniu ago disponebla",
     "Error fetching contact actions" : "Eraro dum serĉo de kontakt-agoj",
+    "Close \"{dialogTitle}\" dialog" : "Fermi la dialogon \"{dialogTitle}\"",
     "Non-existing tag #{tag}" : "Ne ekzistas etikedo #{tag}",
     "Restricted" : "Limigita",
     "Invisible" : "Nevidebla",
@@ -198,7 +206,7 @@ OC.L10N.register(
     "Collaborative tags" : "Kunlaboraj etikedoj",
     "No tags found" : "Neniu etikedo troviĝis ",
     "Personal" : "Persona",
-    "Users" : "Uzantoj",
+    "Accounts" : "Kontoj",
     "Apps" : "Aplikaĵoj",
     "Admin" : "Administranto",
     "Help" : "Helpo",
@@ -207,7 +215,9 @@ OC.L10N.register(
     "The profile does not exist." : "La profilo ne ekzistas.",
     "Back to %s" : "Antaŭen al %s",
     "Page not found" : "Paĝo ne trovita",
+    "The page could not be found on the server or you may not be allowed to view it." : "La paĝo ne povis esti trovita en la servilo aŭ vi eble ne rajtas vidi ĝin.",
     "Too many requests" : "Tro da petoj",
+    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Estis tro multaj petoj de via reto. Reprovu poste aŭ kontaktu vian administranton se tio estas eraro.",
     "Error" : "Eraro",
     "Previous" : "Antaŭa",
     "Internal Server Error" : "Interna servileraro",
@@ -227,15 +237,15 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Via datumdosierujo kaj dosieroj estas probable elireblaj el la interreto, ĉar la dosiero „.htaccess“ ne funkcias.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Por pli da informoj pri kielo agordi vian retservilon, bv. vidi la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaron</a>.",
     "Create an <strong>admin account</strong>" : "Krei <strong>administranto-konton</strong>",
-    "Username" : "Uzantnomo",
     "Show password" : "Montri pasvorton",
+    "Toggle password visibility" : "Ŝanĝi videblecon de pasvorto",
     "Storage & database" : "Konservejo kaj datumbazo",
     "Data folder" : "Datuma dosierujo",
     "Configure the database" : "Agordi la datumbazon",
     "Only %s is available." : "Nur %s disponeblas.",
     "Install and activate additional PHP modules to choose other database types." : "Instalu kaj aktivigu pliajn PHP-modulojn por elekti aliajn datumbazajn specojn..",
     "For more details check out the documentation." : "Por pli detaloj, vidu la dokumentaron.",
-    "Database user" : "Datumbaza uzanto",
+    "Database account" : "Datumbaza konto",
     "Database password" : "Datumbaza pasvorto",
     "Database name" : "Datumbaza nomo",
     "Database tablespace" : "Datumbaza tabelospaco",
@@ -256,14 +266,11 @@ OC.L10N.register(
     "Skip to navigation of app" : "Iru al la aplikaĵa navigado",
     "Go to %s" : "Iri al %s",
     "Get your own free account" : "Ekhavu vian propran senpagan konton",
-    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas, ke vi konfirmas vian pasvorton",
-    "Confirm your password" : "Konfirmu vian pasvorton",
-    "Confirm" : "Konfirmi",
     "Connect to your account" : "Konekti al via konto",
     "Please log in before granting %1$s access to your %2$s account." : "Bv. unue ensaluti por doni al %1$s aliron al via konto %2$s.",
-    "App token" : "Aplikaĵa ĵetono",
+    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Se vi ne provas agordi novan aparaton aŭ apon, iu provas trompi vin por doni al ili aliron al viaj datumoj. En ĉi tiu kazo ne procedu kaj anstataŭe kontaktu vian sisteman administranton.",
+    "App password" : "Aplikaĵa pasvorto",
     "Grant access" : "Doni alirpermeson",
-    "Alternative log in using app token" : "Ensaluti alimaniere per aplikaĵa ĵetono",
     "Account access" : "Aliro al konto",
     "Currently logged in as %1$s (%2$s)." : "Aktuale salutinta kiel %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Vi tuj donos permeson al %1$s aliri al via konto %2$s.",
@@ -271,6 +278,7 @@ OC.L10N.register(
     "Your client should now be connected!" : "Via kliento estas konektita!",
     "You can close this window." : "Vi povas fermi tiun ĉi fenestron.",
     "This share is password-protected" : "Tiu kunhavigo estas protektata per pasvorto",
+    "The password is wrong or expired. Please try again or request a new one." : "La pasvorto estas malĝusta aŭ eksvalidiĝis. Bonvolu provi denove aŭ peti novan.",
     "Email address" : "Retpoŝtadreso",
     "Password sent!" : "Pasvorto sendiĝis!",
     "Two-factor authentication" : "Dufaza aŭtentigo",
@@ -281,6 +289,7 @@ OC.L10N.register(
     "Set up two-factor authentication" : "Agordi dufazan aŭtentigon",
     "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Dufaza aŭtentigo estas ebligita, sed ĝi ne estis agordita por via konto. Uzu unu el viaj rezervkodoj por ensaluti, aŭ kontaktu vian administranton por helpo.",
     "Use backup code" : "Uzi rezervkodon",
+    "Cancel login" : "Nuligi ensaluton",
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "Plibonigita sekurigo estas devigata por via konto. Elektu provizanton agordotan:",
     "Error while validating your second factor" : "Eraro dum validigo de via dua fazo",
     "Access through untrusted domain" : "Aliro tra nefidinda domajno",
@@ -288,6 +297,7 @@ OC.L10N.register(
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Pliaj informoj pri agordo de tio troveblas en la %1$sdokumentaro%2$s.",
     "App update required" : "Aplikaĵa ĝisdatigo nepras",
     "%1$s will be updated to version %2$s" : "%1$s ĝisdatiĝos al versio %2$s",
+    "The following apps will be updated:" : "La jenaj aplikaĵoj estos ĝisdatigitaj:",
     "These incompatible apps will be disabled:" : "La jenaj malkongruaj aplikaĵoj estos malŝaltataj:",
     "The theme %s has been disabled." : "La etoso %s estis malebligita.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bonvolu certiĝi, ke la datumbazo, la dosierujo de agordoj kaj la dosierujo de datumoj jam estis savkopiitaj antaŭ ol plui.",
@@ -295,7 +305,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Por eviti eltempiĝon ĉe grandaj instalaĵoj, vi povas anstataŭe ruli la jenan komandon en via instalo-dosierujo:",
     "Detailed logs" : "Detalaj protokoloj",
     "Update needed" : "Bezonas ĝisdatigi",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Bv. uzi la komandlinian ĝisdatigilon, ĉar vi havas pli da 50 uzantojn en tiu servilo.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Vidu la  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaron</a> por helpo.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Mi scias, ke, se mi daŭrigas la ĝisdatigon per la reteja fasado, estas risko, ke la peto eltempiĝos kaj okazigos perdon de datumoj. Sed, mi havas sekurkopion kaj scias, kiel restaŭri mian servilon okaze de paneo.",
     "Upgrade via web on my own risk" : "Ĝisdatigi per reteja fasado je mia risko",
@@ -304,17 +313,39 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Tiu ĉi paĝo aktualiĝos mem, kiam la servilo redisponeblos.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktu vian administranton, se tiu ĉi mesaĝo daŭras aŭ aperas neatendite.",
     "Please try again" : "Bonvolu reprovi",
+    "The user limit of this instance is reached." : "La maksimuma nombro de uzantoj estis atingita en tiu ĉi servilo.",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Via retservilo ne estas bone agordita por trovi la adreson „{url}“. Tio plej verŝajne estas kaŭzita de servilo ne ĝisdatigita por rekte liveri tiun ĉi dosierujon. Bv. kompari vian agordon al transformreguloj en „.htaccess“ por Apache, aŭ la reguloj por Nginx en la {linkstart}dokumentaro ↗{linkend}. Ĉe Nginx, tio, kio devas ĝisdatiĝi estas kutime linioj komencantaj per „location ~“.",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Via retservilo ne estas bone agordita por sendi .woff2-dosierojn. Tio estas tipe problemo kun la agordo de Nginx. Nextcloud 15 bezonas adapton por ankaŭ sendi .woff2-dosierojn. Komparu vian Nginx-agordon kun la rekomendita agordo en nia {linkstart}dokumentaro ↗{linkend}.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ŝajnas ne esti taŭge agordita por informpeti sistemajn medivariablojn. La testado kun getenv(\"PATH\") revenigas nur malplenan respondon.",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Bv. legi la {linkstart}instal-dokumentaron ↗{linkend} pri agordo-notoj pri PHP kaj pri PHP-agordo de via retservilo, precipe kiam vi uzas la modulon „php-fpm“.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La nurlega agordodosiero estis ebligita. Tio baras modifon de kelkaj agordoj per la reta fasado. Plie, la dosiero bezonos esti markita mane kiel legebla dum ĉiu ĝisdatigo.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Via datumbazo ne uzas la nivelon de izoltransakcio „READ COMMITTED“ (angle por „asertita datumlegado“). Tio povas estigi problemojn, kiam pluraj agoj ruliĝas paralele.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "La PHP-modulo „fileinfo“ mankas. Oni rekomendas ebligi tiun modulon por havi la plej bonan malkovron de MIME-tipo.",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Via instalaĵo ne difinas defaŭltan telefon-regionon. Tio necesas por validigi telefonnumerojn en la profil-agordoj sen landkodo. Por ebligi la uzon de numeroj sen lankodo, aldonu „default_phone_region“ kun la {linkstart}ISO-3166-1-kodo ↗{linkend} de via regiono en la agordodosiero.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ne eblis ruli la cron-taskon per komandlinia interfaco. La jenaj eraroj okazis:",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La PHP-funkcio „set_time_limit“ (angle „difini tempolimo“) ne disponeblas. Pro tio, skriptoj povus halti mezvoje, eble difektante vian instalaĵon. Ebligi tiun funkcion estas tre rekomendita.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Via PHP ne subtenas la bibliotekon FreeType, kio provokos misfunkcion de profilbildo kaj de la agorda fasado.",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Mankanta indekso „{indexName}“ en tabelo „{tableName}“.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankas kelkaj indeksoj en la datumbazo. Pro la ebla malrapideco aldoni indeksojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-indices“, dum la servilo estas funkcianta. Kiam la indeksoj ekzistos, la uzo de tiuj tabelojn estos kutime pli rapida.",
+    "Missing primary key on table \"{tableName}\"." : "Mankas ĉefŝlosilo ĉe la tablo „{tableName}“.",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Mankas kelkaj ĉefŝlosiloj en la datumbazo. Pro la ebla malrapideco aldoni ĉefŝlosilojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-primary-keys“, dum la servilo estas funkcianta.",
+    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Mankas malnepra kolumno ĉe la tablo „{tableName}“.",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankas kelkaj malnepraj kolumnoj en la datumbazo. Pro la ebla malrapideco aldoni kolumnojn en grandaj tabeloj, ili ne estis aldonitaj aŭtomate. Vi povas aldoni ilin mane, rulante komandlinie „occ db:add-missing-columns“, dum la servilo estas funkcianta. Kiam la kolumnoj aldoniĝos, la uzo de tiuj tabelojn estos kutime pli rapida.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "En tiu servilo mankas rekomenditaj PHP-moduloj. Por pli da rapideco kaj pli bona kongrueco, bv. instali ilin.",
+    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "En tiu servilo, la PHP-modulo „php-imagick“ ne subtenas SVG. Por pli bona kongrueco, instalu ĝin.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite estas la nuna datumbazo uzita de la servilo. Por grandaj instalaĵoj, ni rekomendas uzi alian tipon de datumbazo.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Tio estas precipe rekomendinda, kiam oni uzas la surtablan programon por sinkronigi la dosierojn.",
     "The PHP memory limit is below the recommended value of 512MB." : "La PHP-memorlimo estas sub la rekomendita valoro de 512 MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Kelkaj aplikaĵ-dosierujoj apartenas al malsama uzanto ol tiu de la retservilo. Tio povas okazi, kiam aplikaĵoj estis instalita mane. Kontrolu la permesojn de la jenaj dosierujoj:",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Tiu Nextcloud-servilo uzas objektokonservejon bazitan sur S3 kiel ĉefkonservejo. La alŝutitaj dosieroj provizore konserviĝas en la servilo, kaj pro tio oni rekomendas havi liberan spacon je 50 GB en la PHP-a provizora dosierujo. Kontrolu la protokolojn por ĉiuj detaloj pri la dosiervojo kaj la libera spaco. Do, aŭ ŝanĝu la provizoran dosierujon en „php.ini“, aŭ liberigu spacon en tiu loko.",
+    "Account name or email" : "Kontonomo aŭ retpoŝta adreso",
+    "Wrong username or password." : "Neĝusta uzantnomo aŭ pasvorto.",
+    "User disabled" : "Uzanto malvalidigita",
+    "Username or email" : "Uzantnomo aŭ retpoŝtadreso",
     "If it is not there ask your local administrator." : "Se tio ne estas tie, kontaktu vian lokan administranton.",
     "Start search" : "Ekserĉi",
+    "Press enter to start searching" : "Premu enter por komenci serĉon",
+    "Open settings menu" : "Malfermi agardan menuon",
     "Settings" : "Agordo",
     "Show all contacts …" : "Montri ĉiujn kontaktojn",
     "No files in here" : "Neniu dosiero ĉi tie",
@@ -322,6 +353,7 @@ OC.L10N.register(
     "No more subfolders in here" : "Ne plu estas subdosierujo ĉi tie.",
     "Name" : "Nomo",
     "Size" : "Grando",
+    "Modified" : "Modifita",
     "\"{name}\" is an invalid file name." : "„{name}“ estas nevalida dosiernomo.",
     "File name cannot be empty." : "Dosiernomo devas ne malpleni.",
     "\"/\" is not allowed inside a file name." : "Ne eblas uziĝi „/“ en dosiernomo.",
@@ -329,14 +361,23 @@ OC.L10N.register(
     "{newName} already exists" : "{newName} jam ekzistas",
     "Error loading file picker template: {error}" : "Eraro dum ŝargo de ŝablono pri dosier-elektilo: {error}",
     "Show list view" : "Montri listan vidon",
+    "Show grid view" : "Montri kradan vidon",
     "Pending" : "Pritraktota",
     "Home" : "Hejmo",
     "Copy to {folder}" : "Kopii al {folder}",
     "Move to {folder}" : "Movi al {folder}",
     "Authentication required" : "Aŭtentiĝo nepras",
+    "This action requires you to confirm your password" : "Tiu ĉi ago bezonas, ke vi konfirmas vian pasvorton",
+    "Confirm" : "Konfirmi",
     "Failed to authenticate, try again" : "Malsukcesis aŭtentigi, provu ree",
-    "File not found" : "Dosiero ne troviĝis",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "La dokumento ne troveblis en la servilo. Eble la kunhavigo estis forigita aŭ eksvalidiĝis?",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Bv. uzi komandlinian ĝisdatigilon, ĉar aŭtomata ĝisdatigo estas malebligita en la dosiero „config.php“."
+    "Users" : "Uzantoj",
+    "The page could not be found on the server." : "La paĝo ne povis esti trovita en la servilo.",
+    "Username" : "Uzantnomo",
+    "Database user" : "Datumbaza uzanto",
+    "Confirm your password" : "Konfirmu vian pasvorton",
+    "App token" : "Aplikaĵa ĵetono",
+    "Alternative log in using app token" : "Ensaluti alimaniere per aplikaĵa ĵetono",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Bv. uzi la komandlinian ĝisdatigilon, ĉar vi havas pli da 50 uzantojn en tiu servilo.",
+    "Avatar of {fullName}" : "Avataro de {fullName}"
 },
 "nplurals=2; plural=(n != 1);");
