@@ -75,13 +75,9 @@ OC.L10N.register(
     "Please contact your administrator." : "Palun võta ühendust oma administraatoriga.",
     "An internal error occurred." : "Tekkis sisemine tõrge.",
     "Please try again or contact your administrator." : "Palun proovi uuesti või võta ühendust oma administraatoriga.",
-    "Account name or email" : "Konto nimi või e-posti aadress",
     "Password" : "Parool",
-    "Wrong username or password." : "Vale kasutajanimi või parool.",
-    "User disabled" : "Kasutaja deaktiveeritud",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Me tuvastasime sinu IP-aadressilt palju ebaõnnestunud sisselogimiskatseid. Seetõttu on su järgmine sisselogimine ootel kuni 30 sekundit.",
     "Log in with a device" : "Logi sisse seadmega",
-    "Username or email" : "Kasutajanimi või e-posti aadress",
     "Your account is not setup for passwordless login." : "Su konto ei ole seadistatud paroolivaba sisenemise jaoks.",
     "Browser not supported" : "Brauser pole toetatud",
     "Passwordless authentication is not supported in your browser." : "Sinu brauser ei toeta paroolivaba sisenemist.",
@@ -182,7 +178,6 @@ OC.L10N.register(
     "Collaborative tags" : "Koostöö sildid",
     "No tags found" : "Silte ei leitud",
     "Personal" : "Isiklik",
-    "Users" : "Kasutajad",
     "Apps" : "Rakendused",
     "Admin" : "Admin",
     "Help" : "Abiinfo",
@@ -212,7 +207,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su andmekataloog ja failid on tõenäoliselt internetist vabalt ligipääsetavad, kuna .htaccess fail ei toimi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Serveri õigeks seadistamiseks leiad infot <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentatsioonist</a>.",
     "Create an <strong>admin account</strong>" : "Loo <strong>administraatori konto</strong>",
-    "Username" : "Kasutajanimi",
     "Show password" : "Näita parooli",
     "Toggle password visibility" : "Lülita parooli nähtavust",
     "Storage & database" : "Andmehoidla ja andmebaas",
@@ -221,7 +215,6 @@ OC.L10N.register(
     "Only %s is available." : "Ainult %s on saadaval.",
     "Install and activate additional PHP modules to choose other database types." : "Paigalda ja aktiveeri täiendavaid PHP mooduleid, et teisi andmebaasi tüüpe valida.",
     "For more details check out the documentation." : "Lisainfot vaata dokumentatsioonist.",
-    "Database user" : "Andmebaasi kasutaja",
     "Database password" : "Andmebaasi parool",
     "Database name" : "Andmebaasi nimi",
     "Database tablespace" : "Andmebaasi tabeliruum",
@@ -265,7 +258,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Suurtel saitidel aegumise vältimiseks võid sa paigalduskaustas käivitada järgmise käsu:",
     "Detailed logs" : "Üksikasjalikud logid",
     "Update needed" : "Uuendamine vajaliik",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Palun kasuta uuendamiseks käsurida, kuna sul on suur instants rohkem kui 50 kasutajaga.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Abi saamiseks vaata <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentatsiooni</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Olen teadlik, et veebiliidese kaudu uuendusega jätkamine hõlmab riski, et päring aegub ja põhjustab andmekadu, aga mul on varundus ja ma tean, kuidas tõrke korral oma instantsi taastada.",
     "Upgrade via web on my own risk" : "Uuenda veebi kaudu omal vastutusel",
@@ -275,6 +267,10 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Võta ühendust administraatoriga, kui see teade püsib või on tekkinud ootamatult.",
     "Please try again" : "Palun proovi uuesti",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ei tundu olevat süsteemsete keskkonnamuutujate pärimiseks korrektselt seadistatud. Test getenv(\"PATH\") abil tagastab tühja vastuse.",
+    "Account name or email" : "Konto nimi või e-posti aadress",
+    "Wrong username or password." : "Vale kasutajanimi või parool.",
+    "User disabled" : "Kasutaja deaktiveeritud",
+    "Username or email" : "Kasutajanimi või e-posti aadress",
     "Start search" : "Alusta otsingut",
     "Press enter to start searching" : "Otsimiseks vajuta Enter",
     "Settings" : "Seaded",
@@ -300,6 +296,10 @@ OC.L10N.register(
     "This action requires you to confirm your password" : "See tegevus nõuab parooli kinnitamist",
     "Confirm" : "Kinnita",
     "Failed to authenticate, try again" : "Autentimine ebaõnnestus, proovi uuesti",
-    "Confirm your password" : "Kinnita oma parool"
+    "Users" : "Kasutajad",
+    "Username" : "Kasutajanimi",
+    "Database user" : "Andmebaasi kasutaja",
+    "Confirm your password" : "Kinnita oma parool",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Palun kasuta uuendamiseks käsurida, kuna sul on suur instants rohkem kui 50 kasutajaga."
 },
 "nplurals=2; plural=(n != 1);");
