@@ -37,7 +37,6 @@ OC.L10N.register(
     "Nextcloud Server" : "שרת Nextcloud",
     "Some of your link shares have been removed" : "חלק מקישורי השיתופים שלך הוסרו",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "עקב תקלת אבטחה נאלצנו להסיר חלק מקישורי השיתופים שלך. נא להיכנס לקישור לקבלת פרטים נוספים.",
-    "The user limit of this instance is reached." : "מגבלת המשתמשים של מופע זה הושגה.",
     "Learn more ↗" : "מידע נוסף ↖ ",
     "Preparing update" : "מכין עדכון",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -60,19 +59,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "היישומים הבאים הושבתו: %s",
     "Already up to date" : "כבר עדכני",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "שרת האינטרנט לא מוגדר עדיין כראוי כדי לאפשר סנכרון קבצים, כיוון שמנשק ה־WebDAV כנראה אינו מתפקד.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "לא ניתן היה להפעיל את משימות ה־cron דרך שורת פקודה. השגיאות הטכניות הבאות התרחשו:",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "פונקציית ה־PHP‏ „set_time_limit” אינה זמינה. מצב זה עשוי לגרום לעצירת סקריפטים באמצע הפעולה ולפגיעה בהתקנה שלך. אנו ממליצים בחום להפעיל את הפונקציה הזאת.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "חסר אינדקס „{indexName}” בטבלה „{tableName}”.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה.",
-    "Missing primary key on table \"{tableName}\"." : "חסר מפתח ראשי בטבלה \"{tableName}\".",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "במסד הנתונים חסרים כמה מפתחות ראשיים. בשל העובדה שהוספת מפתחות ראשיים לטבלאות גדולות עשויה להימשך זמן מה, הם לא נוספו אוטומטית. על ידי הפעלת \"occ db: add-missing-primary-keys\", ניתן להוסיף מפתחות הראשיים החסרים האלה באופן ידני, בזמן שהמופע ממשיך לפעול.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "חסרה עמודה האופציונלית \"{columnName}\" בטבלה \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "במסד הנתונים חסרים כמה עמודות אופציונליות. בשל העובדה שהוספת עמודות בטבלאות גדולות עשויה להימשך זמן מה, הן לא נוספו אוטומטית כאשר הן יכולות להיות אופציונליות. על ידי הפעלת \"occ db: add-missing-column\", ניתן להוסיף את העמודות החסרות האלה באופן ידני בזמן שהמופע ממשיך לפעול. לאחר הוספת העמודות, חלק מהתכונות עשויות לשפר את ההיענות או את השימושיות.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "למודול php-imagick במקרה הזה אין תמיכה ב- SVG. לקבלת תאימות טובה יותר, מומלץ להתקין אותו.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite הוא מנגנון מסד הנתונים נכון לעכשיו. במערכות גדולות מוטב להחליף למנגנון מסד נתונים אחר.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "מצב זה מומלץ במיוחד כאשר מריצים את לקוח שולחן העבודה לסנכרון קבצים.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ספריות אפליקציות מסוימות הן בבעלות משתמש אחר מזה של שרת האינטרנט. זה יכול להיות במקרה שאפליקציות הותקנו באופן ידני. בדוק את ההרשאות של ספריות האפליקציות הבאות:",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "מופע זה משתמש באיחסון אובייקטים מבוססת S3 כאחסון ראשי. הקבצים שהועלו מאוחסנים באופן זמני בשרת, ולכן מומלץ שיהיה שטח פנוי של 50 GB בספריית ה- temp של PHP. בדוק ביומנים לקבלת יותר פרטים על הנתיב והשטח הזמין. כדי לשפר זאת, אנא שנה את הספריה הזמנית ב- php.ini, או תפנה יותר מקום בנתיב זה.",
     "Error occurred while checking server setup" : "שגיאה אירעה בזמן בדיקת התקנת השרת",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. מדובר בפרצת אבטחה או פרטיות, מומלץ להתאים את ההגדרה הזאת בהתאם.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "כותרת ה־HTTP‏ „{header}” אינה מוגדרת לערך „{expected}”. יתכן שחלק מהתכונות לא תעבודנה כראוי, מומלץ להתאים את ההגדרה הזאת בהתאם.",
@@ -83,7 +69,7 @@ OC.L10N.register(
     "Hello {name}" : "שלום {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>אלו תוצאות החיפוש שלך<script>alert(1)</script></strong>",
     "new" : "חדש",
-    "_download %n file_::_download %n files_" : ["התקבל קובץ %n","התקבלו %n קבצים","התקבלו %n קבצים","התקבלו %n קבצים"],
+    "_download %n file_::_download %n files_" : ["התקבל קובץ %n","התקבלו %n קבצים","התקבלו %n קבצים"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "העדכון מתבצע, יציאה מהעמוד הזה עשויה להפריע לתהליך בסביבות מסוימות.",
     "Update to {version}" : "עדכון ל־{version}",
     "An error occurred." : "אירעה שגיאה.",
@@ -97,13 +83,9 @@ OC.L10N.register(
     "Please contact your administrator." : "יש ליצור קשר עם המנהל.",
     "An internal error occurred." : "אירעה שגיאה פנימית.",
     "Please try again or contact your administrator." : "יש לנסות שוב ליצור קשר עם המנהל שלך.",
-    "Account name or email" : "שם משתמש או דואר אלקטרוני",
     "Password" : "ססמה",
-    "Wrong username or password." : "שם המשתמש או הססמה שגויים.",
-    "User disabled" : "משתמש מושבת",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "זיהינו מספר ניסיונות כניסה שגויים מכתובת ה־IP שלך. לכן, ניסיון הכניסה הבא יתאפשר עבורך רק בעוד 30 שניות.",
     "Log in with a device" : "כניסה עם מכשיר",
-    "Username or email" : "שם משתמש או דואר אלקטרוני",
     "Your account is not setup for passwordless login." : "החשבון שלך לא מוגדר לכניסה בלי ססמה.",
     "Passwordless authentication is not supported in your browser." : "אימות ללא ססמה אינו נתמך על ידי הדפדפן שלך.",
     "Passwordless authentication is only available over a secure connection." : "אימות ללא ססמה זמין רק דרך חיבור מאובטח.",
@@ -131,22 +113,23 @@ OC.L10N.register(
     "Install the Contacts app" : "התקנת יישומון אנשי הקשר",
     "Loading your contacts …" : "אנשי הקשר שלך נטענים…",
     "Looking for {term} …" : "מתבצע חיפוש אחר {term}…",
-    "Modified" : "מועד שינוי",
-    "Today" : "היום",
-    "Last year" : "שנה שעברה",
-    "Not found" : "לא נמצא",
-    "Load more results" : "לטעון עוד תוצאות",
-    "Forgot password?" : "שכחת ססמה?",
-    "Back" : "חזרה",
     "Search for {name} only" : "חפש ל-{name} בלבד",
     "Start typing to search" : "להתחלת החיפוש יש להקליד",
     "Loading more results …" : "נטענות תוצאות נוספות…",
+    "Load more results" : "לטעון עוד תוצאות",
     "Search" : "חיפוש",
     "No results for {query}" : "אין תוצאות עבור {query}",
     "An error occurred while searching for {type}" : "אירעה שגיאה בחיפוש אחר {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["נא להקליד לפחות תו אחד כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש","נא להקליד לפחות {minSearchLength} תווים כדי לחפש"],
-    "Settings menu" : "תפריט הגדרות",
+    "Forgot password?" : "שכחת ססמה?",
+    "Back" : "חזרה",
     "Search {types} …" : "חפש {types} ...",
+    "Date" : "תאריך",
+    "Today" : "היום",
+    "Last year" : "שנה שעברה",
+    "Not found" : "לא נמצא",
+    "Searching …" : "מתבצע חיפוש…",
+    "Settings menu" : "תפריט הגדרות",
     "No" : "לא",
     "Yes" : "כן",
     "Choose" : "בחירה",
@@ -196,7 +179,6 @@ OC.L10N.register(
     "Collaborative tags" : "תגיות שיתופיות",
     "No tags found" : "לא נמצאו תגים",
     "Personal" : "אישי",
-    "Users" : "משתמשים",
     "Apps" : "יישומים",
     "Admin" : "מנהל",
     "Help" : "עזרה",
@@ -224,7 +206,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "תיקיות וקובצי הנתונים שלך כנראה נגישים מהאינטרנט מכיוון שקובץ ה־‎.htaccess לא עובד.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "למידע בנוגע להגדרת השרת שלך כראוי, נא לעיין ב<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">תיעוד</a>.",
     "Create an <strong>admin account</strong>" : "יצירת <strong>חשבון מנהל</strong>",
-    "Username" : "שם משתמש",
     "Show password" : "הצגת ססמה",
     "Storage & database" : "אחסון ומסד נתונים",
     "Data folder" : "תיקיית נתונים",
@@ -232,7 +213,6 @@ OC.L10N.register(
     "Only %s is available." : "רק %s זמין.",
     "Install and activate additional PHP modules to choose other database types." : "לבחירת סוגים אחרים של מסדי נתונים יש להתקין ולהפעיל מודולי PHP נוספים.",
     "For more details check out the documentation." : "למידע נוסף יש לבדוק במסמכי התיעוד.",
-    "Database user" : "שם משתמש במסד הנתונים",
     "Database password" : "ססמת מסד הנתונים",
     "Database name" : "שם מסד הנתונים",
     "Database tablespace" : "מרחב הכתובות של מסד הנתונים",
@@ -252,15 +232,10 @@ OC.L10N.register(
     "Skip to navigation of app" : "דילוג לניווט של היישומון",
     "Go to %s" : "מעבר אל %s",
     "Get your own free account" : "קבלת חשבון משלך בחינם",
-    "This action requires you to confirm your password" : "פעולה זו דורשת ממך לאמת את הססמה שלך",
-    "Confirm your password" : "אימות הססמה שלך",
-    "Confirm" : "אימות",
     "Connect to your account" : "התחברות לחשבון שלך",
     "Please log in before granting %1$s access to your %2$s account." : "נא להיכנס בטרם הענקת גישה לחשבון שלך ב־%2$s לטובת %1$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "אם אינך מנסה להגדיר מכשיר חדש או אפליקציה חדשה, מישהו מנסה לרמות אותך להעניק לו גישה לנתונים שלך. במקרה הזה, אל תמשיך, ובמקום זאת פנה למנהל המערכת שלך.",
-    "App token" : "אסימון יישום",
     "Grant access" : "הענקת גישה",
-    "Alternative log in using app token" : "כניסה חלופית באמצעות אסימון יישומון",
     "Account access" : "גישה לחשבון",
     "You are about to grant %1$s access to your %2$s account." : "פעולה זו תעניק ל־%1$s גישה לחשבון ה־%2$s שלך.",
     "Account connected" : "חשבון מחובר",
@@ -292,7 +267,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "למניעת פסקי זמן בהתקנות גדולות, ניתן במקום להריץ את הפקודה הבאה בתיקיית ההתקנה שלך:",
     "Detailed logs" : "יומן מפורט",
     "Update needed" : "עדכון נדרש",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "נא להשתמש בתכנית העדכון משורת הפקודה כיוון שיש לך עותק גדול עם למעלה מ־50 משתמשים.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "לעזרה יש לעיין ב<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">תיעוד</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ידוע לי שאם אמשיך דרך מנשק הדפדפן אהיה חשוף לסכנה, שהבקשה עשויה להיקלע לחוסר מענה וכתוצאה מכך אבדן נתונים, אך יש לי גיבוי וידוע לי איך לשחזר את העותק שלי במקרה של כשל.",
     "Upgrade via web on my own risk" : "השדרוג דרך האינטרנט הוא על אחריותי",
@@ -300,13 +274,31 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "עותק %s זה כרגע במצב תחזוקה, שיארך זמן מה.",
     "This page will refresh itself when the instance is available again." : "עמוד זה ירענן את עצמו כאשר העותק ישוב להיות זמין.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "יש ליצור קשר עם מנהל המערכת אם הודעה שו נמשכת או מופיעה באופן בלתי צפוי. ",
+    "The user limit of this instance is reached." : "מגבלת המשתמשים של מופע זה הושגה.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "מסתבר כי PHP לא מוגדר כראוי כדי לתשאל משתני סביבה. הבדיקה עם getenv(\"PATH\") מחזירה תשובה ריקה בלבד.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "הופעלה תצורה לקריאה בלבד. מצב זה מונע את הגדרת חלק מההגדרות דרך מנשק דפדפן. יתרה מכך, יש להפוך את הקובץ למורשה לכתיבה ידנית בכל עדכון מחדש.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "מסד הנתונים שלך לא עובד עם רמת הפרדת פעולות של „READ COMMITTED” . מצב כזה יכול לגרום לבעיות כאשר מספר פעולות רצות במקביל.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "מודול ה־PHP בשם „fileinfo” חסר. מומלץ בחום להפעיל את המודול הזה כדי לקבל את התוצאות הטובות ביותר בזיהוי סוג MIME.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "לא ניתן היה להפעיל את משימות ה־cron דרך שורת פקודה. השגיאות הטכניות הבאות התרחשו:",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "פונקציית ה־PHP‏ „set_time_limit” אינה זמינה. מצב זה עשוי לגרום לעצירת סקריפטים באמצע הפעולה ולפגיעה בהתקנה שלך. אנו ממליצים בחום להפעיל את הפונקציה הזאת.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "ל־PHP שלך אין תמיכה ב־FreeType. מצב כזה יגרום לתמונות פרופיל משובשות לצד מנשק הגדרות משובש.",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "חסר אינדקס „{indexName}” בטבלה „{tableName}”.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה.",
+    "Missing primary key on table \"{tableName}\"." : "חסר מפתח ראשי בטבלה \"{tableName}\".",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "במסד הנתונים חסרים כמה מפתחות ראשיים. בשל העובדה שהוספת מפתחות ראשיים לטבלאות גדולות עשויה להימשך זמן מה, הם לא נוספו אוטומטית. על ידי הפעלת \"occ db: add-missing-primary-keys\", ניתן להוסיף מפתחות הראשיים החסרים האלה באופן ידני, בזמן שהמופע ממשיך לפעול.",
+    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "חסרה עמודה האופציונלית \"{columnName}\" בטבלה \"{tableName}\".",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "במסד הנתונים חסרים כמה עמודות אופציונליות. בשל העובדה שהוספת עמודות בטבלאות גדולות עשויה להימשך זמן מה, הן לא נוספו אוטומטית כאשר הן יכולות להיות אופציונליות. על ידי הפעלת \"occ db: add-missing-column\", ניתן להוסיף את העמודות החסרות האלה באופן ידני בזמן שהמופע ממשיך לפעול. לאחר הוספת העמודות, חלק מהתכונות עשויות לשפר את ההיענות או את השימושיות.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "במופע זה חסרים כמה מודולי PHP מומלצים. לשיפור ביצועים ותאימות טובה יותר, מומלץ להתקין אותם.",
+    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "למודול php-imagick במקרה הזה אין תמיכה ב- SVG. לקבלת תאימות טובה יותר, מומלץ להתקין אותו.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite הוא מנגנון מסד הנתונים נכון לעכשיו. במערכות גדולות מוטב להחליף למנגנון מסד נתונים אחר.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "מצב זה מומלץ במיוחד כאשר מריצים את לקוח שולחן העבודה לסנכרון קבצים.",
     "The PHP memory limit is below the recommended value of 512MB." : "מגבלת הזיכרון של ה־PHP היא מתחת לערך המומלץ על סך 512 מ״ב.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ספריות אפליקציות מסוימות הן בבעלות משתמש אחר מזה של שרת האינטרנט. זה יכול להיות במקרה שאפליקציות הותקנו באופן ידני. בדוק את ההרשאות של ספריות האפליקציות הבאות:",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "מופע זה משתמש באיחסון אובייקטים מבוססת S3 כאחסון ראשי. הקבצים שהועלו מאוחסנים באופן זמני בשרת, ולכן מומלץ שיהיה שטח פנוי של 50 GB בספריית ה- temp של PHP. בדוק ביומנים לקבלת יותר פרטים על הנתיב והשטח הזמין. כדי לשפר זאת, אנא שנה את הספריה הזמנית ב- php.ini, או תפנה יותר מקום בנתיב זה.",
+    "Account name or email" : "שם משתמש או דואר אלקטרוני",
+    "Wrong username or password." : "שם המשתמש או הססמה שגויים.",
+    "User disabled" : "משתמש מושבת",
+    "Username or email" : "שם משתמש או דואר אלקטרוני",
     "If it is not there ask your local administrator." : "אם זה לא נמצא, שאל את המנהל המקומי שלך.",
     "Settings" : "הגדרות",
     "Show all contacts …" : "הצגת כל אנשי הקשר…",
@@ -315,6 +307,7 @@ OC.L10N.register(
     "No more subfolders in here" : "אין כאן עוד תת־תיקיות",
     "Name" : "שם",
     "Size" : "גודל",
+    "Modified" : "מועד שינוי",
     "\"{name}\" is an invalid file name." : "\"{name}\" הנו שם קובץ לא חוקי.",
     "File name cannot be empty." : "שם קובץ אינו יכול להיות ריק",
     "\"/\" is not allowed inside a file name." : "אסור להשתמש ב־„/” בתוך שם קובץ.",
@@ -326,9 +319,15 @@ OC.L10N.register(
     "Copy to {folder}" : "העתקה אל {folder}",
     "Move to {folder}" : "העברה אל {folder}",
     "Authentication required" : "נדרש אימות",
+    "This action requires you to confirm your password" : "פעולה זו דורשת ממך לאמת את הססמה שלך",
+    "Confirm" : "אימות",
     "Failed to authenticate, try again" : "האימות נכשל, נא לנסות שוב",
-    "File not found" : "קובץ לא נמצא",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "לא ניתן למצוא את המסמך בשרת. יכול להיות שהשיתוף נמחק או פג?",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "יש להשתמש בעדכון על בסיס שורת פקודה כיוון שעדכון אוטומטי מנוטרל בקובץ config.php."
+    "Users" : "משתמשים",
+    "Username" : "שם משתמש",
+    "Database user" : "שם משתמש במסד הנתונים",
+    "Confirm your password" : "אימות הססמה שלך",
+    "App token" : "אסימון יישום",
+    "Alternative log in using app token" : "כניסה חלופית באמצעות אסימון יישומון",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "נא להשתמש בתכנית העדכון משורת הפקודה כיוון שיש לך עותק גדול עם למעלה מ־50 משתמשים."
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
