@@ -37,7 +37,6 @@ OC.L10N.register(
     "Nextcloud Server" : "Nextcloud poslužitelj",
     "Some of your link shares have been removed" : "Uklonjene su neke od vaših dijeljenih poveznica",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Zbog sigurnosne pogreške morali smo ukloniti neke od vaših dijeljenih poveznica. Za više informacija pogledajte poveznicu.",
-    "The user limit of this instance is reached." : "Dostignuto je ograničenje broja korisnika za ovu instancu.",
     "Learn more ↗" : "Saznajte više ↗",
     "Preparing update" : "Priprema ažuriranja",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -62,17 +61,6 @@ OC.L10N.register(
     "Already up to date" : "Nema potrebe za ažuriranjem",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Vaš mrežni poslužitelj nije pravilno podešen za sinkronizaciju podataka jer je sučelje protokola WebDAV neispravno.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Vaš mrežni poslužitelj ne može razriješiti „{url}”. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Vaš web poslužitelj nije ispravno postavljen za razrješavanje „{url}”. To je najvjerojatnije uzrokovano konfiguracijom web-poslužitelja koja nije ažurirana i ne isporučuje izravno mapu. Usporedite svoju konfiguraciju s isporučenim pravilima za prepisivanje u „.htaccess” za Apache ili u dokumentaciji za Nginx na {linkstart}stranici s dokumentacijom ↗{linkend}. Na Nginxu su to obično linije koje počinju s „location ~” i potrebno ih je ažurirati.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Vaš web poslužitelj nije ispravno postavljen za isporuku .woff2 datoteka. To je obično problem s konfiguracijom Nginxa. Nextcloud 15 zahtijeva podešavanje za isporuku .woff2 datoteka. Usporedite svoju Nginx konfiguraciju s preporučenom konfiguracijom u našoj {linkstart}dokumentaciji ↗{linkend}.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nije bilo moguće izvršiti cron zadatak putem sučelja komandne linije. Došlo je do sljedećih tehničkih pogrešaka:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Zadnje izvršenje zadatka u pozadini trajalo je {relativeTime}. Nešto nije u redu. {linkstart}Provjerite postavke za pozadinske zadatke ↗{linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached je konfiguriran kao distribuirana predmemorija, ali je instaliran pogrešan PHP modul „memcache”. \\OC\\Memcache\\Memcached podržava samo „memcached”, a ne „memcache”. Pogledajte {linkstart}memcached wiki za informacije o oba modula ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Neke datoteke nisu prošle provjeru cjelovitosti. Dodatne informacije o tome kako riješiti taj problem možete pronaći u {linkstart1}dokumentaciji ↗{linkend}. ({linkstart2}Popis nevažećih datoteka…{linkend} / {linkstart3}Ponovno skeniranje…{linkend})",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcija PHP-a „set_time_limit” nije dostupna. To bi moglo dovesti do zaustavljanja skripti tijekom izvršenja i prekida instalacije. Preporučuje se uključivanje ove funkcije.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modul php-imagick nema podršku za SVG u ovoj instanci. Preporučuje se da ga instalirate kako biste osigurali bolju kompatibilnost.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Određeni direktoriji aplikacija vlasništvo su korisnika koji nije vlasnik web poslužitelja. To se može dogoditi ako su aplikacije ručno instalirane. Provjerite dopuštenja za sljedeće direktorije aplikacija:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL se koristi kao aktivna baza podataka, ali ne podržava 4-bajtne znakove. Kako biste se mogli koristiti 4-bajtnim znakovima (primjerice, smajlići) bez problema u nazivima datoteka ili komentarima, preporučuje se da omogućite 4-bajtnu podršku u MySQL-u. Za više pojedinosti pročitajte {linkstart}odgovarajuće poglavlje u dokumentaciji ↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ova instanca upotrebljava pohranu objekta temeljenu na S3 kao primarnu pohranu. Otpremljene datoteke privremeno se pohranjuju na poslužitelju i stoga je preporučljivo osigurati 50 GB slobodnog prostora u privremenom direktoriju PHP-a. Više informacija o putovima i dostupnom prostoru potražite u zapisima poslužitelja. Ako želite osloboditi više prostora, promijenite privremeni direktorij u datoteci php.ini ili oslobodite prostor na tom putu.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Instanci pristupate putem sigurne veze, ali instanca generira nesigurne URL-ove. To najvjerojatnije znači da se nalazite iza obrnutog proxyja i nisu točno postavljene varijable za izmjenu konfiguracijske datoteke. Pročitajte {linkstart}odgovarajuću dokumentaciju ↗{linkend}.",
     "Error occurred while checking server setup" : "Pogreška prilikom provjere postavki poslužitelja",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Više informacija potražite u {linkstart}dokumentaciji ↗{linkend}.",
@@ -104,11 +92,8 @@ OC.L10N.register(
     "An internal error occurred." : "Došlo je do unutarnje pogreške.",
     "Please try again or contact your administrator." : "Pokušajte ponovno ili se obratite svom administratoru.",
     "Password" : "Zaporka",
-    "Wrong username or password." : "Pogrešno korisničko ime ili zaporka.",
-    "User disabled" : "Korisnik je onemogućen",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Otkrili smo nekoliko nevažećih pokušaja prijave s vaše IP adrese. Iduća prijava odgađa se za najviše 30 sekundi.",
     "Log in with a device" : "Prijavite se s pomoću uređaja",
-    "Username or email" : "Korisničko ime ili adresa e-pošte",
     "Your account is not setup for passwordless login." : "Nije odabrana mogućnost prijave bez zaporke za vaš račun.",
     "Browser not supported" : "Preglednik nije podržan",
     "Passwordless authentication is not supported in your browser." : "Vaš preglednik ne podržava autentifikaciju bez zaporke.",
@@ -210,7 +195,7 @@ OC.L10N.register(
     "Collaborative tags" : "Oznake za suradnju",
     "No tags found" : "Nema pronađenih oznaka",
     "Personal" : "Osobno",
-    "Users" : "Korisnici",
+    "Accounts" : "Korisnićki računi",
     "Apps" : "Aplikacije",
     "Admin" : "Administrator",
     "Help" : "Pomoć",
@@ -238,7 +223,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Vašem podatkovnom direktoriju i datotekama vjerojatno se može pristupiti putem interneta jer .htaccess datoteka ne radi.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informacije o ispravnom konfiguriranju poslužitelja potražite u <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentaciji</a>.",
     "Create an <strong>admin account</strong>" : "Stvori <strong>administracijski račun</strong>",
-    "Username" : "Korisničko ime",
     "Show password" : "Pokaži zaporku",
     "Toggle password visibility" : "Uključivanje/isključivanje vidljivosti zaporke",
     "Storage & database" : "Pohrana i baza podataka",
@@ -247,7 +231,6 @@ OC.L10N.register(
     "Only %s is available." : "Jedino je %s dostupan.",
     "Install and activate additional PHP modules to choose other database types." : "Instalirajte i aktivirajte dodatne module PHP-a kako biste odabrali druge vrste baza podataka.",
     "For more details check out the documentation." : "Za više informacija pogledajte dokumentaciju.",
-    "Database user" : "Korisnik baze podataka",
     "Database password" : "Zaporka baze podataka",
     "Database name" : "Naziv baze podataka",
     "Database tablespace" : "Tablični prostor baze podataka",
@@ -267,15 +250,10 @@ OC.L10N.register(
     "Skip to navigation of app" : "Preskoči na navigaciju aplikacije",
     "Go to %s" : "Idi na %s",
     "Get your own free account" : "Otvorite besplatni račun",
-    "This action requires you to confirm your password" : "Za izvršavanje ove radnje potvrdite svoju zaporku",
-    "Confirm your password" : "Potvrdite svoju zaporku",
-    "Confirm" : "Potvrdi",
     "Connect to your account" : "Povežite se sa svojim računom",
     "Please log in before granting %1$s access to your %2$s account." : "Prijavite se prije odobravanja pristupa %1$s svom računu %2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Ako ne pokušavate postaviti novi uređaj ili aplikaciju, netko vas pokušava navesti da mu odobrite pristup svojim podacima. U tom slučaju nemojte nastaviti, već se obratite administratoru sustava.",
-    "App token" : "Aplikacijski token",
     "Grant access" : "Dodijeli pristup",
-    "Alternative log in using app token" : "Alternativna prijava s pomoću aplikacijskog tokena",
     "Account access" : "Pristup računu",
     "You are about to grant %1$s access to your %2$s account." : "Dopustit ćete osobi %1$s pristup vašem računu %2$s.",
     "Account connected" : "Račun povezan",
@@ -307,7 +285,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Kako biste izbjegli vremensko prekoračenje pri većim instalacijama, možete pokrenuti sljedeću naredbu iz svog instalacijskog direktorija:",
     "Detailed logs" : "Detaljni zapisnik",
     "Update needed" : "Potrebno ažurirati",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Ažurirajte putem naredbenog retka jer imate veliku instancu s više od 50 korisnika.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pomoć potražite u <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentaciji</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Ako nastavim s ažuriranjem putem korisničkog web sučelja, postoji rizik da taj zahtjev dosegne vremensko ograničenje i dođe do gubitka podataka, ali imam sigurnosnu kopiju i znam kako vratiti instancu u slučaju problema.",
     "Upgrade via web on my own risk" : "Nadogradnja preko mreže na vlastitu odgovornost",
@@ -315,6 +292,9 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Ova %s instanca trenutno je u načinu za održavanje; ovo može potrajati.",
     "This page will refresh itself when the instance is available again." : "Ova će se stranica osvježiti kada je instanca ponovno dostupna.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Obratite se administratoru sustava ako se ova poruka ponavlja ili se pojavila neočekivano.",
+    "The user limit of this instance is reached." : "Dostignuto je ograničenje broja korisnika za ovu instancu.",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Vaš web poslužitelj nije ispravno postavljen za razrješavanje „{url}”. To je najvjerojatnije uzrokovano konfiguracijom web-poslužitelja koja nije ažurirana i ne isporučuje izravno mapu. Usporedite svoju konfiguraciju s isporučenim pravilima za prepisivanje u „.htaccess” za Apache ili u dokumentaciji za Nginx na {linkstart}stranici s dokumentacijom ↗{linkend}. Na Nginxu su to obično linije koje počinju s „location ~” i potrebno ih je ažurirati.",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Vaš web poslužitelj nije ispravno postavljen za isporuku .woff2 datoteka. To je obično problem s konfiguracijom Nginxa. Nextcloud 15 zahtijeva podešavanje za isporuku .woff2 datoteka. Usporedite svoju Nginx konfiguraciju s preporučenom konfiguracijom u našoj {linkstart}dokumentaciji ↗{linkend}.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Čini se da PHP nije ispravno postavljen za slanje upita u vezi s varijablama okruženja sustava. Ispitivanje s getenv („PATH”) vraća samo prazan odgovor.",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Provjerite {linkstart}instalacijsku dokumentaciju ↗{linkend} za napomene o konfiguraciji PHP-a i konfiguraciju PHP-a na svojem poslužitelju, posebice ako upotrebljavate php-fpm.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Omogućena je konfiguracija samo za čitanje. Time se sprječava postavljanje nekih konfiguracija putem web-sučelja. Nadalje, datoteku treba ručno prebaciti u način pisanja pri svakom ažuriranju.",
@@ -322,10 +302,15 @@ OC.L10N.register(
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Nedostaje PHP modul „fileinfo”. Preporučujemo da omogućite ovaj modul kako biste postigli najbolje rezultate s detekcijom vrste MIME.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Onemogućeno je zaključavanje transakcijskih datoteka što može dovesti do problema s uvjetima utrke. Omogućite „filelocking.enabled” u datoteci config.php kako biste izbjegli navedene probleme. Pogledajte {linkstart}dokumentaciju ↗{linkend} za više informacija.",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Nije postavljena zadana regija telefonskih brojeva za vašu instalaciju. Potrebna je radi provjeravanja valjanosti telefonskih brojeva u postavkama profila bez pozivnog broja države. Kako biste omogućili korištenje brojeva bez pozivnog broja države dodajte „default_phone_region” s odgovarajućom {linkstart}ISO 3166-1 šifrom ↗{linkend} regije u svoju konfiguracijsku datoteku.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nije bilo moguće izvršiti cron zadatak putem sučelja komandne linije. Došlo je do sljedećih tehničkih pogrešaka:",
+    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Zadnje izvršenje zadatka u pozadini trajalo je {relativeTime}. Nešto nije u redu. {linkstart}Provjerite postavke za pozadinske zadatke ↗{linkend}.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nije konfigurirana nikakva predmemorija. Kako biste poboljšali performanse sustava, konfigurirajte predmemoriju ako je dostupna. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP nije pronašao nikakav izvor nasumičnosti što nije povoljno iz sigurnosnog gledišta. Više informacija možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Trenutno upotrebljavate PHP {version}. Nadogradite inačicu PHP-a kako biste iskoristili {linkstart}ažuriranja performansi i sigurnosti koje isporučuje PHP Grupa ↗{linkend} čim vam vaša distribucija to omogući.",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfiguracija obrnutog proxy zaglavlja je netočna ili pristupate Nextcloudu putem pouzdanog proxy poslužitelja. Ako to nije slučaj, radi se o sigurnosnom problemu koji može omogućiti napadaču da lažno predstavi svoju IP adresu koja je vidljiva Nextcloudu. Dodatne informacije možete pronaći u {linkstart}dokumentaciji ↗{linkend}.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached je konfiguriran kao distribuirana predmemorija, ali je instaliran pogrešan PHP modul „memcache”. \\OC\\Memcache\\Memcached podržava samo „memcached”, a ne „memcache”. Pogledajte {linkstart}memcached wiki za informacije o oba modula ↗{linkend}.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Neke datoteke nisu prošle provjeru cjelovitosti. Dodatne informacije o tome kako riješiti taj problem možete pronaći u {linkstart1}dokumentaciji ↗{linkend}. ({linkstart2}Popis nevažećih datoteka…{linkend} / {linkstart3}Ponovno skeniranje…{linkend})",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcija PHP-a „set_time_limit” nije dostupna. To bi moglo dovesti do zaustavljanja skripti tijekom izvršenja i prekida instalacije. Preporučuje se uključivanje ove funkcije.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vaš PHP nema podršku za FreeType što može uzrokovati neispravan prikaz profilnih slika i sučelja postavki.",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Nedostaje indeks „{indexName}” u tablici „{tableName}”.",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "U bazi podataka nedostaju određeni indeksi. Zbog činjenice da bi dodavanje indeksa u velikim tablicama moglo potrajati neko duže vrijeme, isti se ne dodaju automatski. Izvršenjem „occ db:add-missing-indices” se ti indeksi mogu ručno dodati dok instanca radi. Kada se indeksi dodaju, upiti u te tablice obično su mnogo brži.",
@@ -334,9 +319,16 @@ OC.L10N.register(
     "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Nedostaje neobavezan stupac „{columnName}” u tablici „{tableName}”.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "U bazi podataka nedostaju određeni neobavezni stupci. Zbog činjenice da bi dodavanje stupaca u velikim tablicama moglo potrajati neko duže vrijeme, stupci se ne dodaju automatski, već je njihovo dodavanje neobavezno. Izvršenjem „occ db:add-missing-columns” ti se stupci mogu ručno dodati dok instanca radi. Nakon dodavanja stupaca može se poboljšati odaziv ili uporabljivost određenih značajki.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "U ovoj instanci nedostaju neki preporučeni moduli PHP-a. Preporučujemo da ih instalirate kako biste poboljšali performanse i ostvarili bolju kompatibilnost.",
+    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modul php-imagick nema podršku za SVG u ovoj instanci. Preporučuje se da ga instalirate kako biste osigurali bolju kompatibilnost.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite se trenutno upotrebljava kao pozadinska baza podataka. Za veće instalacije preporučujemo da se prebacite na neku drugu pozadinsku bazu podataka.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "To se osobito preporučuje ako upotrebljavate klijent za sinkronizaciju datoteka.",
     "The PHP memory limit is below the recommended value of 512MB." : "Ograničenje memorije PHP-a ispod je preporučene vrijednosti od 512 MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Određeni direktoriji aplikacija vlasništvo su korisnika koji nije vlasnik web poslužitelja. To se može dogoditi ako su aplikacije ručno instalirane. Provjerite dopuštenja za sljedeće direktorije aplikacija:",
+    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL se koristi kao aktivna baza podataka, ali ne podržava 4-bajtne znakove. Kako biste se mogli koristiti 4-bajtnim znakovima (primjerice, smajlići) bez problema u nazivima datoteka ili komentarima, preporučuje se da omogućite 4-bajtnu podršku u MySQL-u. Za više pojedinosti pročitajte {linkstart}odgovarajuće poglavlje u dokumentaciji ↗{linkend}.",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ova instanca upotrebljava pohranu objekta temeljenu na S3 kao primarnu pohranu. Otpremljene datoteke privremeno se pohranjuju na poslužitelju i stoga je preporučljivo osigurati 50 GB slobodnog prostora u privremenom direktoriju PHP-a. Više informacija o putovima i dostupnom prostoru potražite u zapisima poslužitelja. Ako želite osloboditi više prostora, promijenite privremeni direktorij u datoteci php.ini ili oslobodite prostor na tom putu.",
+    "Wrong username or password." : "Pogrešno korisničko ime ili zaporka.",
+    "User disabled" : "Korisnik je onemogućen",
+    "Username or email" : "Korisničko ime ili adresa e-pošte",
     "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Poslana Vam je poruka za resetiranje zaporke na adresu e-pošte za ovaj račun. Ako je niste primili, provjerite Vaše mape smeća i neželjene pošte, ili se obratite svom lokalnom administratoru.",
     "If it is not there ask your local administrator." : "Ako i tamo nema poruke, obratite se lokalnom administratoru.",
     "Settings" : "Postavke",
@@ -358,6 +350,15 @@ OC.L10N.register(
     "Copy to {folder}" : "Kopiraj u {folder}",
     "Move to {folder}" : "Premjesti u {folder}",
     "Authentication required" : "Potrebna autentifikacija",
-    "Failed to authenticate, try again" : "Pogreška pri provjeri autentičnosti, pokušajte ponovo"
+    "This action requires you to confirm your password" : "Za izvršavanje ove radnje potvrdite svoju zaporku",
+    "Confirm" : "Potvrdi",
+    "Failed to authenticate, try again" : "Pogreška pri provjeri autentičnosti, pokušajte ponovo",
+    "Users" : "Korisnici",
+    "Username" : "Korisničko ime",
+    "Database user" : "Korisnik baze podataka",
+    "Confirm your password" : "Potvrdite svoju zaporku",
+    "App token" : "Aplikacijski token",
+    "Alternative log in using app token" : "Alternativna prijava s pomoću aplikacijskog tokena",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Ažurirajte putem naredbenog retka jer imate veliku instancu s više od 50 korisnika."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
