@@ -50,8 +50,8 @@ OC.L10N.register(
     "Nextcloud Server" : "Nextcloud サーバー",
     "Some of your link shares have been removed" : "リンク共有の一部が削除されました",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "セキュリティ上の不具合により、あなたのリンク共有をいくつか削除する必要がありました。 詳しくはリンクをご覧ください。",
-    "The user limit of this instance is reached." : "このインスタンスのユーザー制限に達しました。",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "サポートappへサブスクリプションキーを入力すると、ユーザー数の上限を増やすことができます。また、Nextcloud Enterpriseが提供するすべての追加特典が付与されますので、企業で運用に必須です",
+    "The account limit of this instance is reached." : "このインスタンスのアカウント制限に達しました。",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "support app にサブスクリプションキーを入力して、アカウント数の上限を増やすことができます。これにより、Nextcloud Enterprise が提供するすべての追加特典が付与され、企業での運用には非常におすすめです。",
     "Learn more ↗" : "もっと詳しく知る",
     "Preparing update" : "アップデートの準備中",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -77,14 +77,7 @@ OC.L10N.register(
     "Already up to date" : "すべて更新済",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "WebDAVインターフェースが動作していないようです。Webサーバーは、ファイルの同期を許可するよう適切に設定されていません。",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。これは、このフォルダーを直接配信するように更新されていないWebサーバー構成が影響している可能性があります。構成を、Apacheの \".htaccess\" にある設定済みの書き換えルールまたはNginxのドキュメントの{linkstart}ドキュメントページ↗{linkend}で提供されているルールと比較してください。 Nginxでは、これらは通常、修正が必要な \"location〜\" で始まる行です。",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Webサーバーで.woff2ファイルが配信されるように適切に設定されていません。これは通常、Nginx構成の問題です。 Nextcloud 15の場合、.woff2ファイルも配信するように調整する必要があります。 Nginx構成を{linkstart}ドキュメント↗{linkend}の推奨構成と比較してください。",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "本サーバーはNextcloudのサポートがないコミュニティビルドで動いています。実行中の規模でのパフォーマンス、信頼性、スケーラビリティを保証するものではありません。プッシュ通知は無料サービスへ負荷がかからないように制限されています。Nextcloud Enterpriseのメリットについては、{linkstart}https://nextcloud.com/enterprise{linkend}を参照してください。",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "データベースとしてMySQLを使用していますが、4バイト文字をサポートしていません。ファイル名やコメントなどで4バイト文字（絵文字など）を問題なく扱うためには、MySQLで4バイトサポートを有効にすることが推奨されます。詳細は{linkstart}これに関するドキュメントページ↗{linkend}をお読みください。",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "このインスタンスは、S3ベースのオブジェクトストアをプライマリストレージとして使用します。 アップロードされたファイルは一時的にサーバーに保存されるため、PHPの一時ディレクトリに50 GBの空き容量を確保することをお勧めします。 パスと空き容量についての完全な詳細はログを確認してください。 一時ディレクトリを修正するには、php.iniの一時ディレクトリを変更するか、またはそのパスでより多くのスペースを利用できるようにしてください。",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "このインスタンスで指定している一時ディレクトリは、存在しないか書き込みできないディレクトリです。",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "安全な接続でインスタンスにアクセスしていますが、インスタンスは安全でないURLを生成しています。これは、リバースプロキシの背後にあり、構成設定変数が正しく上書きされていない可能性があります。これについては、{linkend}ドキュメントページ↗{linkstart}をお読みください。",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "このインスタンスはデバッグ モードで実行されています。これはローカル開発の場合にのみ有効にし、運用環境では有効にしないでください。",
     "Error occurred while checking server setup" : "サーバー設定のチェック中にエラーが発生しました",
     "For more details see the {linkstart}documentation ↗{linkend}." : "詳細については、{linkstart}ドキュメント↗{linkend}を参照してください。",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "データディレクトリやファイルがインターネットからアクセスされている可能性があります。.htaccessファイルが機能していません。データディレクトリにアクセスできないようにWebサーバーを設定するか、データディレクトリをWebサーバーのドキュメントルートの外に移動することを強くお勧めします。",
@@ -126,21 +119,20 @@ OC.L10N.register(
     "Please try again." : "もう一度お試しください。",
     "An internal error occurred." : "内部エラーが発生しました。",
     "Please try again or contact your administrator." : "もう一度やり直してみるか、管理者にお問い合わせください。",
-    "Account name or email" : "アカウント名またはメールアドレス",
+    "Login or email" : "ログイン名またはEメール",
     "Password" : "パスワード",
     "Log in to {productName}" : "{productName} へログイン",
-    "Wrong username or password." : "ユーザー名またはパスワードが間違っています",
-    "User disabled" : "ユーザーは無効です",
+    "Wrong login or password." : "ログイン名またはパスワードが間違っています。",
+    "This account is disabled" : "アカウントが無効化されています",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "あなたのIPから複数の無効なログイン試行が検出されました。 したがって、次回のログインは最大30秒間抑制されます。",
     "Log in with a device" : "デバイスを使ってログインする",
-    "Username or email" : "ユーザー名またはメールアドレス",
     "Your account is not setup for passwordless login." : "あなたのアカウントはパスワードなしでログインできるように設定されていません。",
     "Browser not supported" : "サポートされていないブラウザーです",
     "Passwordless authentication is not supported in your browser." : "お使いのブラウザーはパスワードレス認証に対応していません。",
     "Your connection is not secure" : "この接続は安全ではありません",
     "Passwordless authentication is only available over a secure connection." : "パスワードレス認証は、セキュアな接続でのみ利用可能です。",
     "Reset password" : "パスワードをリセット",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在したら、パスワード変更のメッセージがそのメールアドレスに送信されます。\nもしメールが届いていない場合は、メールアドレスまたはアカウント名を確認するか、メールが迷惑メールフォルダに入っていないか確認するか、もしくは管理者にお問い合わせください。",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在する場合、パスワードリセットメッセージがメールアドレスに送信されています。もしメッセージが届かない場合は、メールアドレスやログイン名を確認するか、迷惑メールフォルダをチェックするか、もしくは管理者にお問い合わせください。",
     "Couldn't send reset email. Please contact your administrator." : "リセットメールを送信できませんでした。管理者に問い合わせてください。",
     "Password cannot be changed. Please contact your administrator." : "パスワードは変更できません。管理者に問い合わせてください。",
     "Back to login" : "ログインに戻る",
@@ -269,7 +261,7 @@ OC.L10N.register(
     "Collaborative tags" : "コラボタグ",
     "No tags found" : "タグが見つかりません",
     "Personal" : "個人",
-    "Users" : "ユーザー",
+    "Accounts" : "アカウント",
     "Apps" : "アプリ",
     "Admin" : "管理",
     "Help" : "ヘルプ",
@@ -300,7 +292,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccessファイルが動作していないため、おそらくあなたのデータディレクトリまたはファイルはインターネットからアクセス可能になっています。",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "サーバーを適正に設定する情報は、こちらの<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ドキュメント</a>を参照してください。",
     "Create an <strong>admin account</strong>" : "<strong>管理者アカウント</strong>を作成してください",
-    "Username" : "ユーザー名",
     "Show password" : "パスワードを表示",
     "Toggle password visibility" : "パスワードの表示/非表示を切り替える",
     "Storage & database" : "ストレージとデータベース",
@@ -309,7 +300,7 @@ OC.L10N.register(
     "Only %s is available." : "%s のみ有効です。",
     "Install and activate additional PHP modules to choose other database types." : "他のデータベースタイプを選択するためには、追加の PHP モジュールインストールして有効化してください。",
     "For more details check out the documentation." : "詳細は、ドキュメントを確認してください。",
-    "Database user" : "データベースのユーザー名",
+    "Database account" : "データベースアカウント",
     "Database password" : "データベースのパスワード",
     "Database name" : "データベース名",
     "Database tablespace" : "データベースの表領域",
@@ -372,7 +363,7 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "大規模なサイトの場合、ブラウザーがタイムアウトする可能性があるため、インストールディレクトリで次のコマンドを実行することもできます。",
     "Detailed logs" : "詳細ログ",
     "Update needed" : "更新が必要です",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "50人以上が使う大規模システムの場合は、コマンドラインでアップグレードを行ってください。",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "50人以上のアカウントを持つ大規模なインスタンスの場合は、コマンドラインのアップデータを使用してください。",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "不明な場合、  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ドキュメント</a>を参照してください。",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Web 画面から続行すると危険性があることを理解しています。この操作がタイムアウトすると、データが失われる危険性があることを理解しています。もし失敗した場合には取得済みのバックアップから修復する方法を理解しています。",
     "Upgrade via web on my own risk" : "危険性を理解した上でWeb画面からアップグレード",
@@ -381,6 +372,10 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "この画面は、サーバー の再起動後に自動的に更新されます。",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "このメッセージが引き続き、または予期せず現れる場合は、システム管理者に問い合わせてください。",
     "Please try again" : "再度お試しください",
+    "The user limit of this instance is reached." : "このインスタンスのユーザー制限に達しました。",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "サポートappへサブスクリプションキーを入力すると、ユーザー数の上限を増やすことができます。また、Nextcloud Enterpriseが提供するすべての追加特典が付与されますので、企業で運用に必須です",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Webサーバーで \"{url}\" が解決されるように正しく設定されていません。これは、このフォルダーを直接配信するように更新されていないWebサーバー構成が影響している可能性があります。構成を、Apacheの \".htaccess\" にある設定済みの書き換えルールまたはNginxのドキュメントの{linkstart}ドキュメントページ↗{linkend}で提供されているルールと比較してください。 Nginxでは、これらは通常、修正が必要な \"location〜\" で始まる行です。",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Webサーバーで.woff2ファイルが配信されるように適切に設定されていません。これは通常、Nginx構成の問題です。 Nextcloud 15の場合、.woff2ファイルも配信するように調整する必要があります。 Nginx構成を{linkstart}ドキュメント↗{linkend}の推奨構成と比較してください。",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHPのシステム環境変数が正しく設定されていないようです。getenv(\"PATH\") コマンドでテストして何も値を返さないことを確認してください。",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "特にphp-fpmを使用する場合は、{linkstart}インストールドキュメント↗{linkend}でPHP構成に関する注意事項とサーバーのPHP構成を確認してください。",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "\"config\"は読み取り専用になってます。そのためにWEBインターフェースで設定できません可能性があります。さらに、更新時に\"config\"ファイルを書き込み権限を与えることが必要",
@@ -392,6 +387,7 @@ OC.L10N.register(
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "ご使用のシステムには、デフォルトの電話地域が設定されていません。これは、国コードなしでプロファイル設定の電話番号を検証するために必要です。国コードなしで番号を許可するには、地域のそれぞれの{linkstart} ISO3166-1コード↗{linkend}とともに \"default_phone_region\" を設定ファイルに追加してください。",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "CLI から cronジョブを実行することができませんでした。次の技術的なエラーが発生しています：",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "最後のバックグラウンドジョブの実行は{relativeTime}を実行しました。何かがおかしいようです。 {linkstart}バックグラウンドジョブの設定を確認してください↗{linkend}。",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "本サーバーはNextcloudのサポートがないコミュニティビルドで動いています。実行中の規模でのパフォーマンス、信頼性、スケーラビリティを保証するものではありません。プッシュ通知は無料サービスへ負荷がかからないように制限されています。Nextcloud Enterpriseのメリットについては、{linkstart}https://nextcloud.com/enterprise{linkend}を参照してください。",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "このサーバーにはインターネット接続がありません。複数のエンドポイントに到達できませんでした。 つまり、外部ストレージのマウント、アップデートに関する通知、サードパーティ製アプリのインストールなどの機能の一部は機能しません。 リモートからファイルにアクセスしたり、通知メールを送信したりすることもできません。インターネットへの接続を確立できれば、すべての機能を利用することができます。",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "メモリーキャッシュが構成されていません。パフォーマンスを向上させるために、可能な場合はmemcacheを構成してください。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHPで利用する乱数に適切なソースがありません。これは、セキュリティ上の理由から全く推奨されていません。詳細については、{linkstart}ドキュメント↗{linkend}をご覧ください。",
@@ -419,6 +415,13 @@ OC.L10N.register(
     "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "別のデータベースに移行するには、コマンドラインツールを使います。\"occ db:convert-type\" または {linkstart}ドキュメント {linkend} を参照してください。",
     "The PHP memory limit is below the recommended value of 512MB." : "PHPのメモリ制限が推奨値の512MB以下です。",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "一部のアプリディレクトリは、Webサーバーディレクトリとは異なるユーザーによって所有されています。 アプリが手動でインストールされた場合、これがそのケースに値します。 次のアプリディレクトリの権限を確認します。",
+    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "データベースとしてMySQLを使用していますが、4バイト文字をサポートしていません。ファイル名やコメントなどで4バイト文字（絵文字など）を問題なく扱うためには、MySQLで4バイトサポートを有効にすることが推奨されます。詳細は{linkstart}これに関するドキュメントページ↗{linkend}をお読みください。",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "このインスタンスは、S3ベースのオブジェクトストアをプライマリストレージとして使用します。 アップロードされたファイルは一時的にサーバーに保存されるため、PHPの一時ディレクトリに50 GBの空き容量を確保することをお勧めします。 パスと空き容量についての完全な詳細はログを確認してください。 一時ディレクトリを修正するには、php.iniの一時ディレクトリを変更するか、またはそのパスでより多くのスペースを利用できるようにしてください。",
+    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "このインスタンスで指定している一時ディレクトリは、存在しないか書き込みできないディレクトリです。",
+    "Account name or email" : "アカウント名またはメールアドレス",
+    "Wrong username or password." : "ユーザー名またはパスワードが間違っています",
+    "User disabled" : "ユーザーは無効です",
+    "Username or email" : "ユーザー名またはメールアドレス",
     "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "このアカウントのメールアドレスにパスワードリセットメッセージを送信しました。届かない場合は、スパム/ジャンクフォルダーを確認するか、ローカル管理者にサポートを依頼してください。",
     "If it is not there ask your local administrator." : "もしそうでない場合は、管理者に問い合わせてください。",
     "Start search" : "検索開始",
@@ -448,13 +451,19 @@ OC.L10N.register(
     "This action requires you to confirm your password" : "この操作では、パスワードを確認する必要があります",
     "Confirm" : "確認",
     "Failed to authenticate, try again" : "認証に失敗しました。もう一度お試しください",
+    "Users" : "ユーザー",
     "The page could not be found on the server." : "ページがサーバー上に見つかりませんでした。",
+    "Username" : "ユーザー名",
+    "Database user" : "データベースのユーザー名",
     "Confirm your password" : "パスワードを確認",
     "App token" : "アプリのトークン",
     "Alternative log in using app token" : "アプリトークンを使って代替ログイン",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "50人以上が使う大規模システムの場合は、コマンドラインでアップグレードを行ってください。",
     "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "あなたのIPアドレスは、\"{remoteAddress}\" として認識されており、現在ブルートフォース対策機能により様々なリクエストのパフォーマンスが低下しています。IPアドレスがあなたのアドレスでない場合、プロキシが正しく設定されていない可能性があります。詳細は{linkstart}ドキュメント{linkend}をご覧ください。",
     "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "データベースがトランザクションファイルロックに使われています。パフォーマンスをあげるには、可能であればメモリーのキャッシュを設定してください。詳しくは {linkstart}こちらの文書↗{linkend}をご覧ください。",
     "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 は Nextcloud 27 で非推奨になりました。Nextcloud 28 では少なくとも PHP 8.1 が必要になる場合があります。できるだけ早く、{linkstart}PHP グループ が提供する、正式にサポートされている PHP バージョンのいずれか↗{linkend} にアップグレードしてください。",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "このインスタンスはデバッグ モードで実行されています。これはローカル開発の場合にのみ有効にし、運用環境では有効にしないでください。",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "このアカウントが存在したら、パスワード変更のメッセージがそのメールアドレスに送信されます。\nもしメールが届いていない場合は、メールアドレスまたはアカウント名を確認するか、メールが迷惑メールフォルダに入っていないか確認するか、もしくは管理者にお問い合わせください。",
     "Avatar of {fullName}" : "{fullName} のアバター"
 },
 "nplurals=1; plural=0;");
