@@ -29,7 +29,6 @@ OC.L10N.register(
     "Nextcloud Server" : "ເຊີບເວີ ເນັກຄຮາວ",
     "Some of your link shares have been removed" : "ບາງລີ້ງທີທ່ານໄດ້ແບ່ງປັນຖືກຍົກເລີກແລ້ວ",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "ເນື່ອງຈາກບັນຫາດ້ານຄວາມປອດໄພ, ພວກເຮົາໄດ້ຍົກເລິກການແບ່ງປັນລີ້ງ. ສໍາລັບຂໍ້ມູນເພີ່ມເຕີ່ມ ກະລຸນນາກົດເບີ່ງລີງ ",
-    "The user limit of this instance is reached." : "ຮອດກໍານົດ ຈໍາກັດຈໍານວນຜູ້ໃຊ້ແລ້ວ",
     "Preparing update" : "ກະກຽມອັບເດດ",
     "[%d / %d]: %s" : "[%d/%d]:%s",
     "Repair step:" : "ຂັ້ນຕອນໃນການປັບປຸງ",
@@ -52,37 +51,6 @@ OC.L10N.register(
     "Already up to date" : "ໄດ້ອັບເດດແລ້ວ",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "ເວັບເຊີບເວີ ຂອງທ່ານຍັງບໍ່ຖືກຕັ້ງຄ່າຢ່າງຖືກຕ້ອງເພື່ອອະນຸຍາດໃຫ້ຟາຍເອກະສານກົງກັນ, ເພາະວ່າອິນເຕີເຟດ WebDAV ອາດຖືກທໍາລາຍ ",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "ເວັບໄຊຂອງທ່ານບໍ່ໄດ້ຖືກຕິດຕັ້ງຢ່າງຖືກຕ້ອງ  ເພື່ອແກ້ ໄຂ \"{url}\" . ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນເອກະສານ {linkstart}↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "ເວັບໄຊຂອງທ່ານບໍ່ໄດ້ຕິດຕັ້ງຢ່າງຖືກຕ້ອງ ເພື່ອແກ້ ໄຂ \"{url}\" . ກ່ຽວຂ້ອງກັບການຕັ້ງຄ່າເວັບໄຊທີ່ບໍ່ມີການປັບປຸງເພື່ອສົ່ງໂຟນເດີນີ້ໂດຍກົງ. ກະລຸນາປຽບທຽບການຕັ້ງຄ່າຂອງທ່ານກັບກົດລະບຽບການຂຽນຄືນທີ່ຖືກສົ່ງໃນ \".htaccess\" ສໍາລັບ Apache ຫຼື ທີ່ສະຫນອງໃນເອກະສານສໍາລັບ Nginx ທີ່ມັນເປັນ {linkstart}ຫນ້າເອກະສານ↗{linkend}. ໃນ Nginx ເຫຼົ່ານັ້ນໂດຍປົກກະຕິແລ້ວແມ່ນເລີ່ມຕົ້ນດ້ວຍ \"ສະຖານທີ່ ~\" ທີ່ຕ້ອງການການປັບປຸງ.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "ເວັບ ໄຊຂອງທ່ານບໍ່ໄດ້ ຕິດຕັ້ງຢ່າງຖືກຕ້ອງເພື່ອສົ່ງຟາຍ ໌.woff2 . ໂດຍປົກກະຕິແລ້ວແມ່ນບັນຫາທີ່ມີການຕັ້ງຄ່າ Nginx. ສໍາລັບ Nextcloud 15 ມັນຈໍາເປັນຕ້ອງມີການປັບຕົວເພື່ອສົ່ງຟາຍ .woff2 ອີກດ້ວຍ. ປຽບທຽບການຕັ້ງຄ່າ Nginx ຂອງທ່ານກັບການຕັ້ງຄ່າທີ່ ແນະນໍາໃນເອກະສານ {linkstart} ຂອງພວກເຮົາ ↗{linkend}.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ບໍ່ໄດ້ຮັບການຕັ້ງຄ່າຢ່າງເຫມາະສົມເພື່ອສອບຖາມຕົວແປສະພາບແວດລ້ອມຂອງລະບົບ. ການທົດສອບກັບ getenv(\"PATH\") ພຽງແຕ່ກັບຄືນການຕອບສະຫນອງທີ່ຫວ່າງເປົ່າ.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "ກະລຸນາກວດເບິ່ງເອກະສານການຕິດຕັ້ງ {linkstart}↗{linkend} ສໍາລັບບັນທຶກການຕັ້ງຄ່າ PHP ແລະ ການຕັ້ງຄ່າ PHP ຂອງ server ຂອງທ່ານ, ໂດຍສະເພາະເມື່ອໃຊ້ php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "ການຕັ້ງຄ່າແບບອ່ານເທົ່ານັ້ນໄດ້ຖືກເປີດໃຊ້. ການຕັ້ງຄ່າປ້ອງກັນບາງຢ່າງຜ່ານເວັບໄຊ. ຍິ່ງໄປກວ່ານັ້ນ, ຟາຍຈໍາເປັນຕ້ອງໄດ້ຂຽນດ້ວຍມືສໍາລັບທຸກໆການປັບປຸງ.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "ຖານຂໍ້ມູນຂອງທ່ານບໍ່ສາມາດດຳເນີນການກັບ \"READ COMMITTED”. ປະເພດການເຮັດທຸລະກຳລະດັບນີ້ “ ຊື່ງອາດເຮັດໃຫ້ເກີດບັນຫາ ໃນເວລາ ເປີດການປະຕິບັດການຫຼາຍ ລາຍການພ້ອມກັນ.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "ໂມດູນ PHP \"fileinfo\" ຫາຍໄປ. ແນະນຳ ໃຫ້ເປີດໃຊ້ໂມດູນນີ້ ເພື່ອໃຫ້ ໄດ້ຜົນທີ່ດີທີ່ສຸດ ເມື່ອຮ່ວມການກວດກາ MIME",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "ການລັອກຟາຍ ທຸລະກຳ ແມ່ນຖືກປິດ, ອາດຈະນໍາໄປສູ່ບັນຫາຈຳເເນກ. ເຮັດໃຫ້ \"filelocking.enabled\" ໃນ config.php ເພື່ອຫຼີກເວັ້ນບັນຫາເຫຼົ່ານີ້. ເບິ່ງ{linkstart}ເອກະສານ ↗{linkend} ສໍາລັບຂໍ້ມູນເພີ່ມເຕີມ.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "ເປັນໄປບໍ່ໄດ້ ທີ່ຈະດໍາເນີນງານcron ຜ່ານ CLI ໄດ້ . ຂໍ້ຜິດພາດທາງດ້ານເຕັກນິກໄດ້ປາກົດຂື້ນ:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "ການປະຕິບັດວຽກງານພື້ນຖານຄັ້ງສຸດທ້າຍໄດ້ ດຳເນີນ {relativeTime}. ມີ{linkstart} ບາງຢ່າງຜິດ,  ກວດສອບການຕັ້ງຄ່າ↗{linkend}ພື້ນຖານ ",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ບໍ່ມີການຕັ້ງຄ່າ cache ຄວາມຈໍາ. ເພື່ອເພີ່ມປະສິດທິພາບ, ກະລຸນາຕັ້ງຄ່າ memcache, ຖ້າມີ. ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ {linkstart} ເອກະສານ ↗{linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ບໍ່ມີແຫລ່ງທີ່ເຫມາະ ສົມສໍາລັບການສູມເອົາ ທີ່ພົບໂດຍ PHP ຊຶ່ງເຫດຜົນຄວາມປອດ ໄພ . ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ{linkstart}ເອກະສານ ↗{linkend}.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ການຕັ້ງຄ່າຫົວຂໍ້ proxy ກັບຄືນບໍ່ຖືກຕ້ອງ, ຫຼື ທ່ານກໍາລັງເຂົ້າເຖິງ Nextcloud ຈາກ proxy ທີ່ເຊື່ອຖືໄດ້. ຖ້າບໍ່ດັ່ງນັ້ນ, ນີ້ແມ່ນບັນຫາຄວາມປອດໄພ ແລະ ສາມາດອະນຸຍາດໃຫ້ຜູ້ໂຈມຕີ spoof ທີ່ຢູ່ IP ຂອງພວກເຂົາດັ່ງທີ່ເຫັນໄດ້ກັບ Nextcloud. ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ{linkstart}ເອກະສານ ↗{linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "cachedຄວາມຈຳ ຖືກຕັ້ງຄ່າ ເປັນ cache ແຈກຢາຍ, ແຕ່ໂມດູນ PHP ທີ່ບໍ່ຖືກຕ້ອງ \"memcache\" ຖືກຕິດຕັ້ງ. OCMemcacheMemcached ສະຫນັບສະຫນູນພຽງແຕ່ \"memcached\" ແລະ ບໍ່ແມ່ນ \"memcache\". ເບິ່ງ {linkstart}memcached wiki ກ່ຽວກັບທັງສອງ↗{linkend}ໂມດູນ ",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "ບາງຟາຍບໍ່ໄດ້ຜ່ານການກວດສອບຄວາມເຊື່ຶອຖື. ຂໍ້ມູນເພີ່ມເຕີມກ່ຽວກັບວິທີແກ້ໄຂບັນຫານີ້ສາມາດເບິ່ງໄດ້ໃນ {linkstart1}ເອກະສານ↗{linkend}/({linkstart2}ລາຍການຟາຍ.. {linkend} / {linkstart3}Rescan... {linkend})",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "ບໍ່ມີ ການກໍານົດ ຫນ້າທີ່ PHP \"ກໍານົດເວລາ\". ອາດຈະເຮັດໃຫ້ scripts ຖືກຢຸດກາງ ການດໍາເນີນງານ, ແລະທໍາລາຍການຕິດຕັ້ງຂອງທ່ານ. ເນະນໍາໃຫ້ເປີດນໍາໃຊ້ ການກໍານົດເວລາ.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP ຂອງທ່ານບໍ່ໄດ້ຮັບການສະຫນັບສະຫນູນ FreeType, ເຮັດໃຫ້ຮູບພາບໜ້າປົກຄວາມຄົມຊັດບໍ່ລະອຽດ ລວມທັງບັນຫາ ການຕັ້ງຄ່າ interface.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "ບໍ່ມີຊື່  index \"{indexName}\" ໃນຕາຕະລາງ \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "ຖານຂໍ້ມູນຂາດດັດຊະນີບາງຢ່າງບໍ່ເຫັນ. ເນື່ອງຈາກວ່າການເພີ່ມດັດຊະນີໃສ່ຕາຕະລາງໃຫຍ່ອາດຈະໃຊ້ ເວລາດົນ . ໂດຍການດຳເນີນ \"occ db:add-missing-indices\" ດັດຊະນີທີ່ຂາດໄປ ສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ. ເມື່ອດັດຊະນີຖືກຕື່ມຄໍາສອບຖາມໃສ່ຕາຕະລາງເຫຼົ່ານັ້ນຕາມປົກກະຕິແລ້ວຈະໄວຂຶ້ນຫຼາຍ.",
-    "Missing primary key on table \"{tableName}\"." : "ຂາດລະຫັດເຂົ້າເຖິງຕາຕະລາງ \"{tableName}\".",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "ຖານຂໍ້ມູນຂາດລະຫັດບາງຢ່າງ. ເນື່ອງຈາກວ່າການເພີ່ມກະແຈຕົ້ນຕໍໃສ່ ໂຕະໃຫຍ່ ອາດ ຈະໃຊ້ ເວລາດົນນານທີ່ພວກເຂົາເຈົ້າບໍ່ໄດ້ ຖືກຕື່ມໂດຍອັດຕະໂນມັດ . ໂດຍການແລ່ນ \"occ db:add-missing-primary-keys\" ຂາດກະແຈຕົ້ນຕໍເຫຼົ່ານັ້ນສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "ຂາດ column ທາງເລືອກ \"{columnName}\" ໃນຕາຕະລາງ \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "ຖານຂໍ້ມູນແມ່ນຂາດບາງ columns ທາງເລືອກ. ເນື່ອງຈາກວ່າການເພີ່ມ columns ໃສ່ ຕາຕະລາງໃຫຍ່ ອາດ ຈະ ໃຊ້ເວລາດົນ ທີ່ບໍ່ໄດ້ຕື່ມໂດຍອັດຕະໂນມັດ ເມື່ອເລືອກ ໄດ້ . ໂດຍການດຳ \"occ db:add-missing-columns\" columns ທີ່ຂາດໄປສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ. ເມື່ອມີການເພີ່ມ columns ອາດຈະປັບປຸງການຕອບສະຫນອງ ຫຼື ການໃຊ້ງານ.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "ຕົວຢ່າງເເນະນຳຂາດໂມດູນ PHP,  ສໍາລັບການປັບປຸງ ແລະ ການປະຕິບັດທີ່ດີກວ່າ ນັ້ນ ແມ່ນແນະນໍາໃຫ້ຕິດຕັ້ງ  ",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "ໂມດູນ php-imagick ໃນກໍລະນີນີ້ບໍ່ມີການສະຫນັບສະຫນູນ SVG. ເພື່ອຄວາມສອດຄ່ອງທີ່ດີກວ່າແມ່ນແນະນໍາໃຫ້ຕິດຕັ້ງ.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite ກໍາລັງຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນbackend. ສໍາລັບການຕິດຕັ້ງທີ່ໃຫຍ່ກວ່າ   ພວກເຮົາຂໍແນະນໍາໃຫ້ທ່ານປ່ຽນໄປຫາ backend ຖານຂໍ້ມູນທີ່ແຕກຕ່າງ ກັນ .",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "ແນະນໍາໂດຍສະເພາະເມື່ອການນໍາໃຊ້ desktop ລູກຄ້າ  ສໍາລັບການ ຢືນຢັນຟາຍ",
-    "The PHP memory limit is below the recommended value of 512MB." : "ຂີດຈໍາກັດຄວາມຈໍາ PHP ແມ່ນຕ່ໍາກວ່າຄ່າທີ່ແນະນໍາຂອງ 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ຊອບແວຂອງຜູ້ ໃຊ້ແຕກຕ່າງຈາກເວັບໄຊ  . ອາດຢູ່ເປັນກໍລະນີ ການຕິດຕັ້ງແອັບພລິເຄຊັນດ້ວຍມື. ກວດສອບການອະນຸຍາດຂອງແອັບພລິເຄຊັນດັ່ງຕໍ່ໄປນີ້:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL ຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນແຕ່ບໍ່ສະຫນັບສະຫນູນຕົວອັກສອນ 4 byte. ເພື່ອ ໃຫ້ ສາມາດຮັບ 4-byteໄດ້(ເຊັ່ນ emojis) ໂດຍບໍ່ມີບັນຫາໃນຊື່ຟາຍ ຫຼື ຄໍາ ເຫັນຍົກຕົວຢ່າງ ແນະນໍາໃຫ້ ເຮັດໃຫ້ ການສະຫນັບສະຫນູນ 4 byte ໃນ MySQL . ສໍາລັບລາຍລະອຽດ ເພີ່ມເຕີມອ່ານ {linkstart} ຫນ້າ ເອກະສານກ່ຽວກັບ ↗{linkend} ນີ້.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "ຕົວຢ່າງນີ້ໃຊ້  S3 ເປັນການເກັບກໍາຂໍ້ມູນຕົ້ນຕໍ. ຟາຍອັບໂຫຼດໄດ້ເກັບ ໄວ້ ຊົ່ວ ຄາວ ຢູ່ ໃນ server ແລະ ດັ່ງນັ້ນຈຶ່ງແນະນໍາໃຫ້ມີ ພຶນທີ່ວ່າງ 50 GB ໃນ directory temp ຂອງ PHP . ກວດເບິ່ງບັນຊີລາຍລະອຽດກ່ຽວກັບຊ່ອງທາງ ແລະ  ພຶນທີ່ວ່າງ  . ເພື່ອປັບປຸງກະລຸນາປ່ຽນ directory ຊົ່ວຄາວໃນ php.ini ຫຼື ເຮັດໃຫ້ມີຊ່ອງຫວ່າງຫຼາຍຂຶ້ນໃນຊ່ອງທາງນັ້ນ.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "ທ່ານກໍາລັງເຂົ້າເຖິງຕົວຢ່າງຂອງທ່ານ ກ່ຽວກັບການຕິດຕໍ່ທີ່ປອດໄພ , ເຖິງຢ່າງໃດ ກໍ ຕາມ ຕົວຢ່າງຂອງ ທ່ານແມ່ນການສ້າງ URLs ບໍ່ ຫມັ້ນ ຄົງ . ຫມາຍຄວາມວ່າທ່ານຢູ່ເບື້ອງຫຼັງ proxy reverse ແລະ ຕົວປ່ຽນໃນconfig overwrite ບໍ່ຖືກຕ້ອງ. ກະລຸນາອ່ານ {linkstart}ຫນ້າເອກະສານກ່ຽວກັບ↗{linkend}.",
     "Error occurred while checking server setup" : "ເກີດຂໍ້ຜິດພາດໃນຂະນະທີ່ກວດສອບການຕັ້ງຄ່າ server",
     "For more details see the {linkstart}documentation ↗{linkend}." : "ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມເບິ່ງໃນ {linkstart}ເອກະສານ↗{linkend} ",
@@ -112,11 +80,8 @@ OC.L10N.register(
     "An internal error occurred." : "ເກີດຂໍ້ຜິດພາດພາຍໃນ.",
     "Please try again or contact your administrator." : "ກະລຸນາລອງອີກ ຫຼື ຕິດຕໍ່ຜູ້ຄຸ້ມຄອງລະບົບຂອງທ່ານ.",
     "Password" : "ລະຫັດຜ່ານ",
-    "Wrong username or password." : "ຊື່ຜູ້ໃຊ້ ຫຼື ລະຫັດຜ່ານຜິດ.",
-    "User disabled" : "ປິດຊື່ຜູ້ໃຊ້",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "ພວກເຮົາກວດພົບຄວາມພະຍາຍາມ login ທີ່ ບໍ່ຖືກຕ້ອງຈາກ IP ຂອງ ທ່ານ . ດັ່ງນັ້ນການເຄື່ອນໄຫວຕໍ່ໄປຂອງທ່ານແມ່ນ throttled ເຖິງ 30 ວິນາທີ.",
     "Log in with a device" : "ເຂົ້າສູ່ລະບົບດ້ວຍອຸປະກອນ",
-    "Username or email" : "ຊື່ຜູ້ໃຊ້ ຫຼື ອີເມວ",
     "Your account is not setup for passwordless login." : "ບັນຊີຂອງທ່ານບໍ່ໄດ້ຕັ້ງຄ່າສໍາລັບການເຂົ້າລະຫັດຜ່ານ.",
     "Passwordless authentication is not supported in your browser." : "ການຢັ້ງຢືນແບບບໍ່ມີລະຫັດຜ່ານບໍ່ໄດ້ຮັບການສະຫນັບສະຫນູນໃນເວັບໄຊຂອງທ່ານ.",
     "Passwordless authentication is only available over a secure connection." : "ການຢັ້ງຢືນແບບບໍ່ມີລະຫັດຜ່ານແມ່ນມີພຽງແຕ່ການເຊື່ອມຕໍ່ທີ່ປອດໄພເທົ່ານັ້ນ.",
@@ -137,17 +102,13 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "ຮັກສາເພື່ອນຮ່ວມງານ ແລະ ຫມູ່ ເພື່ອນ ຂອງ ທ່ານ ໄວ້ ໃນບ່ອນດຽວໂດຍບໍ່ໄດ້ ໃຫ້ຂໍ້ ຄວາມ ສ່ວນ ຕົວ ຂອງ ເຂົາ ເຈົ້າຮົ່ວໄຫຼ .",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "ແອັບອີເມວລວມເຂົ້າກັບ ຟາຍຕ່າງໆ, ເບີຕິດຕໍ່ ແລະ ປະຕິທິນ",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, ການໂທວິດີໂອ, screen sharing, ການປະຊຸມອອນໄລນ໌ ແລະ ການປະຊຸມເວັບໄຊ – ໃນເວັບໄຊຂອງທ່ານ ແລະ apps ມືຖື.",
+    "Reset search" : "Reset ຄົ້ນຫາ",
     "Search contacts …" : "ຄົ້ນຫາຕິດຕໍ່ ...",
     "Could not load your contacts" : "ບໍ່ສາມາດໂຫຼດການຕິດຕໍ່ຂອງທ່ານ",
     "No contacts found" : "ບໍ່ພົບຜູ້ຕິດຕໍ່",
-    "Show all contacts …" : "ສະແດງການຕິດຕໍ່ທັງຫມົດ ...",
     "Install the Contacts app" : "ຕິດຕັ້ງແອັບ Contacts",
     "Loading your contacts …" : "ກໍາລັງໂຫຼດການຕິດຕໍ່ຂອງທ່ານ ...",
     "Looking for {term} …" : "ຊອກຫາ {term} ...",
-    "Forgot password?" : "ລືມລະຫັດຜ່ານ?",
-    "Back" : "ຫຼັງ",
-    "Login form is disabled." : "ຮູບແບບLogin ຖືກປິດ.",
-    "Reset search" : "Reset ຄົ້ນຫາ",
     "Search for {name} only" : "ຄົ້ນຫາ {name} ເທົ່ານັ້ນ",
     "Start typing to search" : "ເລີ່ມພິມເພື່ອຄົ້ນຫາ",
     "Loading more results …" : "ຜົນການດາວໂຫຼດເພີ່ມເຕີມ ...",
@@ -156,8 +117,12 @@ OC.L10N.register(
     "No results for {query}" : "ບໍ່ມີຜົນສໍາລັບ {query}",
     "An error occurred while searching for {type}" : "ເກີດຂໍ້ຜິດພາດໃນຂະນະທີ່ຊອກຫາ {ປະເພດ}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["ກະລຸນາໃສ່ {minSearchLength} ຕົວອັກສອນຫຼືຫຼາຍກວ່ານັ້ນເພື່ອຄົ້ນຫາ"],
-    "Settings menu" : "ການຕັ້ງຄ່າເມນູ",
+    "Forgot password?" : "ລືມລະຫັດຜ່ານ?",
+    "Back" : "ຫຼັງ",
+    "Login form is disabled." : "ຮູບແບບLogin ຖືກປິດ.",
     "Search {types} …" : "ຄົ້ນຫາ {ປະເພດ} ...",
+    "Today" : "ມື້ນີ້",
+    "Settings menu" : "ການຕັ້ງຄ່າເມນູ",
     "No" : "ບໍ່",
     "Yes" : "ແມ່ນແລ້ວ",
     "Choose" : "ເລືອກ",
@@ -206,7 +171,7 @@ OC.L10N.register(
     "Collaborative tags" : "tags ການຮ່ວມມື",
     "No tags found" : "ບໍ່ພົບtags",
     "Personal" : "ສ່ວນບຸກຄົນ",
-    "Users" : "ຜູ້ໃຊ້",
+    "Accounts" : "ບັນຊີ",
     "Apps" : "ແອັບພລິເຄຊັນ",
     "Admin" : "ຜູ້ເບິ່ງເເຍງລະບົບ",
     "Help" : "ການຊ່ວຍເຫຼືອ",
@@ -233,7 +198,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ຊອບແວຂໍ້ມູນແລະ ຟາຍ ຂອງ ທ່ານອາດຈະເຂົ້າເຖິງໄດ້ຈາກອິນເຕີເນັດເພາະວ່າຟາຍ .htaccess ບໍ່ໄດ້ຜົນ .",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "ສໍາລັບຂໍ້ມູນວິທີການຕັ້ງຄ່າ server ຂອງທ່ານຢ່າງຖືກຕ້ອງ, ກະລຸນາເບິ່ງ <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">ເອກະສານ</a>",
     "Create an <strong>admin account</strong>" : "ສ້າງ <strong>ບັນຊີ admin</strong>",
-    "Username" : "ຊື່ຜູ້ໃຊ້",
     "Show password" : "ສະແດງລະຫັດຜ່ານ",
     "Storage & database" : "ການເກັບກໍາຂໍ້ມູນ & ຖານຂໍ້ມູນ",
     "Data folder" : "ໂຟນເດີຂໍ້ມູນ",
@@ -241,7 +205,6 @@ OC.L10N.register(
     "Only %s is available." : "ມີແຕ່ %sເທົ່ານັ້ນ.",
     "Install and activate additional PHP modules to choose other database types." : "ຕິດຕັ້ງ ແລະ ເປິດນຳໃຊ້ໂມດູນ PHP ເພີ່ມເຕີມເພື່ອເລືອກປະເພດຖານຂໍ້ມູນອື່ນໆ.",
     "For more details check out the documentation." : "ສໍາລັບລາຍລະອຽດເພີ່ມເຕີມໃຫ້ ກວດເບິ່ງເອກະສານ",
-    "Database user" : "ຜູ້ໃຊ້ຖານຂໍ້ມູນ",
     "Database password" : "ລະຫັດຖານຂໍ້ມູນ",
     "Database name" : "ຊື່ຖານຂໍ້ມູນ",
     "Database tablespace" : "ຕາຕະລາງຖານຂໍ້ມູນ",
@@ -259,15 +222,10 @@ OC.L10N.register(
     "Skip to main content" : "ຂ້າມ ໄປຫາເນື້ອຫາຫຼັກ",
     "Skip to navigation of app" : "ຂ້າມໄປຍັງແອັບນຳທາງ",
     "Get your own free account" : "ຮັບບັນຊີຟຣີຂອງທ່ານເອງ",
-    "This action requires you to confirm your password" : "ການກະທໍານີ້ຮຽກຮ້ອງໃຫ້ທ່ານເພື່ອຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
-    "Confirm your password" : "ຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
-    "Confirm" : "ຢືນຢັນ",
     "Connect to your account" : "ເຊື່ອມຕໍ່ບັນຊີຂອງທ່ານ",
     "Please log in before granting %1$s access to your %2$s account." : "ກະລຸນາເຂົ້າລະບົບກ່ອນທີ່ຈະໃຫ້ %1$sການເຂົ້າເຖິງບັນຊີຂອງທ່ານ%2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "ຖ້າທ່ານບໍ່ໄດ້ພະຍາຍາມທີ່ຈະຕິດຕັ້ງອຸປະກອນຫຼື app ໃຫມ່ , ບາງຄົນພະຍາຍາມຫຼອກລວງ ທ່ານໃຫ້ອະນຸຍາດໃຫ້ເຂົາເຈົ້າເຂົ້າເຖິງຂໍ້ມູນຂອງທ່ານ. ໃນກໍລະນີນີ້ບໍ່ໄດ້ດໍາເນີນການ ແລະ ແທນທີ່ຈະຕິດຕໍ່ຜູ້ບໍລິຫານລະບົບຂອງທ່ານ.",
-    "App token" : "ແອັບ token",
     "Grant access" : "ການເຂົ້າເຖິງ Grant",
-    "Alternative log in using app token" : "log ທາງເລືອກໃນການນໍາໃຊ້ token app",
     "Account access" : "ການເຂົ້າເຖິງບັນຊີ",
     "You are about to grant %1$s access to your %2$s account." : "ທ່ານກໍາລັງຈະໃຫ້ %1$sການເຂົ້າເຖິງບັນຊີ %2$sຂອງທ່ານ.",
     "Account connected" : "ບັນຊີທີ່ຕິດພັນ",
@@ -298,7 +256,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "ເພື່ອຫຼີກເວັ້ນການໃຊ້ ເວລາທີ່ມີການຕິດຕັ້ງ.  ແທນທີ່ທ່ານສາມາດແລ່ນຄໍາ ສັ່ງດັ່ງຕໍ່ໄປນີ້ຈາກການຕິດຕັ້ງຂອງ ທ່ານໂດຍກົງ :",
     "Detailed logs" : "ບັນທຶກໂດຍລາຍລະອຽດ",
     "Update needed" : "ການປັບປຸງທີ່ຈໍາເປັນ",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "ກະລຸນາໃຊ້  ອັບເດດແຖວຄໍາສັ່ງ ເພາະວ່າທ່ານມີຕົວຢ່າງໃຫຍ່ທີ່ມີຜູ້ໃຊ້ຫຼາຍກວ່າ 50 ຜຸ້ໃຊ້.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "ສໍາລັບການຊ່ວຍເຫຼືອ, ເບິ່ງ <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ເອກະສານ</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ຂ້າ ພະເຈົ້າຮູ້ວ່າຖ້າຫາກວ່າຂ້າພະເຈົ້າສືບຕໍ່ເຮັດການອັບເດດຜ່ານເວັບ UI ມີຄວາມສ່ຽງ , ວ່າ ຄໍາຮ້ອງດຳເນີນການໝົດເວລາ  ແລະ ອາດຈະເຮັດໃຫ້ການສູນເສຍຂໍ້ມູນ, ແຕ່ຂ້າ ພະເຈົ້າມີການສໍາຮອງ ແລະ ຮູ້ວິທີການກູ້ຄືນ ຕົວຢ່າງ ຂອງຂ້າພະເຈົ້າໃນກໍລະນີທີ່ລົ້ມ ເຫລວ .",
     "Upgrade via web on my own risk" : "ການຍົກລະດັບ ຜ່ານເວັບໄຊໃນຄວາມສ່ຽງຂອງຂ້ອຍເອງ",
@@ -306,10 +263,46 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "%sຕົວຢ່າງນີ້ໃນປັດຈຸບັນແມ່ນຢູ່ໃນວິທີການບໍາລຸງຮັກສາ, ຊຶ່ງອາດຈະໃຊ້ ເວລາໃນໄລຍະໜຶ່ງ",
     "This page will refresh itself when the instance is available again." : "ຫນ້ານີ້ຈະ refresh ເມື່ອມີຕົວຢ່າງອີກ.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ຕິດຕໍ່ຜູ້ບໍລິຫານລະບົບຂອງທ່ານຖ້າຫາກວ່າຂ່າວສານນີ້ຍັຢູ່ ຫຼື ປາກົດໂດຍບໍ່ຄາດຄິດ.",
+    "The user limit of this instance is reached." : "ຮອດກໍານົດ ຈໍາກັດຈໍານວນຜູ້ໃຊ້ແລ້ວ",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "ເວັບໄຊຂອງທ່ານບໍ່ໄດ້ຕິດຕັ້ງຢ່າງຖືກຕ້ອງ ເພື່ອແກ້ ໄຂ \"{url}\" . ກ່ຽວຂ້ອງກັບການຕັ້ງຄ່າເວັບໄຊທີ່ບໍ່ມີການປັບປຸງເພື່ອສົ່ງໂຟນເດີນີ້ໂດຍກົງ. ກະລຸນາປຽບທຽບການຕັ້ງຄ່າຂອງທ່ານກັບກົດລະບຽບການຂຽນຄືນທີ່ຖືກສົ່ງໃນ \".htaccess\" ສໍາລັບ Apache ຫຼື ທີ່ສະຫນອງໃນເອກະສານສໍາລັບ Nginx ທີ່ມັນເປັນ {linkstart}ຫນ້າເອກະສານ↗{linkend}. ໃນ Nginx ເຫຼົ່ານັ້ນໂດຍປົກກະຕິແລ້ວແມ່ນເລີ່ມຕົ້ນດ້ວຍ \"ສະຖານທີ່ ~\" ທີ່ຕ້ອງການການປັບປຸງ.",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "ເວັບ ໄຊຂອງທ່ານບໍ່ໄດ້ ຕິດຕັ້ງຢ່າງຖືກຕ້ອງເພື່ອສົ່ງຟາຍ ໌.woff2 . ໂດຍປົກກະຕິແລ້ວແມ່ນບັນຫາທີ່ມີການຕັ້ງຄ່າ Nginx. ສໍາລັບ Nextcloud 15 ມັນຈໍາເປັນຕ້ອງມີການປັບຕົວເພື່ອສົ່ງຟາຍ .woff2 ອີກດ້ວຍ. ປຽບທຽບການຕັ້ງຄ່າ Nginx ຂອງທ່ານກັບການຕັ້ງຄ່າທີ່ ແນະນໍາໃນເອກະສານ {linkstart} ຂອງພວກເຮົາ ↗{linkend}.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ບໍ່ໄດ້ຮັບການຕັ້ງຄ່າຢ່າງເຫມາະສົມເພື່ອສອບຖາມຕົວແປສະພາບແວດລ້ອມຂອງລະບົບ. ການທົດສອບກັບ getenv(\"PATH\") ພຽງແຕ່ກັບຄືນການຕອບສະຫນອງທີ່ຫວ່າງເປົ່າ.",
+    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "ກະລຸນາກວດເບິ່ງເອກະສານການຕິດຕັ້ງ {linkstart}↗{linkend} ສໍາລັບບັນທຶກການຕັ້ງຄ່າ PHP ແລະ ການຕັ້ງຄ່າ PHP ຂອງ server ຂອງທ່ານ, ໂດຍສະເພາະເມື່ອໃຊ້ php-fpm.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "ການຕັ້ງຄ່າແບບອ່ານເທົ່ານັ້ນໄດ້ຖືກເປີດໃຊ້. ການຕັ້ງຄ່າປ້ອງກັນບາງຢ່າງຜ່ານເວັບໄຊ. ຍິ່ງໄປກວ່ານັ້ນ, ຟາຍຈໍາເປັນຕ້ອງໄດ້ຂຽນດ້ວຍມືສໍາລັບທຸກໆການປັບປຸງ.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "ຖານຂໍ້ມູນຂອງທ່ານບໍ່ສາມາດດຳເນີນການກັບ \"READ COMMITTED”. ປະເພດການເຮັດທຸລະກຳລະດັບນີ້ “ ຊື່ງອາດເຮັດໃຫ້ເກີດບັນຫາ ໃນເວລາ ເປີດການປະຕິບັດການຫຼາຍ ລາຍການພ້ອມກັນ.",
+    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "ໂມດູນ PHP \"fileinfo\" ຫາຍໄປ. ແນະນຳ ໃຫ້ເປີດໃຊ້ໂມດູນນີ້ ເພື່ອໃຫ້ ໄດ້ຜົນທີ່ດີທີ່ສຸດ ເມື່ອຮ່ວມການກວດກາ MIME",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "ການລັອກຟາຍ ທຸລະກຳ ແມ່ນຖືກປິດ, ອາດຈະນໍາໄປສູ່ບັນຫາຈຳເເນກ. ເຮັດໃຫ້ \"filelocking.enabled\" ໃນ config.php ເພື່ອຫຼີກເວັ້ນບັນຫາເຫຼົ່ານີ້. ເບິ່ງ{linkstart}ເອກະສານ ↗{linkend} ສໍາລັບຂໍ້ມູນເພີ່ມເຕີມ.",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "ການຕິດຕັ້ງຂອງທ່ານບໍ່ໄດ້ກໍານົດເຂດບໍລິການໂທລະສັບ. ນີ້ແມ່ນຈໍາເປັນເພື່ອຢັ້ງຢືນເບີໂທລະສັບໃນການຕັ້ງຄ່າໂປຟາຍ ທີບໍ່ມີລະຫັດປະເທດ. ເພື່ອອະນຸຍາດ ເລກໝາຍ ທີ່ບໍ່ມີລະຫັດປະເທດ, ກະລຸນາເພີ່ມ \"ກໍານົດເຂດບໍລິການໂທລະສັບ\" ທີ່ມີລະຫັດ {linkstart}ລະຫັດ ISO 3166-1 ↗{linkend} ເຂດພື້ນທີ່ໃສ່ຟາຍ config ຂອງທ່ານ.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "ເປັນໄປບໍ່ໄດ້ ທີ່ຈະດໍາເນີນງານcron ຜ່ານ CLI ໄດ້ . ຂໍ້ຜິດພາດທາງດ້ານເຕັກນິກໄດ້ປາກົດຂື້ນ:",
+    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "ການປະຕິບັດວຽກງານພື້ນຖານຄັ້ງສຸດທ້າຍໄດ້ ດຳເນີນ {relativeTime}. ມີ{linkstart} ບາງຢ່າງຜິດ,  ກວດສອບການຕັ້ງຄ່າ↗{linkend}ພື້ນຖານ ",
+    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ບໍ່ມີການຕັ້ງຄ່າ cache ຄວາມຈໍາ. ເພື່ອເພີ່ມປະສິດທິພາບ, ກະລຸນາຕັ້ງຄ່າ memcache, ຖ້າມີ. ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ {linkstart} ເອກະສານ ↗{linkend}.",
+    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ບໍ່ມີແຫລ່ງທີ່ເຫມາະ ສົມສໍາລັບການສູມເອົາ ທີ່ພົບໂດຍ PHP ຊຶ່ງເຫດຜົນຄວາມປອດ ໄພ . ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ{linkstart}ເອກະສານ ↗{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "ປະຈຸບັນທ່ານກໍາລັງດໍາເນີນການ PHP {version}. ອັບເດດລຸ້ນ PHP ຂອງທ່ານເພື່ອໃຊ້ ປະສິດທິພາບ {linkstart}  ແລະ ການປັບປຸງຄວາມປອດໄພທີ່ສະຫນອງໃຫ້ໂດຍກຸ່ມ↗{linkend}  PHP ທັນທີທີ່ການແຈກຢາຍຂອງທ່ານສະຫນັບສະຫນູນມັນ.",
+    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "ການຕັ້ງຄ່າຫົວຂໍ້ proxy ກັບຄືນບໍ່ຖືກຕ້ອງ, ຫຼື ທ່ານກໍາລັງເຂົ້າເຖິງ Nextcloud ຈາກ proxy ທີ່ເຊື່ອຖືໄດ້. ຖ້າບໍ່ດັ່ງນັ້ນ, ນີ້ແມ່ນບັນຫາຄວາມປອດໄພ ແລະ ສາມາດອະນຸຍາດໃຫ້ຜູ້ໂຈມຕີ spoof ທີ່ຢູ່ IP ຂອງພວກເຂົາດັ່ງທີ່ເຫັນໄດ້ກັບ Nextcloud. ຂໍ້ມູນເພີ່ມເຕີມສາມາດເບິ່ງໄດ້ໃນ{linkstart}ເອກະສານ ↗{linkend}.",
+    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "cachedຄວາມຈຳ ຖືກຕັ້ງຄ່າ ເປັນ cache ແຈກຢາຍ, ແຕ່ໂມດູນ PHP ທີ່ບໍ່ຖືກຕ້ອງ \"memcache\" ຖືກຕິດຕັ້ງ. OCMemcacheMemcached ສະຫນັບສະຫນູນພຽງແຕ່ \"memcached\" ແລະ ບໍ່ແມ່ນ \"memcache\". ເບິ່ງ {linkstart}memcached wiki ກ່ຽວກັບທັງສອງ↗{linkend}ໂມດູນ ",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "ບາງຟາຍບໍ່ໄດ້ຜ່ານການກວດສອບຄວາມເຊື່ຶອຖື. ຂໍ້ມູນເພີ່ມເຕີມກ່ຽວກັບວິທີແກ້ໄຂບັນຫານີ້ສາມາດເບິ່ງໄດ້ໃນ {linkstart1}ເອກະສານ↗{linkend}/({linkstart2}ລາຍການຟາຍ.. {linkend} / {linkstart3}Rescan... {linkend})",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "ບໍ່ມີ ການກໍານົດ ຫນ້າທີ່ PHP \"ກໍານົດເວລາ\". ອາດຈະເຮັດໃຫ້ scripts ຖືກຢຸດກາງ ການດໍາເນີນງານ, ແລະທໍາລາຍການຕິດຕັ້ງຂອງທ່ານ. ເນະນໍາໃຫ້ເປີດນໍາໃຊ້ ການກໍານົດເວລາ.",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP ຂອງທ່ານບໍ່ໄດ້ຮັບການສະຫນັບສະຫນູນ FreeType, ເຮັດໃຫ້ຮູບພາບໜ້າປົກຄວາມຄົມຊັດບໍ່ລະອຽດ ລວມທັງບັນຫາ ການຕັ້ງຄ່າ interface.",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "ບໍ່ມີຊື່  index \"{indexName}\" ໃນຕາຕະລາງ \"{tableName}\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "ຖານຂໍ້ມູນຂາດດັດຊະນີບາງຢ່າງບໍ່ເຫັນ. ເນື່ອງຈາກວ່າການເພີ່ມດັດຊະນີໃສ່ຕາຕະລາງໃຫຍ່ອາດຈະໃຊ້ ເວລາດົນ . ໂດຍການດຳເນີນ \"occ db:add-missing-indices\" ດັດຊະນີທີ່ຂາດໄປ ສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ. ເມື່ອດັດຊະນີຖືກຕື່ມຄໍາສອບຖາມໃສ່ຕາຕະລາງເຫຼົ່ານັ້ນຕາມປົກກະຕິແລ້ວຈະໄວຂຶ້ນຫຼາຍ.",
+    "Missing primary key on table \"{tableName}\"." : "ຂາດລະຫັດເຂົ້າເຖິງຕາຕະລາງ \"{tableName}\".",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "ຖານຂໍ້ມູນຂາດລະຫັດບາງຢ່າງ. ເນື່ອງຈາກວ່າການເພີ່ມກະແຈຕົ້ນຕໍໃສ່ ໂຕະໃຫຍ່ ອາດ ຈະໃຊ້ ເວລາດົນນານທີ່ພວກເຂົາເຈົ້າບໍ່ໄດ້ ຖືກຕື່ມໂດຍອັດຕະໂນມັດ . ໂດຍການແລ່ນ \"occ db:add-missing-primary-keys\" ຂາດກະແຈຕົ້ນຕໍເຫຼົ່ານັ້ນສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ.",
+    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "ຂາດ column ທາງເລືອກ \"{columnName}\" ໃນຕາຕະລາງ \"{tableName}\".",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "ຖານຂໍ້ມູນແມ່ນຂາດບາງ columns ທາງເລືອກ. ເນື່ອງຈາກວ່າການເພີ່ມ columns ໃສ່ ຕາຕະລາງໃຫຍ່ ອາດ ຈະ ໃຊ້ເວລາດົນ ທີ່ບໍ່ໄດ້ຕື່ມໂດຍອັດຕະໂນມັດ ເມື່ອເລືອກ ໄດ້ . ໂດຍການດຳ \"occ db:add-missing-columns\" columns ທີ່ຂາດໄປສາມາດເພີ່ມໄດ້ດ້ວຍມືໃນຂະນະທີ່ຕົວຢ່າງຍັງດໍາເນີນການຕໍ່ໄປ. ເມື່ອມີການເພີ່ມ columns ອາດຈະປັບປຸງການຕອບສະຫນອງ ຫຼື ການໃຊ້ງານ.",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "ຕົວຢ່າງເເນະນຳຂາດໂມດູນ PHP,  ສໍາລັບການປັບປຸງ ແລະ ການປະຕິບັດທີ່ດີກວ່າ ນັ້ນ ແມ່ນແນະນໍາໃຫ້ຕິດຕັ້ງ  ",
+    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "ໂມດູນ php-imagick ໃນກໍລະນີນີ້ບໍ່ມີການສະຫນັບສະຫນູນ SVG. ເພື່ອຄວາມສອດຄ່ອງທີ່ດີກວ່າແມ່ນແນະນໍາໃຫ້ຕິດຕັ້ງ.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite ກໍາລັງຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນbackend. ສໍາລັບການຕິດຕັ້ງທີ່ໃຫຍ່ກວ່າ   ພວກເຮົາຂໍແນະນໍາໃຫ້ທ່ານປ່ຽນໄປຫາ backend ຖານຂໍ້ມູນທີ່ແຕກຕ່າງ ກັນ .",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "ແນະນໍາໂດຍສະເພາະເມື່ອການນໍາໃຊ້ desktop ລູກຄ້າ  ສໍາລັບການ ຢືນຢັນຟາຍ",
+    "The PHP memory limit is below the recommended value of 512MB." : "ຂີດຈໍາກັດຄວາມຈໍາ PHP ແມ່ນຕ່ໍາກວ່າຄ່າທີ່ແນະນໍາຂອງ 512MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "ຊອບແວຂອງຜູ້ ໃຊ້ແຕກຕ່າງຈາກເວັບໄຊ  . ອາດຢູ່ເປັນກໍລະນີ ການຕິດຕັ້ງແອັບພລິເຄຊັນດ້ວຍມື. ກວດສອບການອະນຸຍາດຂອງແອັບພລິເຄຊັນດັ່ງຕໍ່ໄປນີ້:",
+    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL ຖືກນໍາໃຊ້ເປັນຖານຂໍ້ມູນແຕ່ບໍ່ສະຫນັບສະຫນູນຕົວອັກສອນ 4 byte. ເພື່ອ ໃຫ້ ສາມາດຮັບ 4-byteໄດ້(ເຊັ່ນ emojis) ໂດຍບໍ່ມີບັນຫາໃນຊື່ຟາຍ ຫຼື ຄໍາ ເຫັນຍົກຕົວຢ່າງ ແນະນໍາໃຫ້ ເຮັດໃຫ້ ການສະຫນັບສະຫນູນ 4 byte ໃນ MySQL . ສໍາລັບລາຍລະອຽດ ເພີ່ມເຕີມອ່ານ {linkstart} ຫນ້າ ເອກະສານກ່ຽວກັບ ↗{linkend} ນີ້.",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "ຕົວຢ່າງນີ້ໃຊ້  S3 ເປັນການເກັບກໍາຂໍ້ມູນຕົ້ນຕໍ. ຟາຍອັບໂຫຼດໄດ້ເກັບ ໄວ້ ຊົ່ວ ຄາວ ຢູ່ ໃນ server ແລະ ດັ່ງນັ້ນຈຶ່ງແນະນໍາໃຫ້ມີ ພຶນທີ່ວ່າງ 50 GB ໃນ directory temp ຂອງ PHP . ກວດເບິ່ງບັນຊີລາຍລະອຽດກ່ຽວກັບຊ່ອງທາງ ແລະ  ພຶນທີ່ວ່າງ  . ເພື່ອປັບປຸງກະລຸນາປ່ຽນ directory ຊົ່ວຄາວໃນ php.ini ຫຼື ເຮັດໃຫ້ມີຊ່ອງຫວ່າງຫຼາຍຂຶ້ນໃນຊ່ອງທາງນັ້ນ.",
+    "Wrong username or password." : "ຊື່ຜູ້ໃຊ້ ຫຼື ລະຫັດຜ່ານຜິດ.",
+    "User disabled" : "ປິດຊື່ຜູ້ໃຊ້",
+    "Username or email" : "ຊື່ຜູ້ໃຊ້ ຫຼື ອີເມວ",
     "If it is not there ask your local administrator." : "ຖ້າບໍ່ໄດ້ຖາມຜູ້ເບິ່ງລະບົບຂອງທ່ານ.",
     "Settings" : "ການຕັ້ງຄ່າ",
+    "Show all contacts …" : "ສະແດງການຕິດຕໍ່ທັງຫມົດ ...",
     "No files in here" : "ບໍ່ມີຟາຍໃນທີ່ນີ້",
     "New folder" : "ໂຟນເດີໃຫມ່",
     "No more subfolders in here" : "ບໍ່ມີ ໂຟນເດີຍ່ອຍ ອີກຕໍ່ໄປໃນນີ້",
@@ -327,9 +320,15 @@ OC.L10N.register(
     "Copy to {folder}" : "ສໍາເນົາໄປຍັງ {ໂຟນເດີ}",
     "Move to {folder}" : "ຍ້າຍໄປ {folder}",
     "Authentication required" : "ການຢັ້ງຢືນທີ່ຈໍາເປັນ",
+    "This action requires you to confirm your password" : "ການກະທໍານີ້ຮຽກຮ້ອງໃຫ້ທ່ານເພື່ອຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
+    "Confirm" : "ຢືນຢັນ",
     "Failed to authenticate, try again" : "ບໍ່ສາມາດຮັບຮອງຄວາມຖຶກຕ້ອງໄດ້, ລອງອີກຄັ້ງ",
-    "File not found" : " ບໍ່ພົບຟາຍ",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "ເອກະສານບໍ່ສາມາດຄົ້ນພົບໄດ້ໃນ server.  ບາງທີສ່ວນແບ່ງຖືກລຶບ ຫຼື ໄດ້ສິ້ນສຸດລົງ?",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "ກະລຸນາໃຊ້ ຄໍາສັ່ງ ປັບປຸງ ເພາະການອັບເດດໂດຍອັດຕະໂນມັດຖືກປິດໃນລະບົບການຕັ້ງຄ່າ config.php."
+    "Users" : "ຜູ້ໃຊ້",
+    "Username" : "ຊື່ຜູ້ໃຊ້",
+    "Database user" : "ຜູ້ໃຊ້ຖານຂໍ້ມູນ",
+    "Confirm your password" : "ຢືນຢັນລະຫັດຜ່ານຂອງທ່ານ",
+    "App token" : "ແອັບ token",
+    "Alternative log in using app token" : "log ທາງເລືອກໃນການນໍາໃຊ້ token app",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "ກະລຸນາໃຊ້  ອັບເດດແຖວຄໍາສັ່ງ ເພາະວ່າທ່ານມີຕົວຢ່າງໃຫຍ່ທີ່ມີຜູ້ໃຊ້ຫຼາຍກວ່າ 50 ຜຸ້ໃຊ້."
 },
 "nplurals=1; plural=0;");
