@@ -38,12 +38,12 @@ OC.L10N.register(
     "Reset your password" : "Ресетирај ја твојата лозинка",
     "Task not found" : "Задачата не е пронајдена",
     "Internal error" : "Внатрешна грешка",
+    "Image not found" : "Сликата не е пронајдена",
     "Could not detect language" : "Неможе да се детектира јазикот",
     "Unable to translate" : "Неможе да се преведе",
     "Nextcloud Server" : "Nextcloud Сервер",
     "Some of your link shares have been removed" : "Некој од вашите линкови што ги споделивте се избришани",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Поради безбедносен ризик некој од вашите споделувања се избришани. Ве молиме видете го линкот за повеќе информации.",
-    "The user limit of this instance is reached." : "Лимитот на корисници на оваа истанца е исполнет.",
     "Learn more ↗" : "Научи повеќе ↗",
     "Preparing update" : "Ја подготвувам надградбата",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -68,24 +68,6 @@ OC.L10N.register(
     "Already up to date" : "Веќе ажурирано",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Вашиот веб опслужувач сеуште не е точно подесен да овозможува синхронизација на датотеки бидејќи интерфејсот за WebDAV изгледа дека е расипан. ",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Вашиот веб сервер не е правилно поставен за разрешаување на \"{url}\".  Повеќе информации можат да се пронајдат во {linkstart}документацијата ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Вашиот веб сервер не е правилно поставен за разрешаување на \"{url}\". Ова најверојатно е поврзано со конфигурацијата на веб-серверот или не е ажуриран за директен пристап до оваа папка. Ве молиме, споредете ја вашата конфигурација дали е во согласност со правилата за пренасочување во \".htaccess\" за Apache или во документацијата за  Nginx на {linkstart}страната со документација{linkend}. На Nginx тоа се најчето линиите што започнуваат со \"location ~\" што им треба ажурирање.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Вашиот веб сервер не е правилно поставен за испорака на .woff2 датотеки. Ова обично е проблем со конфигурацијата на Nginx. За Nextcloud 15 исто така е потребно да се испорачуваат .woff2 датотеки. Споредете ја вашата конфигурација на Nginx со препорачаната конфигурација во нашата {linkstart}документација{linkend}.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Не е возможно извршување на cron позадинските задачи преку CLI. Се појавија следниве технички грешки:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Од последенио пат како се извршени позадинските задачи се поминати {relativeTime}. Изгледа нешто не е во ред. {linkstart}Проверете ги параметрите за позадинските задачи ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Некои датотеки не ја поминаа проверката на интегритет. Дополнителни информации за тоа како да се реши ова прашање може да се најде во  {linkstart1}документацијата↗{linkend}. ({linkstart2}Листа на невалидни датотеки…{linkend} / {linkstart3}Повторно скенирање…{linkend})",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функцијата \"set_time_limit\" не е достапна. Ова може да резултира со запирање на скриптите во извршувањето, и грешки во вашата инсталација. Овозможувањето на оваа функција е препорачлива.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Недостасува индексот \"{indexName}\" во табелата \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Во базата недостасуваат некој индекси. Поради фактот што додавањето индекси во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-indices\" ќе бидат додадени оние индекси што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени индексите, барањата во табелите ќе биде многу побрзо.",
-    "Missing primary key on table \"{tableName}\"." : "Недостасува примарен клуч во табелата \"{tableName}\".",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Во базата недостасуваат некој примарни клучеви. Поради фактот што додавањето на примарни клучеви во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-primary-keys\" ќе бидат додадени оние примарни клучеви што недостасуваат и инстанцата непречено ќе работи.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Недостасува опција во колоната \"{columnName}\" во табелата \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Во базата недостасуваат некој опционални колони. Поради фактот што додавањето колони во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-columns\" ќе бидат додадени оние колони што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени колоните, некој карактеристики ќе се подобрат и можат да ја подобрат употребата и безбедноста.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модулот php-imagick во оваа истанца не поддржува SVG датотеки. За подобра компатибилност се препорачува да се инсталира.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Моментално се користи SQLite како база за податоци. За користење, препорачуваме различен начин за база на податоци.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Ова особено е препорачливо кога се користи клиент за синхронизација.",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "За да мигрирате во друга база на податоци, користете ја алатката во командната линија: 'occ db:convert-type', или погледнете во {linkstart}документацијата ↗{linkend}.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Некој папки со апликации не се сопственост на корисникот на веб серверот. Ова може да биде случај ако апликациите се инсталирани рачно. Проверете ги дозволите на следниве папки со апликации:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL се користи како база на податоци, но не поддржува 4-бајтни карактери. За да можете да ракувате со 4-бајтни карактери (како емотикони) без проблеми во имиња на датотеки или коментари, се препорачува да се овозможи поддршка од 4-бајти во MySQL. За повеќе детали прочитајте во {linkstart}документација{linkstart}.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Пристапувате на оваа истанца преку безведносна врска, но оваа истанца генерира не-безбедни URL адреси. Ова, најверојатно, значи дека стоите зад обратниот прокси и променливите за конфигурирање за пребришување не се правилно поставени. Прочитајде во {linkstart}документацијата{linkend}.",
     "Error occurred while checking server setup" : "Се случи грешка при проверката на параметрите на серверот",
     "For more details see the {linkstart}documentation ↗{linkend}." : "За повеќе детали погледнете во {linkstart}документацијата ↗{linkend}.",
@@ -114,20 +96,19 @@ OC.L10N.register(
     "More apps" : "Повеќе апликации",
     "Currently open" : "Моментално отворено",
     "_{count} notification_::_{count} notifications_" : ["Едно исзестување","{count} известувања"],
+    "Pick start date" : "Избери почетен датум",
+    "Pick end date" : "Избери краен датум",
     "Log in" : "Најава",
     "Logging in …" : "Најава ...",
     "Server side authentication failed!" : "Автентификацијата на серверската страна е неуспешна!",
     "Please contact your administrator." : "Ве молиме контактирајте го вашиот администратор.",
+    "Please try again." : "Ве молиме обидете се повторно.",
     "An internal error occurred." : "Се случи внатрешна грешка.",
     "Please try again or contact your administrator." : "Ве молиме обидете се повторно или контактирајте го вашиот администратор.",
-    "Account name or email" : "Корисничко име или е-пошта",
     "Password" : "Лозинка",
     "Log in to {productName}" : "Најави се на {productName}",
-    "Wrong username or password." : "Погрешно корисничко име или лозинка.",
-    "User disabled" : "Корисникот е оневозможен",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Детектирани се повеќе неуспешни најавувања од вашата IP адреса. Затоа вашиот следен обид за најавување е одложено за 30 секунди.",
     "Log in with a device" : "Најавете се со уред",
-    "Username or email" : "Корисничко име или е-пошта",
     "Your account is not setup for passwordless login." : "Вашата сметка не е поставена за најавување без лозинка.",
     "Browser not supported" : "Вашиот прелистувач не е поддржан",
     "Passwordless authentication is not supported in your browser." : "Вашиот прелистувач не поддржува автентикација без лозинка.",
@@ -163,11 +144,15 @@ OC.L10N.register(
     "Install the Contacts app" : "Инсталирај апликација за контакти",
     "Loading your contacts …" : "Вчитување на вашите контакти ...",
     "Looking for {term} …" : "Пребарување за {term} …",
-    "Modified" : "Изменето",
-    "Today" : "Денес",
-    "Not found" : "Не е пронајдено",
-    "People" : "Луѓе",
+    "Search for {name} only" : "Пребарај само за {name}",
+    "Start typing to search" : "Напишете нешто за пребарување",
+    "Loading more results …" : "Вчитување на повеќе резултати ...",
     "Load more results" : "Вчитај повеќе резултати",
+    "Search" : "Барај",
+    "No results for {query}" : "Нема резултати за {query}",
+    "Press Enter to start searching" : "Притисни Enter за започне пребарувањето",
+    "An error occurred while searching for {type}" : "Настана грешка при пребарување за {type}",
+    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Внесете најмалку {minSearchLength} карактер за да пребарувате","Внесете најмалку {minSearchLength} карактери или повеќе за да пребарувате"],
     "Forgot password?" : "Заборавена лозинка?",
     "Back to login form" : "Врати се на формата за најавување",
     "Back" : "Назад",
@@ -176,21 +161,27 @@ OC.L10N.register(
     "The headline and about sections will show up here" : "Насловот и за секциите ќе се појават овде",
     "You have not added any info yet" : "Сè уште немате додадено никакви информации",
     "{user} has not added any info yet" : "{user} нема додадено никакви информации",
-    "Search for {name} only" : "Пребарај само за {name}",
-    "Start typing to search" : "Напишете нешто за пребарување",
-    "Loading more results …" : "Вчитување на повеќе резултати ...",
-    "Search" : "Барај",
-    "No results for {query}" : "Нема резултати за {query}",
-    "Press Enter to start searching" : "Притисни Enter за започне пребарувањето",
-    "An error occurred while searching for {type}" : "Настана грешка при пребарување за {type}",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Внесете најмалку {minSearchLength} карактер за да пребарувате","Внесете најмалку {minSearchLength} карактери или повеќе за да пребарувате"],
+    "Search apps, files, tags, messages" : "Барај апликации, датотеки, ознаки, пораки",
+    "Search {types} …" : "Пребарување {types} …",
+    "Apps and Settings" : "Апликации и параметри",
+    "Date" : "Датум",
+    "Today" : "Денес",
+    "Last 7 days" : "Предходни 7 дена",
+    "Last 30 days" : "Предходни 30 дена",
+    "This year" : "Оваа година",
+    "Last year" : "Предходна година",
+    "Not found" : "Не е пронајдено",
+    "People" : "Луѓе",
+    "Search in" : "Барај во",
+    "Searching …" : "Пребарување ...",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Помеѓу ${this.dateFilter.startFrom.toLocaleDateString()} и ${this.dateFilter.endAt.toLocaleDateString()}",
     "This browser is not supported" : "Овој прелистувач не е поддржан",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Вашиот прелистувач не е поддржан. Надградете на понова или поддржана верзија.",
     "Continue with this unsupported browser" : "Продолжете со овој неподдржан прелистувач",
     "Supported versions" : "Поддржани верзии",
     "{name} version {version} and above" : "{name} верзија {version} и понови",
     "Settings menu" : "Мени за параметри",
-    "Search {types} …" : "Пребарување {types} …",
+    "Avatar of {displayName}" : "Аватар на {displayName}",
     "No" : "Не",
     "Yes" : "Да",
     "Choose {file}" : "Избери {file}",
@@ -244,7 +235,7 @@ OC.L10N.register(
     "Collaborative tags" : "Колаборативна ознака",
     "No tags found" : "Не се пронајдени ознаки",
     "Personal" : "Лично",
-    "Users" : "Корисници",
+    "Accounts" : "Сметки",
     "Apps" : "Аппликации",
     "Admin" : "Админ",
     "Help" : "Помош",
@@ -275,7 +266,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Вашиот директориум со податоци и датотеки се веројатно достапни преку интенернт поради што .htaccess датотеката не функционира.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информации како правилно да го конфигурирате вашиот сервер, ве молиме погледнете ја <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацијата</a>.",
     "Create an <strong>admin account</strong>" : "Направете <strong>администраторска сметка</strong>",
-    "Username" : "Корисничко име",
     "Show password" : "Прикажи лозинка",
     "Toggle password visibility" : "Вклучи видливост на лозинки",
     "Storage & database" : "Складиште & база на податоци",
@@ -284,7 +274,6 @@ OC.L10N.register(
     "Only %s is available." : "Само %s е достапно.",
     "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте дополнителни PHP додатоци за да можете да изберете друг вид на база на податоци.",
     "For more details check out the documentation." : "За повеќе детали проверете ја документацијата.",
-    "Database user" : "Корисник на база",
     "Database password" : "Лозинка на база",
     "Database name" : "Име на база",
     "Database tablespace" : "Табела во базата на податоци",
@@ -305,15 +294,12 @@ OC.L10N.register(
     "Skip to navigation of app" : "Оди до навигацијата на апликацијата",
     "Go to %s" : "Оди до %s",
     "Get your own free account" : "Креирајте ваша сметка",
-    "This action requires you to confirm your password" : "За оваа акција потребно е да ја потврдите вашата лозинка",
-    "Confirm your password" : "Потврдете ја вашата лозинка",
-    "Confirm" : "Потврди",
     "Connect to your account" : "Поврзани со вашата сметка",
     "Please log in before granting %1$s access to your %2$s account." : "Ве молиме најавете се пред да доделите пристап на %1$s во вашата %2$s сметка.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Доколку не се обидувате да додадете нов уред, некој се обидува да ве надитри и да обезбеди пристап до вашите податоци. Во тој случај не продолжувајте понатаму и веднаш контактирајте го администраторот.",
-    "App token" : "App token",
+    "App password" : "Лозинка за апликација",
     "Grant access" : "Дозволи пристап",
-    "Alternative log in using app token" : "Алтернативен начин на најава со користење на токен",
+    "Alternative log in using app password" : "Алтернативен начин на најава со користење на лозинка за апликација",
     "Account access" : "Пристап до сметка",
     "Currently logged in as %1$s (%2$s)." : "Најавени сте како %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Ќе доделите пристап на %1$s во вашата %2$s сметка.",
@@ -350,7 +336,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "За да избегнете тајм аут за големи инсталации, можете да ја извршите следнава команда во директориумот за инсталација:",
     "Detailed logs" : "Детални записи",
     "Update needed" : "Потребно е ажутирање",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Ве молиме користете ја командната линија за ажурирање бидејќи имате голема истанца со повеќе од 50 корисници.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помош, прочитајте ја <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацијата</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Знам дека има ризик ако продолжам со ажурирањето преку веб-интерфејс, и да застане во тајм аут и може да предизвика загуба на податоци, но имам резервна копија и знам како да ја вратам мојата истанца во случај на дефект.",
     "Upgrade via web on my own risk" : "Надоградба преку веб-интерфејс на сопствен ризик",
@@ -359,30 +344,53 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Оваа веб страница ќе се рефрешира кога истанцата ќе биде повторно достапна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте го вашиот систем администратор до колку оваа порака продолжи да се појавува или пак се појавува ненадејно.",
     "Please try again" : "Ве молиме обидете се повторно",
+    "The user limit of this instance is reached." : "Лимитот на корисници на оваа истанца е исполнет.",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Вашиот веб сервер не е правилно поставен за разрешаување на \"{url}\". Ова најверојатно е поврзано со конфигурацијата на веб-серверот или не е ажуриран за директен пристап до оваа папка. Ве молиме, споредете ја вашата конфигурација дали е во согласност со правилата за пренасочување во \".htaccess\" за Apache или во документацијата за  Nginx на {linkstart}страната со документација{linkend}. На Nginx тоа се најчето линиите што започнуваат со \"location ~\" што им треба ажурирање.",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Вашиот веб сервер не е правилно поставен за испорака на .woff2 датотеки. Ова обично е проблем со конфигурацијата на Nginx. За Nextcloud 15 исто така е потребно да се испорачуваат .woff2 датотеки. Споредете ја вашата конфигурација на Nginx со препорачаната конфигурација во нашата {linkstart}документација{linkend}.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP се чини дека не е правилно поставена за да испраќа барања до променливите на околината на системот. Тестот со getenv(\"PATH\") враќа само празен одговор.",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Ве молиме проверете ја {linkstart}документацијата за инсталација ↗{linkend} за конфигурационите PHP белешки и PHP конфигурацијата на вашиот сервер, особено кога користите php-fpm.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Антивирана е конфигурација која е само за чирање. Ова спречува поставување на некои конфигурации преку веб-интерфејсот. Понатаму, датотеката треба да се пребрише рачно за секое ажурирање.",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Вашата база на податоци не работи со нивото на изолација со \"READ COMMITTED\". Ова може да предизвика проблеми кога повеќе дејства се извршуваат паралелно.",
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Недостасува PHP модулот \"fileinfo\". Препорачливо е да го овозможите овој додаток за да ги добиете најдобрите резултати со детекција на MIME видот.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Заклучување на активна датотека е оневозможено, ова може да доведе до проблеми со условите на синхронизација. Овозможете \"filelocking.enabled\" во config.php за да ги избегнете овие проблеми. Видете во  {linkstart}документацијата ↗{linkend} за повеќе информации.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Не е возможно извршување на cron позадинските задачи преку CLI. Се појавија следниве технички грешки:",
+    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Од последенио пат како се извршени позадинските задачи се поминати {relativeTime}. Изгледа нешто не е во ред. {linkstart}Проверете ги параметрите за позадинските задачи ↗{linkend}.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Овој опслужувач нема работна Интернет врска. Ова значи дека некои опции како што е монтирање на надворешни складишта, известувања за ажурирање или инсталации на апликации од 3-ти лица нема да работат. Пристапот на датотеки од далечина и праќање на пораки за известувања може исто така да не работат. Ви советуваме да овозможите Интернет врска за овој опслужувач ако сакате да ги имате сите опции. ",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Не е конфигурирана мемориjа за кеширање. За да ги подобрите перформансите, конфигурирајте memcache, доколку е можно. Дополнителни информации може да се најдат во {linkstart}документацијата{linkend}.",
     "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Моненталната верзија на PHP е {version}. Ажурирајте ја PHP верзијата да ги искористите предностите од {linkstart}перформанси и безбедносни ажурирања обезбедени од групацијата PHP ↗{linkend} штом вашата дистрибуција го поддржува.",
+    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Некои датотеки не ја поминаа проверката на интегритет. Дополнителни информации за тоа како да се реши ова прашање може да се најде во  {linkstart1}документацијата↗{linkend}. ({linkstart2}Листа на невалидни датотеки…{linkend} / {linkstart3}Повторно скенирање…{linkend})",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP функцијата \"set_time_limit\" не е достапна. Ова може да резултира со запирање на скриптите во извршувањето, и грешки во вашата инсталација. Овозможувањето на оваа функција е препорачлива.",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Недостасува индексот \"{indexName}\" во табелата \"{tableName}\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Во базата недостасуваат некој индекси. Поради фактот што додавањето индекси во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-indices\" ќе бидат додадени оние индекси што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени индексите, барањата во табелите ќе биде многу побрзо.",
+    "Missing primary key on table \"{tableName}\"." : "Недостасува примарен клуч во табелата \"{tableName}\".",
+    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Во базата недостасуваат некој примарни клучеви. Поради фактот што додавањето на примарни клучеви во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-primary-keys\" ќе бидат додадени оние примарни клучеви што недостасуваат и инстанцата непречено ќе работи.",
+    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Недостасува опција во колоната \"{columnName}\" во табелата \"{tableName}\".",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Во базата недостасуваат некој опционални колони. Поради фактот што додавањето колони во големи бази може да потрае, тие не беа додадени автоматски. Со стартување на командата \"occ db:add-missing-columns\" ќе бидат додадени оние колони што недостасуваат и инстанцата непречено ќе работи. Еднаш кога ќе бидат додадени колоните, некој карактеристики ќе се подобрат и можат да ја подобрат употребата и безбедноста.",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "На оваа истанца недостасуваат некој препорачливи PHP модули. За подобри перформанси и подобра компатибилност, се препорачува да ги инсталирате.",
+    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Модулот php-imagick во оваа истанца не поддржува SVG датотеки. За подобра компатибилност се препорачува да се инсталира.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Моментално се користи SQLite како база за податоци. За користење, препорачуваме различен начин за база на податоци.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Ова особено е препорачливо кога се користи клиент за синхронизација.",
+    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "За да мигрирате во друга база на податоци, користете ја алатката во командната линија: 'occ db:convert-type', или погледнете во {linkstart}документацијата ↗{linkend}.",
     "The PHP memory limit is below the recommended value of 512MB." : "Меморијата за PHP е под препорачаната вредност од 512MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Некој папки со апликации не се сопственост на корисникот на веб серверот. Ова може да биде случај ако апликациите се инсталирани рачно. Проверете ги дозволите на следниве папки со апликации:",
+    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL се користи како база на податоци, но не поддржува 4-бајтни карактери. За да можете да ракувате со 4-бајтни карактери (како емотикони) без проблеми во имиња на датотеки или коментари, се препорачува да се овозможи поддршка од 4-бајти во MySQL. За повеќе детали прочитајте во {linkstart}документација{linkstart}.",
+    "Account name or email" : "Корисничко име или е-пошта",
+    "Wrong username or password." : "Погрешно корисничко име или лозинка.",
+    "User disabled" : "Корисникот е оневозможен",
+    "Username or email" : "Корисничко име или е-пошта",
     "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Порака за ресетирање на лозинката е испратена на е-пошта на оваа сметка. Доколку не сте ја добиле, проверете во spam/junk папката или прашајте го вашиот локален администратор за помош.",
     "If it is not there ask your local administrator." : "Доколку не е таму, прашајте го вашиот локален администратор.",
     "Start search" : "Започни пребарување",
     "Press enter to start searching" : "Притисни Enter за започне пребарувањето",
     "Open settings menu" : "Мени за параметри",
     "Settings" : "Параметри",
-    "Avatar of {fullName}" : "Аватар на {fullName}",
     "Show all contacts …" : "Прикажи ги сите контакти ...",
     "No files in here" : "Тука нема датотеки",
     "New folder" : "Нова папка",
     "No more subfolders in here" : "Нема повеќе поддиректориуми тука",
     "Name" : "Име",
     "Size" : "Големина",
+    "Modified" : "Изменето",
     "\"{name}\" is an invalid file name." : "\"{name}\" е невалидно име за датотека.",
     "File name cannot be empty." : "Името на датотеката не може да биде празно.",
     "\"/\" is not allowed inside a file name." : "\"/\" не е дозволено во името.",
@@ -396,10 +404,17 @@ OC.L10N.register(
     "Copy to {folder}" : "Копирај во {folder}",
     "Move to {folder}" : "Премести во {folder}",
     "Authentication required" : "Потребна е автентификација",
+    "This action requires you to confirm your password" : "За оваа акција потребно е да ја потврдите вашата лозинка",
+    "Confirm" : "Потврди",
     "Failed to authenticate, try again" : "Неуспешна автентификација, обидете се повторно",
-    "File not found" : "Датотеката не е пронајдена",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "Документот не може да се пронајде на серверот. Можеби ова споделување е избришано или рекот за пристап му е истечен?",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Ве молиме користете ја командната линија за ажурирање бидејќи автоматското ажурирање е оневозможено во config.php.",
-    "The page could not be found on the server." : "Страницата не е пронајдена на серверот."
+    "Users" : "Корисници",
+    "The page could not be found on the server." : "Страницата не е пронајдена на серверот.",
+    "Username" : "Корисничко име",
+    "Database user" : "Корисник на база",
+    "Confirm your password" : "Потврдете ја вашата лозинка",
+    "App token" : "App token",
+    "Alternative log in using app token" : "Алтернативен начин на најава со користење на токен",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Ве молиме користете ја командната линија за ажурирање бидејќи имате голема истанца со повеќе од 50 корисници.",
+    "Avatar of {fullName}" : "Аватар на {fullName}"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
