@@ -38,12 +38,20 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klikk følgende knapp for å tilbakestille passordet ditt. Ignorer denne e-posten hvis du ikke har forespurt dette.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klikk følgende lenke for å tilbakestille passordet ditt. Ignorer denne e-posten hvis du ikke har forespurt dette.",
     "Reset your password" : "Tilbakestill passordet ditt",
+    "Requested task type does not exist" : "Den forespurte oppgavetypen eskisterer ikke",
+    "Necessary language model provider is not available" : "Nødvendig tilbyder av språkmodell er ikke tilgjengelig",
+    "Task not found" : "Oppgave ikke funnet",
     "Internal error" : "Intern feil",
+    "No text to image provider is available" : "Ingen tilbyder av tekst til bilde er tilgjengelig",
+    "Image not found" : "Bilde ikke funnet",
+    "No translation provider available" : "Ingen tilbyder av oversetting er tilgjengelig",
+    "Could not detect language" : "Kunne ikke gjenkjenne srpåk",
+    "Unable to translate" : "Ikke i stand til å oversette",
     "Nextcloud Server" : "Nextcloud-server",
     "Some of your link shares have been removed" : "Noen av de delte lenkene dine har blitt fjernet",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "På grunn av et sikkerhetsproblem har vi fjernet enkelte av de delte lenkene dine. Vennligst se linken for mer informasjon. ",
-    "The user limit of this instance is reached." : "Brukergrensen på denne installasjonen er nådd.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Skriv inn abonnementsnøkkelen din i støtteappen for å øke brukergrensen. Dette gir deg også alle tilleggsfordeler som Nextcloud Enterprise tilbyr og anbefales på det sterkeste for driften i selskaper.",
+    "The account limit of this instance is reached." : "Kontogrensen for denne forekomsten er nådd.",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Skriv inn abonnementsnøkkelen din i støtteappen for å øke brukergrensen. Dette gir deg også alle tilleggsfordeler som Nextcloud Enterprise tilbyr og anbefales på det sterkeste for driften i selskaper.",
     "Learn more ↗" : "Lær mer ↗",
     "Preparing update" : "Forbereder oppdatering",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -51,6 +59,7 @@ OC.L10N.register(
     "Repair info:" : "Reparasjonsinformasjon:",
     "Repair warning:" : "Reparasjonsadvarsel:",
     "Repair error:" : "Reparasjonsfeil:",
+    "Please use the command line updater because updating via browser is disabled in your config.php." : "Vennligst bruk kommandolinje til å oppdatere.  Oppdatering via nettleser er ikke aktivert i din config.php.",
     "Turned on maintenance mode" : "Vedlikeholdmodus aktivt",
     "Turned off maintenance mode" : "Vedlikeholdmodus er deaktivert",
     "Maintenance mode is kept active" : "Vedlikeholdmodus beholdes aktivt",
@@ -68,12 +77,6 @@ OC.L10N.register(
     "Already up to date" : "Allerede oppdatert",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Webserveren din er ikke satt opp til å tillate synkronisering av filer ennå, fordi WebDAV-grensesnittet ikke ser ut til å virke.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Din web-server er ikke satt opp korrekt for å hente \"{url}\". Mer informasjon finner du i <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"{docLink}\">dokumentasjonen</a>.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Nettserveren din er ikke riktig konfigurert for å løse \"{url}\". Dette er mest sannsynlig relatert til en webserverkonfigurasjon som ikke ble oppdatert for å levere denne mappen direkte. Sammenlign konfigurasjonen din med de tilsendte omskrivingsreglene i \".htaccess\" for Apache eller den oppgitte i dokumentasjonen for Nginx på sin {linkstart}dokumentasjonsside ↗{linkend}. På Nginx er det vanligvis linjene som starter med \"location ~\" som trenger en oppdatering.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Nettserveren din er ikke riktig konfigurert til å levere .woff2-filer. Dette er vanligvis et problem med Nginx-konfigurasjonen. For Nextcloud 15 trenger den en justering for også å levere .woff2-filer. Sammenlign Nginx-konfigurasjonen din med den anbefalte konfigurasjonen i {linkstart}dokumentasjonen ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Dette er den ustøttede fellesskapsbyggingen til Nextcloud. Gitt størrelsen på denne forekomsten kan ikke ytelse, pålitelighet og skalerbarhet garanteres. Push-varsler er begrenset for å unngå overbelastning av gratistjenesten vår. Finn ut mer om fordelene med Nextcloud Enterprise på {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL brukes som database, men støtter ikke 4-byte tegn. For å kunne håndtere 4-byte-tegn (som emojis) uten problemer i filnavn eller kommentarer for eksempel, anbefales det å aktivere 4-byte-støtten i MySQL. For ytterligere detaljer, les {linkstart}dokumentasjonssiden om dette ↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Denne instansen bruker en S3-basert objektlagring som primærlager. De opplastede filene blir lagret midlertidig på tjeneren og det er anbefalt å ha 50 GB ledig lagringsplass i det midlertidig lageret til PHP. Sjekk logger for fullstendige detaljer om filsti og ledig plass. Endre filstien til midlertidig lagringsplass i php.ini eller frigjør mer plass for å forbedre dette.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Den midlertidige katalogen for denne forekomsten peker til en enten ikke-eksisterende eller ikke-skrivbar katalog.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Du får tilgang til forekomsten din via en sikker tilkobling, men forekomsten genererer usikre nettadresser. Dette betyr mest sannsynlig at du står bak en omvendt proxy og at overskrivingskonfigurasjonsvariablene ikke er satt riktig. Les {linkstart}dokumentasjonssiden om dette ↗{linkend}.",
     "Error occurred while checking server setup" : "Feil oppsto ved sjekking av server-oppsett",
     "For more details see the {linkstart}documentation ↗{linkend}." : "For mer informasjon se {linkstart}dokumentasjonen ↗{linkend}.",
@@ -83,6 +86,7 @@ OC.L10N.register(
     "The \"{header}\" HTTP header does not contain \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "HTTP-hodet \"{header}\" inneholder ikke \"{expected}\". Dette er en potensiell sikkerhets- eller personvernrisiko, da det anbefales å justere denne innstillingen deretter.",
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "HTTP-hodet «{header}» er ikke satt til «{val1}», «{val2}», «{val3}», «{val4}» eller «{val5}». Dette kan lekke refererinformasjon. Se {linkstart}W3C-anbefalingen ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "HTTP-headeren \"Strict-Transport-Security\" er ikke satt til minst \"{seconds}\" sekunder. For økt sikkerhet anbefales det å aktivere HSTS som beskrevet i {linkstart}sikkerhetstipsene ↗{linkend}.",
+    "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Du gåt inn på siden via usikker HTTP.  Det er anbefales på det sterkeste at du setter opp serveren til å kreve HTTPS i stedet, som beskrevet i {linkstart}Sikkerhetstips ↗{linkend}.  Uten dette vil ikke viktig funksjonalitet som \"kopier til utklippstavle\" eller \"Service arbeidere\" virke!",
     "unknown text" : "ukjent tekst",
     "Hello world!" : "Hei, verden!",
     "sunny" : "solfylt",
@@ -99,29 +103,36 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Oppdateringen mislyktes. Rapporter dette problemet til <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud-gemenskapen</a>.",
     "Continue to {productName}" : "Fortsett til {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Oppdatering er vellykket. Går videre til {productName} om %n sekunder.","Oppdatering er vellykket. Går videre til {productName} om %n sekunder."],
+    "Applications menu" : "Applikasjonsmeny",
     "More apps" : "Flere apper",
     "Currently open" : "For øyeblikket åpen",
     "_{count} notification_::_{count} notifications_" : ["{count} varsel","{count} varsler"],
+    "Custom date range" : "Egendefinert datoperiode",
+    "Pick start date" : "Velg start dato",
+    "Pick end date" : "Velg sluttdato",
+    "Search in date range" : "Søk innenfor valgte datoer",
     "Log in" : "Logg inn",
     "Logging in …" : "Logger inn…",
     "Server side authentication failed!" : "Autentisering mislyktes på serveren!",
     "Please contact your administrator." : "Kontakt administratoren din.",
+    "Temporary error" : "Midlertidig feil",
+    "Please try again." : "Vennligst prøv på nytt.",
     "An internal error occurred." : "En intern feil oppsto",
     "Please try again or contact your administrator." : "Prøv igjen eller kontakt en administrator.",
-    "Account name or email" : "Kontonavn eller e-postadresse",
+    "Login or email" : "Pålogging eller e-post",
     "Password" : "Passord",
     "Log in to {productName}" : "Logg på {productName}",
-    "Wrong username or password." : "Feil brukernavn eller passord.",
-    "User disabled" : "Bruker deaktivert",
+    "Wrong login or password." : "Feil pålogging eller passord.",
+    "This account is disabled" : "Denne kontoen er deaktivert",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Vi har detektert flere ugyldige påloggingsforsøk fra din IP-adresse. Derfor er din neste innlogging forsinket med opptil 30 sekunder.",
     "Log in with a device" : "Logg inn med en enhet",
-    "Username or email" : "Brukernavn eller e-post",
     "Your account is not setup for passwordless login." : "Kontoen din er ikke satt opp med passordløs innlogging.",
     "Browser not supported" : "Nettleseren din støttes ikke!",
     "Passwordless authentication is not supported in your browser." : "Passordløs innlogging støttes ikke av nettleseren din.",
     "Your connection is not secure" : "Tilkoblingen din er ikke sikker",
     "Passwordless authentication is only available over a secure connection." : "Passordløs innlogging støttes kun over en sikker tilkobling.",
     "Reset password" : "Tilbakestill passord",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Hvis denne kontoen finnes, er det sendt en melding om tilbakestilling av passord til e-postadressen. Hvis du ikke mottar den, bekreft e-postadressen din og / eller logg inn, sjekk spam / søppelpostmappene dine eller spør din lokale administrasjon om hjelp.",
     "Couldn't send reset email. Please contact your administrator." : "Klarte ikke å sende e-post for tilbakestilling. Kontakt administratoren.",
     "Password cannot be changed. Please contact your administrator." : "Passordet kan ikke endres. Kontakt administratoren din.",
     "Back to login" : "Tilbake til innlogging",
@@ -143,6 +154,7 @@ OC.L10N.register(
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Enkel e-post app smidig integrert med Filer, Kontakter og Kalender.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, videosamtaler, skjermdeling, nettmøter og webkonferanser – i din nettleser og med mobilapper.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samarbeidsdokumenter, regneark og presentasjoner, bygget på Collabora Online.",
+    "Distraction free note taking app." : "Distraksjonsfri notatapp.",
     "Search contacts" : "Søk etter kontakter",
     "Reset search" : "Tilbakestill søk",
     "Search contacts …" : "Søk etter kontakter…",
@@ -159,9 +171,11 @@ OC.L10N.register(
     "Load more results" : "Last flere resultater",
     "Search" : "Søk",
     "No results for {query}" : "Ingen resultater for {query}",
+    "Press Enter to start searching" : "Trykk Enter for å starte søk",
     "An error occurred while searching for {type}" : "Det oppsto en feil ved søk etter {type}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Skriv minst {minSearchLength} bokstav for å søke","Skriv minst {minSearchLength} bokstaver for å søke"],
     "Forgot password?" : "Glemt passord?",
+    "Back to login form" : "Tilbake til innloggingsskjema",
     "Back" : "Tilbake",
     "Login form is disabled." : "Innloggingskjemaet er deaktivert.",
     "Edit Profile" : "Endre profil",
@@ -169,23 +183,38 @@ OC.L10N.register(
     "You have not added any info yet" : "Du har ikke lagt inn noe informasjon ennå",
     "{user} has not added any info yet" : "{user} har ikke lagt inn noe informasjon ennå",
     "Error opening the user status modal, try hard refreshing the page" : "Feil ved åpning av bruker-status modal, prøv å laste inn siden på nytt med hard refresh",
+    "Unified search" : "Enhetlig søk",
+    "Search apps, files, tags, messages" : "Søk i apper, filer, tagger, meldinger",
     "Search {types} …" : "Søk {types} ...",
+    "Apps and Settings" : "Apper og innstillinger",
     "Date" : "Dato",
     "Today" : "I dag",
+    "Last 7 days" : "Siste 7 dager",
+    "Last 30 days" : "Siste 30 dager",
+    "This year" : "I år",
     "Last year" : "I fjor",
+    "Search people" : "Søk etter personer",
     "Not found" : "Ikke funnet",
     "People" : "Mennesker",
+    "Filter in current view" : "Filter i gjeldende visning",
+    "Search in" : "Søk i",
     "Searching …" : "Søker ...",
+    "No matching results" : "Ingen treff",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Mellom ${this.dateFilter.startFrom.toLocaleDateString()} og ${this.dateFilter.endAt.toLocaleDateString()}",
     "This browser is not supported" : "Denne nettleseren støttes ikke",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Nettleseren din støttes ikke. Vennligst oppgrader til en nyere versjon eller en støttet versjon.",
     "Continue with this unsupported browser" : "Fortsett med denne nettleseren som ikke støttes",
     "Supported versions" : "Støttede versjoner",
     "{name} version {version} and above" : "{name} versjon {version} og nyere",
     "Settings menu" : "Meny for innstillinger",
+    "Avatar of {displayName}" : "{displayName} sin Avatar",
     "No" : "Nei",
     "Yes" : "Ja",
+    "Choose {file}" : "Velg {file}",
     "Choose" : "Velg",
+    "Copy to {target}" : "Kopier til {target}",
     "Copy" : "Kopier",
+    "Move to {target}" : "Flytt til {target}",
     "Move" : "Flytt",
     "OK" : "OK",
     "Error loading message template: {error}" : "Feil ved lasting av meldingsmal: {error}",
@@ -223,6 +252,7 @@ OC.L10N.register(
     "Strong password" : "Sterkt passord",
     "No action available" : "Ingen handling tilgjengelig",
     "Error fetching contact actions" : "Feil ved innhenting av kontakt-handlinger",
+    "Close \"{dialogTitle}\" dialog" : "Lukk \"{dialogTitle}\" dialogen",
     "Non-existing tag #{tag}" : "Ikke-eksisterende merkelapp #{tag}",
     "Restricted" : "Begrenset",
     "Invisible" : "Usynlig",
@@ -231,7 +261,7 @@ OC.L10N.register(
     "Collaborative tags" : "Samarbeidsmerkelapper",
     "No tags found" : "Ingen emneknagger funnet",
     "Personal" : "Personlig",
-    "Users" : "Brukere",
+    "Accounts" : "Kontoer",
     "Apps" : "Apper",
     "Admin" : "Admin",
     "Help" : "Hjelp",
@@ -240,6 +270,7 @@ OC.L10N.register(
     "The profile does not exist." : "Profilen finnes ikke",
     "Back to %s" : "Tilbake til %s",
     "Page not found" : "Siden ble ikke funnet",
+    "The page could not be found on the server or you may not be allowed to view it." : "Siden ble ikke funnet på serveren, eller du har ikke tilgang til den.",
     "Too many requests" : "For mange forespørsler",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Det var for mange forespørsler fra ditt nettverk. Prøv igjen senere eller kontakt din administrator hvis dette er en feil.",
     "Error" : "Feil",
@@ -261,7 +292,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Datamappen og filene dine er sannsynligvis tilgjengelig fra Internett fordi .htaccess-filen ikke fungerer.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "For informasjon om hvordan du skal konfigurere serveren skikkelig, les <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dokumentasjonen</a>.",
     "Create an <strong>admin account</strong>" : "Opprett en <strong>administrator-konto</strong>",
-    "Username" : "Brukernavn",
     "Show password" : "Vis passord",
     "Toggle password visibility" : "Vis passord av/på",
     "Storage & database" : "Lagring og database",
@@ -270,7 +300,7 @@ OC.L10N.register(
     "Only %s is available." : "Kun %s er tilgjengelig.",
     "Install and activate additional PHP modules to choose other database types." : "Installer og aktiver flere PHP-moduler for å velge andre databasetyper.",
     "For more details check out the documentation." : "Henvend deg til dokumentasjonen for flere detaljer.",
-    "Database user" : "Databasebruker",
+    "Database account" : "Databasekonto",
     "Database password" : "Databasepassord",
     "Database name" : "Databasenavn",
     "Database tablespace" : "Database-tabellområde",
@@ -294,7 +324,9 @@ OC.L10N.register(
     "Connect to your account" : "Koble til kontoen din",
     "Please log in before granting %1$s access to your %2$s account." : "Logg inn før du tildeler %1$stilgang til din %2$skonto.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Hvis du ikke prøver å sette opp en ny enhet eller app, så er det noen som nå prøver å lure deg til å gi de tilgang til dine data. Stopp i så fall øyeblikkelig og kontakt din systemadministrator.",
+    "App password" : "App passord",
     "Grant access" : "Gi tilgang",
+    "Alternative log in using app password" : "Alternativ innlogging ved bruk av app passord",
     "Account access" : "Kontotilgang",
     "Currently logged in as %1$s (%2$s)." : "Logget inn som %1$s (%2$s).",
     "You are about to grant %1$s access to your %2$s account." : "Du er i ferd med å tildele %1$s tilgang til din %2$skonto.",
@@ -331,7 +363,7 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "For å unngå tidsavbrudd ved store installasjoner, kan du i stedet kjøre følgende kommando fra installasjonsmappen:",
     "Detailed logs" : "Detaljerte logger",
     "Update needed" : "Oppdatering er nødvendig",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Bruk kommandolinjeoppdatereren siden du har en stor installasjon med mer enn 50 brukere.",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bruk kommandolinjeoppdatereren siden du har en stor forekomst med mer enn 50 kontoer.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "For hjelp, les <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dokumentasjonen</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Jeg vet at hvis jeg fortsetter oppdateringen via web-grensesnittet er det en mulighet for tap av data som følge av tidsavbrudd, men jeg har en sikkerhetskopi og vet hvordan jeg skal gjenopprette min installasjon hvis den feiler.",
     "Upgrade via web on my own risk" : "Oppgrader via web på min egen risikio",
@@ -340,6 +372,10 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Siden vil oppdatere seg selv når instans er tilgjengelig igjen.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontakt systemadministratoren hvis denne meldingen var uventet eller ikke forsvinner.",
     "Please try again" : "Vennligst prøv igjen",
+    "The user limit of this instance is reached." : "Brukergrensen på denne installasjonen er nådd.",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Skriv inn abonnementsnøkkelen din i støtteappen for å øke brukergrensen. Dette gir deg også alle tilleggsfordeler som Nextcloud Enterprise tilbyr og anbefales på det sterkeste for driften i selskaper.",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Nettserveren din er ikke riktig konfigurert for å løse \"{url}\". Dette er mest sannsynlig relatert til en webserverkonfigurasjon som ikke ble oppdatert for å levere denne mappen direkte. Sammenlign konfigurasjonen din med de tilsendte omskrivingsreglene i \".htaccess\" for Apache eller den oppgitte i dokumentasjonen for Nginx på sin {linkstart}dokumentasjonsside ↗{linkend}. På Nginx er det vanligvis linjene som starter med \"location ~\" som trenger en oppdatering.",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Nettserveren din er ikke riktig konfigurert til å levere .woff2-filer. Dette er vanligvis et problem med Nginx-konfigurasjonen. For Nextcloud 15 trenger den en justering for også å levere .woff2-filer. Sammenlign Nginx-konfigurasjonen din med den anbefalte konfigurasjonen i {linkstart}dokumentasjonen ↗{linkend}.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP er satt opp feil for å nå systemets miljøvariable. Test med getenv(\"PATH\") gir tom respons.",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Vennligst sjekk {linkstart}installasjonsdokumentasjonen ↗{linkend} for PHP-konfigurasjonsnotater og PHP-konfigurasjonen til serveren din, spesielt når du bruker php-fpm.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ikke skrivbar konfigurasjon er aktivert. Dette hindrer endring av konfigurasjon via web-grensesnitt. Filen må gjøres skrivbar manuelt for hver oppdatering.",
@@ -351,6 +387,7 @@ OC.L10N.register(
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Installasjonen din har ingen angitt standard telefonregion. Dette er nødvendig for å validere telefonnumrene i profilinnstillingene uten en landskode. For å tillate telefonnummer uten en landskode, vennligst legg til \"default_phone_region\" med den respektive  {linkstart}ISO 3166-1 koden↗{linkend} for regionen i konfigurasjonsfilen. ",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Det var ikke mulig å utføre cron jobben via CLI. Følgende tekniske feil har oppstått:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Siste bakgrunnsjobbkjøring kjørte {relativeTime}. Noe virker galt. {linkstart}Sjekk jobbinnstillingene i bakgrunnen ↗{linkend}.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Dette er den ustøttede fellesskapsbyggingen til Nextcloud. Gitt størrelsen på denne forekomsten kan ikke ytelse, pålitelighet og skalerbarhet garanteres. Push-varsler er begrenset for å unngå overbelastning av gratistjenesten vår. Finn ut mer om fordelene med Nextcloud Enterprise på {linkstart}https://nextcloud.com/enterprise{linkend}.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Denne serveren har ingen fungerende internettforbindelse: Flere endepunkter kunne ikke nås. Dette betyr at noen av funksjonene som montering av ekstern lagring, varsler om oppdateringer eller installasjon av tredjepartsapper ikke vil fungere. Tilgang til filer eksternt og sending av e-postvarsler fungerer kanskje heller ikke. Etabler en tilkobling fra denne serveren til internett for å nyte alle funksjonene.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ingen minnebuffer er konfigurert. For å forbedre ytelsen, vennligst konfigurer en memcache, hvis tilgjengelig. Mer informasjon finner du i {linkstart}dokumentasjonen ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ingen passende kilde for tilfeldighet funnet av PHP, som er sterkt frarådd av sikkerhetsgrunner. Mer informasjon finner du i {linkstart}dokumentasjonen ↗{linkend}.",
@@ -378,6 +415,13 @@ OC.L10N.register(
     "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "For å migrere til en annen database, bruk kommandolinjeverktøyet: \"occ db:convert-type\", eller se {linkstart}dokumentasjonen ↗{linkend}.",
     "The PHP memory limit is below the recommended value of 512MB." : "PHP er satt opp med mindre minne enn anbefalt minste verdi på 512MB.",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Enkelte mapper er eid av annen bruker enn den webserveren kjører som. Dette kan kan oppstå hvis apper er installert manuelt. Sjekk eierskap og tillatelser på følgende mapper:",
+    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL brukes som database, men støtter ikke 4-byte tegn. For å kunne håndtere 4-byte-tegn (som emojis) uten problemer i filnavn eller kommentarer for eksempel, anbefales det å aktivere 4-byte-støtten i MySQL. For ytterligere detaljer, les {linkstart}dokumentasjonssiden om dette ↗{linkend}.",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Denne instansen bruker en S3-basert objektlagring som primærlager. De opplastede filene blir lagret midlertidig på tjeneren og det er anbefalt å ha 50 GB ledig lagringsplass i det midlertidig lageret til PHP. Sjekk logger for fullstendige detaljer om filsti og ledig plass. Endre filstien til midlertidig lagringsplass i php.ini eller frigjør mer plass for å forbedre dette.",
+    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Den midlertidige katalogen for denne forekomsten peker til en enten ikke-eksisterende eller ikke-skrivbar katalog.",
+    "Account name or email" : "Kontonavn eller e-postadresse",
+    "Wrong username or password." : "Feil brukernavn eller passord.",
+    "User disabled" : "Bruker deaktivert",
+    "Username or email" : "Brukernavn eller e-post",
     "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Melding om tilbakestilling av passord har blitt send til e-postadressen til denne kontoen. Hvis du ikke mottok den, burde du sjekke spam/søppelpost-mappene eller spørre din lokale administrator om hjelp.",
     "If it is not there ask your local administrator." : "Spør din lokale administrator hvis den ikke er der. ",
     "Start search" : "Start søk",
@@ -407,9 +451,19 @@ OC.L10N.register(
     "This action requires you to confirm your password" : "Denne handlingen krever at du bekrefter ditt passord",
     "Confirm" : "Bekreft",
     "Failed to authenticate, try again" : "Autentisering mislyktes, prøv igjen",
+    "Users" : "Brukere",
     "The page could not be found on the server." : "Siden ble ikke funnet på serveren.",
+    "Username" : "Brukernavn",
+    "Database user" : "Databasebruker",
     "Confirm your password" : "Bekreft ditt passord",
     "App token" : "App-symbol",
-    "Alternative log in using app token" : "Alternativ logg inn ved hjelp av app-kode"
+    "Alternative log in using app token" : "Alternativ logg inn ved hjelp av app-kode",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Bruk kommandolinjeoppdatereren siden du har en stor installasjon med mer enn 50 brukere.",
+    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Din eksterne adresse ble identifisert som \"{remoteAddress}\" and is brute-force strupet for øyeblikket, noe som bremser hastigheten av diverse forespørsler. Hvis den eksterne adressen ikke er din adresse, kan dette være en indikasjon på at en proxy ikke er korrekt konfigurert. Ytterligere informasjon kan finnes i {linkstart}documentation ↗{linkend}.",
+    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "Databasen brukes til låsing av transaksjonsfiler. For å forbedre ytelsen, vennligst konfigurer memcache, hvis tilgjengelig. Se {linkstart}dokumentasjonen ↗{linkend} for mer informasjon.",
+    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 er nå avviklet i Nextcloud 27. Nextcloud 28 kan kreve minst PHP 8.1. Oppgrader til {linkstart}en av de offisielt støttede PHP-versjonene levert av PHP Group ↗{linkend} så snart som mulig.",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Denne forekomsten kjører i feilsøkingsmodus. Bare aktiver dette for lokal utvikling og ikke i produksjonsmiljøer.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Hvis denne kontoen eksisterer blir en melding om hvordan man resetter passordet sendt til kontoens epost.  Hvis du ikke mottar denne, sjekk epostadressen og/eller ditt brukernavn, sjekk søppelfilteret eller kontakt din lokale administrator for hjelp.",
+    "Avatar of {fullName}" : "Avatar til {fullName}"
 },
 "nplurals=2; plural=(n != 1);");
