@@ -42,7 +42,6 @@ OC.L10N.register(
     "Nextcloud Server" : "Nextcloud Server",
     "Some of your link shares have been removed" : "Alguns dos links das suas partilhas foram removidos",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Devido a bugs de segurança tivemos que remover algumas das suas ligações às partilhas.\nPor favor veja o link para mais informação.",
-    "The user limit of this instance is reached." : "O limite de utilizador desta instância foi atingido",
     "Learn more ↗" : "Aprenda mais ↗",
     "Preparing update" : "A preparar a atualização",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -67,12 +66,6 @@ OC.L10N.register(
     "Already up to date" : "Já está atualizado",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "O seu servidor da Web não está configurado corretamente para permitir a sincronização de ficheiros, porque a interface WebDAV parece estar com problemas.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "O seu webserver não está configurado correctamente resolver \"{url}\". Pode encontrar mais informações na documentação {linkstart} ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "O seu servidor web não está configurado correctamente para resolver \"{url}\". Provavelmente, isso está relacionado a uma configuração do servidor web que não foi actualizada para entregar essa pasta directamente. Compare a sua configuração com as regras de reescrita disponibilizadas em \".htaccess\" para Apache ou as fornecida na documentação para Nginx na {linkstart}página de documentação ↗{linkend}. No Nginx essas são normalmente as linhas que começam com \"location ~\" que precisam de uma actualização. ",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "O seu servidor web não está configurado correctamente para entregar arquivos .woff2. Normalmente, esse é um problema com a configuração do Nginx. Para o Nextcloud 15, é necessário um ajuste para entregar também arquivos .woff2. Compare sua configuração Nginx com a configuração recomendada na nossa {linkstart}documentação ↗{linkend}.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Não foi possível executar o cron job via CLI. Ocorreram os seguintes erros técnicos:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "A última execução do trabalho em segundo plano foi {relativeTime}. Parece que há algo errado. {linkstart}Verifique as configurações do trabalho em segundo plano ↗{linkend}.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A activação desta função é altamente recomendada.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Algumas diretorias de aplicações pertencem a um utilizador diferente do servidor web. Pode ser esse o caso se as aplicações foram instaladas manualmente. Verifique as permissões das seguintes diretorias de aplicações:",
     "Error occurred while checking server setup" : "Ocorreu um erro durante a verificação da configuração do servidor",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{cabeçalho}\" não está definido como \"{esperado}\". Isto é um potencial risco de segurança ou privacidade, pelo que recomendamos que ajuste esta opção em conformidade.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "O cabeçalho HTTP \"{cabeçalho}\" não está definido como \"{esperado}\". Algumas funcionalidades poderão não funcionar correctamente, pelo que recomendamos que ajuste esta opção em conformidade.",
@@ -99,10 +92,7 @@ OC.L10N.register(
     "An internal error occurred." : "Ocorreu um erro interno.",
     "Please try again or contact your administrator." : "Por favor, tente novamente ou contacte o seu administrador.",
     "Password" : "Palavra-passe",
-    "Wrong username or password." : "Nome de utilizador ou palavra passe errados",
-    "User disabled" : "Utilizador desativado",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Detectamos múltiplas tentativas falhadas de login do seu IP. Por esse motivo, o seu próximo login será adiado por, até, 30 segundos. ",
-    "Username or email" : "Utilizador ou e-mail",
     "Your account is not setup for passwordless login." : "A sua conta não está configurada para autenticação sem palavra-passe.",
     "Browser not supported" : "Navegador não suportado",
     "Passwordless authentication is not supported in your browser." : "O seu navegador não suporta autenticação sem palavra-passe.",
@@ -205,7 +195,6 @@ OC.L10N.register(
     "Collaborative tags" : "Etiquetas colaborativas",
     "No tags found" : "Etiquetas não encontradas",
     "Personal" : "Pessoal",
-    "Users" : "Utilizadores",
     "Apps" : "Aplicações",
     "Admin" : "Administração",
     "Help" : "Ajuda",
@@ -234,7 +223,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "A pasta de dados e os respetivos ficheiros estão provavelmente acessíveis a partir da internet pois o ficheiro .htaccess não funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para obter informações de como configurar correctamente o servidor, veja em: <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentação</a>.",
     "Create an <strong>admin account</strong>" : "Criar uma <strong>conta administrativa</strong>",
-    "Username" : "Nome de utilizador",
     "Show password" : "Mostrar senha",
     "Toggle password visibility" : "Altere a visibilidade da palavra-passe",
     "Storage & database" : "Armazenamento e base de dados",
@@ -243,7 +231,6 @@ OC.L10N.register(
     "Only %s is available." : "Só está disponível %s.",
     "Install and activate additional PHP modules to choose other database types." : "Instale e ative os módulos PHP adicionais para escolher outros tipos de base de dados.",
     "For more details check out the documentation." : "Para mais detalhes consulte a documentação.",
-    "Database user" : "Utilizador da base de dados",
     "Database password" : "Palavra-passe da base de dados",
     "Database name" : "Nome da base de dados",
     "Database tablespace" : "Tablespace da base de dados",
@@ -260,14 +247,9 @@ OC.L10N.register(
     "Skip to navigation of app" : "Saltar para navegação da aplicação",
     "Go to %s" : "Ir para %s",
     "Get your own free account" : "Obtenha a sua própria conta grátis",
-    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
-    "Confirm your password" : "Confirmar senha",
-    "Confirm" : "Confirmar",
     "Connect to your account" : "Ligar à sua conta",
     "Please log in before granting %1$s access to your %2$s account." : "Por favor, autentique-se antes de permitir o acesso de %1$s à sua conta %2$s.",
-    "App token" : "Token da aplicação",
     "Grant access" : "Conceder acesso",
-    "Alternative log in using app token" : "Autenticação alternativa usando token da aplicação",
     "Account access" : "Acesso à conta",
     "You are about to grant %1$s access to your %2$s account." : "Está prestes a permitir a %1$s aceder à sua conta conta %2$s. ",
     "Account connected" : "Conta ligada",
@@ -293,7 +275,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tempos limites com instalações maiores, pode executar o seguinte comando na diretoria de instalação:",
     "Detailed logs" : "Registos detalhados",
     "Update needed" : "É necessário atualizar",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Por favor, use o atualizador da linha de comandos porque tem uma instância grande com mais de 50 utilizadores.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Para obter ajuda, consulte a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentação</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Sei que se continuar a fazer a atualização via interface web arrisco a que o pedido expire e pode causar a perda de dados, no entanto tenho uma cópia de segurança e sei como restaurar a minha instância em caso de falha. ",
     "Upgrade via web on my own risk" : "Atualizar via web por minha conta e risco.",
@@ -302,6 +283,9 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Esta página irá ser atualizada quando a instância ficar novamente disponível.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte o seu administrador do sistema se esta mensagem persistir ou apareceu inesperadamente.",
     "Please try again" : "Por favor tente novamente",
+    "The user limit of this instance is reached." : "O limite de utilizador desta instância foi atingido",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "O seu servidor web não está configurado correctamente para resolver \"{url}\". Provavelmente, isso está relacionado a uma configuração do servidor web que não foi actualizada para entregar essa pasta directamente. Compare a sua configuração com as regras de reescrita disponibilizadas em \".htaccess\" para Apache ou as fornecida na documentação para Nginx na {linkstart}página de documentação ↗{linkend}. No Nginx essas são normalmente as linhas que começam com \"location ~\" que precisam de uma actualização. ",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "O seu servidor web não está configurado correctamente para entregar arquivos .woff2. Normalmente, esse é um problema com a configuração do Nginx. Para o Nextcloud 15, é necessário um ajuste para entregar também arquivos .woff2. Compare sua configuração Nginx com a configuração recomendada na nossa {linkstart}documentação ↗{linkend}.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parece estar bem configurado para consultar variáveis do ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Por favor, verifique a {linkstart}documentação de instalação ↗{linkend} para notas de configuração de PHP e a configuração de PHP do seu servidor, especialmente ao utilizar php-fpm.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
@@ -309,12 +293,19 @@ OC.L10N.register(
     "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "O módulo PHP 'fileinfo' está ausente. Recomendamos vivamente que ative este módulo para obter melhores resultados na detecção de tipo MIME.",
     "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "O bloqueio de arquivo transaccional está desativado, isso pode levar a problemas com condições de corrida. Ative \"filelocking.enabled\" em config.php para evitar esses problemas. Consulte a {linkstart}documentação ↗{linkend} para obter mais informação.",
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "A instalação não tem uma região de telefone predefinida. A região predefinida é necessária para validar números de telefone sem código de país nas configurações do perfil . Para permitir números sem um código de país, adicione \"default_phone_region\" com o respectivo {linkstart}código ISO 3166-1 ↗{linkend} da região ao seu ficheiro de configuração.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Não foi possível executar o cron job via CLI. Ocorreram os seguintes erros técnicos:",
+    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "A última execução do trabalho em segundo plano foi {relativeTime}. Parece que há algo errado. {linkstart}Verifique as configurações do trabalho em segundo plano ↗{linkend}.",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A activação desta função é altamente recomendada.",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "O seu PHP não suporta FreeType, podendo resultar em fotos de perfil e interface de definições corrompidos. ",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "Índice \"{indexName}\" em falta na tabela \"{tableName}\".",
     "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Esta instância tem em falta alguns módulos PHP recomendados. Para melhor desempenho e melhor compatibilidade, é altamente recomendável instalá-los.",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite é atualmente utilizado como a base de dados de backend. Para instalações maiores recomendamos que mude para uma base de dados de backend diferente.",
     "This is particularly recommended when using the desktop client for file synchronisation." : "Isto é particularmente recomendado quando estiver a usar um cliente de desktop para sincronização de ficheiros.",
     "The PHP memory limit is below the recommended value of 512MB." : "O limite de memória do PHP está abaixo do valor recomendado de 512MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Algumas diretorias de aplicações pertencem a um utilizador diferente do servidor web. Pode ser esse o caso se as aplicações foram instaladas manualmente. Verifique as permissões das seguintes diretorias de aplicações:",
+    "Wrong username or password." : "Nome de utilizador ou palavra passe errados",
+    "User disabled" : "Utilizador desativado",
+    "Username or email" : "Utilizador ou e-mail",
     "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "Foi enviada uma mensagem de reposição da sua palavra-passe para o endereço de email desta conta. Se não a receber, verifique as pastas de spam/lixo ou entre em contacto com o administrador local para ajuda.",
     "If it is not there ask your local administrator." : "Se não estiver aí pergunte ao seu administrador local.",
     "Start search" : "Inicie a pesquisa",
@@ -341,7 +332,16 @@ OC.L10N.register(
     "Copy to {folder}" : "Copiar para {folder}",
     "Move to {folder}" : "Mover para {folder}",
     "Authentication required" : "Autenticação necessária",
+    "This action requires you to confirm your password" : "Esta ação requer a confirmação da senha",
+    "Confirm" : "Confirmar",
     "Failed to authenticate, try again" : "Falha ao autenticar. Tente outra vez.",
-    "The page could not be found on the server." : "Esta página não foi encontrada no servidor."
+    "Users" : "Utilizadores",
+    "The page could not be found on the server." : "Esta página não foi encontrada no servidor.",
+    "Username" : "Nome de utilizador",
+    "Database user" : "Utilizador da base de dados",
+    "Confirm your password" : "Confirmar senha",
+    "App token" : "Token da aplicação",
+    "Alternative log in using app token" : "Autenticação alternativa usando token da aplicação",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Por favor, use o atualizador da linha de comandos porque tem uma instância grande com mais de 50 utilizadores."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
