@@ -50,8 +50,8 @@ OC.L10N.register(
     "Nextcloud Server" : "Nextcloud сервер",
     "Some of your link shares have been removed" : "Неке везе дељења су уклоњене",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Услед безбедоносних мера, морали смо да уклонимо неке од ваших веза дељења. Кликните везу за више информација.",
-    "The user limit of this instance is reached." : "Достигнута је граница броја корисника ове инстанце.",
-    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Унестите ваш кључ претплате у апликацију за подршку да бисте увећали границу броја корисника. На овај начин добијате још погодности које нуди Nextcloud Enterprise и топло се препоручује за рад у компанијама.",
+    "The account limit of this instance is reached." : "Достигнута је граница броја налога на овој инстанци.",
+    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Унестите ваш кључ претплате у апликацију за подршку да бисте увећали границу броја налога. На овај начин добијате још погодности које нуди Nextcloud Enterprise и топло се препоручује за рад у компанијама.",
     "Learn more ↗" : "Сазнајте више ↗",
     "Preparing update" : "Припремам ажурирање",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -77,14 +77,7 @@ OC.L10N.register(
     "Already up to date" : "Већ је ажурна",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Сервер није правилно подешен за синхронизацију фајлова. Изгледа да је ВебДАВ сучеље покварено.",
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ваш веб сервер није исправно подешен да разреши „{url}”. Више информација можете да пронађете у {linkstart}документацији ↗{linkend}.",
-    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Ваш веб сервер није исправно подешен да разреши „{url}”. Ово је највероватније везано за конфигурацију веб сервера која није ажурирана тако да директно достави овај фолдер. Молимо вас да упоредите своју конфигурацију са оном испорученом уз програм и поново испишите правила у „.htaccess” за Apache, или приложену у документацији за Nginx на његовој {linkstart}страници документације ↗{linkend}. На Nginx су обично линије које почињу са \"location ~\" оне које треба да се преправе.",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Ваш веб сервер није исправно подешен да испоручи .woff2 фајлове. Ово је обично проблем са Nginx конфигурацијом. За Nextcloud 15 је неопходно да се направе измене у конфигурацији како би могли да се испоруче и .woff2 фајлови. Упоредите своју Nginx конфигурацију са препорученом конфигурацијом у нашој {linkstart}документацији ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Ово је Nextcloud који је изградила заједница и није подржан. Узевши у обзир величину инстанце, перформансе, поузданост и скалабилност не могу да се гарантују. Брза обавештења су ограничена да би се спречило загушење нашег бесплатног сервиса. Сазнајте више о предностима Nextcloud Enterprise на {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Као база података се користи MySQL, али не подржава 4-бајтне карактере. Препоручује се да укључите подршку за 4-бајтне карактере у MySQL да би се у именима фајлова и коментарима, на пример, без проблема обрадили 4-бајтни карактери (као што су емођи). За више детаља прочитајте {linkstart}страницу документације о овоме ↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ова инстанца користи S3 базирано чување података за основно складиште. Отпремљени фајлови се привремено чувају на серверу и препоручује се да имате доступно бар 50 GB слободног простора у PHP привременом директоријуму. Погледајте дневник за више детаља око путања и слободном простору. Да бисте ово променили или побољшали, измените привремени директоријум у php.ini фајлу или направите више слободног места на тренутној путањи.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Привремени директоријум ове инстанце показује или на непостојећи, или на директоријум у који не може да се уписује.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Вашој инстанци приступате преко безбедне везе, међутим, ова инстанца генерише небезбедне URL адресе. Ово највероватније значи да се налазите иза реверсног проксија и да променљиве подешавања преписивања нису исправно постављене. Молимо вас да прочитате {linkstart}страницу документације у вези овога ↗{linkend}.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Ова инстанца се извршава у дибаг режиму. Укључите га само за локални развој, никако у продукционом окружењу.",
     "Error occurred while checking server setup" : "Дошло је до грешке при провери поставки сервера",
     "For more details see the {linkstart}documentation ↗{linkend}." : "За више детаља погледајте {linkstart}документацију ↗{linkend}.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Вашем директоријуму са подацима и фајловама вероватно може да се приступи са интернета. Фајл .htaccess не функционише. Изричито препоручујемо да свој веб сервер подесите тако да се забрани приступ директоријуму са подацима, или да да преместите ван кореног директоријума докумената вашег веб сервера.",
@@ -126,21 +119,20 @@ OC.L10N.register(
     "Please try again." : "Молимо вас покушајте поново.",
     "An internal error occurred." : "Догодила се унутрашња грешка. ",
     "Please try again or contact your administrator." : "Покушајте поново или контактирајте вашег администратора.",
-    "Account name or email" : "Име налога или е-адреса",
+    "Login or email" : "Име за пријаву или и-мејл",
     "Password" : "Лозинка",
     "Log in to {productName}" : "Пријавите се на {productName}",
-    "Wrong username or password." : "Погрешно корисничко име или лозинка",
-    "User disabled" : "Корисник искључен",
+    "Wrong login or password." : "Погрешно име за пријаву или лозинка",
+    "This account is disabled" : "Овај налог је искључен",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Приметили смо више неисправних покушаја пријава са Ваше IP адресе. Следећа пријава ће бити могућа тек за 30 секунди.",
     "Log in with a device" : "Пријава са уређајем",
-    "Username or email" : "Корисничко име или е-адреса",
     "Your account is not setup for passwordless login." : "Ваш налог није подешен за пријаву без лозинке.",
     "Browser not supported" : "Веб читач није подржан",
     "Passwordless authentication is not supported in your browser." : "Ваш веб читач не подржава пријављивање без лозинке.",
     "Your connection is not secure" : "Ваша веза није безбедна",
     "Passwordless authentication is only available over a secure connection." : "Пријављивање без лозинке је доступно само на безбедним конекцијама.",
     "Reset password" : "Ресетуј лозинку",
-    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Ако овај налог постоји, на његову и-мејл адресу је послата порука за ресетовање лозинке. Ако је не примите, потврдите своју и-мејл адресу и/или назив налога, проверите фолдере за нежељену пошту, или потражите помоћ свог локалног администратора.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Ако овај налог постоји, на његову и-мејл адресу је послата порука за ресетовање лозинке. Ако је не примите, потврдите своју и-мејл адресу и/или име за пријаву, проверите фолдере за нежељену пошту, или потражите помоћ свог локалног администратора.",
     "Couldn't send reset email. Please contact your administrator." : "Не могу да пошаљем поруку за ресетовање. Контактирајте администратора.",
     "Password cannot be changed. Please contact your administrator." : "Лозинка не може да се промени. Молимо вас контактирајте администратора.",
     "Back to login" : "Назад на пријаву",
@@ -269,7 +261,7 @@ OC.L10N.register(
     "Collaborative tags" : "Oзнаке сарадње",
     "No tags found" : "Ознаке нису нађене",
     "Personal" : "Лично",
-    "Users" : "Корисници",
+    "Accounts" : "Налози",
     "Apps" : "Апликације",
     "Admin" : "Администрација",
     "Help" : "Помоћ",
@@ -300,7 +292,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Ваш директоријум са подацима и фајлови су вероватно доступни са интернета јер .htaccess не ради.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "За информације како да правилно подесите Ваш сервер, погледајте <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">документацију</a>.",
     "Create an <strong>admin account</strong>" : "Направи <strong>административни налог</strong>",
-    "Username" : "Корисничко име",
     "Show password" : "Прикажи лозинку",
     "Toggle password visibility" : "Укључи/искључи видљивост лозинке",
     "Storage & database" : "Складиште и база података",
@@ -309,7 +300,7 @@ OC.L10N.register(
     "Only %s is available." : "Само %s је доступна.",
     "Install and activate additional PHP modules to choose other database types." : "Инсталирајте и активирајте додатне „ПХП“ модуле за одабир других база података.",
     "For more details check out the documentation." : "За више детаља погледајте документацију.",
-    "Database user" : "Корисник базе",
+    "Database account" : "Налог базе података",
     "Database password" : "Лозинка базе",
     "Database name" : "Назив базе",
     "Database tablespace" : "Радни простор базе података",
@@ -372,7 +363,7 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Да избегнете прекорачење времена одзива на већим инсталацијама, можете покренути следећу команду у инсталационом директоријуму:",
     "Detailed logs" : "Детаљни дневници",
     "Update needed" : "Потребно је ажурирање",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Молимо користите ажурирање из конзоле пошто имате велики сервер са више од 50 корисника.",
+    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Молимо вас да употребите ажурирање из конзоле пошто имате велику инстанцу са више од 50 налога.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "За помоћ, погледајте <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">документацију</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Свестан сам да уколико наставим ажурирање преко веб сучеља, постоји ризик да захтеву истекне време за извршење и да то може да изазове губитак података, али имам резервну копију и знам како да је повратим у случају грешке.",
     "Upgrade via web on my own risk" : "Надогради преко веба на сопствену одговорност",
@@ -381,6 +372,10 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "Ова страница ће се сама освежити када инстанца постане поново доступна.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Контактирајте администратора ако се порука понавља или се неочекивано појавила.",
     "Please try again" : "Молимо вас да покушате поново",
+    "The user limit of this instance is reached." : "Достигнута је граница броја корисника ове инстанце.",
+    "Enter your subscription key in the support app in order to increase the user limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Унестите ваш кључ претплате у апликацију за подршку да бисте увећали границу броја корисника. На овај начин добијате још погодности које нуди Nextcloud Enterprise и топло се препоручује за рад у компанијама.",
+    "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Ваш веб сервер није исправно подешен да разреши „{url}”. Ово је највероватније везано за конфигурацију веб сервера која није ажурирана тако да директно достави овај фолдер. Молимо вас да упоредите своју конфигурацију са оном испорученом уз програм и поново испишите правила у „.htaccess” за Apache, или приложену у документацији за Nginx на његовој {linkstart}страници документације ↗{linkend}. На Nginx су обично линије које почињу са \"location ~\" оне које треба да се преправе.",
+    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Ваш веб сервер није исправно подешен да испоручи .woff2 фајлове. Ово је обично проблем са Nginx конфигурацијом. За Nextcloud 15 је неопходно да се направе измене у конфигурацији како би могли да се испоруче и .woff2 фајлови. Упоредите своју Nginx конфигурацију са препорученом конфигурацијом у нашој {linkstart}документацији ↗{linkend}.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP изгледа није исправно подешен да дохвата променљиве окружења. Тест са getenv(\"PATH\") враћа празну листу као одговор.",
     "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Молимо вас да погледате напомене у вези са PHP конфигурацијом и PHP конфигурацијом вашег сервера у {linkstart}документацији за инсталирање, ↗{linkend} поготово ако користите php-fpm.",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Омогућена је конфигурација само за читање. То спречава постављање неке конфигурације преко веб-интерфејса. Осим тога, фајлу мора бити ручно омогућено уписивање код сваког освежавања.",
@@ -392,6 +387,7 @@ OC.L10N.register(
     "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Ваша инсталација нема постављен подразумевани телефонски позивни број. Ово је неопходно за проверу бројева телефона у подешавањима профила без кода земље. Ако желите да дозволите бројеве без кода земље, молимо вас да у свој конфигурациони фајл додате „default_phone_region” са одговарајућим {linkstart}ISO 3166-1 кодом ↗{linkend} региона.",
     "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Није било могуће да се изврши крон задатак путем интерфејса командне линије. Појавиле су се следеће техничке грешке:",
     "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Последњи посао у позадини се извршавао {relativeTime}. Изгледа да нешто није у реду. {linkstart}Проверите подешавања посла у позадини ↗{linkend}.",
+    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Ово је Nextcloud који је изградила заједница и није подржан. Узевши у обзир величину инстанце, перформансе, поузданост и скалабилност не могу да се гарантују. Брза обавештења су ограничена да би се спречило загушење нашег бесплатног сервиса. Сазнајте више о предностима Nextcloud Enterprise на {linkstart}https://nextcloud.com/enterprise{linkend}.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Овај сервер нема функционалну интернет конекцију: више крајњих тачака није доступно. Ово значи да неће радити неке могућности као што су качење спољних складишта, обавештења о ажурирањима или инсталација апликација треће стране. Приступање фајловима споља и слање обавештења е-поштом исто тако може да не ради. Ако желите да уживате у свим могућностима, обезбедите везу овог сервера са интернетом.",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Нисте подесили меморијски кеш. Да бисте побољшали перформансе, подесите меморијски кеш ако је доступан. Више информација можете да пронађете у {linkstart}документацији ↗{linkend}.",
     "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP није пронашао погодан извор случајности, а то се не пропоручује из разлога безбедности. Више информација можете да пронађете у {linkstart}документацији ↗{linkend}.",
@@ -419,6 +415,13 @@ OC.L10N.register(
     "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "За прелазак на другу базу података, користите алат командне линије:  „occ db:convert-type”, или погледајте {linkstart}документацију ↗{linkend}.",
     "The PHP memory limit is below the recommended value of 512MB." : "Меморијско ограничење за ПХП је испод препоручене вредности од 512MB.",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Власник неких апликативних директоријума је корисник који није исти као и корисник по којим ради веб сервер. Ово је могуће ако су се апликације инсталирале ручно. Проверите привилегије над следећим апликативним директоријумима:",
+    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Као база података се користи MySQL, али не подржава 4-бајтне карактере. Препоручује се да укључите подршку за 4-бајтне карактере у MySQL да би се у именима фајлова и коментарима, на пример, без проблема обрадили 4-бајтни карактери (као што су емођи). За више детаља прочитајте {linkstart}страницу документације о овоме ↗{linkend}.",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Ова инстанца користи S3 базирано чување података за основно складиште. Отпремљени фајлови се привремено чувају на серверу и препоручује се да имате доступно бар 50 GB слободног простора у PHP привременом директоријуму. Погледајте дневник за више детаља око путања и слободном простору. Да бисте ово променили или побољшали, измените привремени директоријум у php.ini фајлу или направите више слободног места на тренутној путањи.",
+    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Привремени директоријум ове инстанце показује или на непостојећи, или на директоријум у који не може да се уписује.",
+    "Account name or email" : "Име налога или е-адреса",
+    "Wrong username or password." : "Погрешно корисничко име или лозинка",
+    "User disabled" : "Корисник искључен",
+    "Username or email" : "Корисничко име или е-адреса",
     "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "На е-мејл адресу овог налога је послата порука за ресетовање лозинке. Ако је не примите, проверите фолдере за нежељену пошту/отпад или потражите помоћ од свог локалног администратора.",
     "If it is not there ask your local administrator." : "Ако није ни тамо, контактирајте вашег администратора.",
     "Start search" : "Покрени претрагу",
@@ -448,13 +451,19 @@ OC.L10N.register(
     "This action requires you to confirm your password" : "Ова радња захтева да потврдите лозинку",
     "Confirm" : "Потврди",
     "Failed to authenticate, try again" : "Неуспешна провера идентитета, покушајте поново",
+    "Users" : "Корисници",
     "The page could not be found on the server." : "На серверу не може да се пронађе ова страница.",
+    "Username" : "Корисничко име",
+    "Database user" : "Корисник базе",
     "Confirm your password" : "Потврдите лозинку",
     "App token" : "Апликативни жетон",
     "Alternative log in using app token" : "Алтернативна пријава коришћењем апликативног жетона",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Молимо користите ажурирање из конзоле пошто имате велики сервер са више од 50 корисника.",
     "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ваша удаљена адреса је идентификована као „{remoteAddress}” и тренутно је пригушена због напада грубом силом чиме се успоравају перформансе разних захтева. Ако удаљена адреса није ваша, ово може бити знак да прокси није исправно подешен. Више информација може да се пронађе у {linkstart}документацији ↗{linkend}.”",
     "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "База података се користи за трансакционо закључавање фајлова. Да бисте побољшали перформансе, молимо вас да конфигуришете memcache, ако је то могуће. За више информација, погледајте {linkstart}документацију ↗{linkend}.",
     "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 је сада застарео у Nextcloud 27. Nextcloud 28 може да захтева барем PHP 8.1. Молимо вас да ажурирате на {linkstart}једну од званично подржаних PHP верзија које обезбеђује PHP Група ↗{linkend} што је пре могуће.",
+    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Ова инстанца се извршава у дибаг режиму. Укључите га само за локални развој, никако у продукционом окружењу.",
+    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Ако овај налог постоји, на његову и-мејл адресу је послата порука за ресетовање лозинке. Ако је не примите, потврдите своју и-мејл адресу и/или назив налога, проверите фолдере за нежељену пошту, или потражите помоћ свог локалног администратора.",
     "Avatar of {fullName}" : "Аватар корисника {fullName}"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
