@@ -25,7 +25,9 @@ OC.L10N.register(
     "State token does not match" : "โทเค็นสถานะไม่ตรงกัน",
     "Invalid app password" : "รหัสผ่านแอปไม่ถูกต้อง",
     "Could not complete login" : "ไม่สามารถดำเนินการเข้าสู่ระบบ",
+    "State token missing" : "โทเค็นของสถานะหายไป",
     "Your login token is invalid or has expired" : "โทเค็นเข้าสู่ระบบของคุณไม่ถูกต้องหรือหมดอายุแล้ว",
+    "This community release of Nextcloud is unsupported and push notifications are limited." : "คอมมูนิตี้เวอร์ชันนี้ของ Nextcloud ไม่ได้รับการสนับสนุนและการแจ้งเตือนแบบพุชถูกจำกัด",
     "Login" : "เข้าสู่ระบบ",
     "Password reset is disabled" : "การตั้งรหัสผ่านใหม่ถูกปิดใช้งาน",
     "Could not reset password because the token is expired" : "ไม่สามารถรีเซ็ตรหัสผ่านได้ เนื่องจาก Token หมดอายุ",
@@ -39,7 +41,6 @@ OC.L10N.register(
     "Nextcloud Server" : "เซิร์ฟเวอร์ Nextcloud",
     "Some of your link shares have been removed" : "ลิงก์แชร์บางลิงก์ของคุณถูกลบออก",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "เนื่องจากข้อบกพร่องความปลอดภัย เราจำเป็นต้องลบลิงก์แชร์บางลิงก์ของคุณออก โปรดดูที่ลิงก์สำหรับข้อมูลเพิ่มเติม",
-    "The user limit of this instance is reached." : "ถึงขีดจำกัดจำนวนผู้ใช้ของเซิร์ฟเวอร์นี้แล้ว",
     "Learn more ↗" : "เรียนรู้เพิ่มเติม ↗",
     "Preparing update" : "กำลังเตรียมอัปเดต",
     "[%d / %d]: %s" : "[%d / %d]: %s",
@@ -63,7 +64,6 @@ OC.L10N.register(
     "The following apps have been disabled: %s" : "แอปต่อไปนี้ถูกปิดการใช้งาน: %s",
     "Already up to date" : "ล่าสุดแล้ว",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "เว็บเซิร์ฟเวอร์ของคุณยังไม่ถูกตั้งค่าอย่างถูกต้องเพื่ออนุญาตการซิงโครไนซ์ไฟล์ เนื่องจากส่วนติดต่อ WebDAV อาจมีปัญหา",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "โมดูล php-imagick ในเซิร์ฟเวอร์นี้ไม่รองรับ SVG แนะนำให้ติดตั้งเพื่อความเข้ากันได้ที่ดีขึ้น",
     "Error occurred while checking server setup" : "เกิดข้อผิดพลาดขณะตรวจสอบการติดตั้งเซิร์ฟเวอร์",
     "For more details see the {linkstart}documentation ↗{linkend}." : "สำหรับข้อมูลเพิ่มเติม โปรดดู{linkstart}เอกสารประกอบ ↗{linkend}",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "ส่วนหัว HTTP \"{header}\" ไม่ได้กำหนดค่าให้เท่ากับ \"{expected}\" ดังนั้นจึงมีความเสี่ยงด้านความปลอดภัยหรือความเป็นส่วนตัวที่เป็นไปได้ เราแนะนำให้ปรับการตั้งค่านี้",
@@ -93,14 +93,10 @@ OC.L10N.register(
     "Please contact your administrator." : "กรุณาติดต่อผู้ดูแลระบบ",
     "An internal error occurred." : "เกิดข้อผิดพลาดภายใน",
     "Please try again or contact your administrator." : "กรุณาลองอีกครั้งหรือติดต่อผู้ดูแลระบบ",
-    "Account name or email" : "ชื่อหรืออีเมลบัญชี",
     "Password" : "รหัสผ่าน",
     "Log in to {productName}" : "เข้าสู่ระบบไปยัง {productName}",
-    "Wrong username or password." : "ชื่อผู้ใช้หรือรหัสผ่านไม่ถูกต้อง",
-    "User disabled" : "ผู้ใช้ถูกปิดใช้งาน",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "เราตรวจพบการเข้าสู่ระบบที่ไม่ถูกต้องจากที่อยู่ IP ของคุณหลายครั้ง การเข้าสู่ระบบถัดไปของคุณถูกควบคุมเป็นเวลาอย่างมาก 30 วินาที",
     "Log in with a device" : "เข้าสู่ระบบด้วยอุปกรณ์",
-    "Username or email" : "ชื่อผู้ใช้หรืออีเมล",
     "Your account is not setup for passwordless login." : "บัญชีของคุณยังไม่ได้ตั้งค่าการเข้าสู่ระบบแบบไร้รหัสผ่าน",
     "Browser not supported" : "ไม่รองรับเบราว์เซอร์",
     "Passwordless authentication is not supported in your browser." : "เบราว์เซอร์ของคุณไม่รองรับการรับรองความถูกต้องแบบไร้รหัสผ่าน",
@@ -206,7 +202,6 @@ OC.L10N.register(
     "Collaborative tags" : "แท็กแบบทำงานร่วมกัน",
     "No tags found" : "ไม่พบแท็ก",
     "Personal" : "ส่วนตัว",
-    "Users" : "ผู้ใช้",
     "Apps" : "แอป",
     "Admin" : "ผู้ดูแลระบบ",
     "Help" : "ช่วยเหลือ",
@@ -236,7 +231,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "ไดเรกทอรี data และไฟล์ของคุณอาจเข้าถึงได้จากอินเทอร์เน็ต เพราะไฟล์ .htaccess ไม่ทำงาน",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "สำหรับวิธีการกำหนดค่าเซิร์ฟเวอร์ของคุณอย่างถูกต้อง โปรดดู<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">เอกสารประกอบ</a>",
     "Create an <strong>admin account</strong>" : "สร้าง<strong>บัญชีผู้ดูแลระบบ</strong>",
-    "Username" : "ชื่อผู้ใช้",
     "Show password" : "แสดงรหัสผ่าน",
     "Toggle password visibility" : "เปิด-ปิด การมองเห็นรหัสผ่าน",
     "Storage & database" : "พื้นที่จัดเก็บข้อมูลและฐานข้อมูล",
@@ -245,7 +239,6 @@ OC.L10N.register(
     "Only %s is available." : "เฉพาะ %s สามารถใช้ได้",
     "Install and activate additional PHP modules to choose other database types." : "ติดตั้งและเปิดใช้งานโมดูล PHP เพิ่มเติมเพื่อเลือกชนิดฐานข้อมูลอื่น ๆ",
     "For more details check out the documentation." : "สำหรับรายละเอียดเพิ่มเติมสามารถตรวจสอบได้ที่<a href=\"%s\" target=\"_blank\">เอกสารประกอบ</a>",
-    "Database user" : "ชื่อผู้ใช้ฐานข้อมูล",
     "Database password" : "รหัสผ่านฐานข้อมูล",
     "Database name" : "ชื่อฐานข้อมูล",
     "Database tablespace" : "พื้นที่ตารางในฐานข้อมูล",
@@ -266,15 +259,10 @@ OC.L10N.register(
     "Skip to navigation of app" : "ข้ามไปที่การนำทางของแอป",
     "Go to %s" : "ไปที่ %s",
     "Get your own free account" : "รับบัญชีฟรีของคุณ",
-    "This action requires you to confirm your password" : "การกระทำนี้จำเป็นให้คุณยืนยันรหัสผ่าน",
-    "Confirm your password" : "ยืนยันรหัสผ่านของคุณ",
-    "Confirm" : "ยืนยัน",
     "Connect to your account" : "เชื่อมต่อบัญชีของคุณ",
     "Please log in before granting %1$s access to your %2$s account." : "กรุณาเข้าสู่ระบบก่อนอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "หากคุณไม่ได้เป็นคนตั้งค่าอุปกรณ์หรือแอปใหม่ อาจมีบุคคลอื่นกำลังหลอกให้คุณอนุญาตให้พวกเขาเข้าถึงข้อมูลของคุณ ในกรณีนี้ห้ามดำเนินการต่อ ให้ติดต่อผู้ดูแลระบบของคุณ",
-    "App token" : "โทเค็นแอป",
     "Grant access" : "อนุญาตให้เข้าถึง",
-    "Alternative log in using app token" : "ทางเลือกเข้าสู่ระบบด้วยโทเค็นแอป",
     "Account access" : "การเข้าถึงบัญชี",
     "Currently logged in as %1$s (%2$s)." : "ขณะนี้เข้าสู่ระบบเป็น %1$s (%2$s)",
     "You are about to grant %1$s access to your %2$s account." : "คุณกำลังจะอนุญาตให้ %1$s เข้าถึงบัญชี %2$s ของคุณ",
@@ -311,7 +299,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "เพื่อหลีกเลี่ยงการหมดเวลากับการติดตั้งขนาดใหญ่ คุณสามารถเรียกใช้คำสั่งต่อไปนี้จากไดเรกทอรีการติดตั้งของคุณ:",
     "Detailed logs" : "บันทึกอย่างละเอียด",
     "Update needed" : "จำเป็นต้องอัปเดต",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "กรุณาใช้ตัวอัปเดตผ่านบรรทัดคำสั่ง เนื่องจากคุณมีเซิร์ฟเวอร์ขนาดใหญ่ที่มีจำนวนผู้ใช้มากกว่า 50 ผู้ใช้",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "สำหรับความช่วยเหลือ ดู<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">เอกสารประกอบ</a>",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "ฉันทราบว่าการดำเนินการอัปเดตผ่าน UI เว็บมีความเสี่ยง และหากคำขอหมดเวลาอาจทำให้ข้อมูลสูญหาย แต่ฉันได้สำรองข้อมูลไว้แล้วและทราบวิธีการกู้คืนข้อมูลหากเกิดข้อผิดพลาด",
     "Upgrade via web on my own risk" : "อัปเกรดผ่านเว็บบนความเสี่ยงของฉัน",
@@ -320,11 +307,17 @@ OC.L10N.register(
     "This page will refresh itself when the instance is available again." : "หน้านี้จะรีเฟรชตัวเองเมื่อเซิร์ฟเวอร์สามารถใช้ได้อีกครั้ง",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "ติดต่อผู้ดูแลระบบของคุณหากข้อความนี้ยังคงอยู่หรือปรากฏโดยไม่คาดคิด",
     "Please try again" : "กรุณาลองอีกครั้ง",
+    "The user limit of this instance is reached." : "ถึงขีดจำกัดจำนวนผู้ใช้ของเซิร์ฟเวอร์นี้แล้ว",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP ของคุณไม่รองรับ FreeType ส่งผลให้รูปภาพโปรไฟล์และส่วนติดต่อการตั้งค่าไม่สมบูรณ์",
     "Missing index \"{indexName}\" in table \"{tableName}\"." : "ขาดดัชนี \"{indexName}\" ในตาราง \"{tableName}\"",
     "Missing primary key on table \"{tableName}\"." : "ขาดคีย์หลักบนตาราง \"{tableName}\"",
+    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "โมดูล php-imagick ในเซิร์ฟเวอร์นี้ไม่รองรับ SVG แนะนำให้ติดตั้งเพื่อความเข้ากันได้ที่ดีขึ้น",
     "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "ขณะนี้ใช้ SQLite เป็นฐานข้อมูล สำหรับการติดตั้งขนาดใหญ่เราแนะนำให้สลับไปยังแบ็กเอนด์ฐานข้อมูลแบบอื่น",
     "This is particularly recommended when using the desktop client for file synchronisation." : "เราแนะนำเมื่อใช้ไคลเอ็นต์เดสก์ท็อปสำหรับการประสานข้อมูลไฟล์",
+    "Account name or email" : "ชื่อหรืออีเมลบัญชี",
+    "Wrong username or password." : "ชื่อผู้ใช้หรือรหัสผ่านไม่ถูกต้อง",
+    "User disabled" : "ผู้ใช้ถูกปิดใช้งาน",
+    "Username or email" : "ชื่อผู้ใช้หรืออีเมล",
     "A password reset message has been sent to the email address of this account. If you do not receive it, check your spam/junk folders or ask your local administrator for help." : "ส่งข้อความตั้งรหัสผ่านใหม่ไปยังที่อยู่อีเมลของบัญชีนี้แล้ว หากคุณยังไม่ได้รับ ให้ตรวจสอบโฟลเดอร์สแปม/จดหมายขยะ หรือสอบถามผู้ดูแลระบบเซิร์ฟเวอร์ของคุณเพื่อขอความช่วยเหลือ",
     "If it is not there ask your local administrator." : "หากยังไม่เจอ ถามผู้ดูแลระบบเซิร์ฟเวอร์ของคุณ",
     "Start search" : "เริ่มค้นหา",
@@ -351,7 +344,16 @@ OC.L10N.register(
     "Copy to {folder}" : "คัดลอกไปยัง {folder}",
     "Move to {folder}" : "ย้ายไปยัง {folder}",
     "Authentication required" : "จำเป็นต้องตรวจสอบความถูกต้อง",
+    "This action requires you to confirm your password" : "การกระทำนี้จำเป็นให้คุณยืนยันรหัสผ่าน",
+    "Confirm" : "ยืนยัน",
     "Failed to authenticate, try again" : "ไม่สามารถรับรองความถูกต้อง โปรดลองอีกครั้ง",
-    "The page could not be found on the server." : "ไม่พบหน้านี้บนเซิร์ฟเวอร์"
+    "Users" : "ผู้ใช้",
+    "The page could not be found on the server." : "ไม่พบหน้านี้บนเซิร์ฟเวอร์",
+    "Username" : "ชื่อผู้ใช้",
+    "Database user" : "ชื่อผู้ใช้ฐานข้อมูล",
+    "Confirm your password" : "ยืนยันรหัสผ่านของคุณ",
+    "App token" : "โทเค็นแอป",
+    "Alternative log in using app token" : "ทางเลือกเข้าสู่ระบบด้วยโทเค็นแอป",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "กรุณาใช้ตัวอัปเดตผ่านบรรทัดคำสั่ง เนื่องจากคุณมีเซิร์ฟเวอร์ขนาดใหญ่ที่มีจำนวนผู้ใช้มากกว่า 50 ผู้ใช้"
 },
 "nplurals=1; plural=0;");
