@@ -19,7 +19,6 @@ OC.L10N.register(
     "Address" : "Adres",
     "Profile picture" : "Profielprent",
     "About" : "Oor",
-    "Unknown user" : "Onbekende gebruiker",
     "Open »%s«" : "Open »%s«",
     "Sunday" : "Sondag",
     "Monday" : "Maandag",
@@ -30,6 +29,7 @@ OC.L10N.register(
     "Saturday" : "Saterdag",
     "a safe home for all your data" : "’n veilige tuiste vir al u data",
     "Storage is temporarily not available" : "Berging is tydelik nie beskikbaar nie",
-    "Full name" : "Volle naam"
+    "Full name" : "Volle naam",
+    "Unknown user" : "Onbekende gebruiker"
 },
 "nplurals=2; plural=(n != 1);");
