@@ -8,7 +8,6 @@ OC.L10N.register(
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "التطبيق %1$s غير موجود أو ليس له إصدار متطابق مع هذا الخادوم. رجاءً، راجع دليل التطبيقات apps directory.",
     "Sample configuration detected" : "تمّ العثور على عيّنة إعدادات sample configuration.",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "تمّ اكتشاف أن عيّنة الإعدادات قد تمّ نسخها. يُمكن لهذا أن يُعطّل عملية التنصيب و هو أمر غير مدعوم. نرجو الاطلاع على التعليمات الواردة في وثائق النظام قبل إحداث أي تعديلات على ملف config.php",
-    "404" : "404",
     "The page could not be found on the server." : "تعذّر العثور على الصفحة في الخادوم",
     "%s email verification" : "%s التحقّق من الإيميل",
     "Email verification" : "التحقّق من الإيميل",
@@ -37,9 +36,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "المنصّات التالية مدعومة: %s",
     "Server version %s or higher is required." : "مطلوب إصدار الخادم %s أو أعلى.",
     "Server version %s or lower is required." : "مطلوب إصدار الخادم %s أو أقل.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin، أو يحمل صلاحياتٍ خاصّةٍ للوصول إلى هذه الإعدادات.",
-    "Logged in user must be an admin or sub admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin.",
-    "Logged in user must be an admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin.",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "الداخل للحساب يجب أن يكون مُشرفاً أو مشرفاً فرعيّاً أو يملك حقاً خاصاً للوصول إلى هذا الإعداد",
+    "Logged in account must be an admin or sub admin" : "الداخل للحساب يجب أن يكون مُشرفاً أو مشرفاً فرعيّاً ",
+    "Logged in account must be an admin" : "الداخل للحساب يجب أن يكون مُشرفاً ",
     "Wiping of device %s has started" : "بدأ مسح الجهاز %s ",
     "Wiping of device »%s« has started" : "بدأ مسح الجهاز »%s« ",
     "»%s« started remote wipe" : "»%s« بدأ المسح عن بُعدٍ",
@@ -118,22 +117,22 @@ OC.L10N.register(
     "Headline" : "عنوان ",
     "Organisation" : "مؤسسة",
     "Role" : "الدور",
-    "Unknown user" : "المستخدم غير معروف",
+    "Unknown account" : "حساب غير معروف",
     "Additional settings" : "الإعدادات المتقدمة",
-    "Enter the database username and name for %s" : "أدخل اسم المستخدم لقاعدة البيانات و اسم %s",
-    "Enter the database username for %s" : "أدخل اسم المستخدم لقاعدة البيانات لـ %s",
+    "Enter the database Login and name for %s" : "أدخِل حيثيات الدخول لقاعدة البيانات %s",
+    "Enter the database Login for %s" : "أدخِل حيثيات دخول قاعدة البيانات لـ %s",
     "Enter the database name for %s" : "أدخل اسم قاعدة البيانات لـ%s",
     "You cannot use dots in the database name %s" : "لا يمكنك استخدام النقاط dots في اسم قاعدة البيانات %s",
-    "MySQL username and/or password not valid" : "اسم المستخدم لقاعدة البيانات MySQL و/أو كلمة المرور غير صحيحة",
+    "MySQL Login and/or password not valid" : "حيثيات دخول او كلمة مرور MySQL غير صحيحة",
     "You need to enter details of an existing account." : "يلزمك إدخال تفاصيل حسابك الحالي.",
     "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
-    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
-    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
+    "Oracle Login and/or password not valid" : "حيثيات دخول او كلمة مرور Oracle غير صحيحة",
+    "PostgreSQL Login and/or password not valid" : "حيثيات دخول او كلمة مرورPostgreSQL غير صحيحة",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "نظام ماك الإصدار X غير مدعوم و %s لن يعمل بشكل صحيح على هذه المنصة.  استخدمه على مسؤوليتك!",
     "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "يبدو أن كائن %s يعمل على بيئة PHP 32-Bit  وكذلك تم تكوين open_basedir في ملف php.ini. يؤدي ذلك إلى مشاكل مع الملفات التي يزيد حجمها عن 4 غيغابايت ولا يُنصح بذلك بشدة.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
-    "Set an admin username." : "اعداد اسم مستخدم للمدير",
+    "Set an admin Login." : "تعيين حيثيات دخول المشرف.",
     "Set an admin password." : "تعيين كلمة مرور للمدير",
     "Cannot create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في  data directory دليل البيانات %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "يجب أن تقوم الواجهة الخلفية للمشاركة (Sharing backend) %s بتطبيق الواجهة OCP\\Share_Backend",
@@ -151,7 +150,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "تاريخ انتهاء الصلاحية غير صالح.  التاريخ المحدد في الماضي!",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر من %n أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر من %n يوم في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل"],
     "Sharing is only allowed with group members" : "المشاركة مسموحة فقط مع أعضاء المجموعة",
-    "Sharing %s failed, because this item is already shared with user %s" : "المشاركة %sلم تتم لأن هذا العنصر سبقت مشاركته سلفاً مع المستخدم %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "فشلت مشاركة %s؛ لأن هذا العنصر سبقت مشاركته مع الحساب %s",
     "%1$s shared »%2$s« with you" : "%1$s شارك »%2$s« معك",
     "%1$s shared »%2$s« with you." : "%1$s شَارَكَ »%2$s« معك.",
     "Click the button below to open it." : "أنقر على الزر أدناه لفتحه.",
@@ -205,14 +204,14 @@ OC.L10N.register(
     "Nov." : "نوف.",
     "Dec." : "ديس.",
     "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
-    "The username is already being used" : "اسم المستخدم قيد الاستخدام بالفعل",
-    "Could not create user" : "لا يمكن إنشاء المستخدم",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "الحروف التالية فقط مسموحٌ بها في اسم المستخدِم: \"a-z\"و \"A-Z\"و \"0-9\" و الفراغ و  \"_.@-'\"",
-    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
-    "Username contains whitespace at the beginning or at the end" : "إنّ إسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
-    "Username must not consist of dots only" : "اسم المستخدم يجب ألاّ يتكون من نقاطٍ dots فقط",
-    "Username is invalid because files already exist for this user" : "اسم المستخدم غير صحيحٍ لأن هنالك ملفات موجودة سلفاً لهذا المستخدم",
-    "User disabled" : "المستخدم معطّل",
+    "The Login is already being used" : "تسجيل الدخول قيد الاستعمال بالفعل",
+    "Could not create account" : "تعذّر إنشاء الحساب",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "الأحرف التالية فقط مسموح باستعمالها في حيثيات الدخول:  \"a-z\" و , و \"A-Z\"، و \"0-9\", و المسافة، و \"_.@-'\"",
+    "A valid Login must be provided" : "يجب إعطاء حيثيات الدخول الصحيحة",
+    "Login contains whitespace at the beginning or at the end" : "حيثيات الدخول تحوي مسافات بيضاء في بدايتها أو في نهايتها",
+    "Login must not consist of dots only" : "يجب ألّا تكون حيثيات الدخول محتوية فقط على نُقَطٍ",
+    "Login is invalid because files already exist for this user" : "الدخول غير صحيح لأن هنالك ملفات موجودة مسبقاً لهذا المستخدِم",
+    "Account disabled" : "الحساب مُعطَّل",
     "Login canceled by app" : "تم إلغاء الدخول مِن طرف التطبيق",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "التطبيق \"%1$s\" لا يمكن تنصيبه بسبب أن التبعيّات التالية لم تتحقق: %2$s",
     "a safe home for all your data" : "المكان الآمن لجميع بياناتك",
@@ -245,8 +244,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "يرجى مطالبة مسؤول الخادم بإعادة تشغيل خادم الويب.",
     "The required %s config variable is not configured in the config.php file." : "مُتغيّر التهيئة %s المطلوب لم تتم تهيئته في الملف config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "رجاءً، أطلب من مشرف نظامك مراجعة تهيئة نكست كلاود Nextcloud configuration.",
-    "Your data directory is readable by other users." : "دليل بياناتك data directory يُمكن قراءته من مستخدمين آخرين.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "الرجاء تغيير الصلاحيات إلى 0770 حتى لا يتمكن المستخدمون الآخرون من عرض محتويات المجلد.",
+    "Your data directory is readable by other people." : "دليل بياناتك مسموحٌ بقراءته من قِبَل أشخاص آخرين.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "قُم رجاءً بتغيير الأذونات إلى 0770 حتى لا يتسنّى لأشخاص آخرين استعراض الدليل.",
     "Your data directory must be an absolute path." : "مسار دليل بياناتك data directory يجب أن يكون مساراً مُطلقاً absolute path.",
     "Check the value of \"datadirectory\" in your configuration." : "راجع قيمة \"datadirectory\" في تهيئتك.",
     "Your data directory is invalid." : "دليل بياناتك data directory غير صحيح.",
@@ -271,12 +270,32 @@ OC.L10N.register(
     "Extract topics" : "إستخلاص الموضوعات",
     "Extracts topics from a text and outputs them separated by commas." : "يستخلص المواضيع من النص و إخراجها مفصولة بفواصل.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "ملفات التطبيق %1$s لم يتم استبدالها مؤخّراً. تأكد من تطابق إصدارها مع الخادوم.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin، أو يحمل صلاحياتٍ خاصّةٍ للوصول إلى هذه الإعدادات.",
+    "Logged in user must be an admin or sub admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin.",
+    "Logged in user must be an admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin.",
     "Full name" : "الاسم الكامل",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "بسبب الوصول إلى الحدّ الأقصى من عدد المستخدمين، لم يتم إنشا المستخدم. رجاءً، راجع إشعاراتك لمزيد المعلومات.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "مسموح باستخدام الأحرف التالية فقط في اسم المستخدم: \"a-z\" و \"A-Z\" و \"0-9\" و \"_. @ - '\"",
+    "Unknown user" : "المستخدم غير معروف",
+    "Enter the database username and name for %s" : "أدخل اسم المستخدم لقاعدة البيانات و اسم %s",
+    "Enter the database username for %s" : "أدخل اسم المستخدم لقاعدة البيانات لـ %s",
+    "MySQL username and/or password not valid" : "اسم المستخدم لقاعدة البيانات MySQL و/أو كلمة المرور غير صحيحة",
+    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
+    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
+    "Set an admin username." : "اعداد اسم مستخدم للمدير",
+    "Sharing %s failed, because this item is already shared with user %s" : "المشاركة %sلم تتم لأن هذا العنصر سبقت مشاركته سلفاً مع المستخدم %s",
+    "The username is already being used" : "اسم المستخدم قيد الاستخدام بالفعل",
+    "Could not create user" : "لا يمكن إنشاء المستخدم",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "الحروف التالية فقط مسموحٌ بها في اسم المستخدِم: \"a-z\"و \"A-Z\"و \"0-9\" و الفراغ و  \"_.@-'\"",
+    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
+    "Username contains whitespace at the beginning or at the end" : "إنّ إسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
+    "Username must not consist of dots only" : "اسم المستخدم يجب ألاّ يتكون من نقاطٍ dots فقط",
+    "Username is invalid because files already exist for this user" : "اسم المستخدم غير صحيحٍ لأن هنالك ملفات موجودة سلفاً لهذا المستخدم",
+    "User disabled" : "المستخدم معطّل",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "نحتاج النسخة 2.7.0 من libxml2 على الأقل. النسخة المتوافرة حالياً هي %s",
     "To fix this issue update your libxml2 version and restart your web server." : "لإصلاح هذه المشكلة، قم بتحديث إصدار libxml2 الخاص بك وأعد تشغيل خادم الويب.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 مطلوبة.",
-    "Please upgrade your database version." : "رجاءً، قم بترقية إصدار قاعدة بياناتك."
+    "Please upgrade your database version." : "رجاءً، قم بترقية إصدار قاعدة بياناتك.",
+    "Your data directory is readable by other users." : "دليل بياناتك data directory يُمكن قراءته من مستخدمين آخرين.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "الرجاء تغيير الصلاحيات إلى 0770 حتى لا يتمكن المستخدمون الآخرون من عرض محتويات المجلد."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
