@@ -4,10 +4,12 @@ OC.L10N.register(
     "Cannot write into \"config\" directory!" : "\"configurasiya\" direktoriyasının daxilində yazmaq mümkün deyil",
     "See %s" : "Bax %s",
     "Sample configuration detected" : "Konfiqurasiya nüsxəsi təyin edildi",
+    "Authentication" : "Autentifikasiya",
     "Unknown filetype" : "Fayl tipi bəlli deyil.",
     "Invalid image" : "Yalnış şəkil",
     "Files" : "Fayllar",
     "today" : "Bu gün",
+    "yesterday" : "dünən",
     "seconds ago" : "saniyələr öncə",
     "__language_name__" : "Azərbaycan dili",
     "Help" : "Kömək",
@@ -18,11 +20,8 @@ OC.L10N.register(
     "Address" : "Ünvan",
     "Profile picture" : "Profil şəkli",
     "About" : "Haqqında",
-    "Unknown user" : "Istifadəçi tanınmır ",
     "Additional settings" : "Əlavə parametrlər",
     "Oracle connection could not be established" : "Oracle qoşulması alınmır",
-    "Oracle username and/or password not valid" : "Oracle istifadəçi adı və/ya şifrəsi düzgün deyil",
-    "Set an admin username." : "İnzibatçı istifadəçi adını təyin et.",
     "Set an admin password." : "İnzibatçı şifrəsini təyin et.",
     "You are not allowed to share %s" : "%s-in yayimlanmasına sizə izin verilmir",
     "Sunday" : "Bazar",
@@ -64,11 +63,14 @@ OC.L10N.register(
     "Nov." : "Noy.",
     "Dec." : "Dek.",
     "A valid password must be provided" : "Düzgün şifrə daxil edilməlidir",
-    "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir",
     "Application is not enabled" : "Proqram təminatı aktiv edilməyib",
     "Authentication error" : "Təyinat metodikası",
     "Token expired. Please reload page." : "Token vaxtı bitib. Xahiş olunur səhifəni yenidən yükləyəsiniz.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu ola bilər ki, cache/accelerator such tərəfindən cağırılıb hansi ki, Zend OPcache və eAccelerator-da olduğu kimidir.",
-    "Full name" : "Tam ad"
+    "Full name" : "Tam ad",
+    "Unknown user" : "Istifadəçi tanınmır ",
+    "Oracle username and/or password not valid" : "Oracle istifadəçi adı və/ya şifrəsi düzgün deyil",
+    "Set an admin username." : "İnzibatçı istifadəçi adını təyin et.",
+    "A valid username must be provided" : "Düzgün istifadəçi adı daxil edilməlidir"
 },
 "nplurals=2; plural=(n != 1);");
