@@ -56,8 +56,8 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dec.",
     "A valid password must be provided" : "Nužno je navesti valjanu lozinku",
-    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime",
     "Authentication error" : "Grešna autentifikacije",
-    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator."
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemorisanja kao što je Zend OPcache ili eAccelerator.",
+    "A valid username must be provided" : "Nužno je navesti valjano korisničko ime"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
