@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Jsou podporovány následující systémy: %s",
     "Server version %s or higher is required." : "Je potřeba verze serveru %s nebo novější.",
     "Server version %s or lower is required." : "Je potřeba verze serveru %s nebo starší.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Aby mohl přistupovat k tomuto nastavení je třeba, aby přihlášený uživatel byl správce, dílčí správce nebo obdržel speciální oprávnění",
-    "Logged in user must be an admin or sub admin" : "Je třeba, aby přihlášený uživatel byl správcem či správcem pro dílčí oblast",
-    "Logged in user must be an admin" : "Je třeba, aby přihlášený uživatel byl správce",
     "Wiping of device %s has started" : "Vymazávání ze zařízení %s zahájeno",
     "Wiping of device »%s« has started" : "Vymazávání ze zařízení „%s“ zahájeno",
     "»%s« started remote wipe" : "„%s“ zahájilo vymazávání na dálku",
@@ -117,22 +114,15 @@ OC.L10N.register(
     "Headline" : "Nadpis",
     "Organisation" : "Organizace",
     "Role" : "Role",
-    "Unknown user" : "Neznámý uživatel",
     "Additional settings" : "Další nastavení",
-    "Enter the database username and name for %s" : "Zadejte uživatelské jméno v databázi a název pro %s",
-    "Enter the database username for %s" : "Zadejte uživatelské jméno v databázi pro %s",
     "Enter the database name for %s" : "Zadejte název databáze pro %s",
     "You cannot use dots in the database name %s" : "V názvu databáze %s není možné použít tečky",
-    "MySQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do MySQL",
     "You need to enter details of an existing account." : "Je třeba zadat podrobnosti existujícího účtu.",
     "Oracle connection could not be established" : "Spojení s Oracle nemohlo být navázáno",
-    "Oracle username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do Oracle",
-    "PostgreSQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do PostgreSQL",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "macOS není podporován a %s nebude na této platformě správně fungovat. Používejte pouze na vlastní nebezpečí!",
     "For the best results, please consider using a GNU/Linux server instead." : "Místo toho zvažte pro nejlepší funkčnost použití GNU/Linux serveru.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Zdá se, že tato instance %s je provozována v 32-bitovém PHP prostředí a v php.ini je nastavena volba open_basedir. Toto povede k problémům se soubory většími než 4 GB a silně není doporučováno.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraňte z php.ini nastavení volby open_basedir nebo přejděte na 64-bitové PHP.",
-    "Set an admin username." : "Nastavte uživatelské jméno správce.",
     "Set an admin password." : "Nastavte heslo pro účet správce.",
     "Cannot create or write into the data directory %s" : "Nedaří se vytvořit nebo zapisovat do datového adresáře %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Je třeba, aby podpůrná vrstva pro sdílení %s implementovala  rozhraní OCP\\Share_Backend",
@@ -150,7 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Datum skončení platnosti je v minulosti",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Datum vypršení nelze nastavit na více než %n den do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti","Datum vypršení nelze nastavit na více než %n dnů do budoucnosti","Datum vypršení nelze nastavit na více než %n dny do budoucnosti"],
     "Sharing is only allowed with group members" : "Je povoleno pouze sdílení s členy skupiny",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sdílení %s se nezdařilo, protože tato položka už je sdílena s uživatelem %s",
     "%1$s shared »%2$s« with you" : "%1$s vám sdílí „%2$s“",
     "%1$s shared »%2$s« with you." : "%1$s vám nasdílel(a) „%2$s“.",
     "Click the button below to open it." : "Pro otevření klikněte na tlačítko níže.",
@@ -204,14 +193,6 @@ OC.L10N.register(
     "Nov." : "list.",
     "Dec." : "pro.",
     "A valid password must be provided" : "Je třeba zadat platné heslo",
-    "The username is already being used" : "Uživatelské jméno už je využíváno",
-    "Could not create user" : "Nepodařilo se vytvořit uživatele",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, mezery  a „_.@-'“",
-    "A valid username must be provided" : "Je třeba zadat platné uživatelské jméno",
-    "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
-    "Username must not consist of dots only" : "Uživatelské jméno se nemůže skládat pouze ze samých teček",
-    "Username is invalid because files already exist for this user" : "Uživatelské jméno není platné, protože protože pro tohoto uživatele už existují soubory",
-    "User disabled" : "Uživatel zakázán",
     "Login canceled by app" : "Přihlášení zrušeno aplikací",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikaci „%1$s“ nelze nainstalovat, protože nejsou splněny následující závislosti: %2$s",
     "a safe home for all your data" : "bezpečný domov pro všechna vaše data",
@@ -244,8 +225,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Požádejte správce serveru, který využíváte o restart webového serveru.",
     "The required %s config variable is not configured in the config.php file." : "Požadovaná proměnná nastavení %s není v souboru s nastaveními config.php nastavena.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Požádejte správce serveru, který využíváte, aby zkontroloval nastavení serveru.",
-    "Your data directory is readable by other users." : "Váš adresář data je čitelný ostatním uživatelům.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními uživateli.",
     "Your data directory must be an absolute path." : "Je třeba, aby váš adresář data byl zadán jako úplný popis umístění.",
     "Check the value of \"datadirectory\" in your configuration." : "Zkontrolujte hodnotu „datadirectory“ ve svém nastavení.",
     "Your data directory is invalid." : "Váš adresář data není platný.",
@@ -270,13 +249,32 @@ OC.L10N.register(
     "Extract topics" : "Vyzískat témata",
     "Extracts topics from a text and outputs them separated by commas." : "Vyzíská témata z textu a vypíše je oddělované čárkami.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Soubory aplikace %1$s nebyly nahrazeny řádně. Ověřte, že se jedná o verzi, která je kompatibilní se serverem.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Aby mohl přistupovat k tomuto nastavení je třeba, aby přihlášený uživatel byl správce, dílčí správce nebo obdržel speciální oprávnění",
+    "Logged in user must be an admin or sub admin" : "Je třeba, aby přihlášený uživatel byl správcem či správcem pro dílčí oblast",
+    "Logged in user must be an admin" : "Je třeba, aby přihlášený uživatel byl správce",
     "Full name" : "Celé jméno",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Bylo dosaženo limitu počtu uživatelů a uživatel proto nebyl vytvořen. Podrobnosti viz upozornění pro vás.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, a „_.@-'“",
+    "Unknown user" : "Neznámý uživatel",
+    "Enter the database username and name for %s" : "Zadejte uživatelské jméno v databázi a název pro %s",
+    "Enter the database username for %s" : "Zadejte uživatelské jméno v databázi pro %s",
+    "MySQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do MySQL",
+    "Oracle username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do Oracle",
+    "PostgreSQL username and/or password not valid" : "Neplatné uživatelské jméno a/nebo heslo do PostgreSQL",
+    "Set an admin username." : "Nastavte uživatelské jméno správce.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Sdílení %s se nezdařilo, protože tato položka už je sdílena s uživatelem %s",
+    "The username is already being used" : "Uživatelské jméno už je využíváno",
+    "Could not create user" : "Nepodařilo se vytvořit uživatele",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Pouze následující znaky jsou povoleny pro uživatelské jméno: „a-z“, „A-Z“, „0-9“, mezery  a „_.@-'“",
+    "A valid username must be provided" : "Je třeba zadat platné uživatelské jméno",
+    "Username contains whitespace at the beginning or at the end" : "Uživatelské jméno je chybné – na jeho začátku či konci se nachází prázdný znak (mezera, tabulátor, atp.)",
+    "Username must not consist of dots only" : "Uživatelské jméno se nemůže skládat pouze ze samých teček",
+    "Username is invalid because files already exist for this user" : "Uživatelské jméno není platné, protože protože pro tohoto uživatele už existují soubory",
+    "User disabled" : "Uživatel zakázán",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Je zapotřebí verze softwarové knihovny libxml2 přinejmenším 2.7.0. Nyní je nainstalována verze %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Tento problém opravíte instalací novější verze knihovny libxml2 a restartem webového serveru.",
     "PostgreSQL >= 9 required." : "Je vyžadováno PostgreSQL verze 9 a novější.",
     "Please upgrade your database version." : "Aktualizujte verzi vámi využívané databáze.",
-    "404" : "404"
+    "Your data directory is readable by other users." : "Váš adresář data je čitelný ostatním uživatelům.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Změňte práva na 0770, aby obsah adresáře nemohl být vypisován ostatními uživateli."
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
