@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Følgende platforme understøttes: %s",
     "Server version %s or higher is required." : "Du skal have server version %s eller nyere.",
     "Server version %s or lower is required." : "Du skal have server version %s eller ældre.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Bruger skal være administrator, underadministrator eller have tildelt specielle rettigheder for at have adgang til denne indstilling",
-    "Logged in user must be an admin or sub admin" : "Bruger skal være administrator eller underadministrator",
-    "Logged in user must be an admin" : "Brugeren skal være administrator",
     "Wiping of device %s has started" : "Komplet sletning af enhed %s er påbegyndt",
     "Wiping of device »%s« has started" : "Komplet sletning af enhed »%s« er påbegyndt",
     "»%s« started remote wipe" : "Fjernsletning påbegyndt af »%s« ",
@@ -117,22 +114,15 @@ OC.L10N.register(
     "Headline" : "Overskrift",
     "Organisation" : "Organisation",
     "Role" : "Rolle",
-    "Unknown user" : "Ukendt bruger",
     "Additional settings" : "Yderligere indstillinger",
-    "Enter the database username and name for %s" : "Indtast navn til databasen og brugernavn for %s",
-    "Enter the database username for %s" : "Indtast brugernavn til databasen for %s",
     "Enter the database name for %s" : "Indtast databasenavnet for %s",
     "You cannot use dots in the database name %s" : "Du må ikke bruge punktummer i databasenavnet %s",
-    "MySQL username and/or password not valid" : "MySQL brugernavn og/eller kodeord er ikke gyldigt",
     "You need to enter details of an existing account." : "Du skal indtaste detaljerne for en eksisterende konto.",
     "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
-    "Oracle username and/or password not valid" : "Oracle brugernavn og/eller kodeord er ikke gyldigt.",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL brugernavn og/eller kodeord er ikke gyldigt.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X understøttes ikke og %s vil ikke virke optimalt på denne platform. Anvend på eget ansvar!",
     "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
-    "Set an admin username." : "Angiv et admin brugernavn.",
     "Set an admin password." : "Angiv et admin kodeord.",
     "Cannot create or write into the data directory %s" : "Kan ikke oprette eller skrive ind i datamappen %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delingsbackend'en %s skal implementere grænsefladen OCP\\Share_Backend",
@@ -150,7 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Udløbsdatoen ligger tilbage i tid",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Udløbsdato kan ikke sættes mere end %n dag ud i fremtiden","Udløbsdato kan ikke sættes mere end %n dage ud i fremtiden"],
     "Sharing is only allowed with group members" : "Deling er kun tilladt med gruppemedlemmer",
-    "Sharing %s failed, because this item is already shared with user %s" : "Deling af %s mislykkedes, fordi dette element allerede er delt med brugeren %s",
     "%1$s shared »%2$s« with you" : "%1$s delte »%2$s« med dig",
     "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med dig",
     "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
@@ -203,14 +192,6 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dec.",
     "A valid password must be provided" : "En gyldig adgangskode skal angives",
-    "The username is already being used" : "Brugernavnet er allerede i brug",
-    "Could not create user" : "Kunne ikke oprette bruger",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kun følgende tegn kan indgå i et brugernavn: \"a-z\", \"A-Z\", \"0-9\", mellemrum and \"_.@-'\"",
-    "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
-    "Username contains whitespace at the beginning or at the end" : "Brugernavnet har et mellemrum i starten eller slutningen",
-    "Username must not consist of dots only" : "Brugernavnet må ikke bestå af rene prikker/punktummer",
-    "Username is invalid because files already exist for this user" : "Brugernavnet er ugyldigt, da der allerede eksisterer filer for denne bruger",
-    "User disabled" : "Bruger deaktiveret",
     "Login canceled by app" : "Login annulleret af app",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan ikke installeres, da følgende afhængigheder ikke imødekommes: %2$s",
     "a safe home for all your data" : "et sikkert hjem til alle dine data",
@@ -243,8 +224,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Du bedes anmode din serveradministrator om at genstarte webserveren.",
     "The required %s config variable is not configured in the config.php file." : "Den krævede config variabel %s er ikke konfigureret i config.php filen.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Du bedes anmode din serveradministrator om at kontrollere Nextcloud konfigurationen.",
-    "Your data directory is readable by other users." : "Datamappen kan læses af andre brugere.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Tilpas venligst rettigheder til 0770, så mappen ikke fremvises for andre brugere.",
     "Your data directory must be an absolute path." : "Datamappen skal have en absolut sti.",
     "Check the value of \"datadirectory\" in your configuration." : "Tjek værdien for \"datadictionary\" i din konfiguration.",
     "Your data directory is invalid." : "Datamappen er ugyldig.",
@@ -269,13 +248,32 @@ OC.L10N.register(
     "Extract topics" : "Uddrag emner",
     "Extracts topics from a text and outputs them separated by commas." : "Uddrager emner fra en tekst og skriver dem adskilt af kommaer.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Filerne tilhørende appen %1$s blev ikke erstattet korrekt. Check at versionen er kompatibel med serveren.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Bruger skal være administrator, underadministrator eller have tildelt specielle rettigheder for at have adgang til denne indstilling",
+    "Logged in user must be an admin or sub admin" : "Bruger skal være administrator eller underadministrator",
+    "Logged in user must be an admin" : "Brugeren skal være administrator",
     "Full name" : "Fulde navn",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Grænsen for brugere er nået, og den nye bruger er ikke blevet oprettet. Læs dine notifikationer for at lære mere.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kun følgende tegn kan indgå i et brugernavn: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
+    "Unknown user" : "Ukendt bruger",
+    "Enter the database username and name for %s" : "Indtast navn til databasen og brugernavn for %s",
+    "Enter the database username for %s" : "Indtast brugernavn til databasen for %s",
+    "MySQL username and/or password not valid" : "MySQL brugernavn og/eller kodeord er ikke gyldigt",
+    "Oracle username and/or password not valid" : "Oracle brugernavn og/eller kodeord er ikke gyldigt.",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL brugernavn og/eller kodeord er ikke gyldigt.",
+    "Set an admin username." : "Angiv et admin brugernavn.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Deling af %s mislykkedes, fordi dette element allerede er delt med brugeren %s",
+    "The username is already being used" : "Brugernavnet er allerede i brug",
+    "Could not create user" : "Kunne ikke oprette bruger",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kun følgende tegn kan indgå i et brugernavn: \"a-z\", \"A-Z\", \"0-9\", mellemrum and \"_.@-'\"",
+    "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
+    "Username contains whitespace at the beginning or at the end" : "Brugernavnet har et mellemrum i starten eller slutningen",
+    "Username must not consist of dots only" : "Brugernavnet må ikke bestå af rene prikker/punktummer",
+    "Username is invalid because files already exist for this user" : "Brugernavnet er ugyldigt, da der allerede eksisterer filer for denne bruger",
+    "User disabled" : "Bruger deaktiveret",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 skal mindst være version 2.7.0. Du har version %s installeret.",
     "To fix this issue update your libxml2 version and restart your web server." : "Opdater din libxml2 version og genstart webserveren for at løse problemet.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 kræves.",
     "Please upgrade your database version." : "Opgradér venligst din databaseversion.",
-    "404" : "404"
+    "Your data directory is readable by other users." : "Datamappen kan læses af andre brugere.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Tilpas venligst rettigheder til 0770, så mappen ikke fremvises for andre brugere."
 },
 "nplurals=2; plural=(n != 1);");
