@@ -5,6 +5,7 @@ OC.L10N.register(
     "See %s" : "Vidi %s",
     "Sample configuration detected" : "Ekzempla agordo trovita",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Ekzempla agordo estis kopiita en via sistemo. Tio povas paneigi vian instalaĵon, kaj ne estas subtenata. Bv. legi la dokumentaron antaŭ ol fari ŝanĝojn en config.php",
+    "The page could not be found on the server." : "La paĝo ne povis esti trovita en la servilo.",
     "Other activities" : "Alia aktivado",
     "%1$s and %2$s" : "%1$s kaj %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s kaj %3$s",
@@ -27,8 +28,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "La sekvaj platformoj estas subtenataj: %s",
     "Server version %s or higher is required." : "Servilo kun versio %s aŭ pli bezoniĝas.",
     "Server version %s or lower is required." : "Servilo kun versio %s aŭ malpli bezoniĝas.",
-    "Logged in user must be an admin or sub admin" : "La ensalutanta uzanto estu administranto aŭ subadministranto",
-    "Logged in user must be an admin" : "La ensalutanta uzanto estu administranto",
     "Wiping of device %s has started" : "Forviŝado de la aparato %s komencis",
     "Wiping of device »%s« has started" : "Forviŝado de la aparato „%s“ komencis",
     "»%s« started remote wipe" : "„%s“ komencis foran forviŝadon",
@@ -92,18 +91,13 @@ OC.L10N.register(
     "Profile picture" : "Profila bildo",
     "About" : "Pri",
     "Display name" : "Vidiga nomo",
-    "Unknown user" : "Nekonata uzanto",
     "Additional settings" : "Plia agordo",
-    "MySQL username and/or password not valid" : "La uzantnomo kaj/aŭ pasvorto de MySQL ne estas valida",
     "You need to enter details of an existing account." : "Vi entajpu detalojn pri ekzistanta konto.",
     "Oracle connection could not be established" : "Konekto al Oracle ne povis stariĝi",
-    "Oracle username and/or password not valid" : "La uzantnomo kaj/aŭ la pasvorto de Oracle ne estas valida",
-    "PostgreSQL username and/or password not valid" : "La uzantnomo aŭ la pasvorto de PostgreSQL ne validas",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "MacOS X ne estas subtenata kaj %s ne bone funkcios ĉe ĝi. Uzu ĝin je via risko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Por pli bona funkciado, bv. pripensi uzi GNU-Linuksan servilon anstataŭe.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ŝajnas, ke tiu servilo %s uzas 32-bitan PHP-version, kaj ke la agordo „open_basedir“ ekzistas. Tio kaŭzos problemojn pri dosieroj pli grandaj ol 4 GB, kaj do estas tre malrekomendita.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bv. forigi la agordon „open_basedir“ de via php.ini, aŭ uzu 64-bitan version de PHP.",
-    "Set an admin username." : "Agordi uzantnomon de administranto.",
     "Set an admin password." : "Agordi pasvorton de administranto.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Kunhava interna servo %s devas realigi la interfacon „OCP\\Share_Backend“",
     "Sharing backend %s not found" : "Kunhava interna servo %s ne troviĝas",
@@ -116,7 +110,6 @@ OC.L10N.register(
     "You are not allowed to share %s" : "Vi ne permesatas kunhavigi %s",
     "Cannot increase permissions of %s" : "Ne eblas pliigi permesojn de %s",
     "Expiration date is in the past" : "Limdato troviĝas en la estinteco",
-    "Sharing %s failed, because this item is already shared with user %s" : "Kunhavigo de %s malsukcesis, ĉar la ero jam kunhaviĝis kun %s",
     "%1$s shared »%2$s« with you" : "%1$s kunhavigis „%2$s“ kun vi",
     "%1$s shared »%2$s« with you." : "%1$s kunhavigis „%2$s“ kun vi.",
     "Click the button below to open it." : "Alklaku la butonon ĉi-sube por malfermi ĝin.",
@@ -168,13 +161,6 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dec.",
     "A valid password must be provided" : "Valida pasvorto devas esti provizita",
-    "The username is already being used" : "La uzantnomo jam estas uzata",
-    "Could not create user" : "Ne povis krei uzanton",
-    "A valid username must be provided" : "Valida uzantnomo devas esti provizita",
-    "Username contains whitespace at the beginning or at the end" : "Uzantnomo enhavas spaceton ĉe la komenco aŭ la fino",
-    "Username must not consist of dots only" : "Uzantnomo ne povas enhavi nur punktojn",
-    "Username is invalid because files already exist for this user" : "La uzantnomo ne estas valida pro dosieroj por la uzanto jam ekzistas",
-    "User disabled" : "Uzanto malebligita",
     "Login canceled by app" : "Ensaluto estis nuligita de aplikaĵo",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "La aplikaĵo „%1$s“ ne instaliĝas, ĉar la jenaj dependecoj ne plenumiĝas: %2$s",
     "a safe home for all your data" : "sekura hejmo por ĉiuj viaj datumoj",
@@ -192,7 +178,6 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tion kaŭzas probable kaŝilo aŭ plirapidigilo kiel „Zend OPcache“ aŭ „eAccelerator“.",
     "PHP modules have been installed, but they are still listed as missing?" : "Ĉu PHP-moduloj estas instalitaj, sed ĉiam montritaj kiel mankantaj?",
     "Please ask your server administrator to restart the web server." : "Bonvolu peti vian serviladministranton, ke ŝi aŭ li restartigu la TTT-servilon.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bv. ŝanĝi la permesojn al 0770, tiel la dosierujo ne listigeblas de aliaj uzantoj.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Certigu, ke estas dosiero nomata „.ocdata“ en la radiko de la dosierujo de datumoj.",
     "Action \"%s\" not supported or implemented." : "Ago „%s“ ne estas subtenata aŭ realigita.",
     "Authentication failed, wrong token or provider ID given" : "Aŭtentigo malsukcesis: neĝusta ĵetono aŭ provizanto-identigilo specifita",
@@ -206,9 +191,24 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Konservejo provizore ne disponeblas",
     "Storage connection timeout. %s" : "Konekto al konservejo eltempiĝis. %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "La dosieroj de la aplikaĵo %1$s ne estis ĝuste anstataŭigitaj. Certigu, ke tiu aplikaĵa versio kongruas la servilon.",
+    "Logged in user must be an admin or sub admin" : "La ensalutanta uzanto estu administranto aŭ subadministranto",
+    "Logged in user must be an admin" : "La ensalutanta uzanto estu administranto",
     "Full name" : "Plena nomo",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Nur sekvaj signoj estas permesitaj en uzantnomo: \"a-z“, \"A-Z“, \"0-9“ kaj \"_“ (substreko), \"@“ (ĉe), \"-“ (streketo), \"'“ (apostrofo), \".“ (punkto)",
+    "Unknown user" : "Nekonata uzanto",
+    "MySQL username and/or password not valid" : "La uzantnomo kaj/aŭ pasvorto de MySQL ne estas valida",
+    "Oracle username and/or password not valid" : "La uzantnomo kaj/aŭ la pasvorto de Oracle ne estas valida",
+    "PostgreSQL username and/or password not valid" : "La uzantnomo aŭ la pasvorto de PostgreSQL ne validas",
+    "Set an admin username." : "Agordi uzantnomon de administranto.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Kunhavigo de %s malsukcesis, ĉar la ero jam kunhaviĝis kun %s",
+    "The username is already being used" : "La uzantnomo jam estas uzata",
+    "Could not create user" : "Ne povis krei uzanton",
+    "A valid username must be provided" : "Valida uzantnomo devas esti provizita",
+    "Username contains whitespace at the beginning or at the end" : "Uzantnomo enhavas spaceton ĉe la komenco aŭ la fino",
+    "Username must not consist of dots only" : "Uzantnomo ne povas enhavi nur punktojn",
+    "Username is invalid because files already exist for this user" : "La uzantnomo ne estas valida pro dosieroj por la uzanto jam ekzistas",
+    "User disabled" : "Uzanto malebligita",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 almenaŭ necesas. Nun %s estas instalita.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Por ripari tiun problemon, ĝisdatigu vian version de libxml2, kaj restartigu la TTT-servilon."
+    "To fix this issue update your libxml2 version and restart your web server." : "Por ripari tiun problemon, ĝisdatigu vian version de libxml2, kaj restartigu la TTT-servilon.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bv. ŝanĝi la permesojn al 0770, tiel la dosierujo ne listigeblas de aliaj uzantoj."
 },
 "nplurals=2; plural=(n != 1);");
