@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Las siguientes plataformas son compatibles: %s",
     "Server version %s or higher is required." : "Se requiere la versión del servidor %s o superior. ",
     "Server version %s or lower is required." : "La versión del servidor %s o inferior es requerdia. ",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "El usuario que ha iniciado sesión debe ser un administrador, un subadministrador o tener permisos especiales para acceder a esta configuración.",
-    "Logged in user must be an admin or sub admin" : "El usuario que ha iniciado sesión debe ser un administrador o un subadministrador.",
-    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
     "Wiping of device %s has started" : "El borrado del dispositivo %s ha comenzado",
     "Wiping of device »%s« has started" : "El borrado del dispositivo »%s« ha comenzado",
     "»%s« started remote wipe" : "»%s« ha iniciado el borrado remoto",
@@ -117,22 +114,15 @@ OC.L10N.register(
     "Headline" : "Título",
     "Organisation" : "Organización",
     "Role" : "Rol",
-    "Unknown user" : "Ususario desconocido",
     "Additional settings" : "Configuraciones adicionales",
-    "Enter the database username and name for %s" : "Introduce el nombre de usuario y el nombre de la base de datos para %s",
-    "Enter the database username for %s" : "Introduce el nombre de usuario de la base de datos para %s",
     "Enter the database name for %s" : "Introduce el nombre de la base de datos para %s",
     "You cannot use dots in the database name %s" : "No se pueden utilizar puntos en el nombre de la base de datos %s",
-    "MySQL username and/or password not valid" : "Nombre de usuario y/o contraseña de MySQL no válidos",
     "You need to enter details of an existing account." : "Necesitas ingresar los detalles de una cuenta existente.",
     "Oracle connection could not be established" : "No fue posible establecer la conexión a Oracle",
-    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
-    "PostgreSQL username and/or password not valid" : "El Usuario y/o Contraseña de PostgreSQL inválido(s)",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "OS X de Mac no está soportado y %s no funcionará correctamente en esta plataforma ¡Úsalo bajo tu propio riesgo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para mejores resultados, por favor cosidera usar en su lugar un servidor GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Al parecer esta instancia %s está corriendo en un ambiente PHP de 32-bits y el open_basedir ha sido configurado en el archivo php.ini. Esto generará problemas con archivos de más de 4GB de tamaño y es altamente desalentado. ",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Por favor elimina el ajuste open_basedir de tu archivo php.ini o cambia a PHP de 64 bits. ",
-    "Set an admin username." : "Establecer un Usuario administrador",
     "Set an admin password." : "Establecer la contraseña del administrador.",
     "Cannot create or write into the data directory %s" : "No se puede crear ni escribir en el directorio de datos %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El backend %s que comparte debe implementar la interface OCP\\Share_Backend",
@@ -150,7 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "La fecha de expiración se encuentra en el pasado",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No se puede establecer una fecha de caducidad más de %n día en el futuro","No se puede establecer una fecha de caducidad más de %n días en el futuro","No se puede establecer una fecha de caducidad más de %n días en el futuro"],
     "Sharing is only allowed with group members" : "Solo se permite compartir con miembros del grupo",
-    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
     "%1$s shared »%2$s« with you" : "%1$s compartió »%2$s« contigo",
     "%1$s shared »%2$s« with you." : "%1$s compartió »%2$s« contigo.",
     "Click the button below to open it." : "Haz click en el botón inferior para abrirlo. ",
@@ -203,14 +192,6 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dic.",
     "A valid password must be provided" : "Se debe proporcionar una contraseña válida",
-    "The username is already being used" : "Ese usuario ya está en uso",
-    "Could not create user" : "No fue posible crear el usuario",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Solo se permiten los siguientes caracteres en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", espacios y \"_.@-'\"",
-    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
-    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
-    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
-    "Username is invalid because files already exist for this user" : "El nombre de usuario no es válido porque ya existen archivos para este usuario",
-    "User disabled" : "Usuario deshabilitado",
     "Login canceled by app" : "Inicio de sesión cancelado por la aplicación",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "No se puede instalar la aplicación \"%1$s\" porque no se cumplen las siguientes dependencias: %2$s",
     "a safe home for all your data" : "un lugar seguro para todos tus datos",
@@ -243,8 +224,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Por favor solicita al administrador reiniciar el servidor web. ",
     "The required %s config variable is not configured in the config.php file." : "No se ha configurado la variable de configuración %s requerida en el archivo config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Pide a tu administrador del servidor que verifique la configuración de Nextcloud.",
-    "Your data directory is readable by other users." : "Tu directorio de datos es legible por otros usuarios.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. ",
     "Your data directory must be an absolute path." : "Tu directorio de datos debe ser una ruta absoluta.",
     "Check the value of \"datadirectory\" in your configuration." : "Verifica el valor de \"datadirectory\" en tu configuración.",
     "Your data directory is invalid." : "Tu directorio de datos no es válido.",
@@ -261,13 +240,32 @@ OC.L10N.register(
     "Storage is temporarily not available" : "El almacenamieto se encuentra temporalmente no disponible",
     "Storage connection timeout. %s" : "El tiempo de la conexión del almacenamiento se agotó. %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Los archivos de la aplicación %1$s no se reemplazaron correctamente. Asegúrate de que sea una versión compatible con el servidor.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "El usuario que ha iniciado sesión debe ser un administrador, un subadministrador o tener permisos especiales para acceder a esta configuración.",
+    "Logged in user must be an admin or sub admin" : "El usuario que ha iniciado sesión debe ser un administrador o un subadministrador.",
+    "Logged in user must be an admin" : "El usuario firmado debe ser un administrador",
     "Full name" : "Nombre completo",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Se ha alcanzado el límite de usuarios y no se creó el usuario. Consulta tus notificaciones para obtener más información.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Sólo se permiten los siguientes caracteres en el usuario: \"a-z\", \"A-Z\", \"0-9\" y \"_.@-'\"",
+    "Unknown user" : "Ususario desconocido",
+    "Enter the database username and name for %s" : "Introduce el nombre de usuario y el nombre de la base de datos para %s",
+    "Enter the database username for %s" : "Introduce el nombre de usuario de la base de datos para %s",
+    "MySQL username and/or password not valid" : "Nombre de usuario y/o contraseña de MySQL no válidos",
+    "Oracle username and/or password not valid" : "Usuario y/o contraseña de Oracle inválidos",
+    "PostgreSQL username and/or password not valid" : "El Usuario y/o Contraseña de PostgreSQL inválido(s)",
+    "Set an admin username." : "Establecer un Usuario administrador",
+    "Sharing %s failed, because this item is already shared with user %s" : "Se presento una falla al compartir %s, porque este elemento ya ha sido compartido con el usuario %s",
+    "The username is already being used" : "Ese usuario ya está en uso",
+    "Could not create user" : "No fue posible crear el usuario",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Solo se permiten los siguientes caracteres en un nombre de usuario: \"a-z\", \"A-Z\", \"0-9\", espacios y \"_.@-'\"",
+    "A valid username must be provided" : "Debes proporcionar un nombre de usuario válido",
+    "Username contains whitespace at the beginning or at the end" : "El usuario contiene un espacio en blanco al inicio o al final",
+    "Username must not consist of dots only" : "El usuario no debe consistir de solo puntos. ",
+    "Username is invalid because files already exist for this user" : "El nombre de usuario no es válido porque ya existen archivos para este usuario",
+    "User disabled" : "Usuario deshabilitado",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Se requiere de por lo menos libxml2 2.7.0. Actualmente %s está instalado. ",
     "To fix this issue update your libxml2 version and restart your web server." : "Para corregir este tema, por favor actualiza la versión de su libxml2 y reinicia tu servidor web. ",
     "PostgreSQL >= 9 required." : "Se requiere PostgreSQL >= 9.",
     "Please upgrade your database version." : "Actualiza la versión de tu base de datos.",
-    "404" : "404"
+    "Your data directory is readable by other users." : "Tu directorio de datos es legible por otros usuarios.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Por favor cambia los permisos a 0770 para que el directorio no pueda ser enlistado por otros usuarios. "
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
