@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Hurrengo plataformak onartzen dira: %s",
     "Server version %s or higher is required." : "Zerbitzariaren %s bertsioa edo berriagoa behar da.",
     "Server version %s or lower is required." : "Zerbitzariaren %s bertsioa edo zaharragoa behar da.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako erabiltzailea administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
-    "Logged in user must be an admin or sub admin" : "Saioa hasitako erabiltzailea administratzaile edo azpi-administratzailea izan behar du",
-    "Logged in user must be an admin" : "Saioa hasitako erabiltzailea administratzailea izan behar da",
     "Wiping of device %s has started" : "%s gailuaren garbiketa hasi da",
     "Wiping of device »%s« has started" : "»%s« gailuaren garbiketa hasi da",
     "»%s« started remote wipe" : "»%s«(e)k urruneko garbiketa hasi du",
@@ -117,22 +114,15 @@ OC.L10N.register(
     "Headline" : "Izenburua",
     "Organisation" : "Erakundea",
     "Role" : "Zeregina",
-    "Unknown user" : "Erabiltzaile ezezaguna",
     "Additional settings" : "Ezarpen gehiago",
-    "Enter the database username and name for %s" : "%s sartu datu-basearen izena eta erabiltzaile-izena",
-    "Enter the database username for %s" : "Sartu %s(r)en datu-base erabiltzaile-izena",
     "Enter the database name for %s" : "Sartu %s(r)en datu-base izena",
     "You cannot use dots in the database name %s" : "Ezin duzu punturik erabili %s datu-base izenean",
-    "MySQL username and/or password not valid" : "MySQL erabiltzaile-izen edota pasahitza baliogabea",
     "You need to enter details of an existing account." : "Existitzen den kontu baten xehetasunak sartu behar dituzu.",
     "Oracle connection could not be established" : "Ezin da Oracle konexioa sortu",
-    "Oracle username and/or password not valid" : "Oracle erabiltzaile edo/eta pasahitza ez dira baliozkoak.",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzailea edo/eta pasahitza ez dira baliozkoak.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X ez da onartzen eta %s gaizki ibiliko da plataforma honetan. Erabiltzekotan, zure ardurapean.",
     "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez kontsideratu GNU/Linux zerbitzari bat erabiltzea.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Badirudi %s instantzia hau 32 biteko PHP ingurune bat exekutatzen ari dela eta open_basedir aldagaia php.ini fitxategian konfiguratu dela. Honek arazoak sortuko ditu 4 GB baino gehiagoko fitxategiekin eta ez da batere gomendagarria.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez kendu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
-    "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
     "Set an admin password." : "Ezarri administraziorako pasahitza.",
     "Cannot create or write into the data directory %s" : "Ezin da sortu edo idatzi %s datu-direktorioan ",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "%s partekatze motorrak OCP\\Share_Backend interfazea inplementatu behar du ",
@@ -150,7 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Iraungitze-data iraganean dago",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri","Ezin da iraungitze-data etorkizunean %n egun baino gehiagora jarri"],
     "Sharing is only allowed with group members" : "Taldeko kideekin bakarrik parteka daiteke",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s partekatzeak huts egin du dagoeneko %serabiltzailearekin partekatuta dagoelako",
     "%1$s shared »%2$s« with you" : "%1$serabiltzaileak »%2$s« partekatu du zurekin",
     "%1$s shared »%2$s« with you." : "%1$serabiltzaileak »%2$s« partekatu du zurekin.",
     "Click the button below to open it." : "Egin klik beheko botoian hura irekitzeko.",
@@ -204,14 +193,6 @@ OC.L10N.register(
     "Nov." : "Aza.",
     "Dec." : "Abe.",
     "A valid password must be provided" : "Baliozko pasahitza eman behar da",
-    "The username is already being used" : "Erabiltzaile izena dagoeneko erabilita dago",
-    "Could not create user" : "Ezin izan da erabiltzailea sortu",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira erabiltzaile izenetan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
-    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
-    "Username contains whitespace at the beginning or at the end" : "Erabiltzaile-izenak zuriuneren bat du hasieran edo amaieran",
-    "Username must not consist of dots only" : "Erabiltzaile-izena ezin da puntuz osatuta soilik egon",
-    "Username is invalid because files already exist for this user" : "Erabiltzaile-izena ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
-    "User disabled" : "Erabiltzaile desgaituta",
     "Login canceled by app" : "Aplikazioak saioa bertan behera utzi du",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" aplikazioa ezin da instalatu, menpekotasun hauek betetzen ez direlako:%2$s",
     "a safe home for all your data" : "zure datu guztientzako toki segurua",
@@ -244,8 +225,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Mesedez eskatu zerbitzariaren administratzaileari web zerbitzaria berrabiarazteko.",
     "The required %s config variable is not configured in the config.php file." : "Beharrezko %s config aldagaia ez dago konfiguratuta config.php fitxategian.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Mesedez, eskatu zure zerbitzari administratzaileari Nextclouden konfigurazioa egiaztatzeko.",
-    "Your data directory is readable by other users." : "Zure datuen karpeta beste erabiltzaileek irakur dezakete.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko.",
     "Your data directory must be an absolute path." : "Zure datuen karpeta bide-izen absolutua izan behar da.",
     "Check the value of \"datadirectory\" in your configuration." : "Egiaztatu \"datadirectory\"-ren balioa zure konfigurazioan.",
     "Your data directory is invalid." : "Zure datuen karpeta baliogabea da.",
@@ -270,13 +249,32 @@ OC.L10N.register(
     "Extract topics" : "Atera gaiak",
     "Extracts topics from a text and outputs them separated by commas." : "Gaiak ateratzen ditu testu batetik eta komaz banatuta erakusten ditu.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s aplikazioaren fitxategiak ez dira behar bezala ordezkatu. Ziurtatu zerbitzariarekin bateragarria den bertsioa dela.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Saioa hasitako erabiltzailea administratzailea, azpi-administratzailea edo baimen berezi bat duena izan behar da ezarpen hau aldatzeko.",
+    "Logged in user must be an admin or sub admin" : "Saioa hasitako erabiltzailea administratzaile edo azpi-administratzailea izan behar du",
+    "Logged in user must be an admin" : "Saioa hasitako erabiltzailea administratzailea izan behar da",
     "Full name" : "Izen osoa",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Ezin izan da erabiltzailea sortu, erabiltzaile muga gainditu delako. Egiaztatu zure jakinarazpenak gehiago jakiteko.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Erabiltzaile-izenean karaktere hauek soilik erabil daitezke: \"a-z\", \"A-Z\", \"0-9\", eta \"_.@-'\"",
+    "Unknown user" : "Erabiltzaile ezezaguna",
+    "Enter the database username and name for %s" : "%s sartu datu-basearen izena eta erabiltzaile-izena",
+    "Enter the database username for %s" : "Sartu %s(r)en datu-base erabiltzaile-izena",
+    "MySQL username and/or password not valid" : "MySQL erabiltzaile-izen edota pasahitza baliogabea",
+    "Oracle username and/or password not valid" : "Oracle erabiltzaile edo/eta pasahitza ez dira baliozkoak.",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL erabiltzailea edo/eta pasahitza ez dira baliozkoak.",
+    "Set an admin username." : "Ezarri administraziorako erabiltzaile izena.",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s partekatzeak huts egin du dagoeneko %serabiltzailearekin partekatuta dagoelako",
+    "The username is already being used" : "Erabiltzaile izena dagoeneko erabilita dago",
+    "Could not create user" : "Ezin izan da erabiltzailea sortu",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Honako karaktereak bakarrik onartzen dira erabiltzaile izenetan: \"a-z\", \"A-Z\", \"0-9\", zuriuneak eta \"_.@-'\"",
+    "A valid username must be provided" : "Baliozko erabiltzaile izena eman behar da",
+    "Username contains whitespace at the beginning or at the end" : "Erabiltzaile-izenak zuriuneren bat du hasieran edo amaieran",
+    "Username must not consist of dots only" : "Erabiltzaile-izena ezin da puntuz osatuta soilik egon",
+    "Username is invalid because files already exist for this user" : "Erabiltzaile-izena ez da baliozkoa erabiltzaile honentzako fitxategiak dagoeneko existitzen direlako",
+    "User disabled" : "Erabiltzaile desgaituta",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 bertsioa edo berriagoa behar da. Orain %s dago instalatuta.",
     "To fix this issue update your libxml2 version and restart your web server." : "Arazo hori konpontzeko, eguneratu zure libxml2 bertsioa eta berrabiarazi web zerbitzaria.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 behar da",
     "Please upgrade your database version." : "Mesedez eguneratu zure datu-basearen bertsioa.",
-    "404" : "404"
+    "Your data directory is readable by other users." : "Zure datuen karpeta beste erabiltzaileek irakur dezakete.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Aldatu baimenak 0770ra beste erabiltzaileek karpetan sartu ezin izateko."
 },
 "nplurals=2; plural=(n != 1);");
