@@ -36,9 +36,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Les plateformes suivantes sont prises en charge : %s",
     "Server version %s or higher is required." : "Un serveur de version %s ou supérieure est requis.",
     "Server version %s or lower is required." : "Un serveur de version %s ou inférieure est requis.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utilisateur connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
-    "Logged in user must be an admin or sub admin" : "L'utilisateur connecté doit être administrateur ou sous-administrateur",
-    "Logged in user must be an admin" : "L'utilisateur connecté doit être un administrateur",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Le compte connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
+    "Logged in account must be an admin or sub admin" : "Le compte connecté doit être administrateur ou sous-administrateur",
+    "Logged in account must be an admin" : "Le compte connecté doit être un administrateur",
     "Wiping of device %s has started" : "L'effaçage de l'appareil %s a démarré",
     "Wiping of device »%s« has started" : "L'effaçage de l'appareil « %s » a démarré",
     "»%s« started remote wipe" : "« %s » a démarré l'effaçage distant",
@@ -117,22 +117,22 @@ OC.L10N.register(
     "Headline" : "Titre",
     "Organisation" : "Organisme",
     "Role" : "Fonction",
-    "Unknown user" : "Utilisateur inconnu",
+    "Unknown account" : "Compte inconnu",
     "Additional settings" : "Paramètres supplémentaires",
-    "Enter the database username and name for %s" : "Entrez le nom d'utilisateur et le nom de la base de données pour %s",
-    "Enter the database username for %s" : "Entrez le nom d'utilisateur de la base de données pour %s",
+    "Enter the database Login and name for %s" : "Saisissez l'identifiant et le nom de la base de données pour %s",
+    "Enter the database Login for %s" : "Saisissez l'identifiant de la base de données pour %s",
     "Enter the database name for %s" : "Entrez le nom de la base de données pour %s",
     "You cannot use dots in the database name %s" : "Vous ne pouvez pas utiliser de points dans le nom de la base de données %s",
-    "MySQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base MySQL non valide(s)",
+    "MySQL Login and/or password not valid" : "Identifiant et/ou mot de passe MySQL invalide",
     "You need to enter details of an existing account." : "Vous devez indiquer les détails d'un compte existant.",
     "Oracle connection could not be established" : "La connexion Oracle ne peut être établie",
-    "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
-    "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
+    "Oracle Login and/or password not valid" : "Identifiant et/ou mot de passe Oracle invalide",
+    "PostgreSQL Login and/or password not valid" : "Identifiant et/ou mot de passe PostgreSQL invalide",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plate-forme. Son utilisation est à vos risques et périls !",
     "For the best results, please consider using a GNU/Linux server instead." : "Pour obtenir les meilleurs résultats, vous devriez utiliser un serveur GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32 bits et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez retirer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
-    "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
+    "Set an admin Login." : "Définissez un identifiant administrateur.",
     "Set an admin password." : "Spécifiez un mot de passe pour l'administrateur.",
     "Cannot create or write into the data directory %s" : "Impossible de créer ou d'écrire dans le répertoire des données %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Le service de partage %s doit implémenter l'interface OCP\\Share_Backend",
@@ -150,7 +150,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "La date d'expiration est dans le passé",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossible de définir la date d'expiration à dans plus de %n jour","Impossible de définir la date d'expiration à dans plus de %n jours","Impossible de définir la date d'expiration à dans plus de %n jours"],
     "Sharing is only allowed with group members" : "Le partage n'est que possible qu'avec les membres du groupe",
-    "Sharing %s failed, because this item is already shared with user %s" : "Impossible de partager %s car il est déjà partagé avec l'utilisateur %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Impossible de partager %s car il est déjà partagé avec le compte %s",
     "%1$s shared »%2$s« with you" : "%1$s a partagé « %2$s » avec vous",
     "%1$s shared »%2$s« with you." : "%1$s a partagé « %2$s » avec vous.",
     "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir",
@@ -204,14 +204,14 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Déc.",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
-    "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
-    "Could not create user" : "Impossible de créer l'utilisateur",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", espaces et \"_.@-'\"",
-    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
-    "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
-    "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
-    "Username is invalid because files already exist for this user" : "Ce nom d'utilisateur n'est pas valide car des fichiers existent déjà pour cet utilisateur",
-    "User disabled" : "Utilisateur désactivé",
+    "The Login is already being used" : "L'identifiant est déjà utilisé",
+    "Could not create account" : "Impossible de créer le compte",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un identifiant : \"a-z\", \"A-Z\", \"0-9\", espaces et \"_.@-'\"",
+    "A valid Login must be provided" : "Un identifiant valide doit être saisi",
+    "Login contains whitespace at the beginning or at the end" : "L'identifiant contient des espaces au début ou à la fin",
+    "Login must not consist of dots only" : "L'identifiant ne doit pas être composé uniquement de points",
+    "Login is invalid because files already exist for this user" : "L’identifiant n'est pas valide car des fichiers existent déjà pour cet utilisateur",
+    "Account disabled" : "Compte désactivé",
     "Login canceled by app" : "L'authentification a été annulée par l'application",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'application « %1$s » ne peut pas être installée à cause des dépendances suivantes non satisfaites : %2$s",
     "a safe home for all your data" : "un lieu sûr pour toutes vos données",
@@ -244,8 +244,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Veuillez demander à votre administrateur serveur de redémarrer le serveur web.",
     "The required %s config variable is not configured in the config.php file." : "La valeur de configuration requise %s n'est pas configurée dans votre fichier config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Veuillez demander à votre administrateur serveur de vérifier la configuration de Nextcloud.",
-    "Your data directory is readable by other users." : "Votre répertoire est lisible par d'autres utilisateurs.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
+    "Your data directory is readable by other people." : "Votre répertoire de données est lisible par d'autres personnes.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres personnes.",
     "Your data directory must be an absolute path." : "Le chemin de votre répertoire doit être un chemin absolu.",
     "Check the value of \"datadirectory\" in your configuration." : "Verifiez la valeur de \"datadirectory\" dans votre configuration.",
     "Your data directory is invalid." : "Votre répertoire des données n'est pas valide.",
@@ -271,10 +271,31 @@ OC.L10N.register(
     "Extracts topics from a text and outputs them separated by commas." : "Extrait les thèmes d'un texte et les restitue séparés par des virgules.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %1$s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
     "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utilisateur connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
+    "Logged in user must be an admin or sub admin" : "L'utilisateur connecté doit être administrateur ou sous-administrateur",
+    "Logged in user must be an admin" : "L'utilisateur connecté doit être un administrateur",
     "Full name" : "Nom complet",
+    "Unknown user" : "Utilisateur inconnu",
+    "Enter the database username and name for %s" : "Entrez le nom d'utilisateur et le nom de la base de données pour %s",
+    "Enter the database username for %s" : "Entrez le nom d'utilisateur de la base de données pour %s",
+    "MySQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base MySQL non valide(s)",
+    "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
+    "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
+    "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Impossible de partager %s car il est déjà partagé avec l'utilisateur %s",
+    "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
+    "Could not create user" : "Impossible de créer l'utilisateur",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", espaces et \"_.@-'\"",
+    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
+    "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
+    "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
+    "Username is invalid because files already exist for this user" : "Ce nom d'utilisateur n'est pas valide car des fichiers existent déjà pour cet utilisateur",
+    "User disabled" : "Utilisateur désactivé",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 au moins est requis. Actuellement %s est installé.",
     "To fix this issue update your libxml2 version and restart your web server." : "Pour régler ce problème, mettez à jour votre version de libxml2 et redémarrez votre serveur web.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 requis.",
-    "Please upgrade your database version." : "Veuillez mettre à jour votre gestionnaire de base de données."
+    "Please upgrade your database version." : "Veuillez mettre à jour votre gestionnaire de base de données.",
+    "Your data directory is readable by other users." : "Votre répertoire est lisible par d'autres utilisateurs.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
