@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Admítense as seguintes plataformas: %s",
     "Server version %s or higher is required." : "Precísase da versión %s ou superior do servidor.",
     "Server version %s or lower is required." : "Precísase da versión %s ou inferior do servidor.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuario que accede debe ser un administrador, un subadministrador ou ter un dereito especial para acceder a esta configuración",
-    "Logged in user must be an admin or sub admin" : "O usuario autenticado debe ser un administrador ou subadministrador",
-    "Logged in user must be an admin" : "O usuario conectado debe ser un administrador",
     "Wiping of device %s has started" : "Iniciouse a limpeza do dispositivo %s",
     "Wiping of device »%s« has started" : "Iniciouse a limpeza do dispositivo «%s»",
     "»%s« started remote wipe" : "«%s» iniciou a limpeza remota",
@@ -62,19 +59,19 @@ OC.L10N.register(
     "tomorrow" : "mañá",
     "yesterday" : "onte",
     "_in %n day_::_in %n days_" : ["en %n día","en %n días"],
-    "_%n day ago_::_%n days ago_" : ["hai %n día","hai %n días"],
+    "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n días"],
     "next month" : "o vindeiro mes",
     "last month" : "o mes pasado",
     "_in %n month_::_in %n months_" : ["en %n mes","en %n meses"],
-    "_%n month ago_::_%n months ago_" : ["hai %n mes","hai %n meses"],
+    "_%n month ago_::_%n months ago_" : ["Hai %n mes","Hai %n meses"],
     "next year" : "o vindeiro ano",
     "last year" : "o ano pasado",
     "_in %n year_::_in %n years_" : ["en %n ano","en %n anos"],
-    "_%n year ago_::_%n years ago_" : ["hai %n ano","hai %n anos"],
+    "_%n year ago_::_%n years ago_" : ["Hai %n ano","Hai %n anos"],
     "_in %n hour_::_in %n hours_" : ["en %n hora","en %n horas"],
-    "_%n hour ago_::_%n hours ago_" : ["hai %n hora","hai %n horas"],
+    "_%n hour ago_::_%n hours ago_" : ["Hai %n hora","Hai %n horas"],
     "_in %n minute_::_in %n minutes_" : ["en %n minuto","en %n minutos"],
-    "_%n minute ago_::_%n minutes ago_" : ["hai %n minuto","hai %n minutos"],
+    "_%n minute ago_::_%n minutes ago_" : ["Hai %n minuto","Hai %n minutos"],
     "in a few seconds" : "en poucos segundos",
     "seconds ago" : "segundos atrás",
     "Empty file" : "Ficheiro baleiro",
@@ -117,22 +114,15 @@ OC.L10N.register(
     "Headline" : "Titular",
     "Organisation" : "Organización",
     "Role" : "Cargo",
-    "Unknown user" : "Usuario descoñecido",
     "Additional settings" : "Axustes adicionais",
-    "Enter the database username and name for %s" : "Introduza o nome de usuario da ase de datos e o nome para %s",
-    "Enter the database username for %s" : "Introduza o nome de usuario da base de datos para %s",
     "Enter the database name for %s" : "Introduza o nome da base de datos para %s",
     "You cannot use dots in the database name %s" : "Non pode usar puntos no nome da base de datos %s",
-    "MySQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de MySQL incorrecto",
     "You need to enter details of an existing account." : "Debe introducir os detalles dunha conta existente.",
     "Oracle connection could not be established" : "Non foi posíbel estabelecer a conexión con Oracle",
-    "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
-    "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non é compatíbel e %s non funcionará correctamente nesta plataforma. Utilíceo baixo a  súa responsabilidade!",
     "For the best results, please consider using a GNU/Linux server instead." : "Para obter mellores resultados, considere o emprego dun servidor GNU/Linux no seu canto.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Semella que esta instancia de %s está a funcionar nun contorno PHP de 32 bisst e o open_basedir foi configurado no php.ini. Isto provocará problemas con ficheiros maiores de 4 GB e está absolutamente desaconsellado.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Retire o axuste de open_basedir no php.ini ou cambie a PHP de 64 bits.",
-    "Set an admin username." : "Estabeleza un nome de usuario administrador",
     "Set an admin password." : "Estabeleza un contrasinal de administrador",
     "Cannot create or write into the data directory %s" : "Non é posíbel crear ou escribir no directorio de datos %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "A infraestrutura de compartición %s ten que implementar a interface OCP\\Share_Backend",
@@ -150,7 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Xa pasou a data de caducidade",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Non é posíbel estabelecer a data de caducidade máis alo de %n día no futuro","Non é posíbel estabelecer a data de caducidade máis alo de %n días no futuro"],
     "Sharing is only allowed with group members" : "Só se permite compartir cos membros do grupo",
-    "Sharing %s failed, because this item is already shared with user %s" : "Fallou a compartición de %s por mor de que este elemento xa foi compartido co usuario %s",
     "%1$s shared »%2$s« with you" : "%1$s compartiu «%2$s» con Vde.",
     "%1$s shared »%2$s« with you." : "%1$s compartiu «%2$s» con Vde.",
     "Click the button below to open it." : "Prema no botón de embaixo para abrilo.",
@@ -204,14 +193,6 @@ OC.L10N.register(
     "Nov." : "nov.",
     "Dec." : "dec.",
     "A valid password must be provided" : "Debe fornecer un contrasinal",
-    "The username is already being used" : "Este nome de usuario xa está a ser usado",
-    "Could not create user" : "Non foi posíbel crear o usuario",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun nome de usuario: «a-z», «A-Z», «0-9», espazos e «_.@-'»",
-    "A valid username must be provided" : "Debe fornecer un nome de usuario correcto",
-    "Username contains whitespace at the beginning or at the end" : "O nome de usuario contén un espazo en branco no inicio ou no final",
-    "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
-    "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
-    "User disabled" : "Usuario desactivado",
     "Login canceled by app" : "Acceso cancelado pola aplicación",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non é posíbel instalar a aplicación «%1$s» por mor de non cumprirse as dependencias: %2$s",
     "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
@@ -244,8 +225,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Pídalle á administración do seu servidor que reinicie o servidor web.",
     "The required %s config variable is not configured in the config.php file." : "Precísase da variábel de configuración %s e non está configurada no ficheiro config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Pídalle á administración do seu servidor que verifique a configuración de Nextcloud.",
-    "Your data directory is readable by other users." : "Outros usuarios poden leer o seu directorio de datos.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios.",
     "Your data directory must be an absolute path." : "O seu directorio de datos debe ser unha ruta absoluta.",
     "Check the value of \"datadirectory\" in your configuration." : "Comprobe o valor de «datadirectory» na súa configuración-",
     "Your data directory is invalid." : "O seu directorio de datos non é válido.",
@@ -270,13 +249,32 @@ OC.L10N.register(
     "Extract topics" : "Extraer temas",
     "Extracts topics from a text and outputs them separated by commas." : "Extrae temas dun texto e amósaos separados por comas.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Os ficheiros da aplicación %1$s non foron substituídos correctamente. Asegúrese que é unha versión compatíbel co servidor.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "O usuario que accede debe ser un administrador, un subadministrador ou ter un dereito especial para acceder a esta configuración",
+    "Logged in user must be an admin or sub admin" : "O usuario autenticado debe ser un administrador ou subadministrador",
+    "Logged in user must be an admin" : "O usuario conectado debe ser un administrador",
     "Full name" : "Nome completo",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Acadouse o límite de usuarios e non se creou o usuario. Consulte as súas notificacións para obter máis información.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Só os seguintes caracteres están permitidos nos nomes de usuario: «a-z», «A-Z», «0-9» e «_.@-'»",
+    "Unknown user" : "Usuario descoñecido",
+    "Enter the database username and name for %s" : "Introduza o nome de usuario da ase de datos e o nome para %s",
+    "Enter the database username for %s" : "Introduza o nome de usuario da base de datos para %s",
+    "MySQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de MySQL incorrecto",
+    "Oracle username and/or password not valid" : "O nome de usuario e/ou contrasinal de Oracle é incorrecto",
+    "PostgreSQL username and/or password not valid" : "Nome de usuario e/ou contrasinal de PostgreSQL incorrecto",
+    "Set an admin username." : "Estabeleza un nome de usuario administrador",
+    "Sharing %s failed, because this item is already shared with user %s" : "Fallou a compartición de %s por mor de que este elemento xa foi compartido co usuario %s",
+    "The username is already being used" : "Este nome de usuario xa está a ser usado",
+    "Could not create user" : "Non foi posíbel crear o usuario",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Só se permiten os seguintes caracteres nun nome de usuario: «a-z», «A-Z», «0-9», espazos e «_.@-'»",
+    "A valid username must be provided" : "Debe fornecer un nome de usuario correcto",
+    "Username contains whitespace at the beginning or at the end" : "O nome de usuario contén un espazo en branco no inicio ou no final",
+    "Username must not consist of dots only" : "O nome de usuario non debe consistir só de puntos",
+    "Username is invalid because files already exist for this user" : "O nome de usuario non é válido porque xa existen ficheiros para este usuario",
+    "User disabled" : "Usuario desactivado",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Precísase, cando menos, de libxml2 2.7.0. Actualmente esta instalado %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Para arranxar esta incidencia, actualice a versión de libxml2 e reinicie o servidor web. ",
     "PostgreSQL >= 9 required." : "Precísase de PostgreSQL >= 9.",
     "Please upgrade your database version." : "Anove a versión da súa base de datos",
-    "404" : "404"
+    "Your data directory is readable by other users." : "Outros usuarios poden leer o seu directorio de datos.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Cambie os permisos a 0770 para que o directorio non poida ser listado por outros usuarios."
 },
 "nplurals=2; plural=(n != 1);");
