@@ -33,9 +33,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Podržane su sljedeće platforme: %s",
     "Server version %s or higher is required." : "Inačica poslužitelja treba biti %s ili viša.",
     "Server version %s or lower is required." : "Potrebna je inačica poslužitelja %s ili niža.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljeni korisnik mora biti administrator, podadministrator ili imati posebna prava za pristupanje ovoj postavci",
-    "Logged in user must be an admin or sub admin" : "Prijavljeni korisnik mora biti administrator ili podadministrator",
-    "Logged in user must be an admin" : "Korisnik koji je prijavljen mora biti administrator",
     "Wiping of device %s has started" : "Počelo je brisanje sadržaja s uređaja %s",
     "Wiping of device »%s« has started" : "Počelo je brisanje sadržaja s uređaja »%s«",
     "»%s« started remote wipe" : "»%s« je počeo daljinsko brisanje",
@@ -107,18 +104,13 @@ OC.L10N.register(
     "Headline" : "Naslov",
     "Organisation" : "Organizacija",
     "Role" : "Uloga",
-    "Unknown user" : "Nepoznat korisnik",
     "Additional settings" : "Dodatne postavke",
-    "MySQL username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka MySQL",
     "You need to enter details of an existing account." : "Trebate unijeti informacije o postojećem računu.",
     "Oracle connection could not be established" : "Nije moguće uspostaviti vezu s bazom podataka Oracle",
-    "Oracle username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka Oracle",
-    "PostgreSQL username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka PostgreSQL",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba. Koristite na vlastiti rizik!",
     "For the best results, please consider using a GNU/Linux server instead." : "Za najbolje rezultate razmotrite mogućnost korištenja poslužitelja GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Čini se da se ova %s instanca izvodi u 32-bitnom PHP okruženju, a open_basedir je konfiguriran u php.ini. To će dovesti do problema s datotekama većim od 4 GB i stoga se ne preporučuje.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Uklonite postavku open_basedir iz datoteke php.ini ili se prebacite na 64-bitni PHP.",
-    "Set an admin username." : "Postavite korisničko ime administratora.",
     "Set an admin password." : "Postavite zaporku administratora.",
     "Cannot create or write into the data directory %s" : "Nije moguće stvoriti ili pisati u direktorij s podacima %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Pozadina za dijeljenje %s mora implementirati sučelje OCP\\Share_Backend",
@@ -136,7 +128,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Datum isteka je u prošlosti",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ne može se postaviti datum isteka više od %n dan u budućnosti","Ne može se postaviti datum isteka više od %n dana u budućnosti","Ne može se postaviti datum isteka više od %n dana u budućnosti"],
     "Sharing is only allowed with group members" : "Dijeljenje je dopušteno samo članovima grupe",
-    "Sharing %s failed, because this item is already shared with user %s" : "Dijeljenje %s nije uspjelo jer je ova stavka već podijeljena s korisnikom %s",
     "%1$s shared »%2$s« with you" : "%1$s dijeli »%2$s« s vama",
     "%1$s shared »%2$s« with you." : "%1$s dijeli »%2$s« s vama.",
     "Click the button below to open it." : "Kliknite gumb u nastavku za otvaranje.",
@@ -188,13 +179,6 @@ OC.L10N.register(
     "Nov." : "Stu.",
     "Dec." : "Pro.",
     "A valid password must be provided" : "Nužno je navesti ispravnu zaporku",
-    "The username is already being used" : "Korisničko ime se već koristi",
-    "Could not create user" : "Nije moguće stvoriti korisnika",
-    "A valid username must be provided" : "Nužno je navesti ispravno korisničko ime",
-    "Username contains whitespace at the beginning or at the end" : "Korisničko ime sadrži bijeli prostor na početku ili na kraju",
-    "Username must not consist of dots only" : "Korisničko ime ne smije se sastojati samo od točkica",
-    "Username is invalid because files already exist for this user" : "Korisničko ime je nevažeće jer već postoje datoteke za ovog korisnika",
-    "User disabled" : "Korisnik je onemogućen",
     "Login canceled by app" : "Prijava je otkazana putem aplikacije",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Aplikaciju „%1$s” nije moguće instalirati jer nisu ispunjene sljedeće ovisnosti: %2$s",
     "a safe home for all your data" : "siguran dom za sve vaše podatke",
@@ -212,7 +196,6 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemoriranja kao što je Zend OPcache ili eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP moduli su instalirani, ali još uvijek su na popisu onih koji nedostaju?",
     "Please ask your server administrator to restart the web server." : "Molimo zamolite svog administratora poslužitelja da ponovno pokrene web poslužitelj.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Promijenite dozvole na 0770 tako da se tim direktorijem ne mogu služiti drugi korisnici.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Provjerite postoji li datoteka pod nazivom „.ocdata” u korijenu podatkovnog direktorija.",
     "Action \"%s\" not supported or implemented." : "Radnja „%s” nije podržana ili provedena.",
     "Authentication failed, wrong token or provider ID given" : "Autentifikacija nije uspjela, dan je pogrešan token ili ID davatelja usluge",
@@ -226,8 +209,25 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Pohrana privremeno nije dostupna",
     "Storage connection timeout. %s" : "Istek veze pohrane. %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Datoteke aplikacije %1$s nisu ispravno zamijenjene. Provjerite je li inačica kompatibilna s poslužiteljem.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljeni korisnik mora biti administrator, podadministrator ili imati posebna prava za pristupanje ovoj postavci",
+    "Logged in user must be an admin or sub admin" : "Prijavljeni korisnik mora biti administrator ili podadministrator",
+    "Logged in user must be an admin" : "Korisnik koji je prijavljen mora biti administrator",
     "Full name" : "Puno ime",
+    "Unknown user" : "Nepoznat korisnik",
+    "MySQL username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka MySQL",
+    "Oracle username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka Oracle",
+    "PostgreSQL username and/or password not valid" : "Neispravno korisničko ime i/ili zaporka baze podataka PostgreSQL",
+    "Set an admin username." : "Postavite korisničko ime administratora.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Dijeljenje %s nije uspjelo jer je ova stavka već podijeljena s korisnikom %s",
+    "The username is already being used" : "Korisničko ime se već koristi",
+    "Could not create user" : "Nije moguće stvoriti korisnika",
+    "A valid username must be provided" : "Nužno je navesti ispravno korisničko ime",
+    "Username contains whitespace at the beginning or at the end" : "Korisničko ime sadrži bijeli prostor na početku ili na kraju",
+    "Username must not consist of dots only" : "Korisničko ime ne smije se sastojati samo od točkica",
+    "Username is invalid because files already exist for this user" : "Korisničko ime je nevažeće jer već postoje datoteke za ovog korisnika",
+    "User disabled" : "Korisnik je onemogućen",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Potreban je barem Libxml2 2.7.0. Trenutno je instalirana inačica %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Kako biste riješili ovaj problem, ažurirajte svoju inačicu libxml2 i ponovno pokrenite web poslužitelj."
+    "To fix this issue update your libxml2 version and restart your web server." : "Kako biste riješili ovaj problem, ažurirajte svoju inačicu libxml2 i ponovno pokrenite web poslužitelj.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Promijenite dozvole na 0770 tako da se tim direktorijem ne mogu služiti drugi korisnici."
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
