@@ -51,16 +51,12 @@ OC.L10N.register(
     "Address" : "Alamat",
     "Profile picture" : "Foto profil",
     "About" : "Tentang.",
-    "Unknown user" : "Pengguna tidak dikenal",
     "Additional settings" : "Setelan tambahan",
     "Oracle connection could not be established" : "Koneksi Oracle tidak dapat dibuat",
-    "Oracle username and/or password not valid" : "Nama pengguna dan/atau kata sandi Oracle tidak sah",
-    "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau kata sandi PostgreSQL tidak valid",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X tidak didukung dan %s tidak akan bekerja dengan baik pada platform ini. Gunakan dengan resiko Anda sendiri!",
     "For the best results, please consider using a GNU/Linux server instead." : "Untuk hasil terbaik, pertimbangkan untuk menggunakan server GNU/Linux sebagai gantinya. ",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kelihatannya instansi %s ini berjalan di lingkungan PHP 32-bit dan open_basedir telah dikonfigurasi di php.ini. Hal ini akan menyebabkan masalah dengan berkas lebih dari 4 GB dan sangat tidak disarankan.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mohon hapus pengaturan open_basedir didalam php.ini atau beralih ke PHP 64-bit.",
-    "Set an admin username." : "Tetapkan nama pengguna admin.",
     "Set an admin password." : "Tetapkan kata sandi admin.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Backend berbagi %s harus mengimplementasi antarmuka OCP\\Share_Backend",
     "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
@@ -69,7 +65,6 @@ OC.L10N.register(
     "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
     "Cannot increase permissions of %s" : "Tidak dapat menambah izin %s",
     "Expiration date is in the past" : "Tanggal kedaluwarsa sudah lewat",
-    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
     "Could not find category \"%s\"" : "Tidak menemukan kategori \"%s\"",
     "Sunday" : "Minggu",
     "Monday" : "Senin",
@@ -117,10 +112,6 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Des.",
     "A valid password must be provided" : "Tuliskan kata sandi yang valid",
-    "The username is already being used" : "Nama pengguna ini telah digunakan",
-    "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
-    "Username contains whitespace at the beginning or at the end" : "Nama pengguna mengandung spasi di depan atau di belakang.",
-    "User disabled" : "Pengguna dinonaktifkan",
     "Login canceled by app" : "Log masuk dibatalkan oleh aplikasi",
     "a safe home for all your data" : "rumah yang aman untuk semua data Anda",
     "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
@@ -136,7 +127,6 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Hal ini kemungkinan disebabkan oleh cache/akselerator seperti Zend OPcache atau eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Modul PHP telah terinstal, tetapi mereka terlihat tidak ada?",
     "Please ask your server administrator to restart the web server." : "Mohon minta administrator Anda untuk menjalankan ulang server web.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain.",
     "Could not obtain lock type %d on \"%s\"." : "Tidak bisa memperoleh jenis kunci %d pada \"%s\".",
     "Storage unauthorized. %s" : "Penyimpanan tidak terotorisasi. %s",
     "Storage incomplete configuration. %s" : "Konfigurasi penyimpanan tidak terselesaikan. %s",
@@ -144,7 +134,17 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Penyimpanan sementara tidak tersedia",
     "Storage connection timeout. %s" : "Koneksi penyimpanan waktu-habis. %s",
     "Full name" : "Nama lengkap",
+    "Unknown user" : "Pengguna tidak dikenal",
+    "Oracle username and/or password not valid" : "Nama pengguna dan/atau kata sandi Oracle tidak sah",
+    "PostgreSQL username and/or password not valid" : "Nama pengguna dan/atau kata sandi PostgreSQL tidak valid",
+    "Set an admin username." : "Tetapkan nama pengguna admin.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Berbagi %s gagal karena item ini sudah dibagikan dengan pengguna %s",
+    "The username is already being used" : "Nama pengguna ini telah digunakan",
+    "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
+    "Username contains whitespace at the beginning or at the end" : "Nama pengguna mengandung spasi di depan atau di belakang.",
+    "User disabled" : "Pengguna dinonaktifkan",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Setidaknya libxml2 2.7.0 dibutuhkan. Saat ini %s dipasang.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Untuk mengatasi masalah ini, perbarui versi libxml2 Anda dan mulai-ulang server web Anda."
+    "To fix this issue update your libxml2 version and restart your web server." : "Untuk mengatasi masalah ini, perbarui versi libxml2 Anda dan mulai-ulang server web Anda.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain."
 },
 "nplurals=1; plural=0;");
