@@ -2,9 +2,19 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Get ekki skrifað í \"config\" möppuna!",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í stillingamöppuna.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "En ef þú vilt halda config.php skránni einungis til lesanlegri, skaltu setja valkostinn \"config_is_read_only\" á 'true' í henni.",
     "See %s" : "Skoðaðu %s",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Forritið %1$s er ekki til staðar eða er af útgáfu sem ekki er samhæfð þessum netþjóni. Endilega skoðaðu í forritamöppuna.",
     "Sample configuration detected" : "Fann sýnisuppsetningu",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Komið hefur í ljós að sýniuppsetningin var afrituð. Þetta getur skemmt uppsetninguna og er ekki stutt. Endilega lestu hjálparskjölin áður en þú gerir breytingar á config.php",
+    "The page could not be found on the server." : "Síðan fannst ekki á netþjóninum.",
+    "%s email verification" : "Sannvottun tölvupósts fyrir %s",
+    "Email verification" : "Sannvottun tölvupósts",
+    "Click the following button to confirm your email." : "Smelltu á eftirfarandi hnapp til að staðfesta tölvupóstfangið þitt.",
+    "Click the following link to confirm your email." : "Smelltu á eftirfarandi tengil til að staðfesta tölvupóstfangið þitt.",
+    "Confirm your email" : "Staðfestu tölvupóstfangið þitt",
+    "Other activities" : "Aðrar athafnir",
     "%1$s and %2$s" : "%1$s og %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
@@ -12,18 +22,20 @@ OC.L10N.register(
     "Education Edition" : "Kennsluútgáfa",
     "Enterprise bundle" : "Fyrirtækjavöndull",
     "Groupware bundle" : "Hópvinnsluvöndull",
+    "Hub bundle" : "Tengivöndull",
     "Social sharing bundle" : "Deilivöndull fyrir samfélagsmiðla",
     "PHP %s or higher is required." : "Krafist er PHP %s eða hærra.",
     "PHP with a version lower than %s is required." : "Krafist er PHP útgáfu %s eða lægri.",
     "%sbit or higher PHP required." : "Krafist er PHP %sbita eða hærra.",
+    "The following architectures are supported: %s" : "Eftirfarandi tölvukerfi eru studd: %s",
+    "The following databases are supported: %s" : "Eftirfarandi gagnagrunnar eru studdir: %s",
     "The command line tool %s could not be found" : "Skipanalínutólið \"%s\" fannst ekki",
     "The library %s is not available." : "Aðgerðasafnið %s er ekki tiltækt.",
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Krafist er aðgerðasafns %1$s með útgáfu hærri en %2$s - tiltæk útgáfa er %3$s.",
     "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Krafist er aðgerðasafns %1$s með útgáfu lægri en %2$s - tiltæk útgáfa er %3$s.",
+    "The following platforms are supported: %s" : "Eftirfarandi stýrikerfi eru studd: %s",
     "Server version %s or higher is required." : "Krafist er þjóns af útgáfu %s eða hærra.",
     "Server version %s or lower is required." : "Krafist er þjóns af útgáfu %s eða lægri.",
-    "Logged in user must be an admin or sub admin" : "Innskráður notandi verður að vera kerfisstjóri eða undirstjórnandi",
-    "Logged in user must be an admin" : "Innskráður notandi verður að vera stjórnandi",
     "Wiping of device %s has started" : "Útþurrkun af tækinu %s er byrjuð",
     "Wiping of device »%s« has started" : "Útþurrkun af tækinu »%s« er byrjuð",
     "»%s« started remote wipe" : "»%s« byrjaði fjartengda útþurrkun",
@@ -41,6 +53,8 @@ OC.L10N.register(
     "Invalid image" : "Ógild mynd",
     "Avatar image is not square" : "Auðkennismynd er ekki ferningslaga",
     "Files" : "Skrár",
+    "View profile" : "Skoða notandasnið",
+    "Local time: %s" : "Staðartími: %s",
     "today" : "í dag",
     "tomorrow" : "á morgun",
     "yesterday" : "í gær",
@@ -60,8 +74,11 @@ OC.L10N.register(
     "_%n minute ago_::_%n minutes ago_" : ["fyrir %n mínútu síðan","fyrir %n mínútum síðan"],
     "in a few seconds" : "eftir örfáar sekúndur",
     "seconds ago" : "sekúndum síðan",
+    "Empty file" : "Tóm skrá",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Eining með auðkenni: %s er ekki til. Virkjaðu hana í forritastillingum eða hafðu samband við kerfisstjóra.",
     "File already exists" : "Skrá er þegar til",
+    "Invalid path" : "Ógild slóð",
+    "Failed to create file from template" : "Mistókst að búa til skrá út frá sniðmáti",
     "Templates" : "Sniðmát",
     "File name is a reserved word" : "Skráarheiti er þegar frátekið orð",
     "File name contains at least one invalid character" : "Skráarheitið inniheldur að minnsta kosti einn ógildan staf",
@@ -73,31 +90,41 @@ OC.L10N.register(
     "__language_name__" : "Íslenska",
     "This is an automatically sent email, please do not reply." : "Þetta er sjálfvirk tölvupóstsending, ekki svara þessu.",
     "Help" : "Hjálp",
+    "Appearance and accessibility" : "Útlit og aðgengi",
     "Apps" : "Forrit",
+    "Personal settings" : "Persónulegar stillingar",
+    "Administration settings" : "Stillingar stjórnunar",
     "Settings" : "Stillingar",
     "Log out" : "Skrá út",
     "Users" : "Notendur",
     "Email" : "Tölvupóstur",
+    "Mail %s" : "Póstur %s",
+    "Fediverse" : "Skýjasamband",
+    "View %s on the fediverse" : "Skoða %s á skýjasambandi (fediverse)",
     "Phone" : "Sími",
+    "Call %s" : "Hringja í %s",
     "Twitter" : "Twitter",
+    "View %s on Twitter" : "Skoða %s á Twitter",
     "Website" : "Vefsvæði",
+    "Visit %s" : "Heimsækja %s",
     "Address" : "Vistfang",
     "Profile picture" : "Einkennismynd",
     "About" : "Um hugbúnaðinn",
+    "Display name" : "Birtingarnafn",
     "Headline" : "Fyrirsögn",
+    "Organisation" : "Stofnun/Félag/Fyrirtæki",
     "Role" : "Role",
-    "Unknown user" : "Óþekktur notandi",
     "Additional settings" : "Valfrjálsar stillingar",
+    "Enter the database name for %s" : "Settu inn nafn á gagnagrunni fyrir %s",
+    "You cannot use dots in the database name %s" : "Þú mátt ekki nota punkta í gagnagrunnsheitinu %s",
     "You need to enter details of an existing account." : "Þú verður að setja inn auðkenni fyrirliggjandi notandaaðgangs.",
     "Oracle connection could not be established" : "Ekki tókst að koma tengingu á við Oracle",
-    "Oracle username and/or password not valid" : "Notandanafn eða lykilorð Oracle er ekki gilt",
-    "PostgreSQL username and/or password not valid" : "Notandanafn eða lykilorð PostgreSQL er ekki gilt",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X er ekki stutt og %s mun ekki vinna eðlilega á þessu stýrikerfi. Notaðu þetta því á þína eigin ábyrgð! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Fyrir bestu útkomu ættirðu að íhuga að nota GNU/Linux þjón í staðinn.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Það lítur út eins og þessi %s uppsetning sé að keyra á 32-bita PHP umhverfi og að open_basedir hafi verið stillt í php.ini. Þetta mun valda vandamálum með skrár stærri en 4 GB og er stranglega mælt gegn því að þetta sé gert.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjarlægðu stillinguna open_basedir úr php.ini eða skiptu yfir í 64-bita PHP.",
-    "Set an admin username." : "Stilltu notandanafn kerfisstjóra.",
     "Set an admin password." : "Stilltu lykilorð kerfisstjóra.",
+    "Cannot create or write into the data directory %s" : "Gat ekki búið til eða skrifað í gagnamöppuna %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Deilingarbakendinn %s verður að vera settur upp fyrir viðmótið OCP\\Share_Backend",
     "Sharing backend %s not found" : "Deilingarbakendinn %s fannst ekki",
     "Sharing backend for %s not found" : "Deilingarbakendi fyrir %s fannst ekki",
@@ -108,12 +135,17 @@ OC.L10N.register(
     "%1$s via %2$s" : "%1$s með %2$s",
     "You are not allowed to share %s" : "Þú hefur ekki heimild til að deila %s",
     "Cannot increase permissions of %s" : "Get ekki aukið aðgangsheimildir %s",
+    "Files cannot be shared with delete permissions" : "Ekki er hægt að deila skrá með eyða-heimildum",
+    "Files cannot be shared with create permissions" : "Ekki er hægt að deila skrá með búa-til-heimildum",
     "Expiration date is in the past" : "Gildistíminn er þegar runninn út",
-    "Sharing %s failed, because this item is already shared with user %s" : "Deiling %s mistókst, því þessu atriði er þegar deilt með notandanum %s",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Ekki er hægt að setja lokadagsetningu meira en %n dag fram í tímann","Ekki er hægt að setja lokadagsetningu meira en %n daga fram í tímann"],
+    "Sharing is only allowed with group members" : "Deiling er aðeins leyfð með meðlimum hópsins",
     "%1$s shared »%2$s« with you" : "%1$s deildi »%2$s« með þér",
     "%1$s shared »%2$s« with you." : "%1$s deildi »%2$s« með þér.",
     "Click the button below to open it." : "Smelltu á hnappinn hér fyrir neðan til að opna það.",
     "The requested share does not exist anymore" : "Umbeðin sameign er ekki lengur til",
+    "The requested share comes from a disabled user" : "Umbeðin sameign kemur frá notanda sem er óvirkur",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Notandinn var ekki búinn til þar sem takmörkum á fjölda notenda var náð. Skoðaðu tilkynningarnar þínar til að sjá meira.",
     "Could not find category \"%s\"" : "Fann ekki flokkinn \"%s\"",
     "Sunday" : "Sunnudagur",
     "Monday" : "Mánudagur",
@@ -161,31 +193,41 @@ OC.L10N.register(
     "Nov." : "Nóv.",
     "Dec." : "Des.",
     "A valid password must be provided" : "Skráðu inn gilt lykilorð",
-    "The username is already being used" : "Notandanafnið er þegar í notkun",
-    "Could not create user" : "Gat ekki búið til notanda",
-    "A valid username must be provided" : "Skráðu inn gilt notandanafn",
-    "Username contains whitespace at the beginning or at the end" : "Notandanafnið inniheldur orðabil í upphafi eða enda",
-    "Username must not consist of dots only" : "Notandanafn má ekki einungis samanstanda af punktum",
-    "Username is invalid because files already exist for this user" : "Notandanafnið er ógilt vegna þess að þegar eru fyrir hendi skrár sem tilheyra þessum notanda",
-    "User disabled" : "Notandi óvirkur",
     "Login canceled by app" : "Forrit hætti við innskráningu",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Ekki var hægt að setja upp \"%1$s\" forritið þar sem eftirfarandi kerfiskröfur eru ekki uppfylltar: %2$s",
     "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
     "File is currently busy, please try again later" : "Skráin er upptekin í augnablikinu, reyndu aftur síðar",
+    "Cannot download file" : "Get ekki sótt skrá",
     "Application is not enabled" : "Forrit ekki virkt",
     "Authentication error" : "Villa við auðkenningu",
     "Token expired. Please reload page." : "Kenniteikn er útrunnið. Þú ættir að hlaða síðunni aftur inn.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Engir reklar fyrir gagnagrunn eru uppsettir (sqlite, mysql eða postgresql).",
+    "Cannot write into \"config\" directory." : "Get ekki skrifað í \"config\" möppuna.",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í stillingamöppuna. Skoðaðu %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Eða, ef þú vilt halda config.php skránni aðeins til lestrar, settu valkostinn \"config_is_read_only\" á 'true' í henni. Skoðaðu %s",
+    "Cannot write into \"apps\" directory." : "Get ekki skrifað í \"apps\" möppuna.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í forritamöppuna eða gera App Store forritabúðina óvirka í stillingaskránni. ",
+    "Cannot create \"data\" directory." : "Get ekki búið til \"data\" möppu.",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Þetta er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í rótarmöppuna. Skoðaðu %s",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Heimildir er venjulega hægt að laga með því að gefa vefþjóninum skrifréttindi í rótarmöppuna. Skoðaðu %s.",
+    "Your data directory is not writable." : "Gagnamappn þín er ekki lesanleg.",
+    "Setting locale to %s failed." : "Mistókst að setja upp staðfærsluna %s.",
+    "Please install one of these locales on your system and restart your web server." : "Settu upp eina af þessum staðfærslum og endurræstu vefþjóninn.",
     "PHP module %s not installed." : "PHP-einingin %s er ekki uppsett.",
     "Please ask your server administrator to install the module." : "Biddu kerfisstjórann þinn um að setja eininguna upp.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP-stillingin \"%s\" er ekki sett á \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ef þessi stilling er löguð í php.ini mun Nextcloud keyra aftur",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> er stillt á <code>%s</code> í stað gildisins \"<code>0</code> eins og vænst var.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Til að laga þetta vandamál ættirðu að setja <code>mbstring.func_overload</code> sem <code>0</code> í php.ini.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP virðist vera sett upp to fjarlægja innantextablokkir (inline doc blocks). Þetta mun gera ýmis kjarnaforrit óaðgengileg.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Þessu veldur væntanlega biðminni/hraðall á borð við Zend OPcache eða eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Búið er að setja upp PHP-einingar, en eru þær ennþá taldar upp eins og þær vanti?",
     "Please ask your server administrator to restart the web server." : "Biddu kerfisstjórann þinn um að endurræsa vefþjóninn.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endilega breyttu heimildunum í 0770 svo að aðrir notendur geti ekki listað upp innihald hennar.",
+    "The required %s config variable is not configured in the config.php file." : "Nauðsynleg %s stillingabreyta er ekki stillt í config.php file.",
+    "Please ask your server administrator to check the Nextcloud configuration." : "Biddu kerfisstjórann þinn um að athuga uppsetninguna á Nextcloud.",
+    "Your data directory must be an absolute path." : "Gagnamappan þín verður að vera með algilda slóð.",
+    "Check the value of \"datadirectory\" in your configuration." : "Athugaðu gildi \"datadirectory\" í uppsetningunni þinni.",
+    "Your data directory is invalid." : "Gagnamappan þín er ógild.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Gakktu úr skugga um að til staðar sé skrá með heitinu \".ocdata\" í rót gagnageymslunnar.",
     "Action \"%s\" not supported or implemented." : "Aðgerðin \"%s\" er ekki studd eða útfærð.",
     "Authentication failed, wrong token or provider ID given" : "Auðkenning mistókst, uppgefið rangt teikn eða auðkenni þjónustuveitu",
@@ -198,14 +240,41 @@ OC.L10N.register(
     "Storage connection error. %s" : "Villa í tengingu við gagnageymslu. %s",
     "Storage is temporarily not available" : "Gagnageymsla ekki tiltæk í augnablikinu",
     "Storage connection timeout. %s" : "Gagnageymsla féll á tíma. %s",
+    "Free prompt" : "Frjáls kvaðning",
+    "Runs an arbitrary prompt through the language model." : "Keyrir óreglulega kvaðningu (prompt) í gegnum tungumálslíkanið.",
+    "Generate headline" : "Útbúa fyrirsögn",
+    "Generates a possible headline for a text." : "Útbýr mögulega fyrirsögn fyrir texta.",
+    "Summarize" : "Gera samantekt",
+    "Summarizes text by reducing its length without losing key information." : "Tekur saman aðalatriði texta með því að stytta hann án þess að tapa mikilvægustu upplýsingum.",
+    "Extract topics" : "Taka út efnisflokka",
+    "Extracts topics from a text and outputs them separated by commas." : "Greinir efnisflokka úr texta og aðskilur þá með kommum.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Skrám forritsins %$1s var ekki rétt skipt út. Gakktu úr skugga um að þetta sé útgáfa sem sé samhæfð útgáfu vefþjónsins.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Innskráður notandi verður að vera kerfisstjóri eða undirstjórnandi eða hafa fengið sérstaka aðgangsheimild fyrir þessa stillingu",
+    "Logged in user must be an admin or sub admin" : "Innskráður notandi verður að vera kerfisstjóri eða undirstjórnandi",
+    "Logged in user must be an admin" : "Innskráður notandi verður að vera stjórnandi",
     "Full name" : "Fullt nafn",
-    "%s enter the database username and name." : "%s settu inn notandanafn og nafn á gagnagrunni.",
-    "%s enter the database username." : "%s settu inn notandanafn í gagnagrunni.",
-    "%s enter the database name." : "%s settu inn nafn á gagnagrunni.",
-    "%s you may not use dots in the database name" : "%s þú mátt ekki nota punkta í nafni á gagnagrunni",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Einungis eru leyfilegir eftirfarandi stafir í notandanafni: \"a-z\", \"A-Z\", \"0-9\", og \"_.@-'\"",
+    "Unknown user" : "Óþekktur notandi",
+    "Enter the database username and name for %s" : "Settu inn notandanafn og nafn í gagnagrunni fyrir %s",
+    "Enter the database username for %s" : "Settu inn notandanafn í gagnagrunni fyrir %s",
+    "MySQL username and/or password not valid" : "Notandanafn eða lykilorð MySQL er ekki gilt",
+    "Oracle username and/or password not valid" : "Notandanafn eða lykilorð Oracle er ekki gilt",
+    "PostgreSQL username and/or password not valid" : "Notandanafn eða lykilorð PostgreSQL er ekki gilt",
+    "Set an admin username." : "Stilltu notandanafn kerfisstjóra.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Deiling %s mistókst, því þessu atriði er þegar deilt með notandanum %s",
+    "The username is already being used" : "Notandanafnið er þegar í notkun",
+    "Could not create user" : "Gat ekki búið til notanda",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Einungis eru leyfilegir eftirfarandi stafir í notandanafni: \"a-z\", \"A-Z\", \"0-9\", bil og \"_.@-'\"",
+    "A valid username must be provided" : "Skráðu inn gilt notandanafn",
+    "Username contains whitespace at the beginning or at the end" : "Notandanafnið inniheldur orðabil í upphafi eða enda",
+    "Username must not consist of dots only" : "Notandanafn má ekki einungis samanstanda af punktum",
+    "Username is invalid because files already exist for this user" : "Notandanafnið er ógilt vegna þess að þegar eru fyrir hendi skrár sem tilheyra þessum notanda",
+    "User disabled" : "Notandi óvirkur",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Krafist er libxml2 2.7.0 hið minnsta. Núna er %s uppsett.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Til að laga þetta vandamál ættirðu að uppfæra útgáfu þína af libxml2 og endurræsa vefþjóninn."
+    "To fix this issue update your libxml2 version and restart your web server." : "Til að laga þetta vandamál ættirðu að uppfæra útgáfu þína af libxml2 og endurræsa vefþjóninn.",
+    "PostgreSQL >= 9 required." : "Krefst PostgreSQL >= 9.",
+    "Please upgrade your database version." : "Uppfærðu útgáfu gagnagrunnsins.",
+    "Your data directory is readable by other users." : "Gagnamappn þín er lesanleg fyrir aðra notendur.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endilega breyttu heimildunum í 0770 svo að aðrir notendur geti ekki listað upp innihald hennar."
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
