@@ -5,14 +5,14 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella config.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ma, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true.",
     "See %s" : "Vedi %s",
-    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "L'applicazione %1$s non è presente o ha una versione non compatibile con questo server. Controlla l'elenco delle app.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "L'applicazione %1$s non è presente o ha una versione non compatibile con questo server. Controlla l'elenco delle applicazioni.",
     "Sample configuration detected" : "Configurazione di esempio rilevata",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "È stato rilevato che la configurazione di esempio è stata copiata. Ciò può compromettere la tua installazione e non è supportato. Leggi la documentazione prima di modificare il file config.php",
     "The page could not be found on the server." : "Impossibile trovare la pagina sul server.",
     "%s email verification" : "Verifica email di %s",
     "Email verification" : "Verifica email",
-    "Click the following button to confirm your email." : "Clicca il pulsante seguente per confermare la tua email.",
-    "Click the following link to confirm your email." : "Clicca il collegamento seguente per confermare la tua email.",
+    "Click the following button to confirm your email." : "Fai clic sul pulsante seguente per confermare la tua email.",
+    "Click the following link to confirm your email." : "Fai clic sul collegamento seguente per confermare la tua email.",
     "Confirm your email" : "Conferma la tua email",
     "Other activities" : "Altre attività",
     "%1$s and %2$s" : "%1$s e %2$s",
@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Le seguenti piattaforme sono supportate: %s",
     "Server version %s or higher is required." : "È richiesta la versione %s o successiva.",
     "Server version %s or lower is required." : "È richiesta la versione %s o precedente.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utente connesso deve essere un admin, un sub admin o avere il permesso di accedere a questa impostazione",
-    "Logged in user must be an admin or sub admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore o sub-amministratore",
-    "Logged in user must be an admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore ",
     "Wiping of device %s has started" : "La cancellazione del dispositivo %s è iniziata",
     "Wiping of device »%s« has started" : "La cancellazione del dispositivo «%s» è iniziata",
     "»%s« started remote wipe" : "«%s» ha iniziato la cancellazione remota",
@@ -117,22 +114,15 @@ OC.L10N.register(
     "Headline" : "Titolo",
     "Organisation" : "Organizzazione",
     "Role" : "Ruolo",
-    "Unknown user" : "Utente sconosciuto",
     "Additional settings" : "Impostazioni aggiuntive",
-    "Enter the database username and name for %s" : "Inserisci il nome utente del database e il nome per %s",
-    "Enter the database username for %s" : "Inserisci il nome utente del database per %s",
     "Enter the database name for %s" : "Inserisci il nome del database per %s",
     "You cannot use dots in the database name %s" : "Non puoi usare punti nel nome del database %s",
-    "MySQL username and/or password not valid" : "Nome utente e/o password di MySQL non validi",
     "You need to enter details of an existing account." : "Devi inserire i dettagli di un account esistente.",
     "Oracle connection could not be established" : "La connessione a Oracle non può essere stabilita",
-    "Oracle username and/or password not valid" : "Nome utente e/o password di Oracle non validi",
-    "PostgreSQL username and/or password not valid" : "Nome utente e/o password di PostgreSQL non validi",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X non è supportato e %s non funzionerà correttamente su questa piattaforma. Usalo a tuo rischio!",
     "For the best results, please consider using a GNU/Linux server instead." : "Per avere il risultato migliore, prendi in considerazione l'utilizzo di un server GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Sembra che questa istanza di %s sia in esecuzione in un ambiente PHP a 32 bit e che open_basedir sia stata configurata in php.ini. Ciò comporterà problemi con i file più grandi di 4 GB ed è altamente sconsigliato.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Rimuovi l'impostazione di open_basedir nel tuo php.ini o passa alla versione a 64 bit di PHP.",
-    "Set an admin username." : "Imposta un nome utente di amministrazione.",
     "Set an admin password." : "Imposta una password di amministrazione.",
     "Cannot create or write into the data directory %s" : "Impossibile creare o scrivere nella cartella dei dati %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Il motore di condivisione %s deve implementare l'interfaccia OCP\\Share_Backend",
@@ -150,7 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "La data di scadenza è nel passato",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossibile impostare la data di scadenza a più di %n giorni nel futuro","Impossibile impostare la data di scadenza a più di %n giorni nel futuro","Impossibile impostare la data di scadenza a più di %n giorni nel futuro"],
     "Sharing is only allowed with group members" : "La condivisione è consentita solo con i membri del gruppo",
-    "Sharing %s failed, because this item is already shared with user %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con l'utente %s",
     "%1$s shared »%2$s« with you" : "%1$s ha condiviso «%2$s» con te",
     "%1$s shared »%2$s« with you." : "%1$s ha condiviso «%2$s» con te.",
     "Click the button below to open it." : "Fai clic sul pulsante sotto per aprirlo.",
@@ -204,20 +193,12 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dic.",
     "A valid password must be provided" : "Deve essere fornita una password valida",
-    "The username is already being used" : "Il nome utente è già utilizzato",
-    "Could not create user" : "Impossibile creare l'utente",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Solo i seguenti caratteri sono consentiti in un nome utente: \"a-z\", \"A-Z\", \"0-9\", spazi e \"_.@-'\"",
-    "A valid username must be provided" : "Deve essere fornito un nome utente valido",
-    "Username contains whitespace at the beginning or at the end" : "Il nome utente contiene spazi all'inizio o alla fine",
-    "Username must not consist of dots only" : "Il nome utente non può consistere di soli punti",
-    "Username is invalid because files already exist for this user" : "Il nome utente non è valido poiché esiste già per questo utente",
-    "User disabled" : "Utente disabilitato",
     "Login canceled by app" : "Accesso annullato dall'applicazione",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'applicazione \"%1$s\" non può essere installata poiché le seguenti dipendenze non sono soddisfatte: %2$s",
     "a safe home for all your data" : "un posto sicuro per tutti i tuoi dati",
     "File is currently busy, please try again later" : "Il file è attualmente occupato, riprova più tardi",
     "Cannot download file" : "Impossibile scaricare il file",
-    "Application is not enabled" : "L'applicazione  non è abilitata",
+    "Application is not enabled" : "L'applicazione non è abilitata",
     "Authentication error" : "Errore di autenticazione",
     "Token expired. Please reload page." : "Token scaduto. Ricarica la pagina.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Nessun driver di database (sqlite, mysql o postgresql) installato",
@@ -225,7 +206,7 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella config. Vedi %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "O, se preferisci mantenere il file config.php in sola lettura, imposta l'opzione \"config_is_read_only\" a true. Vedi %s",
     "Cannot write into \"apps\" directory." : "Impossibile scrivere nella cartella \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella apps o disattivando il negozio delle applicazioni nel file di configurazione.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella delle applicazioni o disattivando il negozio delle applicazioni nel file di configurazione.",
     "Cannot create \"data\" directory." : "Impossibile creare la cartella \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ciò può essere corretto di solito fornendo al server web accesso in scrittura alla cartella radice. Vedi %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "I permessi possono essere corretti di solito fornendo al server web accesso in scrittura alla cartella radice. Vedi %s.",
@@ -244,8 +225,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Chiedi all'amministratore di riavviare il server web.",
     "The required %s config variable is not configured in the config.php file." : "La variabile %s necessaria non è configurata nel file config.php .",
     "Please ask your server administrator to check the Nextcloud configuration." : "Chiedi all'amministratore del server di controllare la configurazione di Nextcloud.",
-    "Your data directory is readable by other users." : "La cartella dei dati è leggibile dagli altri utenti.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Modifica i permessi in 0770 in modo tale che la cartella non sia leggibile dagli altri utenti.",
     "Your data directory must be an absolute path." : "La cartella dei dati deve essere un percorso assoluto.",
     "Check the value of \"datadirectory\" in your configuration." : "Controlla il valore di \"datadirectory\" nella tua configurazione.",
     "Your data directory is invalid." : "La cartella dei dati non è valida.",
@@ -270,13 +249,32 @@ OC.L10N.register(
     "Extract topics" : "Estrai argomenti",
     "Extracts topics from a text and outputs them separated by commas." : "Estrae gli argomenti da un testo e li elenca separati da virgole.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "I file dell'applicazione %1$s non sono stati sostituiti correttamente. Assicurati che sia una versione compatibile con il server.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utente connesso deve essere un admin, un sub admin o avere il permesso di accedere a questa impostazione",
+    "Logged in user must be an admin or sub admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore o sub-amministratore",
+    "Logged in user must be an admin" : "L'utente che ha eseguito l'accesso deve essere un amministratore ",
     "Full name" : "Nome completo",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "È stato raggiunto il limite di utenti e l'utente non è stato creato. Controlla le notifiche per maggiori informazioni.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Solo i seguenti caratteri sono consentiti in un nome utente: \"a-z\", \"A-Z\", \"0-9\", e \"_.@-'\"",
+    "Unknown user" : "Utente sconosciuto",
+    "Enter the database username and name for %s" : "Inserisci il nome utente del database e il nome per %s",
+    "Enter the database username for %s" : "Inserisci il nome utente del database per %s",
+    "MySQL username and/or password not valid" : "Nome utente e/o password di MySQL non validi",
+    "Oracle username and/or password not valid" : "Nome utente e/o password di Oracle non validi",
+    "PostgreSQL username and/or password not valid" : "Nome utente e/o password di PostgreSQL non validi",
+    "Set an admin username." : "Imposta un nome utente di amministrazione.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Condivisione di %s non riuscita, poiché l'oggetto è già condiviso con l'utente %s",
+    "The username is already being used" : "Il nome utente è già utilizzato",
+    "Could not create user" : "Impossibile creare l'utente",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Solo i seguenti caratteri sono consentiti in un nome utente: \"a-z\", \"A-Z\", \"0-9\", spazi e \"_.@-'\"",
+    "A valid username must be provided" : "Deve essere fornito un nome utente valido",
+    "Username contains whitespace at the beginning or at the end" : "Il nome utente contiene spazi all'inizio o alla fine",
+    "Username must not consist of dots only" : "Il nome utente non può consistere di soli punti",
+    "Username is invalid because files already exist for this user" : "Il nome utente non è valido poiché esiste già per questo utente",
+    "User disabled" : "Utente disabilitato",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "È richiesta almeno la versione 2.7.0 di libxml2. Quella attualmente installata è la %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Per risolvere questo problema, aggiorna la tua versione di libxml2 e riavvia il server web.",
     "PostgreSQL >= 9 required." : "Richiesto PostgreSQL >= 9.",
     "Please upgrade your database version." : "Aggiorna la versione del tuo database.",
-    "404" : "404"
+    "Your data directory is readable by other users." : "La cartella dei dati è leggibile dagli altri utenti.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Modifica i permessi in 0770 in modo tale che la cartella non sia leggibile dagli altri utenti."
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
