@@ -20,7 +20,6 @@ OC.L10N.register(
     "The library %s is not available." : "ბიბლიოთეკა %s ვერ იქნა ნაპოვნი.",
     "Server version %s or higher is required." : "საჭიროა სერვერი ვერსიით %s ან მეტი.",
     "Server version %s or lower is required." : "საჭიროა სერვერი ვერსიით %s ან ნაკლები.",
-    "Logged in user must be an admin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ადმინისტრატორი",
     "Authentication" : "აუტენტიფიკაცია",
     "Unknown filetype" : "ამოუცნობი ფაილის ტიპი",
     "Invalid image" : "არასწორი სურათი",
@@ -68,17 +67,13 @@ OC.L10N.register(
     "Address" : "მისამართი",
     "Profile picture" : "პროფილის სურათი",
     "About" : "შესახებ",
-    "Unknown user" : "ამოუცნობი მომხმარებელი",
     "Additional settings" : "დამატებითი პარამეტრები",
     "You need to enter details of an existing account." : "საჭიროა შეიყვანოთ არსებული ანგარიშის დეტალები.",
     "Oracle connection could not be established" : "Oracle კავშირი ვერ დამყარდა",
-    "Oracle username and/or password not valid" : "Oracle მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X არაა მხარდაჭერილი და %s ამ პლატფორმაზე სწორად არ იმუშავებს. გამოიყენეთ საკუთარი რისკით!",
     "For the best results, please consider using a GNU/Linux server instead." : "საუკეთესო შედეგებისთვის სანაცვლოდ გამოიყენეთ GNU/Linux სერვერი.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "როგორც ჩანს ეს %s ინსტანცია მოქმედებს 32-ბიტიან PHP გარემოზე და open_basedir php.ini-ში კონფიგურირებულია. ეს 4 გბ-ზე დიდ ფაილებთან გამოიწვევს პრობლემს და რეკომედირებული არაა.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "გთხოვთ ამოშალოთ open_basedir პარამეტრი php.ini-დან ან გადახვიდეთ 64-ბიტიან PHP-ზე.",
-    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
     "Set an admin password." : "დააყენეთ ადმინისტრატორის პაროლი.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "გაზიარების ბექენდმა %s-მ მოქმედებაში უნდა მოიყვანოს ინტეფეისი OCP\\Share_Backend",
     "Sharing backend %s not found" : "გაზიარების ბექენდი %s ვერ იქნა ნაპოვნი",
@@ -87,7 +82,6 @@ OC.L10N.register(
     "You are not allowed to share %s" : "თქვენ არ გაქვთ უფლება გააზიაროთ %s",
     "Cannot increase permissions of %s" : "%s-ის უფლებების გაზრდა ვერ ხერხდება",
     "Expiration date is in the past" : "ვადის ამოწურვის თარიღი წარსულშია",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s-ის გაზიარება არ მოხერხდა, რადგან ობიექტი მომხმარებელ %s-თან უკვე გაზიარებულია",
     "Click the button below to open it." : "გასახსნელად დააჭირეთ ქვემოთ მყოფ ღილაკს.",
     "The requested share does not exist anymore" : "მოთხოვნილი გაზიარება მეტი აღარ არსებობს",
     "Could not find category \"%s\"" : "\"%s\" კატეგორიის მოძებნა ვერ მოხერხდა",
@@ -137,12 +131,6 @@ OC.L10N.register(
     "Nov." : "ნოე.",
     "Dec." : "დეკ.",
     "A valid password must be provided" : "უნდა მიუთითოთ სწორი პაროლი",
-    "The username is already being used" : "ესეთი მომხმარებლის სახელი უკვე არსებობს",
-    "Could not create user" : "მომხმარებლის შექმნა ვერ მოხერხდა",
-    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
-    "Username contains whitespace at the beginning or at the end" : "მომხმარებლის სახელი დასაწყისსში ან დასასრულში მოიცავს სიცარიელეს",
-    "Username must not consist of dots only" : "მომხმარებლის სახელი ვერ იქნება შემდგარი მხოლოდ წერტილებისგან",
-    "User disabled" : "მომხმარებელი გათიშულია",
     "Login canceled by app" : "აპლიკაციამ ლოგინი უარყო",
     "a safe home for all your data" : "უსაფრთხო სახლი მთელი თქვენი მონაცემებისათვის",
     "File is currently busy, please try again later" : "ფაილი ამჟამად დაკავებულია, გთხოვთ მოგვიანებით სცადოთ ახლიდან",
@@ -158,7 +146,6 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "ეს შესაძლოა გამოწვეული იყოს ისეთი კეშით/აქსელერატორით როგორიცაა Zend OPcache ან eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP მოდულები დაყენდა, მაგრამ მაინც ჩამოწერილია როგორც არმყოფები?",
     "Please ask your server administrator to restart the web server." : "გთხოვთ სთხოვოთ თქვენს სერვერის ადმინისტრატორს გადატვირთოს ვებ-სერვერი.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "გთხოვთ შეცვალოთ უფლებები 0770-ზე, რათა დირექტორია სხვა მომხმარებლების მიერ აღარ იყოს კითხვადი.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "დარწმუნდით რომ ფაილი სახელად \".ocdata\" მონაცემების დირექტორიის საწყისშია.",
     "Could not obtain lock type %d on \"%s\"." : "ჩაკეთვის ტიპის %d მოძიება \"%s\"-ზე ვერ მოხერხდა.",
     "Storage unauthorized. %s" : "საცავი არაავტორიზირებულია. %s",
@@ -166,13 +153,21 @@ OC.L10N.register(
     "Storage connection error. %s" : "საცავის კავშირის შეცდომა. %s",
     "Storage is temporarily not available" : "საცავი დროებით ხელმიუწვდომელია",
     "Storage connection timeout. %s" : "საცავის კავშირის დროის ამოწურვა. %s",
+    "Logged in user must be an admin" : "ავტორიზირებული მომხმარებელი უნდა იყოს ადმინისტრატორი",
     "Full name" : "სრული სახელი",
-    "%s enter the database username and name." : "%s შეიყვანეთ მონაცემთა ბაზის მომხმარებლის სახელი და სახელი.",
-    "%s enter the database username." : "%s შეიყვანეთ ბაზის მომხმარებლის სახელი.",
-    "%s enter the database name." : "%s შეიყვანეთ ბაზის სახელი.",
-    "%s you may not use dots in the database name" : "%s არ მიუთითოთ წერტილი ბაზის სახელში",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "მომხმარებლის სახელში დაშვებულია მხოლოდ შემდეგი ნიშნები: \"a-z\", \"A-Z\", \"0-9\", და \"_.@-'\"",
+    "Unknown user" : "ამოუცნობი მომხმარებელი",
+    "Oracle username and/or password not valid" : "Oracle მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL მომხმარებლის სახელი და/ან პაროლი არ არის სწორი",
+    "Set an admin username." : "დააყენეთ ადმინისტრატორის სახელი.",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s-ის გაზიარება არ მოხერხდა, რადგან ობიექტი მომხმარებელ %s-თან უკვე გაზიარებულია",
+    "The username is already being used" : "ესეთი მომხმარებლის სახელი უკვე არსებობს",
+    "Could not create user" : "მომხმარებლის შექმნა ვერ მოხერხდა",
+    "A valid username must be provided" : "უნდა მიუთითოთ არსებული მომხმარებლის სახელი",
+    "Username contains whitespace at the beginning or at the end" : "მომხმარებლის სახელი დასაწყისსში ან დასასრულში მოიცავს სიცარიელეს",
+    "Username must not consist of dots only" : "მომხმარებლის სახელი ვერ იქნება შემდგარი მხოლოდ წერტილებისგან",
+    "User disabled" : "მომხმარებელი გათიშულია",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "საჭიროა libxml2 ვერსიით 2.7.0 ან მეტი. ახლა დაყენებულია %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "ამ პრობლემის მოსაგვარებლად განაახლეთ libxml2 ვერსია და გადატვირთეთ თქვენი ვებ-სერვერი."
+    "To fix this issue update your libxml2 version and restart your web server." : "ამ პრობლემის მოსაგვარებლად განაახლეთ libxml2 ვერსია და გადატვირთეთ თქვენი ვებ-სერვერი.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "გთხოვთ შეცვალოთ უფლებები 0770-ზე, რათა დირექტორია სხვა მომხმარებლების მიერ აღარ იყოს კითხვადი."
 },
 "nplurals=2; plural=(n!=1);");
