@@ -35,9 +35,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Следниве платформи се поддржани: %s",
     "Server version %s or higher is required." : "Потребна е верзија %s или поголема на серверот.",
     "Server version %s or lower is required." : "Потербна е верзија %s или помала на серверот.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Најавените корисници мора да бидат администратори, ко-администратори или да имаат специјални дозволи за да пристапат до овие поставки",
-    "Logged in user must be an admin or sub admin" : "Најавениот корисник мора да биде администратор или заменик администратор",
-    "Logged in user must be an admin" : "Најавениот корисник мора да биде администратор",
     "Wiping of device %s has started" : "Започна бришење на уредот %s",
     "Wiping of device »%s« has started" : "Започна бришење на уредот »%s«",
     "»%s« started remote wipe" : "Запошна далечинско бришење на уредот »%s«",
@@ -116,22 +113,15 @@ OC.L10N.register(
     "Headline" : "Наслов",
     "Organisation" : "Организација",
     "Role" : "Улога",
-    "Unknown user" : "Непознат корисник",
     "Additional settings" : "Дополнителни параметри",
-    "Enter the database username and name for %s" : "Внесете го корисничкото име и името на базата за %s",
-    "Enter the database username for %s" : "Внесете го корисничкото име на базата за %s",
     "Enter the database name for %s" : "Внесете го името на базата за %s",
     "You cannot use dots in the database name %s" : "Не можеш да користиш точки во името на базата %s",
-    "MySQL username and/or password not valid" : "Погрешно MySQL корисничко име и/или лозинка",
     "You need to enter details of an existing account." : "Потребно е да внесете детали од постоечката сметка.",
     "Oracle connection could not be established" : "Oracle врската неможе да се воспостави",
-    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не е поддржана и %s нема да работи соодветно на оваа платформа. Користењето е на ваш ризик! ",
     "For the best results, please consider using a GNU/Linux server instead." : "За најдобри резултати, размислете за користење на сервер со GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Највероватно оваа истанца %s е стартувана на 32-битна PHP средина и open_basedir е конфигурано во php.ini. Ова ќе прави проблеми со датотеки поголеми од 4 GB.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Отстранете го параметарот open_basedir од php.ini или преминете на 64-битна PHP средина.",
-    "Set an admin username." : "Постави администраторско корисничко име",
     "Set an admin password." : "Постави администраторска лозинка.",
     "Cannot create or write into the data directory %s" : "Неможете да креирате или да запишувате во папката за податоци %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "За позадинското споделување %s мора се имплементира интерфејсот OCP\\Share_Backend",
@@ -149,7 +139,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Рокот на траење е во минато време",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможе да се постави рок на траење повеќе од 1 ден","Неможе да се постави рок на траење повеќе од %s дена"],
     "Sharing is only allowed with group members" : "Споделувањето е овозможено само со членови на групата",
-    "Sharing %s failed, because this item is already shared with user %s" : "Споделувањето на %s е неуспешно, бидејќи истото веќе е споделено со корисникот %s",
     "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« со вас",
     "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« со вас.",
     "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
@@ -202,14 +191,6 @@ OC.L10N.register(
     "Nov." : "Ное.",
     "Dec." : "Дек.",
     "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
-    "The username is already being used" : "Корисничкото име е веќе во употреба",
-    "Could not create user" : "Неможе да се креира корисник",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Само следниве карактери се дозволени во корисничкото име: \"a-z\", \"A-Z\", \"0-9\", празно место и \"_.@-'\"",
-    "A valid username must be provided" : "Мора да се внесе валидно корисничко име ",
-    "Username contains whitespace at the beginning or at the end" : "Корисничкото име содржи празно место на почетокот или на крајот",
-    "Username must not consist of dots only" : "Корисничкото име не смее да се состои само од точки",
-    "Username is invalid because files already exist for this user" : "Невалидно корисничкото име бидејќи веќе постојат датотеки за овој корисник",
-    "User disabled" : "Оневозможен корисник",
     "Login canceled by app" : "Најавата е одкажана од апликација",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликацијата \"%1$s\" не може да се инсталира затоа што следниве зависности не се исполнети: %2$s",
     "a safe home for all your data" : "безбеден дом за сите ваши податоци",
@@ -242,8 +223,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Замолете го сервер администраторот да го рестартира веб серверот.",
     "The required %s config variable is not configured in the config.php file." : "Потребната променлива %s не е конфигурирана config.php датотеката.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Замолете го сервер администраторот да ја провери конфигурацијата.",
-    "Your data directory is readable by other users." : "Вашата папка со податоци може да се чита и од други корисници.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Поставете дозвола на папката 0770, за да неможе да се чита од други корисници.",
     "Your data directory must be an absolute path." : "Вашата папка со податоци мора да биде апсолутна патека.",
     "Check the value of \"datadirectory\" in your configuration." : "Проверете ја вредноста на \"datadirectory\" во вашата конфигурација.",
     "Your data directory is invalid." : "Вашата папка со податоци не е валидна.",
@@ -262,10 +241,31 @@ OC.L10N.register(
     "Generate headline" : "Генерирај заглавие",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Датотеките од аоликацијата %1$s не се преклопени коректно. Проверете дали верзијата е компатибилна со серверот.",
     "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Најавените корисници мора да бидат администратори, ко-администратори или да имаат специјални дозволи за да пристапат до овие поставки",
+    "Logged in user must be an admin or sub admin" : "Најавениот корисник мора да биде администратор или заменик администратор",
+    "Logged in user must be an admin" : "Најавениот корисник мора да биде администратор",
     "Full name" : "Цело име",
+    "Unknown user" : "Непознат корисник",
+    "Enter the database username and name for %s" : "Внесете го корисничкото име и името на базата за %s",
+    "Enter the database username for %s" : "Внесете го корисничкото име на базата за %s",
+    "MySQL username and/or password not valid" : "Погрешно MySQL корисничко име и/или лозинка",
+    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
+    "Set an admin username." : "Постави администраторско корисничко име",
+    "Sharing %s failed, because this item is already shared with user %s" : "Споделувањето на %s е неуспешно, бидејќи истото веќе е споделено со корисникот %s",
+    "The username is already being used" : "Корисничкото име е веќе во употреба",
+    "Could not create user" : "Неможе да се креира корисник",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Само следниве карактери се дозволени во корисничкото име: \"a-z\", \"A-Z\", \"0-9\", празно место и \"_.@-'\"",
+    "A valid username must be provided" : "Мора да се внесе валидно корисничко име ",
+    "Username contains whitespace at the beginning or at the end" : "Корисничкото име содржи празно место на почетокот или на крајот",
+    "Username must not consist of dots only" : "Корисничкото име не смее да се состои само од точки",
+    "Username is invalid because files already exist for this user" : "Невалидно корисничкото име бидејќи веќе постојат датотеки за овој корисник",
+    "User disabled" : "Оневозможен корисник",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Потербна минимална верзија на libxml2 е 2.7.0. Моментална верзија е %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "За да го поправите овој проблем, ажурирајте ја верзијата на libxml2 и рестартирајте го вашиот веб сервер.",
     "PostgreSQL >= 9 required." : "Потребно е PostgreSQL >= 9 ",
-    "Please upgrade your database version." : "Ве молиме надградете ја верзијата на базата со податоци"
+    "Please upgrade your database version." : "Ве молиме надградете ја верзијата на базата со податоци",
+    "Your data directory is readable by other users." : "Вашата папка со податоци може да се чита и од други корисници.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Поставете дозвола на папката 0770, за да неможе да се чита од други корисници."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
