@@ -35,9 +35,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "De volgende platforms worden ondersteund: %s",
     "Server version %s or higher is required." : "Serverversie %s of hoger vereist.",
     "Server version %s or lower is required." : "Serverversie %s of lager vereist.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Ingelogde gebruiken moet beheerder, sub-beheerder of gebruiker met speciale rechten om deze instelling te veranderen zijn",
-    "Logged in user must be an admin or sub admin" : "Ingelogde gebruiker moet een beheerder of subbeheerder zijn",
-    "Logged in user must be an admin" : "Ingelogde gebruiker moet een beheerder zijn",
     "Wiping of device %s has started" : "Leegmaken van toestel %sis gestart",
     "Wiping of device »%s« has started" : "Leegmaken van toestel  \"%s\" is gestart",
     "»%s« started remote wipe" : "\"%s\" startte leegmaken op afstand",
@@ -112,18 +109,13 @@ OC.L10N.register(
     "Headline" : "Hoofdlijn",
     "Organisation" : "Organisatie",
     "Role" : "Rol",
-    "Unknown user" : "Onbekende gebruiker",
     "Additional settings" : "Aanvullende instellingen",
-    "MySQL username and/or password not valid" : "MySQL gebruikersnaam en/of wachtwoord ongeldig",
     "You need to enter details of an existing account." : "Geef de details van een bestaand account op.",
     "Oracle connection could not be established" : "Er kon geen verbinding met Oracle worden gemaakt.",
-    "Oracle username and/or password not valid" : "Oracle gebruikersnaam en/of wachtwoord ongeldig",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL gebruikersnaam en/of wachtwoord ongeldig",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OSX wordt niet ondersteund en %s zal niet goed werken op dit platform. Gebruik het op eigen risico!",
     "For the best results, please consider using a GNU/Linux server instead." : "Voor het beste resultaat adviseren wij het gebruik van een GNU/Linux server.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Het lijkt erop dat deze %s versie draait in een 32 bits PHP omgeving en dat open_basedir is geconfigureerd in php.ini. Dat zal leiden tot problemen met bestanden groter dan 4 GB en wordt dus sterk afgeraden.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Verwijder de open_basedir instelling in php.ini of schakel over op de 64bit PHP.",
-    "Set an admin username." : "Stel de gebruikersnaam van de beheerder in.",
     "Set an admin password." : "Stel een beheerders wachtwoord in.",
     "Cannot create or write into the data directory %s" : "Kan niets creëren of wegschrijven in de datadirectory %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "De gedeelde achtergrond %s moet de OCP\\Share_Backend interface implementeren",
@@ -141,7 +133,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "De vervaldatum ligt in het verleden",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan de vervaldatum niet meer dan %s dag in de toekomst instellen","Kan de vervaldatum niet meer dan %s dagen in de toekomst instellen"],
     "Sharing is only allowed with group members" : "Delen kan alleen met groepsleden",
-    "Sharing %s failed, because this item is already shared with user %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met gebruiker %s",
     "%1$s shared »%2$s« with you" : "%1$s deelde \"%2$s\" met jou",
     "%1$s shared »%2$s« with you." : "%1$s deelde \"%2$s\" met jou.",
     "Click the button below to open it." : "Klik de onderstaande button om te openen.",
@@ -193,13 +184,6 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dec.",
     "A valid password must be provided" : "Er moet een geldig wachtwoord worden opgegeven",
-    "The username is already being used" : "De gebruikersnaam bestaat al",
-    "Could not create user" : "Kan gebruiker niet aanmaken.",
-    "A valid username must be provided" : "Er moet een geldige gebruikersnaam worden opgegeven",
-    "Username contains whitespace at the beginning or at the end" : "De gebruikersnaam bevat spaties aan het begin of aan het eind",
-    "Username must not consist of dots only" : "De gebruikersnaam mag niet uit alleen punten bestaan",
-    "Username is invalid because files already exist for this user" : "Gebruikersnaam is ongeldig omdat er al bestanden voor deze gebruiker bestaan",
-    "User disabled" : "Gebruiker uitgeschakeld",
     "Login canceled by app" : "Inloggen geannuleerd door app",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "App \"%1$s\" kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld: %2$s",
     "a safe home for all your data" : "een veilige plek voor al je gegevens",
@@ -229,8 +213,6 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dit wordt vermoedelijk veroorzaakt door een cache/accelerator, zoals Zend OPcache of eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modules zijn geïnstalleerd, maar ze worden nog steeds als ontbrekend aangegeven?",
     "Please ask your server administrator to restart the web server." : "Vraag je beheerder de webserver opnieuw te starten.",
-    "Your data directory is readable by other users." : "Je datamap is leesbaar voor andere gebruikers.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Wijzig de machtiging in 0770 zodat de directory niet door andere gebruikers bekeken kan worden.",
     "Your data directory must be an absolute path." : "Je datamap moet een absolute bestandslocatie hebben.",
     "Check the value of \"datadirectory\" in your configuration." : "Controleer de waarde van \"datadirectory\" in je configuratie.",
     "Your data directory is invalid." : "Je datamap is ongeldig.",
@@ -247,11 +229,28 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Opslag is tijdelijk niet beschikbaar",
     "Storage connection timeout. %s" : "Opslag verbinding time-out. %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "De bestanden van app %1$szijn niet correct vervangen. Zorg ervoor dat de versie compatible is met de server.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Ingelogde gebruiken moet beheerder, sub-beheerder of gebruiker met speciale rechten om deze instelling te veranderen zijn",
+    "Logged in user must be an admin or sub admin" : "Ingelogde gebruiker moet een beheerder of subbeheerder zijn",
+    "Logged in user must be an admin" : "Ingelogde gebruiker moet een beheerder zijn",
     "Full name" : "Volledige naam",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Alleen de volgende tekens zijn toegestaan in een gebruikersnaam: \"a-z\", \"A-Z\", \"0-9\", en \"_.@-\"",
+    "Unknown user" : "Onbekende gebruiker",
+    "MySQL username and/or password not valid" : "MySQL gebruikersnaam en/of wachtwoord ongeldig",
+    "Oracle username and/or password not valid" : "Oracle gebruikersnaam en/of wachtwoord ongeldig",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL gebruikersnaam en/of wachtwoord ongeldig",
+    "Set an admin username." : "Stel de gebruikersnaam van de beheerder in.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Delen van %s is mislukt, omdat het object al wordt gedeeld met gebruiker %s",
+    "The username is already being used" : "De gebruikersnaam bestaat al",
+    "Could not create user" : "Kan gebruiker niet aanmaken.",
+    "A valid username must be provided" : "Er moet een geldige gebruikersnaam worden opgegeven",
+    "Username contains whitespace at the beginning or at the end" : "De gebruikersnaam bevat spaties aan het begin of aan het eind",
+    "Username must not consist of dots only" : "De gebruikersnaam mag niet uit alleen punten bestaan",
+    "Username is invalid because files already exist for this user" : "Gebruikersnaam is ongeldig omdat er al bestanden voor deze gebruiker bestaan",
+    "User disabled" : "Gebruiker uitgeschakeld",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "De minimale versie van libxml2 versie is 2.7.0. Momenteel is  versie%s geïnstalleerd.",
     "To fix this issue update your libxml2 version and restart your web server." : "Om dit probleem op te lossen, moet je de libxml2 versie bijwerken en je webserver herstarten.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 is vereist.",
-    "Please upgrade your database version." : "Werk je databaseversie bij."
+    "Please upgrade your database version." : "Werk je databaseversie bij.",
+    "Your data directory is readable by other users." : "Je datamap is leesbaar voor andere gebruikers.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Wijzig de machtiging in 0770 zodat de directory niet door andere gebruikers bekeken kan worden."
 },
 "nplurals=2; plural=(n != 1);");
