@@ -27,7 +27,6 @@ OC.L10N.register(
     "Address" : "Adresse",
     "Profile picture" : "Profilbilete",
     "About" : "Om",
-    "Unknown user" : "Ukjend brukar",
     "Additional settings" : "Tilleggsinnstillingar",
     "Set an admin password." : "Vel eit admin-passord.",
     "Open »%s«" : "Opna »%s«",
@@ -77,10 +76,11 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Des.",
     "A valid password must be provided" : "Du må oppgje eit gyldig passord",
-    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
-    "User disabled" : "Brukar deaktivert",
     "Login canceled by app" : "Innlogging avbroten av app",
     "Authentication error" : "Feil i autentisering",
-    "Full name" : "Fult namn"
+    "Full name" : "Fult namn",
+    "Unknown user" : "Ukjend brukar",
+    "A valid username must be provided" : "Du må oppgje eit gyldig brukarnamn",
+    "User disabled" : "Brukar deaktivert"
 },
 "nplurals=2; plural=(n != 1);");
