@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Obsługiwane są następujące platformy: %s",
     "Server version %s or higher is required." : "Wymagana jest wersja serwera %s lub wyższa.",
     "Server version %s or lower is required." : "Wymagana jest wersja serwera %s lub niższa.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Zalogowany użytkownik musi być administratorem, subadministratorem lub mieć specjalne uprawnienia dostępu do tego ustawienia",
-    "Logged in user must be an admin or sub admin" : "Zalogowany użytkownik musi być administratorem lub współadministratorem",
-    "Logged in user must be an admin" : "Zalogowany użytkownik musi być administratorem",
     "Wiping of device %s has started" : "Rozpoczęto czyszczenie urządzenia %s",
     "Wiping of device »%s« has started" : "Rozpoczęto czyszczenie urządzenia »%s«",
     "»%s« started remote wipe" : "»%s« rozpoczęło zdalne czyszczenie",
@@ -117,22 +114,15 @@ OC.L10N.register(
     "Headline" : "Nagłówek",
     "Organisation" : "Organizacja",
     "Role" : "Rola społeczna",
-    "Unknown user" : "Nieznany użytkownik",
     "Additional settings" : "Ustawienia dodatkowe",
-    "Enter the database username and name for %s" : "Podaj nazwę użytkownika i nazwę bazy danych dla %s",
-    "Enter the database username for %s" : "Podaj nazwę użytkownika bazy danych dla %s",
     "Enter the database name for %s" : "Podaj nazwę bazy danych dla %s",
     "You cannot use dots in the database name %s" : "Nie można używać kropek w nazwie bazy danych %s",
-    "MySQL username and/or password not valid" : "Błędna nazwa użytkownika i/lub hasło do bazy danych MySQL",
     "You need to enter details of an existing account." : "Musisz wprowadzić szczegółowe dane dla istniejącego konta.",
     "Oracle connection could not be established" : "Nie można nawiązać połączenia z bazą danych Oracle",
-    "Oracle username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych Oracle",
-    "PostgreSQL username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych PostgreSQL",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nie jest wspierany i %s nie będzie działać poprawnie na tej platformie. Używasz go na własne ryzyko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Aby uzyskać najlepszy efekt, rozważ użycie serwera GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Wydaje się, że ta instancja %s używa PHP dla 32-bitowego środowiska, ponieważ open_basedir został tak skonfigurowany w php.ini. Doprowadzi to do problemów z plikami powyżej 4 GB i jest bardzo niezalecane.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Usuń ustawienie open_basedir w php.ini lub przełącz na PHP 64-bitowe.",
-    "Set an admin username." : "Ustaw nazwę administratora.",
     "Set an admin password." : "Ustaw hasło administratora.",
     "Cannot create or write into the data directory %s" : "Nie można tworzyć ani zapisywać w katalogu %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Zaplecze do udostępniania %s musi implementować interfejs OCP\\Share_Backend",
@@ -150,7 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Data ważności już minęła",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Nie można utworzyć daty wygaśnięcia na %n dzień do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu","Nie można utworzyć daty wygaśnięcia na %n dni do przodu"],
     "Sharing is only allowed with group members" : "Udostępnianie jest dozwolone tylko członkom grupy",
-    "Sharing %s failed, because this item is already shared with user %s" : "Udostępnianie %s nie powiodło się, ponieważ element jest już udostępniony użytkownikowi %s",
     "%1$s shared »%2$s« with you" : "%1$s udostępnił Tobie »%2$s«",
     "%1$s shared »%2$s« with you." : "%1$s udostępnił Tobie »%2$s«.",
     "Click the button below to open it." : "Kliknij przycisk poniżej, aby otworzyć.",
@@ -204,14 +193,6 @@ OC.L10N.register(
     "Nov." : "Lis.",
     "Dec." : "Gru.",
     "A valid password must be provided" : "Należy podać prawidłowe hasło",
-    "The username is already being used" : "Ta nazwa użytkownika jest już używana",
-    "Could not create user" : "Nie można utworzyć użytkownika",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "W nazwie użytkownika dozwolone są tylko następujące znaki : \"a-z\", \"A-Z\", \"0-9\", spacje i \"_.@-'\"",
-    "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
-    "Username contains whitespace at the beginning or at the end" : "Nazwa użytkownika zawiera spację na początku albo na końcu",
-    "Username must not consist of dots only" : "Nazwa użytkownika nie może się składać tylko z kropek",
-    "Username is invalid because files already exist for this user" : "Nazwa użytkownika jest nieprawidłowa, ponieważ pliki już istnieją dla tego użytkownika",
-    "User disabled" : "Użytkownik zablokowany",
     "Login canceled by app" : "Logowanie anulowane przez aplikację",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Nie można zainstalować aplikacji \"%1$s\", ponieważ nie są spełnione następujące zależności: %2$s",
     "a safe home for all your data" : "bezpieczny dom dla wszystkich Twoich danych",
@@ -244,8 +225,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Poproś administratora serwera o ponowne uruchomienie serwera WWW.",
     "The required %s config variable is not configured in the config.php file." : "Wymagana zmienna konfiguracyjna %s nie jest skonfigurowana w pliku config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Poproś administratora serwera o sprawdzenie konfiguracji Nextcloud.",
-    "Your data directory is readable by other users." : "Twój katalog danych jest widoczny dla innych użytkowników.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, aby katalog nie był widoczny dla innych użytkowników.",
     "Your data directory must be an absolute path." : "Katalog danych musi mieć ścieżkę absolutną.",
     "Check the value of \"datadirectory\" in your configuration." : "Sprawdź wartość \"datadirectory\" w swojej konfiguracji.",
     "Your data directory is invalid." : "Katalog danych jest nieprawidłowy.",
@@ -270,13 +249,32 @@ OC.L10N.register(
     "Extract topics" : "Wyodrębnij tematy",
     "Extracts topics from a text and outputs them separated by commas." : "Wyodrębnia tematy z tekstu i wyświetla je oddzielone przecinkami.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Pliki aplikacji %1$s nie zostały poprawnie zastąpione. Upewnij się, że jest to wersja zgodna z serwerem.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Zalogowany użytkownik musi być administratorem, subadministratorem lub mieć specjalne uprawnienia dostępu do tego ustawienia",
+    "Logged in user must be an admin or sub admin" : "Zalogowany użytkownik musi być administratorem lub współadministratorem",
+    "Logged in user must be an admin" : "Zalogowany użytkownik musi być administratorem",
     "Full name" : "Pełna nazwa",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Osiągnięto limit użytkowników i użytkownik nie został utworzony. Sprawdź swoje powiadomienia, aby dowiedzieć się więcej.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "W nazwie użytkownika dozwolone są tylko następujące znaki : \"a-z\", \"A-Z\", \"0-9\" i \"_.@-'\"",
+    "Unknown user" : "Nieznany użytkownik",
+    "Enter the database username and name for %s" : "Podaj nazwę użytkownika i nazwę bazy danych dla %s",
+    "Enter the database username for %s" : "Podaj nazwę użytkownika bazy danych dla %s",
+    "MySQL username and/or password not valid" : "Błędna nazwa użytkownika i/lub hasło do bazy danych MySQL",
+    "Oracle username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych Oracle",
+    "PostgreSQL username and/or password not valid" : "Zła nazwa użytkownika i/lub hasło do bazy danych PostgreSQL",
+    "Set an admin username." : "Ustaw nazwę administratora.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Udostępnianie %s nie powiodło się, ponieważ element jest już udostępniony użytkownikowi %s",
+    "The username is already being used" : "Ta nazwa użytkownika jest już używana",
+    "Could not create user" : "Nie można utworzyć użytkownika",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "W nazwie użytkownika dozwolone są tylko następujące znaki : \"a-z\", \"A-Z\", \"0-9\", spacje i \"_.@-'\"",
+    "A valid username must be provided" : "Należy podać prawidłową nazwę użytkownika",
+    "Username contains whitespace at the beginning or at the end" : "Nazwa użytkownika zawiera spację na początku albo na końcu",
+    "Username must not consist of dots only" : "Nazwa użytkownika nie może się składać tylko z kropek",
+    "Username is invalid because files already exist for this user" : "Nazwa użytkownika jest nieprawidłowa, ponieważ pliki już istnieją dla tego użytkownika",
+    "User disabled" : "Użytkownik zablokowany",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Wymagana wersja dla libxml2 to przynajmniej 2.7.0. Aktualnie zainstalowana jest %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Aby rozwiązać ten problem, zaktualizuj wersję libxml2 i ponownie uruchom serwer WWW.",
     "PostgreSQL >= 9 required." : "Wymagany PostgreSQL >= 9",
     "Please upgrade your database version." : "Zaktualizuj wersję bazy danych.",
-    "404" : "404"
+    "Your data directory is readable by other users." : "Twój katalog danych jest widoczny dla innych użytkowników.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Zmień uprawnienia na 0770, aby katalog nie był widoczny dla innych użytkowników."
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
