@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Поддерживаются следующие платформы: %s",
     "Server version %s or higher is required." : "Требуется сервер версии %s или выше.",
     "Server version %s or lower is required." : "Требуется сервер версии %s или ниже.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Для доступа к этому параметру необходимо состоять в группе администраторов, суб-администраторов или иметь специальные права",
-    "Logged in user must be an admin or sub admin" : "Вошедший в систему пользователь должен обладать правами администратора или суб-администратора",
-    "Logged in user must be an admin" : "Вошедший в систему пользователь должен обладать правами администратора",
     "Wiping of device %s has started" : "Удаление данных с устройства «%s».",
     "Wiping of device »%s« has started" : "Удаление данных с устройства «%s».",
     "»%s« started remote wipe" : "Начало удаления данных с устройства «%s»",
@@ -117,22 +114,15 @@ OC.L10N.register(
     "Headline" : "Заголовок",
     "Organisation" : "Организация",
     "Role" : "Роль",
-    "Unknown user" : "Неизвестный пользователь",
     "Additional settings" : "Дополнительные настройки",
-    "Enter the database username and name for %s" : "Укажите имя пользователя и название базы данных %s",
-    "Enter the database username for %s" : "Укажите имя пользователя базы данных %s",
     "Enter the database name for %s" : "Укажите название базы данных %s",
     "You cannot use dots in the database name %s" : "Имя базы данных %s не может содержать символ точки",
-    "MySQL username and/or password not valid" : "Неверное имя пользователя и/или пароль для подключения к MySQL",
     "You need to enter details of an existing account." : "Необходимо уточнить данные существующего акаунта.",
     "Oracle connection could not be established" : "Соединение с Oracle не может быть установлено",
-    "Oracle username and/or password not valid" : "Неверное имя пользователя и/или пароль Oracle",
-    "PostgreSQL username and/or password not valid" : "Неверное имя пользователя и/или пароль PostgreSQL",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не поддерживается и %s может работать некорректно на данной платформе. Используйте на свой страх и риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "Для достижения наилучших результатов, рассмотрите вариант использования сервера на GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Кажется что экземпляр этого %s работает в 32-битной среде PHP и в php.ini был настроен open_basedir. Это приведёт к проблемам с файлами более 4 ГБ и настоятельно не рекомендуется.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Удалите директиву open_basedir из файла php.ini или смените PHP на 64-разрядную сборку.",
-    "Set an admin username." : "Задать имя пользователя для администратора.",
     "Set an admin password." : "Задать пароль для admin.",
     "Cannot create or write into the data directory %s" : "Не удалось создать или записать в каталог данных «%s»",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бэкенд общего доступа %s должен реализовывать интерфейс OCP\\Share_Backend",
@@ -150,7 +140,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Дата окончания срока действия уже прошла",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Срок окончания не может быть более %n дня","Срок окончания не может быть более %n дней","Срок окончания не может быть более %n дней","Срок окончания не может быть более %n дней"],
     "Sharing is only allowed with group members" : "Разрешено публиковать только для участников группы",
-    "Sharing %s failed, because this item is already shared with user %s" : "Не удалось поделиться %s, так как элемент находится в общем доступе у %s",
     "%1$s shared »%2$s« with you" : "%1$s предоставил(а) вам доступ к «%2$s»",
     "%1$s shared »%2$s« with you." : "%1$s предоставил(а) вам доступ к «%2$s».",
     "Click the button below to open it." : "Нажмите расположенную ниже кнопку для перехода к полученному общему ресурсу.",
@@ -204,14 +193,6 @@ OC.L10N.register(
     "Nov." : "Нояб.",
     "Dec." : "Дек.",
     "A valid password must be provided" : "Укажите допустимый пароль",
-    "The username is already being used" : "Имя пользователя уже используется",
-    "Could not create user" : "Не удалось создать пользователя",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "В имени пользователя допускаются следующие символы: «a–z», «A–Z», «0–9» и «_.@-'»",
-    "A valid username must be provided" : "Укажите допустимое имя пользователя",
-    "Username contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробел в начале или в конце",
-    "Username must not consist of dots only" : "Имя пользователя должно состоять не только из точек",
-    "Username is invalid because files already exist for this user" : "Это имя не может быть использовано, файлы этого пользователя уже существуют",
-    "User disabled" : "Пользователь отключен",
     "Login canceled by app" : "Вход отменен приложением",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Приложение «%1$s» не может быть установлено, так как не удовлетворены следующие зависимости: %2$s",
     "a safe home for all your data" : "надёжный дом для всех ваших данных",
@@ -244,8 +225,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Пожалуйста, попросите вашего администратора перезапустить веб-сервер.",
     "The required %s config variable is not configured in the config.php file." : "Необходимая переменная %s не настроена в файле config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Пожалуйста, попросите администратора вашего сервера проверить конфигурацию Nextcloud.",
-    "Your data directory is readable by other users." : "Каталог данных доступен для чтения другим пользователям.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Измените права доступа на 0770, чтобы другие пользователи не могли получить список файлов этого каталога.",
     "Your data directory must be an absolute path." : "Каталог данных должен быть указан в виде абсолютного пути.",
     "Check the value of \"datadirectory\" in your configuration." : "Проверьте в значение параметра «datadirectory» в файле конфигурации.",
     "Your data directory is invalid." : "Каталог данных задан неверно.",
@@ -271,10 +250,31 @@ OC.L10N.register(
     "Extracts topics from a text and outputs them separated by commas." : "Извлекает темы из текста и выводит их через запятую.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файлы приложения %1$s не были заменены корректно. Удостоверьтесь, что устанавливаемая версия этого приложения совместима с версией сервера.",
     "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Для доступа к этому параметру необходимо состоять в группе администраторов, суб-администраторов или иметь специальные права",
+    "Logged in user must be an admin or sub admin" : "Вошедший в систему пользователь должен обладать правами администратора или суб-администратора",
+    "Logged in user must be an admin" : "Вошедший в систему пользователь должен обладать правами администратора",
     "Full name" : "Полное имя",
+    "Unknown user" : "Неизвестный пользователь",
+    "Enter the database username and name for %s" : "Укажите имя пользователя и название базы данных %s",
+    "Enter the database username for %s" : "Укажите имя пользователя базы данных %s",
+    "MySQL username and/or password not valid" : "Неверное имя пользователя и/или пароль для подключения к MySQL",
+    "Oracle username and/or password not valid" : "Неверное имя пользователя и/или пароль Oracle",
+    "PostgreSQL username and/or password not valid" : "Неверное имя пользователя и/или пароль PostgreSQL",
+    "Set an admin username." : "Задать имя пользователя для администратора.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Не удалось поделиться %s, так как элемент находится в общем доступе у %s",
+    "The username is already being used" : "Имя пользователя уже используется",
+    "Could not create user" : "Не удалось создать пользователя",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "В имени пользователя допускаются следующие символы: «a–z», «A–Z», «0–9» и «_.@-'»",
+    "A valid username must be provided" : "Укажите допустимое имя пользователя",
+    "Username contains whitespace at the beginning or at the end" : "Имя пользователя содержит пробел в начале или в конце",
+    "Username must not consist of dots only" : "Имя пользователя должно состоять не только из точек",
+    "Username is invalid because files already exist for this user" : "Это имя не может быть использовано, файлы этого пользователя уже существуют",
+    "User disabled" : "Пользователь отключен",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Требуется как минимум libxml2 версии 2.7.0. На данный момент установлена %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Для исправления этой ошибки обновите версию libxml2 и перезапустите ваш веб-сервер.",
     "PostgreSQL >= 9 required." : "Требуется PostgreSQL версии 9 или более новый.",
-    "Please upgrade your database version." : "Обновите базу данных."
+    "Please upgrade your database version." : "Обновите базу данных.",
+    "Your data directory is readable by other users." : "Каталог данных доступен для чтения другим пользователям.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Измените права доступа на 0770, чтобы другие пользователи не могли получить список файлов этого каталога."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
