@@ -6,6 +6,7 @@ OC.L10N.register(
     "See %s" : "Càstia %s",
     "Sample configuration detected" : "S'at agatadu una cunfiguratzione de esèmpiu",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Est istadu iscobertu ca sa cunfiguratzione de esèmpiu est istada copiada. Custu podet blocare s'installatzione e no est suportadu. Leghe sa documentatzione in config.php antis de fàghere càmbios.",
+    "The page could not be found on the server." : "Impossìbile agatare custa pàgina in su serbidore.",
     "Other activities" : "Àteras atividades",
     "%1$s and %2$s" : "%1$s e %2$s",
     "%1$s, %2$s and %3$s" : "%1$s, %2$s e %3$s",
@@ -28,8 +29,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Sunt suportadas custas prataformas: %s",
     "Server version %s or higher is required." : "Est rechèdidu sa versione de serbidore %s o superiore.",
     "Server version %s or lower is required." : "Est rechèdidu sa versione de serbidore %s o inferiore.",
-    "Logged in user must be an admin or sub admin" : "S'utente devet essere de s'amministratzione o de sa suta-amministratzione ",
-    "Logged in user must be an admin" : "S'utente devet essere de s'amministratzione ",
     "Wiping of device %s has started" : "S'at cumintzadu sa cantzelladura de su dispositivu %s",
     "Wiping of device »%s« has started" : "S'at cumintzadu sa cantzelladura de su dispositivu »%s«",
     "»%s« started remote wipe" : "»%s« at cumintzadu sa cantzelladura de tesu",
@@ -44,30 +43,30 @@ OC.L10N.register(
     "The remote wipe on %s has finished" : "Sa cantzelladura de tesu in %s est acabbada",
     "Authentication" : "Autenticatzione",
     "Unknown filetype" : "Genia de archìviu disconnota",
-    "Invalid image" : "Imàgine non bàlida",
-    "Avatar image is not square" : "S'imàgine de s'avatar no est cuadrada",
+    "Invalid image" : "Immàgine non bàlida",
+    "Avatar image is not square" : "S'immàgine de s'avatar no est cuadrada",
     "Files" : "Archìvios",
     "today" : "oe",
     "tomorrow" : "cras",
     "yesterday" : "eris",
-    "_in %n day_::_in %n days_" : ["tra %n dies","tra %n dies"],
+    "_in %n day_::_in %n days_" : ["tra %n dies","de immoe a %n dies"],
     "_%n day ago_::_%n days ago_" : ["%n dies a oe","%n dies a oe"],
     "next month" : "su mese chi benit",
     "last month" : "su mese passadu",
-    "_in %n month_::_in %n months_" : ["tra %n meses","%n meses"],
+    "_in %n month_::_in %n months_" : ["tra %n meses","de immoe a %n meses"],
     "_%n month ago_::_%n months ago_" : ["%n meses a oe","%n meses a oe"],
     "next year" : "s'annu chi benit",
     "last year" : "s'annu passadu",
-    "_in %n year_::_in %n years_" : ["tra %n annos","tra %n annos"],
+    "_in %n year_::_in %n years_" : ["tra %n annos","de immoe a %n annos"],
     "_%n year ago_::_%n years ago_" : ["%n annos a oe","%n dies a oe"],
-    "_in %n hour_::_in %n hours_" : ["tra %n oras","tra %n oras"],
+    "_in %n hour_::_in %n hours_" : ["tra %n oras","de immoe a %n oras"],
     "_%n hour ago_::_%n hours ago_" : ["%n oras a immoe","%n oras a immoe"],
-    "_in %n minute_::_in %n minutes_" : ["%n meses","tra %n minutos"],
+    "_in %n minute_::_in %n minutes_" : ["%n meses","de immoe a %n minutos"],
     "_%n minute ago_::_%n minutes ago_" : ["%n minutos a immoe","%n minutos a immoe"],
-    "in a few seconds" : "tra pagos segundos",
+    "in a few seconds" : "de immoe a pagos segundos",
     "seconds ago" : "segundos a immoe",
     "Empty file" : "Archìviu bòidu",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Su mòdulu cun ID: %s no esistit. Ativa•ddu in is impostatziones de s'aplicatzione o cuntata s'amministratzione.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Su mòdulu cun ID: %s no esistit. Ativa·ddu in sa cunfiguratzione de s'aplicatzione o cuntata s'amministratzione.",
     "File already exists" : "S'archìviu b'est giai",
     "Invalid path" : "Percursu non bàlidu",
     "Failed to create file from template" : "No at fatu a creare s'archìviu dae su modellu",
@@ -82,8 +81,9 @@ OC.L10N.register(
     "__language_name__" : "sardu",
     "This is an automatically sent email, please do not reply." : "Custu est unu messàgiu de posta imbiadu in automàticu, non rispondas.",
     "Help" : "Agiudu",
+    "Appearance and accessibility" : "Aspetu e atzessibilidade",
     "Apps" : "Aplicatziones",
-    "Settings" : "Impostatziones",
+    "Settings" : "Cunfiguratzione",
     "Log out" : "Essi·nche",
     "Users" : "Utentes",
     "Email" : "Posta eletrònica",
@@ -91,23 +91,18 @@ OC.L10N.register(
     "Twitter" : "Twitter",
     "Website" : "Situ ìnternet",
     "Address" : "Indiritzu",
-    "Profile picture" : "Imàgine de profilu",
+    "Profile picture" : "Immàgine de profilu",
     "About" : "In contu de",
     "Display name" : "Ammustra nùmene",
     "Headline" : "Tìtulos",
     "Role" : "Faina",
-    "Unknown user" : "Utèntzia disconnota",
-    "Additional settings" : "Impostatziones in agiunta",
-    "MySQL username and/or password not valid" : "Su nùmene utente e/o sa crae de MySQL no sunt bàlidos",
+    "Additional settings" : "Cunfiguratziones in agiunta",
     "You need to enter details of an existing account." : "Nche depes insertare is detàllios de unu contu chi b'est giai.",
     "Oracle connection could not be established" : "No at fatu a istabilire sa connessione Oracle",
-    "Oracle username and/or password not valid" : "Su nùmene utente e/o sa crae de Oracle no sunt bàlidos",
-    "PostgreSQL username and/or password not valid" : "Su nùmene utente e/o sa crae de Postgre SQL no sunt bàlidos",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no est suportadu e %s no at a funtzionare in manera curreta in custa prataforma. Imprea•ddu a arriscu tuo!",
     "For the best results, please consider using a GNU/Linux server instead." : "Pro su mellus resurtadu, cunsidera in càmbiu de impreare unu serbidore GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Parit ca custa istàntzia %s est traballende in un'ambiente PHP a 32-bit e sa open_basedir est istada cunfigurada in php.ini. Custu at a causare problemas cun archìvios de prus de 4 GB e est iscussigiadu a forte.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Boga•nche s'impostatzione open_basedir in su php.ini tuo o càmbia a su PHP a 64-bit.",
-    "Set an admin username." : "Imposta unu nùmene utente pro chie amministrat.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Boga·nche sa cunfiguratzione open_basedir in su php.ini tuo o càmbia a su PHP a 64-bit.",
     "Set an admin password." : "Imposta una crae pro chie amministrat.",
     "Cannot create or write into the data directory %s" : "No faghet a creare o a iscriere a intro de sa cartella de datos %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Su motore de cumpartzidura %s depet cumpletare s'interfache OCP\\Share_Backend",
@@ -125,7 +120,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Sa data de iscadèntzia est giai passada",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["No faghet a impostare sa data de iscadèntzia a prus de %n die in su benidore","No faghet a impostare sa data de iscadèntzia a prus de %n dies in su benidore"],
     "Sharing is only allowed with group members" : "Sa cumpartzidura est permìtida isceti cun is partetzipantes de su grupu",
-    "Sharing %s failed, because this item is already shared with user %s" : "No at fatu a cumpartzire %s, ca custu elementu est giai istadu cumpartzidu cun s'utente %s",
     "%1$s shared »%2$s« with you" : "%1$s at cumpartzidu »%2$s cun tegus",
     "%1$s shared »%2$s« with you." : "%1$s at cumpartzidu »%2$s cun tegus.",
     "Click the button below to open it." : "Incarca su butone a suta pro dd'abèrrere.",
@@ -177,13 +171,6 @@ OC.L10N.register(
     "Nov." : "SAnd.",
     "Dec." : "Nad.",
     "A valid password must be provided" : "Depes frunire una crae bàlida",
-    "The username is already being used" : "Su nùmene utente est giai impreadu",
-    "Could not create user" : "No at fatu a creare s'utente",
-    "A valid username must be provided" : "Depes frunire unu nùmene utente bàlidu",
-    "Username contains whitespace at the beginning or at the end" : "Su nùmene utente cuntenet ispàtzios bòidos a su cumintzu o a sa fine",
-    "Username must not consist of dots only" : "Su nùmene utente no depet tènnere isceti puntos",
-    "Username is invalid because files already exist for this user" : "Su nùmene utente no est bàlidu, ca is archìvios bi sunt giai pro cust'utèntzia",
-    "User disabled" : "Utèntzia disativada",
     "Login canceled by app" : "Atzessu annulladu dae s'aplicatzione",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Non faghet a installare s'aplicatzione %1$s ca is dipendèntzias in fatu non sunt  satisfatos:%2$s",
     "a safe home for all your data" : "unu logu siguru pro totu is datos tuos",
@@ -195,13 +182,12 @@ OC.L10N.register(
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ma si preferes allogare s'archìviu de letura isceti congi.php, imposta su sèberu \"config_is_read_only\" a \"true\". Càstia %s",
     "PHP module %s not installed." : "Su mòdulu PHP %s no est installadu.",
     "Please ask your server administrator to install the module." : "Pedi a s'amministratzione de serbidore de installare su mòdulu.",
-    "PHP setting \"%s\" is not set to \"%s\"." : "S'impostatzione PHP %s no est a \"%s\".",
-    "Adjusting this setting in php.ini will make Nextcloud run again" : "Assentende cust'impostatzione in php.ini at a torrare a fàghere traballare Nextcloud",
+    "PHP setting \"%s\" is not set to \"%s\"." : "Sa cunfiguratzione PHP %s no est a \"%s\".",
+    "Adjusting this setting in php.ini will make Nextcloud run again" : "Assentende custa cunfiguratzione in php.ini at a torrare a fàghere traballare Nextcloud",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Parit che PHP siat impostadu pro nde bogare is blocos de documentatzione in lìnia. Custu at a impedire s'atzessu a medas aplicatziones printzipales.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Podet èssere causadu dae una memòria temporànea/atzeleradore cales Zend Opcache o eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Is mòdulos PHP sunt istados installados, ma sunt ancora elencados comente mancantes?",
     "Please ask your server administrator to restart the web server." : "Pedi a s'amministratzione de su serbidore de torrare a aviare su serbidore ìnternet.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Càmbia is permissos a 0770 aici sa cartella no podet èssere in is elencos de àteras utèntzias.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Assegura•ti chi in sa cartella de datos de orìgine nche siat un'archìviu cun nùmene \".ocdata\".",
     "Action \"%s\" not supported or implemented." : "S'atzione \"%s\" no est suportada o cumpletada.",
     "Authentication failed, wrong token or provider ID given" : "No at fatu a fàghere s'autenticatzione, token o ID de su frunidore isballiados",
@@ -215,8 +201,24 @@ OC.L10N.register(
     "Storage is temporarily not available" : "S'archiviatzione no est disponìbile pro immoe.",
     "Storage connection timeout. %s" : "Tempus de connessione a s'archiviatzione iscadidu. %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Is archìvios de s'aplicatzione %1$s no sunt istados cambiados in manera curreta. Assegura•ti chi b'apat una versione cumpatìbile cun su serbidore.",
+    "Logged in user must be an admin or sub admin" : "S'utente devet essere de s'amministratzione o de sa suta-amministratzione ",
+    "Logged in user must be an admin" : "S'utente devet essere de s'amministratzione ",
     "Full name" : "Nùmene cumpletu",
+    "Unknown user" : "Utèntzia disconnota",
+    "MySQL username and/or password not valid" : "Su nùmene utente e/o sa crae de MySQL no sunt bàlidos",
+    "Oracle username and/or password not valid" : "Su nùmene utente e/o sa crae de Oracle no sunt bàlidos",
+    "PostgreSQL username and/or password not valid" : "Su nùmene utente e/o sa crae de Postgre SQL no sunt bàlidos",
+    "Set an admin username." : "Imposta unu nùmene utente pro chie amministrat.",
+    "Sharing %s failed, because this item is already shared with user %s" : "No at fatu a cumpartzire %s, ca custu elementu est giai istadu cumpartzidu cun s'utente %s",
+    "The username is already being used" : "Su nùmene utente est giai impreadu",
+    "Could not create user" : "No at fatu a creare s'utente",
+    "A valid username must be provided" : "Depes frunire unu nùmene utente bàlidu",
+    "Username contains whitespace at the beginning or at the end" : "Su nùmene utente cuntenet ispàtzios bòidos a su cumintzu o a sa fine",
+    "Username must not consist of dots only" : "Su nùmene utente no depet tènnere isceti puntos",
+    "Username is invalid because files already exist for this user" : "Su nùmene utente no est bàlidu, ca is archìvios bi sunt giai pro cust'utèntzia",
+    "User disabled" : "Utèntzia disativada",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Est rechèdida a su mancu sa versione libxml2 2.7.0. Pro immoe cussa installada est sa%s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Pro assentare custu problema, agiorna sa versione libxml2 e torra a aviare su serbidore ìnternet."
+    "To fix this issue update your libxml2 version and restart your web server." : "Pro assentare custu problema, agiorna sa versione libxml2 e torra a aviare su serbidore ìnternet.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Càmbia is permissos a 0770 aici sa cartella no podet èssere in is elencos de àteras utèntzias."
 },
 "nplurals=2; plural=(n != 1);");
