@@ -8,7 +8,6 @@ OC.L10N.register(
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Program %1$s ni na voljo ali pa je nameščena neskladna različica za ta strežnik. Preverite mapo programov.",
     "Sample configuration detected" : "Zaznana je neustrezna vzorčna nastavitev",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "V sistem je bila kopirana datoteka s vzorčnimi nastavitvami. To lahko vpliva na namestitev in zato možnost ni podprta. Pred spremembami datoteke config.php si natančno preberite dokumentacijo.",
-    "404" : "404",
     "The page could not be found on the server." : "Strani na strežniku ni mogoče najti.",
     "Email verification" : "Overjanje elektronskega naslova",
     "Click the following link to confirm your email." : "Kliknite na povezavo za potrditev elektronskega naslova.",
@@ -35,9 +34,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Podprta so okolja: %s",
     "Server version %s or higher is required." : "Zahtevana je različica strežnika %s ali višja.",
     "Server version %s or lower is required." : "Zahtevana je različica strežnika %s ali nižja.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljen uporabnik mora biti določen za skrbnika, pomočnika skrbnika ali pa mora imeti dodeljene posebna dovoljenja za dostop do nastavitve.",
-    "Logged in user must be an admin or sub admin" : "Prijavljen uporabnik mora imeti dovoljenja skrbnika ali podpornega skrbnika",
-    "Logged in user must be an admin" : "Prijavljen uporabnik mora biti tudi skrbnik",
     "Wiping of device %s has started" : "Začeto je brisanje podatkov na napravi %s.",
     "Wiping of device »%s« has started" : "Začeto je brisanje podatkov na napravi »%s«",
     "»%s« started remote wipe" : "Program »%s« je začel izvajati oddaljeno varnostno brisanje",
@@ -116,22 +112,15 @@ OC.L10N.register(
     "Headline" : "Naslov",
     "Organisation" : "Ustanova",
     "Role" : "Vloga",
-    "Unknown user" : "Neznan uporabnik",
     "Additional settings" : "Dodatne nastavitve",
-    "Enter the database username and name for %s" : "Vpis uporabniškega imena in imena podatkovne zbirke za %s.",
-    "Enter the database username for %s" : "Vpis uporabniškega imena podatkovne zbirke za %s.",
     "Enter the database name for %s" : "Vpis imena podatkovne zbirke za %s.",
     "You cannot use dots in the database name %s" : "V imenu podatkovne zbirke %s ni dovoljeno uporabljati pik.",
-    "MySQL username and/or password not valid" : "Uporabniško ime ali geslo MySQL ni veljavno",
     "You need to enter details of an existing account." : "Vpisati je treba podrobnosti obstoječega računa.",
     "Oracle connection could not be established" : "Povezave s sistemom Oracle ni mogoče vzpostaviti.",
-    "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
-    "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Sistem Mac OS X ni podprt, zato %s v tem okolju ne bo deloval zanesljivo. Program uporabljate na lastno odgovornost! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Za najboljše rezultate je priporočljivo uporabljati strežnik GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Kaže, da je dejavna seja %s zagnana v 32-bitnem okolju PHP in, da je v datoteki php.ini nastavljen open_basedir . Tako delovanje ni priporočljivo, saj se lahko pojavijo težave z datotekami, večjimi od 4GB.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Odstraniti je treba nastavitev open_basedir v datoteki php.ini ali pa preklopiti na 64-bitno okolje PHP.",
-    "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
     "Set an admin password." : "Nastavi skrbniško geslo.",
     "Cannot create or write into the data directory %s" : "Ni mogoče zapisati podatkov v podatkovno mapo %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Souporaba ozadnjega programa %s mora vsebovati tudi vmesnik OCP\\Share_Backend",
@@ -149,7 +138,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "Datum preteka je že mimo!",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Datuma pretaka ni mogoče nastaviti za več kot %n dan v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dneva v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dni v prihodnost.","Datuma pretaka ni mogoče nastaviti za več kot %n dni v prihodnost."],
     "Sharing is only allowed with group members" : "Souporaba je dovoljena le med člani skupine",
-    "Sharing %s failed, because this item is already shared with user %s" : "Nastavljanje souporabe %s je spodletelo, ker je predmet že v souporabi z uporabnikom %s.",
     "%1$s shared »%2$s« with you" : "%1$s vam omogoča souporabo »%2$s«",
     "%1$s shared »%2$s« with you." : "%1$s vam omogoča souporabo »%2$s«.",
     "Click the button below to open it." : "Kliknite na gumb za odpiranje.",
@@ -201,14 +189,6 @@ OC.L10N.register(
     "Nov." : "nov",
     "Dec." : "dec",
     "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
-    "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
-    "Could not create user" : "Uporabnika ni mogoče ustvariti",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: »a–z«, »A–Z«, »0–9«, presledki in »_.@-«\".",
-    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
-    "Username contains whitespace at the beginning or at the end" : "Uporabniško ime vsebuje presledni znak na začetku ali na koncu imena.",
-    "Username must not consist of dots only" : "Uporabniško ime ne sme biti zgolj iz pik",
-    "Username is invalid because files already exist for this user" : "Uporabniško ime ni veljavno, ker za tega uporabnika že obstajajo datoteke",
-    "User disabled" : "Uporabnik je onemogočen",
     "Login canceled by app" : "Program onemogoča prijavo",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Programa »%1$s« ni mogoče namestiti zaradi nerešenih odvisnosti: %2$s",
     "a safe home for all your data" : "Varno okolje za vaše podatke!",
@@ -239,7 +219,6 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilnik ali pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Ali so bili moduli PHP nameščeni, pa so še vedno označeni kot manjkajoči?",
     "Please ask your server administrator to restart the web server." : "Obvestite skrbnika strežnika, da je treba ponovno zagnati spletni strežnik.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom.",
     "Your data directory must be an absolute path." : "Podatkovna mapa mora imeti navedeno celotno pot.",
     "Your data directory is invalid." : "Podatkovna mapa ni veljavna.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Prepričajte se, da je datoteka ».ocdata« v korenu podatkovne mape.",
@@ -255,9 +234,29 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Shramba trenutno ni na voljo",
     "Storage connection timeout. %s" : "Povezava do shrambe je časovno potekla. %s",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Datoteke programa %1$s niso bile zamenjane na pravi način. Prepričajte se, da je na strežniku nameščena podprta različica.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Prijavljen uporabnik mora biti določen za skrbnika, pomočnika skrbnika ali pa mora imeti dodeljene posebna dovoljenja za dostop do nastavitve.",
+    "Logged in user must be an admin or sub admin" : "Prijavljen uporabnik mora imeti dovoljenja skrbnika ali podpornega skrbnika",
+    "Logged in user must be an admin" : "Prijavljen uporabnik mora biti tudi skrbnik",
     "Full name" : "Polno ime",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: »a–z«, »A–Z«, »0–9« in »_.@-«\".",
+    "Unknown user" : "Neznan uporabnik",
+    "Enter the database username and name for %s" : "Vpis uporabniškega imena in imena podatkovne zbirke za %s.",
+    "Enter the database username for %s" : "Vpis uporabniškega imena podatkovne zbirke za %s.",
+    "MySQL username and/or password not valid" : "Uporabniško ime ali geslo MySQL ni veljavno",
+    "Oracle username and/or password not valid" : "Uporabniško ime ali geslo Oracle ni veljavno",
+    "PostgreSQL username and/or password not valid" : "Uporabniško ime ali geslo PostgreSQL ni veljavno",
+    "Set an admin username." : "Nastavi uporabniško ime skrbnika.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Nastavljanje souporabe %s je spodletelo, ker je predmet že v souporabi z uporabnikom %s.",
+    "The username is already being used" : "Vpisano uporabniško ime je že v uporabi",
+    "Could not create user" : "Uporabnika ni mogoče ustvariti",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "V uporabniškem imenu je dovoljeno uporabiti le znake: »a–z«, »A–Z«, »0–9«, presledki in »_.@-«\".",
+    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
+    "Username contains whitespace at the beginning or at the end" : "Uporabniško ime vsebuje presledni znak na začetku ali na koncu imena.",
+    "Username must not consist of dots only" : "Uporabniško ime ne sme biti zgolj iz pik",
+    "Username is invalid because files already exist for this user" : "Uporabniško ime ni veljavno, ker za tega uporabnika že obstajajo datoteke",
+    "User disabled" : "Uporabnik je onemogočen",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Različica knjižnice libxml2 mora biti 2.7.0 ali višja. Trenutno je nameščena %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Za rešitev te težave je treba posodobiti knjižnico libxml2 in nato ponovno zagnati spletni strežnik."
+    "To fix this issue update your libxml2 version and restart your web server." : "Za rešitev te težave je treba posodobiti knjižnico libxml2 in nato ponovno zagnati spletni strežnik.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Spremenite dovoljenja mape na 0770 in s tem onemogočite branje vsebine drugim uporabnikom."
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
