@@ -58,17 +58,13 @@ OC.L10N.register(
     "Address" : "Adresa",
     "Profile picture" : "Foto profili",
     "About" : "Rreth ",
-    "Unknown user" : "Përdorues i panjohur",
     "Additional settings" : "Konfigurime shtesë",
     "You need to enter details of an existing account." : "Duhet të futni detajet e një llogarie ekzistuese.",
     "Oracle connection could not be established" : "S’u vendos dot lidhje me Oracle",
-    "Oracle username and/or password not valid" : "Emër përdoruesi dhe/ose fjalëkalim Oracle-i i pavlefshëm",
-    "PostgreSQL username and/or password not valid" : "Emër përdoruesi dhe/ose fjalëkalim PostgreSQL jo të vlefshëm",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nuk mbulohet dhe %s s’do të funksionojë si duhet në këtë platformë. Përdoreni nën përgjegjësinë tuaj! ",
     "For the best results, please consider using a GNU/Linux server instead." : "Për përfundimet më të mira, ju lutemi, më mirë konsideroni përdorimin e një shërbyesi GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Duket se kjo instancë %s xhiron një mjedis PHP 32-bitësh dhe open_basedir është e formësuar, te php.ini. Kjo do të shpjerë në probleme me kartela më të mëdha se 4 GB dhe këshillohet me forcë të mos ndodhë.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ju lutemi, hiqeni rregullimin open_basedir nga php.ini juaj ose hidhuni te PHP për 64-bit.",
-    "Set an admin username." : "Caktoni një emër përdoruesi për përgjegjësin.",
     "Set an admin password." : "Caktoni një fjalëkalim për përgjegjësin.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Mekanizmi i shërbimit për ndarje %s duhet të sendërtojë ndërfaqen OCP\\Share_Backend",
     "Sharing backend %s not found" : "S’u gjet mekanizmi i shërbimit për ndarje %s",
@@ -77,7 +73,6 @@ OC.L10N.register(
     "You are not allowed to share %s" : "Nuk ju lejohet ta ndani %s me të tjerët",
     "Cannot increase permissions of %s" : "S’mund të shtohen lejet për %s",
     "Expiration date is in the past" : "Data e skadimit bie në të kaluarën",
-    "Sharing %s failed, because this item is already shared with user %s" : "Ndarja e %s me të tjerët dështoi, ngaqë ky objekt është ndarë tashmë me përdoruesin %s",
     "Click the button below to open it." : "Kliko butonin më poshtë për të hapur atë.",
     "The requested share does not exist anymore" : "Ndarja e kërkuar nuk ekziston më",
     "Could not find category \"%s\"" : "S’u gjet kategori \"%s\"",
@@ -127,11 +122,6 @@ OC.L10N.register(
     "Nov." : "Nën.",
     "Dec." : "Dhj.",
     "A valid password must be provided" : "Duhet dhënë një fjalëkalim i vlefshëm",
-    "The username is already being used" : "Emri i përdoruesit është tashmë i përdorur",
-    "A valid username must be provided" : "Duhet dhënë një emër i vlefshëm përdoruesi",
-    "Username contains whitespace at the beginning or at the end" : "Emri i përdoruesit përmban hapësirë në fillim ose në fund",
-    "Username must not consist of dots only" : "Emri i përdoruesit nuk duhet të përbëhet vetëm nga pika",
-    "User disabled" : "Përdorues i çaktivizuar",
     "Login canceled by app" : "Hyrja u anulua nga aplikacioni",
     "a safe home for all your data" : "Një shtëpi e sigurt për të dhënat e tua",
     "File is currently busy, please try again later" : "Kartela tani është e zënë, ju lutemi, riprovoni më vonë.",
@@ -147,7 +137,6 @@ OC.L10N.register(
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Kjo ka gjasa të jetë shkaktuar nga një fshehtinë/përshpejtues i tillë si Zend OPcache ose eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Modulet PHP janë instaluar, por tregohen ende sikur mungojnë?",
     "Please ask your server administrator to restart the web server." : "Ju lutemi, kërkojini përgjegjësit të shërbyesit tuaj të rinisë shërbyesin web.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ju lutemi, kalojani lejet në 0770, që kështu atë drejtori të mos mund ta shfaqin përdorues të tjerë.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Sigurohu që ekziston një skedar i quajtur \".ocdata\" në rrënjën e direktorisë së të dhënave.",
     "Could not obtain lock type %d on \"%s\"." : "S’u mor dot lloj kyçjeje %d në \"%s\".",
     "Storage unauthorized. %s" : "Depozitë e paautorizuar. %s",
@@ -156,8 +145,18 @@ OC.L10N.register(
     "Storage is temporarily not available" : "Hapsira ruajtëse nuk është në dispozicion përkohësisht",
     "Storage connection timeout. %s" : "Mbarim kohe lidhjeje për depozitën. %s",
     "Full name" : "Emri i plotë",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Në një emër përdoruesi lejohen vetëm shenjat vijuese: \"a-z\", \"A-Z\", \"0-9\", dhe \"_.@-\"",
+    "Unknown user" : "Përdorues i panjohur",
+    "Oracle username and/or password not valid" : "Emër përdoruesi dhe/ose fjalëkalim Oracle-i i pavlefshëm",
+    "PostgreSQL username and/or password not valid" : "Emër përdoruesi dhe/ose fjalëkalim PostgreSQL jo të vlefshëm",
+    "Set an admin username." : "Caktoni një emër përdoruesi për përgjegjësin.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Ndarja e %s me të tjerët dështoi, ngaqë ky objekt është ndarë tashmë me përdoruesin %s",
+    "The username is already being used" : "Emri i përdoruesit është tashmë i përdorur",
+    "A valid username must be provided" : "Duhet dhënë një emër i vlefshëm përdoruesi",
+    "Username contains whitespace at the beginning or at the end" : "Emri i përdoruesit përmban hapësirë në fillim ose në fund",
+    "Username must not consist of dots only" : "Emri i përdoruesit nuk duhet të përbëhet vetëm nga pika",
+    "User disabled" : "Përdorues i çaktivizuar",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Lypset të paktën libxml2 2.7.0. Hëpërhë e instaluar është %s.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Për të ndrequr këtë problem, përditësoni libxml2 dhe rinisni shërbyesin tuaj web."
+    "To fix this issue update your libxml2 version and restart your web server." : "Për të ndrequr këtë problem, përditësoni libxml2 dhe rinisni shërbyesin tuaj web.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ju lutemi, kalojani lejet në 0770, që kështu atë drejtori të mos mund ta shfaqin përdorues të tjerë."
 },
 "nplurals=2; plural=(n != 1);");
