@@ -36,9 +36,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Şu platformlar destekleniyor: %s",
     "Server version %s or higher is required." : "Sunucu %s ya da daha sonraki bir sürüm olmalıdır.",
     "Server version %s or lower is required." : "Sunucu %s ya da daha önceki bir sürüm olmalıdır.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış kullanıcı bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
-    "Logged in user must be an admin or sub admin" : "Oturum açmış kullanıcı bir yönetici ya da alt yönetici olmalıdır",
-    "Logged in user must be an admin" : "Oturum açmış kullanıcı bir yönetici olmalıdır",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış hesap bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
+    "Logged in account must be an admin or sub admin" : "Oturum açmış hesap bir yönetici ya da alt yönetici olmalıdır",
+    "Logged in account must be an admin" : "Oturum açmış hesap bir yönetici olmalıdır",
     "Wiping of device %s has started" : "%s aygıtının silinmesine başlandı",
     "Wiping of device »%s« has started" : "»%s« aygıtının silinmesine başlandı",
     "»%s« started remote wipe" : "»%s« uzaktan silme işlemi başladı",
@@ -78,7 +78,7 @@ OC.L10N.register(
     "in a few seconds" : "bir kaç saniye içinde",
     "seconds ago" : "saniyeler önce",
     "Empty file" : "Dosya boş",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kodlu modül bulunamadı. Lütfen uygulamalarınız içinden modülü etkinleştirin ya da BT yöneticinizle görüşün.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kimlikli modül bulunamadı. Lütfen uygulamalarınız içinden modülü etkinleştirin ya da BT yöneticinizle görüşün.",
     "File already exists" : "Dosya zaten var",
     "Invalid path" : "Yol geçersiz",
     "Failed to create file from template" : "Kalıptan dosya oluşturulamadı",
@@ -117,22 +117,22 @@ OC.L10N.register(
     "Headline" : "Başlık",
     "Organisation" : "Kuruluş",
     "Role" : "Pozisyon",
-    "Unknown user" : "Kullanıcı bilinmiyor",
+    "Unknown account" : "Hesap bilinmiyor",
     "Additional settings" : "Ek ayarlar",
-    "Enter the database username and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
-    "Enter the database username for %s" : "%s için veri tabanı kullanıcı adını yazın",
+    "Enter the database Login and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
+    "Enter the database Login for %s" : "%s için veri tabanı kullanıcı adını yazın",
     "Enter the database name for %s" : "%s için veri tabanı adını yazın",
     "You cannot use dots in the database name %s" : "%s veri tabanı adında nokta kullanamazsınız",
-    "MySQL username and/or password not valid" : "MySQL kullanıcı adı ya da parolası geçersiz",
+    "MySQL Login and/or password not valid" : "MySQL kullanıcı adı ve/veya parolası geçersiz",
     "You need to enter details of an existing account." : "Var olan bir hesabın bilgilerini yazmalısınız.",
     "Oracle connection could not be established" : "Oracle ile bağlantı kurulamadı",
-    "Oracle username and/or password not valid" : "Oracle kullanıcı adı ya da parolası geçersiz",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL kullanıcı adı ya da parolası geçersiz",
+    "Oracle Login and/or password not valid" : "Oracle kullanıcı adı ve/veya parolası geçersiz",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL kullanıcı adı ve/veya parolası geçersiz",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X desteklenmiyor ve %s bu platformda düzgün çalışmayacak. Kullanmaktan doğacak riskler size aittir!",
     "For the best results, please consider using a GNU/Linux server instead." : "En iyi sonucu almak için GNU/Linux sunucusu kullanın.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Bu %s kopyası 32 bit PHP ortamında çalıştırılıyor ve open_basedir seçeneği php.ini dosyasından ayarlanmış gibi görünüyor. Bu yapılandırma 4 GB boyutundan büyük dosyalarda sorun çıkarır ve kullanılması önerilmez.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Lütfen php.ini dosyasındaki open_basedir ayarını kaldırın ya da 64-bit PHP sürümüne geçin.",
-    "Set an admin username." : "Bir yönetici kullanıcı adı yazın.",
+    "Set an admin Login." : "Bir yönetici kullanıcı adı yazın.",
     "Set an admin password." : "Bir yönetici parolası yazın.",
     "Cannot create or write into the data directory %s" : "%s veri klasörü oluşturulamadı ya da içine yazılamadı",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Paylaşım arka ucu %s OCP\\Share_Backend arayüzünü desteklemeli",
@@ -150,12 +150,12 @@ OC.L10N.register(
     "Expiration date is in the past" : "Geçerlilik sonu tarihi geçmişte",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz","Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz"],
     "Sharing is only allowed with group members" : "Paylaşım yalnızca grup üyeleri ile yapılabilir",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s paylaşılamadı. Bu öge zaten %s kullanıcısı ile paylaşılmış",
+    "Sharing %s failed, because this item is already shared with the account %s" : "%s paylaşılamadı. Bu öge zaten %s hesabı ile paylaşılmış",
     "%1$s shared »%2$s« with you" : "%1$s, sizinle »%2$s« ögesini paylaştı",
     "%1$s shared »%2$s« with you." : "%1$s, sizinle »%2$s« ögesini paylaştı.",
     "Click the button below to open it." : "Açmak için aşağıdaki düğmeye tıklayın.",
     "The requested share does not exist anymore" : "Erişilmek istenilen paylaşım artık yok",
-    "The requested share comes from a disabled user" : "Erişilmek istenilen paylaşım etkisizleştirilmiş bir kullanıcıdan geliyor",
+    "The requested share comes from a disabled user" : "Erişilmek istenilen paylaşım devre dışı bırakılmış bir kullanıcıdan geliyor",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi. Ayrıntılı bilgi almak için bildirimlerinize bakın.",
     "Could not find category \"%s\"" : "\"%s\" kategorisi bulunamadı",
     "Sunday" : "Pazar",
@@ -204,14 +204,14 @@ OC.L10N.register(
     "Nov." : "Kas",
     "Dec." : "Ara",
     "A valid password must be provided" : "Geçerli bir parola yazmalısınız",
-    "The username is already being used" : "Bu kullanıcı adı zaten var",
-    "Could not create user" : "Kullanıcı oluşturulamadı",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kullanıcı adında yalnızca şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", boşluk ve \"_.@-'\"",
-    "A valid username must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
-    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adının başı ya da sonunda boşluk var",
-    "Username must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
-    "Username is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
-    "User disabled" : "Kullanıcı devre dışı",
+    "The Login is already being used" : "Bu kullanıcı adı zaten var",
+    "Could not create account" : "Hesap oluşturulamadı",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kullanıcı adında yalnızca şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", boşluk ve \"_.@-'\"",
+    "A valid Login must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
+    "Login contains whitespace at the beginning or at the end" : "Kullanıcı adının başında ya da sonunda boşluk var",
+    "Login must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
+    "Login is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
+    "Account disabled" : "Hesap devre dışı",
     "Login canceled by app" : "Oturum açma uygulama tarafından iptal edildi",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" uygulaması, şu gereklilikler sağlanmadığı için kurulamıyor: %2$s",
     "a safe home for all your data" : "verileriniz için güvenli bir barınak",
@@ -244,17 +244,17 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Lütfen site sunucusunu yeniden başlatması için BT yöneticinizle görüşün.",
     "The required %s config variable is not configured in the config.php file." : "Gereken %s yapılandırma değişkeni config.php dosyasında ayarlanmamış.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Lütfen Nextcloud yapılandırmasını denetlemesi için BT yöneticinizle görüşün.",
-    "Your data directory is readable by other users." : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kullanıcıların klasörü görebilmesini sağlayın.",
+    "Your data directory is readable by other people." : "Veri klasörünüz diğer kişiler tarafından okunabilir.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kişilerin klasörü görebilmesini sağlayın.",
     "Your data directory must be an absolute path." : "Veri klasörünüz mutlak bir yol olmalıdır.",
     "Check the value of \"datadirectory\" in your configuration." : "Yapılandırmanızdaki \"datadirectory\" değerini denetleyin.",
     "Your data directory is invalid." : "Veri klasörünüz geçersiz.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Veri klasörü kökünde \".ocdata\" adında bir dosya bulunduğundan emin olun.",
     "Action \"%s\" not supported or implemented." : "\"%s\" işlemi desteklenmiyor ya da henüz kullanılamıyor.",
-    "Authentication failed, wrong token or provider ID given" : "Kimlik doğrulanamadı. Belirtilen kod ya da hizmet sağlayıcı kodu hatalı",
+    "Authentication failed, wrong token or provider ID given" : "Kimlik doğrulanamadı. Belirtilen kod ya da hizmet sağlayıcı kimliği hatalı",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "İsteğin tamamlanması için gerekli parametreler eksik: \"%s\"",
-    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "\"%1$s\" kodu zaten \"%2$s\" birleşik hizmet sağlayıcısı tarafından kullanılıyor",
-    "Cloud Federation Provider with ID: \"%s\" does not exist." : "\"%s\" kodlu birleşik bulut hizmeti sağlayıcısı bulunamadı.",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "\"%1$s\" kimliği zaten \"%2$s\" birleşik hizmet sağlayıcısı tarafından kullanılıyor",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "\"%s\" kimlikli birleşik bulut hizmeti sağlayıcısı bulunamadı.",
     "Could not obtain lock type %d on \"%s\"." : "\"%s\" için %d kilit türü alınamadı.",
     "Storage unauthorized. %s" : "Depolamaya erişim izni yok. %s",
     "Storage incomplete configuration. %s" : "Depolama yapılandırması tamamlanmamış. %s",
@@ -271,10 +271,31 @@ OC.L10N.register(
     "Extracts topics from a text and outputs them separated by commas." : "Bir metindeki konuları ayıklar ve bunları virgül ile ayırarak sıralar.",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s uygulamasının dosyaları doğru şekilde değiştirilmedi. Sunucu ile uyumlu dosyaların yüklü olduğundan emin olun.",
     "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış kullanıcı bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
+    "Logged in user must be an admin or sub admin" : "Oturum açmış kullanıcı bir yönetici ya da alt yönetici olmalıdır",
+    "Logged in user must be an admin" : "Oturum açmış kullanıcı bir yönetici olmalıdır",
     "Full name" : "Tam ad",
+    "Unknown user" : "Kullanıcı bilinmiyor",
+    "Enter the database username and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
+    "Enter the database username for %s" : "%s için veri tabanı kullanıcı adını yazın",
+    "MySQL username and/or password not valid" : "MySQL kullanıcı adı ya da parolası geçersiz",
+    "Oracle username and/or password not valid" : "Oracle kullanıcı adı ya da parolası geçersiz",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL kullanıcı adı ya da parolası geçersiz",
+    "Set an admin username." : "Bir yönetici kullanıcı adı yazın.",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s paylaşılamadı. Bu öge zaten %s kullanıcısı ile paylaşılmış",
+    "The username is already being used" : "Bu kullanıcı adı zaten var",
+    "Could not create user" : "Kullanıcı oluşturulamadı",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kullanıcı adında yalnızca şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", boşluk ve \"_.@-'\"",
+    "A valid username must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
+    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adının başı ya da sonunda boşluk var",
+    "Username must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
+    "Username is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
+    "User disabled" : "Kullanıcı devre dışı",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 sürümü en az 2.7.0 olmalıdır. Şu anda %s kurulu.",
     "To fix this issue update your libxml2 version and restart your web server." : "Bu sorunu çözmek için libxml2 sürümünüzü güncelleyin ve site sunucusunu yeniden başlatın.",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 gerekli.",
-    "Please upgrade your database version." : "Lütfen veri tabanı sürümünüzü yükseltin."
+    "Please upgrade your database version." : "Lütfen veri tabanı sürümünüzü yükseltin.",
+    "Your data directory is readable by other users." : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kullanıcıların klasörü görebilmesini sağlayın."
 },
 "nplurals=2; plural=(n > 1);");
