@@ -52,7 +52,7 @@ OC.L10N.register(
     "Nov." : "ئوغلاق",
     "Dec." : "كۆنەك",
     "A valid password must be provided" : "چوقۇم ئىناۋەتلىك ئىم تەمىنلەش كېرەك",
-    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك",
-    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى"
+    "Authentication error" : "سالاھىيەت دەلىللەش خاتالىقى",
+    "A valid username must be provided" : "چوقۇم ئىناۋەتلىك ئىشلەتكۈچى ئىسمىدىن بىرنى تەمىنلەش كېرەك"
 },
 "nplurals=2; plural=(n != 1);");
