@@ -8,7 +8,6 @@ OC.L10N.register(
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Застосунок %1$s відсутній або має несумісну з цим сервером версію. Будь ласка, перевірте каталог додатків.",
     "Sample configuration detected" : "Виявлено приклад конфігурації",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Було виявлено, що приклад конфігурації було скопійовано. Це може нашкодити вашій системі та не підтримується. Будь ласка, зверніться до документації перед внесенням змін в файл config.php",
-    "404" : "404",
     "The page could not be found on the server." : "Сторінку не знайдено на сервері.",
     "%s email verification" : "%s підтвердження електронної пошти",
     "Email verification" : "Підтвердження електронної пошти",
@@ -37,9 +36,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Підтримуються такі платформи: %s",
     "Server version %s or higher is required." : "Потрібна версія сервера %s або вище.",
     "Server version %s or lower is required." : "Потрібна версія сервера %s або нижча.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Користувач, який увійшов у систему, має бути адміністратором, підадміністратором або мати спеціальні права доступу до цього налаштування",
-    "Logged in user must be an admin or sub admin" : "Увійшовши в систему користувач повинен бути адміністратором або підадміністратором",
-    "Logged in user must be an admin" : "Зареєстрований користувач має бути адміністратором",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Обліковий запис для входу має бути адміністратором, заступником адміністратора або мати спеціальні права доступу до цих налаштувань.",
+    "Logged in account must be an admin or sub admin" : "Обліковий запис для входу має бути адміністратором, заступником адміністратора",
+    "Logged in account must be an admin" : "Обліковий запис для входу має бути адміністратором",
     "Wiping of device %s has started" : "Розпочато очищення пристрою %s",
     "Wiping of device »%s« has started" : "Розпочато стирання даних на пристрої \"%s\".",
     "»%s« started remote wipe" : "\"%s\" розпочато віддалене стирання даних",
@@ -79,7 +78,7 @@ OC.L10N.register(
     "in a few seconds" : "через кілька секунд",
     "seconds ago" : "кілька секунд тому",
     "Empty file" : "Порожній файл",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль з ID: %s не існує. Будь ласка, увімкніть це в налаштуваннях програми або зверніться до адміністратора.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль з ID: %s не існує. Будь ласка, увімкніть це в налаштуваннях застосунку або зверніться до адміністратора.",
     "File already exists" : "Файл вже існує",
     "Invalid path" : "Недійсний шлях",
     "Failed to create file from template" : "Не вдалося створити файл із шаблону",
@@ -90,9 +89,9 @@ OC.L10N.register(
     "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
     "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Застосунок \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Програму \"%s\" неможливо встановити, оскільки вона не сумісна з цією версією сервера.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Застосунок \"%s\" неможливо встановити, оскільки він не сумісний з цією версією сервера.",
     "__language_name__" : "Українська",
-    "This is an automatically sent email, please do not reply." : "Це автоматично надісланий електронний лист, будь ласка, не відповідайте.",
+    "This is an automatically sent email, please do not reply." : "Це автоматично надісланий електронний лист, будь ласка, не відповідайте на нього.",
     "Help" : "Допомога",
     "Appearance and accessibility" : "Тема та вигляд",
     "Apps" : "Застосунки",
@@ -103,7 +102,7 @@ OC.L10N.register(
     "Users" : "Користувачі",
     "Email" : "Електронна пошта",
     "Mail %s" : "Пошта %s",
-    "Fediverse" : "Федіверс",
+    "Fediverse" : "Fediverse",
     "View %s on the fediverse" : "Переглянути %s у Fediverse",
     "Phone" : "Телефон",
     "Call %s" : "Телефонуйте %s",
@@ -118,22 +117,22 @@ OC.L10N.register(
     "Headline" : "Заголовок",
     "Organisation" : "Організація",
     "Role" : "Роль",
-    "Unknown user" : "Невідомий користувач",
+    "Unknown account" : "Невідомий обліковий запис",
     "Additional settings" : "Додатково",
-    "Enter the database username and name for %s" : "Введіть ім’я користувача та назву бази даних %s",
-    "Enter the database username for %s" : "Введіть ім’я користувача бази даних для %s",
+    "Enter the database Login and name for %s" : "Введіть ім’я користувача та назву бази даних для %s",
+    "Enter the database Login for %s" : "Введіть ім'я користувача бази даних для %s",
     "Enter the database name for %s" : "Введіть назву бази даних для %s",
     "You cannot use dots in the database name %s" : "Не можна використовувати крапки в назві бази даних %s",
-    "MySQL username and/or password not valid" : "Ім'я користувача та/або пароль MySQL недійсні",
+    "MySQL Login and/or password not valid" : "Ім'я користувача та/або пароль MySQL недійсні",
     "You need to enter details of an existing account." : "Потрібно ввести дані наявного облікового запису.",
     "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
-    "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
+    "Oracle Login and/or password not valid" : "Ім'я користувача та/або пароль Oracle не дійсні",
+    "PostgreSQL Login and/or password not valid" : "Ім'я користувача та/або пароль PostgreSQL не дійсні",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
     "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ймовірно, що сервер %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
-    "Set an admin username." : "Встановіть ім'я адміністратора.",
+    "Set an admin Login." : "Встановіть ім'я облікового запису адміністратора.",
     "Set an admin password." : "Встановіть пароль адміністратора.",
     "Cannot create or write into the data directory %s" : "Неможливо створити або записати в каталог даних %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бекенд спільного доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
@@ -151,7 +150,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "Дата закінчення в минулому",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможливо встановити дату закінчення більше ніж %n день у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому"],
     "Sharing is only allowed with group members" : "Спільний доступ дозволений лише для учасників групи",
-    "Sharing %s failed, because this item is already shared with user %s" : "Не вдалося поділитися %s, оскільки %s вже має до нього доступ",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Не вдалося надати у спільний доступ%s, оскільки цей ресурс вже у спільному доступі з обліковим записом %s",
     "%1$s shared »%2$s« with you" : "%1$s надав(-ла) доступ до \"%2$s\"",
     "%1$s shared »%2$s« with you." : "%1$s надав(-ла) доступ до \"%2$s\".",
     "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
@@ -205,16 +204,16 @@ OC.L10N.register(
     "Nov." : "Лис.",
     "Dec." : "Гру.",
     "A valid password must be provided" : "Потрібно задати вірний пароль",
-    "The username is already being used" : "Ім'я користувача вже використовується",
-    "Could not create user" : "Не вдалося створити користувача",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Лише такі символи дозволено у імені користувача: \"a-z\", \"A-Z\", \"0-9\", пробіл та \"_.@-'\"",
-    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
-    "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
-    "Username must not consist of dots only" : "Ім'я користувача не повинно складатися лише з крапок",
-    "Username is invalid because files already exist for this user" : "Ім'я користувача недійсне, оскільки файли для цього користувача вже існують",
-    "User disabled" : "Користувач виключений",
+    "The Login is already being used" : "Це ім'я облікового запису вже використовується",
+    "Could not create account" : "Не вдалося створити обліковий запис",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Лише такі символи дозволено у імені облікового запису: \"a-z\", \"A-Z\", \"0-9\", пробіл та \"_.@-'\"",
+    "A valid Login must be provided" : "Зазначте дійсне ім'я користувача",
+    "Login contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу на початку або наприкінці",
+    "Login must not consist of dots only" : "Ім'я користувача не може складатися лише з крапок",
+    "Login is invalid because files already exist for this user" : "Недійсне ім'я облікового запису, оскільки файли для цього користувача вже присутні",
+    "Account disabled" : "Обліковий запис вимкнено",
     "Login canceled by app" : "Вхід скасовано застосунком",
-    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Програму \"%1$s\" неможливо встановити, оскільки не виконано такі залежності: %2$s",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Застосунок \"%1$s\" неможливо встановити, оскільки не виконано такі залежності: %2$s",
     "a safe home for all your data" : "безпечний дім для ваших даних",
     "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
     "Cannot download file" : "Неможливо завантажити файл",
@@ -225,8 +224,8 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Не вдається записати в каталог \"config\".",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу конфігурації. Побачити %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Або, якщо ви віддаєте перевагу файлу config.php лише для читання, встановіть для параметра \"config_is_read_only\" значення true. Побачити %s",
-    "Cannot write into \"apps\" directory." : "Не вдається записати в каталог \"програми\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу програм або вимкнувши App Store у конфігураційному файлі.",
+    "Cannot write into \"apps\" directory." : "Відсутній доступ на запис до каталогу застосунків \"apps\".",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Зазвичай це можна виправити, якщо надати вебсерверу доступ для запису до каталогу застосунків або вимкнути App Store у конфігураційному файлі.",
     "Cannot create \"data\" directory." : "Неможливо створити каталог \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ на запис до кореневого каталогу. Побачити %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволи зазвичай можна виправити, надавши веб-серверу доступ на запис до кореневого каталогу. Побачити %s. ",
@@ -245,8 +244,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
     "The required %s config variable is not configured in the config.php file." : "Необхідна змінна конфігурації %s не налаштована у файлі config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Будь ласка, попросіть свого адміністратора сервера перевірити конфігурацію Nextcloud.",
-    "Your data directory is readable by other users." : "Ваш каталог даних доступний для читання іншим користувачам.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
+    "Your data directory is readable by other people." : "Ваш каталог даних доступний для читання для інших користувачів.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
     "Your data directory must be an absolute path." : "Ваш каталог даних має бути абсолютним шляхом.",
     "Check the value of \"datadirectory\" in your configuration." : "Перевірте значення «каталогу даних» у вашій конфігурації.",
     "Your data directory is invalid." : "Ваш каталог даних недійсний.",
@@ -270,13 +269,33 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Викокремлює головне у тексті шляхом зменшення довжини тексту без втрати ключової інформації.",
     "Extract topics" : "Виділити теми",
     "Extracts topics from a text and outputs them separated by commas." : "Виділяє теми, які висвітлює текст, зводить їх у перелік, що розділено комами.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файли програми %1$s замінено неправильно. Переконайтеся, що це версія, сумісна з сервером.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файли застосунку %1$s не було коректно оновлено. Переконайтеся, що ця версія, сумісна із сервером.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Користувач, який увійшов у систему, має бути адміністратором, підадміністратором або мати спеціальні права доступу до цього налаштування",
+    "Logged in user must be an admin or sub admin" : "Увійшовши в систему користувач повинен бути адміністратором або підадміністратором",
+    "Logged in user must be an admin" : "Зареєстрований користувач має бути адміністратором",
     "Full name" : "Повна назва",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Досягнуто обмеження на кількість користувачів, користувача не було створено. Перевірте сповіщення для докладної інформації.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Тільки такі символи допускаються в імені користувача: \"a-z\", \"A-Z\", \"0-9\", і \"_.@-'\"",
+    "Unknown user" : "Невідомий користувач",
+    "Enter the database username and name for %s" : "Введіть ім’я користувача та назву бази даних %s",
+    "Enter the database username for %s" : "Введіть ім’я користувача бази даних для %s",
+    "MySQL username and/or password not valid" : "Ім'я користувача та/або пароль MySQL недійсні",
+    "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
+    "Set an admin username." : "Встановіть ім'я адміністратора.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Не вдалося поділитися %s, оскільки %s вже має до нього доступ",
+    "The username is already being used" : "Ім'я користувача вже використовується",
+    "Could not create user" : "Не вдалося створити користувача",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Лише такі символи дозволено у імені користувача: \"a-z\", \"A-Z\", \"0-9\", пробіл та \"_.@-'\"",
+    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
+    "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
+    "Username must not consist of dots only" : "Ім'я користувача не повинно складатися лише з крапок",
+    "Username is invalid because files already exist for this user" : "Ім'я користувача недійсне, оскільки файли для цього користувача вже існують",
+    "User disabled" : "Користувач виключений",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "Необхідно libxml2 версії принаймні 2.7.0. На разі встановлена %s.",
     "To fix this issue update your libxml2 version and restart your web server." : "Що виправити це оновіть версію libxml2 та перезапустіть веб-сервер.",
     "PostgreSQL >= 9 required." : "Необхідно PostgreSQL >= 9.",
-    "Please upgrade your database version." : "Оновіть версію бази даних."
+    "Please upgrade your database version." : "Оновіть версію бази даних.",
+    "Your data directory is readable by other users." : "Ваш каталог даних доступний для читання іншим користувачам.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
