@@ -5,6 +5,7 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory." : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "但是，如果您更希望将 config.php 文件设为只读，可以将 \"config_is_read_only\" 选项设置为 true。",
     "See %s" : "查看 %s",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "应用程序%1$s不存在或其版本与此服务器不兼容。请检查应用目录。",
     "Sample configuration detected" : "示例配置检测",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接把 config.php 的样例文件直接复制使用。这可能会破坏您的安装。在对 config.php 进行修改之前请先阅读相关文档。",
     "The page could not be found on the server." : "无法在服务器上找到此页面",
@@ -35,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "支持以下平台：%s",
     "Server version %s or higher is required." : "需要服务器版本 %s 或更高版本。",
     "Server version %s or lower is required." : "需要服务器版本 %s 或更低版本。",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登录用户必须是管理员、子管理员或具有访问此设置的特殊权限",
-    "Logged in user must be an admin or sub admin" : "当前登录用户必须为管理员或子管理员",
-    "Logged in user must be an admin" : "当前登录用户必须为管理员",
     "Wiping of device %s has started" : "设备%s的擦除操作已开始",
     "Wiping of device »%s« has started" : "设备 »%s« 的擦除操作已开始",
     "»%s« started remote wipe" : "»%s« 已开始远程擦除",
@@ -116,22 +114,15 @@ OC.L10N.register(
     "Headline" : "标题",
     "Organisation" : "组织",
     "Role" : "角色",
-    "Unknown user" : "未知用户",
     "Additional settings" : "其他设置",
-    "Enter the database username and name for %s" : "输入 %s 的数据库用户名和名称",
-    "Enter the database username for %s" : "输入 %s 的数据库用户名",
     "Enter the database name for %s" : "输入 %s 的数据库名称",
     "You cannot use dots in the database name %s" : "您不能在数据库名称 %s 中使用句点",
-    "MySQL username and/or password not valid" : "MySQL 数据库用户名和/或密码无效",
     "You need to enter details of an existing account." : "您需要输入现有账号的详细信息。",
     "Oracle connection could not be established" : "无法建立 Oracle 连接",
-    "Oracle username and/or password not valid" : "Oracle 数据库用户名和/或密码无效",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL 数据库用户名和/或密码无效",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X 不被支持并且 %s 在这个平台上无法正常工作。请自行承担风险！",
     "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起来这个 %s 实例运行在32位 PHP 环境中并且已在 php.ini 中配置open_basedir。这将在文件超过4GB时出现问题，强烈不建议这样做。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "请删除 php.ini 中的 open_basedir 设置或切换到64位PHP。",
-    "Set an admin username." : "请设置一个管理员用户名。",
     "Set an admin password." : "请设置一个管理员密码。",
     "Cannot create or write into the data directory %s" : "无法创建或写入数据文件夹 %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "共享后端 %s 必须实现 OCP\\Share_Backend 接口",
@@ -149,11 +140,12 @@ OC.L10N.register(
     "Expiration date is in the past" : "到期日期已过",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["允许设置的最远截止期是从今天算起的 %n-1 天之后"],
     "Sharing is only allowed with group members" : "只允许与群组成员共享",
-    "Sharing %s failed, because this item is already shared with user %s" : "共享 %s 失败了，因为该项目已和用户 %s 进行了分享。",
     "%1$s shared »%2$s« with you" : "%1$s 对您共享了 »%2$s«",
     "%1$s shared »%2$s« with you." : "%1$s 对您共享了 »%2$s«。",
     "Click the button below to open it." : "点击下方按钮可打开它。",
     "The requested share does not exist anymore" : "当前请求的共享已经不存在",
+    "The requested share comes from a disabled user" : "请求的分享来自一个被禁用的用户",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "由于已达用户数量上限，用户未创建。请检查通知以了解详情。",
     "Could not find category \"%s\"" : "无法找到分类 \"%s\"",
     "Sunday" : "星期日",
     "Monday" : "星期一",
@@ -201,13 +193,6 @@ OC.L10N.register(
     "Nov." : "十一月",
     "Dec." : "十二月",
     "A valid password must be provided" : "必须提供合法的密码",
-    "The username is already being used" : "用户名已被使用",
-    "Could not create user" : "无法创建用户",
-    "A valid username must be provided" : "必须提供合法的用户名",
-    "Username contains whitespace at the beginning or at the end" : "用户名在开头或结尾处包含空格",
-    "Username must not consist of dots only" : "用户名不能仅由点组成",
-    "Username is invalid because files already exist for this user" : "用户名无效，因为该用户已经存在文件",
-    "User disabled" : "用户已禁用",
     "Login canceled by app" : "已通过应用取消登录",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "应用 \"%1$s\" 无法安装，因为不能满足以下依赖： %2$s",
     "a safe home for all your data" : "给您所有数据一个安全的家",
@@ -240,8 +225,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "请联系您的服务器管理员重启 Web 服务器。",
     "The required %s config variable is not configured in the config.php file." : "所需要的配置变量 %s 没有在 config.php 文件中配置。",
     "Please ask your server administrator to check the Nextcloud configuration." : "请联系您的服务器管理员检查 Nextcloud 设置。",
-    "Your data directory is readable by other users." : "您的数据目录可被其他用户读取。",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "请更改权限为 0770 以避免其他用户查看目录。",
     "Your data directory must be an absolute path." : "您的数据目录必须是绝对路径。",
     "Check the value of \"datadirectory\" in your configuration." : "请检查配置文件中 \"datadirectory\" 的值。",
     "Your data directory is invalid." : "您的数据目录无效。",
@@ -257,14 +240,41 @@ OC.L10N.register(
     "Storage connection error. %s" : "存储连接错误。%s",
     "Storage is temporarily not available" : "存储暂时不可用",
     "Storage connection timeout. %s" : "存储连接超时。%s",
+    "Free prompt" : "自由提示",
+    "Runs an arbitrary prompt through the language model." : "向语言模型中输入任何提示词",
+    "Generate headline" : "产生标题",
+    "Generates a possible headline for a text." : "为一段文本生成一个可能的标题",
+    "Summarize" : "总结归纳",
+    "Summarizes text by reducing its length without losing key information." : "总结一段文本以减少长度而不丢失关键信息",
+    "Extract topics" : "提取主题",
+    "Extracts topics from a text and outputs them separated by commas." : "从文本中摘出主题，输出逗号分隔的结果",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "应用%1$s的文件替换不正确。请确认版本与当前服务器兼容。",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登录用户必须是管理员、子管理员或具有访问此设置的特殊权限",
+    "Logged in user must be an admin or sub admin" : "当前登录用户必须为管理员或子管理员",
+    "Logged in user must be an admin" : "当前登录用户必须为管理员",
     "Full name" : "全名",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "已达到用户上限，未创建该用户。请检查您的通知以了解更多。",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "在用户名中只允许使用以下字符：“a-z”、“A-Z”、“0-9” 和 \"_.@-'\"",
+    "Unknown user" : "未知用户",
+    "Enter the database username and name for %s" : "输入 %s 的数据库用户名和名称",
+    "Enter the database username for %s" : "输入 %s 的数据库用户名",
+    "MySQL username and/or password not valid" : "MySQL 数据库用户名和/或密码无效",
+    "Oracle username and/or password not valid" : "Oracle 数据库用户名和/或密码无效",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL 数据库用户名和/或密码无效",
+    "Set an admin username." : "请设置一个管理员用户名。",
+    "Sharing %s failed, because this item is already shared with user %s" : "共享 %s 失败了，因为该项目已和用户 %s 进行了分享。",
+    "The username is already being used" : "用户名已被使用",
+    "Could not create user" : "无法创建用户",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "在用户名中只允许使用以下字符：“a-z”、“A-Z”、“0-9”、空格和 \"_.@-'\"",
+    "A valid username must be provided" : "必须提供合法的用户名",
+    "Username contains whitespace at the beginning or at the end" : "用户名在开头或结尾处包含空格",
+    "Username must not consist of dots only" : "用户名不能仅由点组成",
+    "Username is invalid because files already exist for this user" : "用户名无效，因为该用户已经存在文件",
+    "User disabled" : "用户已禁用",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "至少需要 libxml2 2.7.0. 当前安装 %s。",
     "To fix this issue update your libxml2 version and restart your web server." : "升级您的libxml2版本然后重启Web服务器以解决该问题。",
     "PostgreSQL >= 9 required." : "需要 PostgreSQL >= 9。",
     "Please upgrade your database version." : "请升级您的数据库版本。",
-    "404" : "404"
+    "Your data directory is readable by other users." : "您的数据目录可被其他用户读取。",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "请更改权限为 0770 以避免其他用户查看目录。"
 },
 "nplurals=1; plural=0;");
