@@ -36,9 +36,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "支援下列平台：%s",
     "Server version %s or higher is required." : "需要伺服器版本 %s 或更高",
     "Server version %s or lower is required." : "需要伺服器版本 %s 或更低",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登入使用者必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
-    "Logged in user must be an admin or sub admin" : "登入的使用者必須要是管理員或是子管理員",
-    "Logged in user must be an admin" : "登入的使用者必須有管理員權限",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "登入帳號必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
+    "Logged in account must be an admin or sub admin" : "登入的帳號必須要是管理員或是子管理員",
+    "Logged in account must be an admin" : "登入的帳號必須有管理員權限",
     "Wiping of device %s has started" : "已開始抹除裝置 %s ",
     "Wiping of device »%s« has started" : "已開始抹除裝置「%s」",
     "»%s« started remote wipe" : "「%s」開始遠端抹除",
@@ -117,22 +117,22 @@ OC.L10N.register(
     "Headline" : "標題",
     "Organisation" : "組織",
     "Role" : "角色",
-    "Unknown user" : "未知的使用者",
+    "Unknown account" : "未知的帳號",
     "Additional settings" : "其他設定",
-    "Enter the database username and name for %s" : "輸入 %s 的資料庫名稱及使用者名稱",
-    "Enter the database username for %s" : "輸入 %s 的資料庫使用者暱稱",
+    "Enter the database Login and name for %s" : "輸入 %s 的資料庫帳號與名稱",
+    "Enter the database Login for %s" : "輸入 %s 的資料庫帳號",
     "Enter the database name for %s" : "輸入 %s 的資料庫名稱",
     "You cannot use dots in the database name %s" : "資料庫名稱 %s 不能包含小數點",
-    "MySQL username and/or password not valid" : "MySQL 使用者名稱或密碼不正確",
+    "MySQL Login and/or password not valid" : "MySQL 帳號或密碼不正確",
     "You need to enter details of an existing account." : "您必須輸入現有帳號的資訊",
     "Oracle connection could not be established" : "無法建立 Oracle 資料庫連線",
-    "Oracle username and/or password not valid" : "Oracle 用戶名和/或密碼無效",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
+    "Oracle Login and/or password not valid" : "Oracle 帳號或密碼不正確",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL 帳號或密碼無效",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "不支援 Mac OS X 而且 %s 在這個平台上面無法正常運作，請自行衡量風險後使用！",
     "For the best results, please consider using a GNU/Linux server instead." : "請考慮使用 GNU/Linux 伺服器以獲得最佳體驗",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起來 %s 是在 32 位元的 PHP 環境運行，並且 php.ini 中被設置了 open_basedir 參數，這將讓超過 4GB 的檔案操作發生問題，強烈建議您更改設定。",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "請移除 php.ini 中的 open_basedir 設定，或是改用 64 位元的 PHP",
-    "Set an admin username." : "設定管理員帳號",
+    "Set an admin Login." : "設定管理員帳號。",
     "Set an admin password." : "設定管理員密碼",
     "Cannot create or write into the data directory %s" : "無法建立或寫入資料目錄 %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "分享後端 %s 必須實作 OCP\\Share_Backend 界面",
@@ -150,7 +150,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "到期日為過去的日期",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["無法設定到期日超過未來%n天"],
     "Sharing is only allowed with group members" : "僅允許與群組成員分享",
-    "Sharing %s failed, because this item is already shared with user %s" : "分享 %s 失敗，因為此項目已與使用者 %s 分享",
+    "Sharing %s failed, because this item is already shared with the account %s" : "分享 %s 失敗，因為此項目已與帳號 %s 分享",
     "%1$s shared »%2$s« with you" : "%1$s 與您分享了 %2$s",
     "%1$s shared »%2$s« with you." : "%1$s 與您分享了 %2$s",
     "Click the button below to open it." : "點下方連結開啟",
@@ -204,14 +204,14 @@ OC.L10N.register(
     "Nov." : "十一月",
     "Dec." : "十二月",
     "A valid password must be provided" : "須提供有效的密碼",
-    "The username is already being used" : "這個使用者名稱已經有人使用了",
-    "Could not create user" : "無法建立使用者",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "使用者名稱僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
-    "A valid username must be provided" : "必須提供一個有效的用戶名",
-    "Username contains whitespace at the beginning or at the end" : "用戶名的開頭或結尾有空白",
-    "Username must not consist of dots only" : "使用者名稱不能只包含小數點",
-    "Username is invalid because files already exist for this user" : "使用者名稱無效，因為使用者的檔案已經存在",
-    "User disabled" : "使用者已停用",
+    "The Login is already being used" : "這個帳號已經有人使用了",
+    "Could not create account" : "無法建立帳號",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "帳號僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
+    "A valid Login must be provided" : "必須提供有效帳號",
+    "Login contains whitespace at the beginning or at the end" : "帳號的開頭或結尾有空白",
+    "Login must not consist of dots only" : "帳號不能只包含小數點",
+    "Login is invalid because files already exist for this user" : "帳號無效，因為使用者的檔案已經存在",
+    "Account disabled" : "帳號已停用",
     "Login canceled by app" : "應用程式取消了登入",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "應用程式 \"%1$s\" 無法被安裝，缺少下列所需元件： %2$s",
     "a safe home for all your data" : "您資料的安全屋",
@@ -244,8 +244,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "請聯絡您的系統管理員重新啟動網頁伺服器",
     "The required %s config variable is not configured in the config.php file." : "必要的 %s 設定變數未在 config.php 檔案中設定。",
     "Please ask your server administrator to check the Nextcloud configuration." : "請聯絡您的伺服器管理員檢查 Nextcloud 設定。",
-    "Your data directory is readable by other users." : "您的 data 目錄可被其他使用讀取。",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表",
+    "Your data directory is readable by other people." : "您的 data 目錄可被其他使用者讀取。",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表",
     "Your data directory must be an absolute path." : "您的 data 目錄必須是絕對路徑。",
     "Check the value of \"datadirectory\" in your configuration." : "請檢查您設定檔中「datadirectory」的值。",
     "Your data directory is invalid." : "您的 data 目錄無效。",
@@ -270,13 +270,32 @@ OC.L10N.register(
     "Extract topics" : "擷取主題",
     "Extracts topics from a text and outputs them separated by commas." : "從文字中擷取主題並輸出，然後用逗號分隔。",
     "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "應用程式 %1$s 中的檔案沒有被正確取代，請確認它的版本與伺服器相容。",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登入使用者必須為管理員、子管理員或有可存取此設定的特殊權限的使用者",
+    "Logged in user must be an admin or sub admin" : "登入的使用者必須要是管理員或是子管理員",
+    "Logged in user must be an admin" : "登入的使用者必須有管理員權限",
     "Full name" : "全名",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "已達使用者限制，所以未建立使用者。請檢查您的通知以取得更多資訊。",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "使用者名稱當中只能包含下列字元：\"a-z\", \"A-Z\", \"0-9\", 和 \"_.@-'\"",
+    "Unknown user" : "未知的使用者",
+    "Enter the database username and name for %s" : "輸入 %s 的資料庫名稱及使用者名稱",
+    "Enter the database username for %s" : "輸入 %s 的資料庫使用者暱稱",
+    "MySQL username and/or password not valid" : "MySQL 使用者名稱或密碼不正確",
+    "Oracle username and/or password not valid" : "Oracle 用戶名和/或密碼無效",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL 用戶名和/或密碼無效",
+    "Set an admin username." : "設定管理員帳號",
+    "Sharing %s failed, because this item is already shared with user %s" : "分享 %s 失敗，因為此項目已與使用者 %s 分享",
+    "The username is already being used" : "這個使用者名稱已經有人使用了",
+    "Could not create user" : "無法建立使用者",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "使用者名稱僅允許以下字元：\"a-z\"、\"A-Z\"、\"0-9\"、空格與 \"_.@-'\"",
+    "A valid username must be provided" : "必須提供一個有效的用戶名",
+    "Username contains whitespace at the beginning or at the end" : "用戶名的開頭或結尾有空白",
+    "Username must not consist of dots only" : "使用者名稱不能只包含小數點",
+    "Username is invalid because files already exist for this user" : "使用者名稱無效，因為使用者的檔案已經存在",
+    "User disabled" : "使用者已停用",
     "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 版本最低需求為 2.7.0。目前安裝版本為 %s 。",
     "To fix this issue update your libxml2 version and restart your web server." : "修正方式為更新您的 libxml2 為 2.7.0 以上版本，再重啟網頁伺服器。",
     "PostgreSQL >= 9 required." : "需要 PostgreSQL 版本 >= 9。",
     "Please upgrade your database version." : "請升級您的資料庫版本。",
-    "404" : "404"
+    "Your data directory is readable by other users." : "您的 data 目錄可被其他使用讀取。",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "請將該目錄權限設定為 0770 ，以免其他使用者讀取目錄列表"
 },
 "nplurals=1; plural=0;");
