@@ -42,6 +42,7 @@ namespace OC\Group;
 use OC\Hooks\PublicEmitter;
 use OCP\EventDispatcher\IEventDispatcher;
 use OCP\GroupInterface;
+use OCP\ICacheFactory;
 use OCP\IGroup;
 use OCP\IGroupManager;
 use OCP\IUser;
@@ -82,12 +83,16 @@ class Manager extends PublicEmitter implements IGroupManager {
 	/** @var \OC\SubAdmin */
 	private $subAdmin = null;
 
+	private DisplayNameCache $displayNameCache;
+
 	public function __construct(\OC\User\Manager $userManager,
 								EventDispatcherInterface $dispatcher,
-								LoggerInterface $logger) {
+								LoggerInterface $logger,
+								ICacheFactory $cacheFactory) {
 		$this->userManager = $userManager;
 		$this->dispatcher = $dispatcher;
 		$this->logger = $logger;
+		$this->displayNameCache = new DisplayNameCache($cacheFactory, $this);
 
 		$cachedGroups = &$this->cachedGroups;
 		$cachedUserGroups = &$this->cachedUserGroups;
@@ -231,14 +236,14 @@ class Manager extends PublicEmitter implements IGroupManager {
 
 	/**
 	 * @param string $search
-	 * @param int $limit
-	 * @param int $offset
+	 * @param ?int $limit
+	 * @param ?int $offset
 	 * @return \OC\Group\Group[]
 	 */
-	public function search($search, $limit = null, $offset = null) {
+	public function search(string $search, ?int $limit = null, ?int $offset = 0) {
 		$groups = [];
 		foreach ($this->backends as $backend) {
-			$groupIds = $backend->getGroups($search, $limit, $offset);
+			$groupIds = $backend->getGroups($search, $limit ?? -1, $offset ?? 0);
 			foreach ($groupIds as $groupId) {
 				$aGroup = $this->get($groupId);
 				if ($aGroup instanceof IGroup) {
@@ -338,6 +343,14 @@ class Manager extends PublicEmitter implements IGroupManager {
 		return $this->cachedUserGroups[$uid];
 	}
 
+	/**
+	 * @param string $groupId
+	 * @return ?string
+	 */
+	public function getDisplayName(string $groupId): ?string {
+		return $this->displayNameCache->getDisplayName($groupId);
+	}
+
 	/**
 	 * get an array of groupid and displayName for a user
 	 *
@@ -346,7 +359,7 @@ class Manager extends PublicEmitter implements IGroupManager {
 	 */
 	public function getUserGroupNames(IUser $user) {
 		return array_map(function ($group) {
-			return ['displayName' => $group->getDisplayName()];
+			return ['displayName' => $this->displayNameCache->getDisplayName($group->getGID())];
 		}, $this->getUserGroups($user));
 	}
 
