@@ -25,8 +25,9 @@ declare(strict_types=1);
  */
 namespace OC\Preview;
 
-use OC\BackgroundJob\TimedJob;
 use OC\Preview\Storage\Root;
+use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\BackgroundJob\TimedJob;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\Files\IMimeTypeLoader;
 use OCP\Files\NotFoundException;
@@ -34,7 +35,6 @@ use OCP\Files\NotPermittedException;
 use OCP\IDBConnection;
 
 class BackgroundCleanupJob extends TimedJob {
-
 	/** @var IDBConnection */
 	private $connection;
 
@@ -47,10 +47,12 @@ class BackgroundCleanupJob extends TimedJob {
 	/** @var IMimeTypeLoader */
 	private $mimeTypeLoader;
 
-	public function __construct(IDBConnection $connection,
+	public function __construct(ITimeFactory $timeFactory,
+								IDBConnection $connection,
 								Root $previewFolder,
 								IMimeTypeLoader $mimeTypeLoader,
 								bool $isCLI) {
+		parent::__construct($timeFactory);
 		// Run at most once an hour
 		$this->setInterval(3600);
 
@@ -126,6 +128,21 @@ class BackgroundCleanupJob extends TimedJob {
 		 */
 		$like = $this->connection->escapeLikeParameter($data['path']) . '/_/_/_/_/_/_/_/%';
 
+		/*
+		 * Deleting a file will not delete related previews right away.
+		 *
+		 * A delete request is usually an HTTP request.
+		 * The preview deleting is done by a background job to avoid timeouts.
+		 *
+		 * Previews for a file are stored within a folder in appdata_/preview using the fileid as folder name.
+		 * Preview folders in oc_filecache are identified by a.storage, a.path (cf. $like) and a.mimetype.
+		 *
+		 * To find preview folders to delete, we query oc_filecache for a preview folder in app data, matching the preview folder structure
+		 * and use the name to left join oc_filecache on a.name = b.fileid. A left join returns all rows from the left table (a),
+		 * even if there are no matches in the right table (b).
+		 *
+		 * If the related file is deleted, b.fileid will be null and the preview folder can be deleted.
+		 */
 		$qb = $this->connection->getQueryBuilder();
 		$qb->select('a.name')
 			->from('filecache', 'a')
