@@ -49,6 +49,7 @@ use OCP\Files\Mount\IMountPoint;
 use OCP\ICacheFactory;
 use OCP\IBinaryFinder;
 use OCP\IUser;
+use OCP\Util;
 use Psr\Log\LoggerInterface;
 
 /**
@@ -56,15 +57,17 @@ use Psr\Log\LoggerInterface;
  */
 class OC_Helper {
 	private static $templateManager;
+	private static ?ICacheFactory $cacheFactory = null;
+	private static ?bool $quotaIncludeExternalStorage = null;
 
 	/**
 	 * Make a human file size
-	 * @param int $bytes file size in bytes
+	 * @param int|float $bytes file size in bytes
 	 * @return string a human readable file size
 	 *
 	 * Makes 2048 to 2 kB.
 	 */
-	public static function humanFileSize($bytes) {
+	public static function humanFileSize(int|float $bytes): string {
 		if ($bytes < 0) {
 			return "?";
 		}
@@ -95,16 +98,16 @@ class OC_Helper {
 	/**
 	 * Make a computer file size
 	 * @param string $str file size in human readable format
-	 * @return float|false a file size in bytes
+	 * @return false|int|float a file size in bytes
 	 *
 	 * Makes 2kB to 2048.
 	 *
 	 * Inspired by: https://www.php.net/manual/en/function.filesize.php#92418
 	 */
-	public static function computerFileSize($str) {
+	public static function computerFileSize(string $str): false|int|float {
 		$str = strtolower($str);
 		if (is_numeric($str)) {
-			return (float)$str;
+			return Util::numericToNumber($str);
 		}
 
 		$bytes_array = [
@@ -129,16 +132,14 @@ class OC_Helper {
 			return false;
 		}
 
-		$bytes = round($bytes);
-
-		return $bytes;
+		return Util::numericToNumber(round($bytes));
 	}
 
 	/**
 	 * Recursive copying of folders
 	 * @param string $src source folder
 	 * @param string $dest target folder
-	 *
+	 * @return void
 	 */
 	public static function copyr($src, $dest) {
 		if (is_dir($src)) {
@@ -387,8 +388,8 @@ class OC_Helper {
 	 * calculates the maximum upload size respecting system settings, free space and user quota
 	 *
 	 * @param string $dir the current folder where the user currently operates
-	 * @param int $freeSpace the number of bytes free on the storage holding $dir, if not set this will be received from the storage directly
-	 * @return int number of bytes representing
+	 * @param int|float $freeSpace the number of bytes free on the storage holding $dir, if not set this will be received from the storage directly
+	 * @return int|float number of bytes representing
 	 */
 	public static function maxUploadFilesize($dir, $freeSpace = null) {
 		if (is_null($freeSpace) || $freeSpace < 0) {
@@ -401,7 +402,7 @@ class OC_Helper {
 	 * Calculate free space left within user quota
 	 *
 	 * @param string $dir the current folder where the user currently operates
-	 * @return int number of bytes representing
+	 * @return int|float number of bytes representing
 	 */
 	public static function freeSpace($dir) {
 		$freeSpace = \OC\Files\Filesystem::free_space($dir);
@@ -416,12 +417,12 @@ class OC_Helper {
 	/**
 	 * Calculate PHP upload limit
 	 *
-	 * @return int PHP upload file size limit
+	 * @return int|float PHP upload file size limit
 	 */
 	public static function uploadLimit() {
 		$ini = \OC::$server->get(IniGetWrapper::class);
-		$upload_max_filesize = (int)OCP\Util::computerFileSize($ini->get('upload_max_filesize'));
-		$post_max_size = (int)OCP\Util::computerFileSize($ini->get('post_max_size'));
+		$upload_max_filesize = Util::computerFileSize($ini->get('upload_max_filesize')) ?: 0;
+		$post_max_size = Util::computerFileSize($ini->get('post_max_size')) ?: 0;
 		if ($upload_max_filesize === 0 && $post_max_size === 0) {
 			return INF;
 		} elseif ($upload_max_filesize === 0 || $post_max_size === 0) {
@@ -463,14 +464,22 @@ class OC_Helper {
 	 * @throws \OCP\Files\NotFoundException
 	 */
 	public static function getStorageInfo($path, $rootInfo = null, $includeMountPoints = true, $useCache = true) {
-		/** @var ICacheFactory $cacheFactory */
-		$cacheFactory = \OC::$server->get(ICacheFactory::class);
-		$memcache = $cacheFactory->createLocal('storage_info');
+		if (!self::$cacheFactory) {
+			self::$cacheFactory = \OC::$server->get(ICacheFactory::class);
+		}
+		$memcache = self::$cacheFactory->createLocal('storage_info');
 
 		// return storage info without adding mount points
-		$includeExtStorage = \OC::$server->getSystemConfig()->getValue('quota_include_external_storage', false);
+		if (self::$quotaIncludeExternalStorage === null) {
+			self::$quotaIncludeExternalStorage = \OC::$server->getSystemConfig()->getValue('quota_include_external_storage', false);
+		}
+
+		$view = Filesystem::getView();
+		if (!$view) {
+			throw new \OCP\Files\NotFoundException();
+		}
+		$fullPath = Filesystem::normalizePath($view->getAbsolutePath($path));
 
-		$fullPath = Filesystem::getView()->getAbsolutePath($path);
 		$cacheKey = $fullPath. '::' . ($includeMountPoints ? 'include' : 'exclude');
 		if ($useCache) {
 			$cached = $memcache->get($cacheKey);
@@ -480,7 +489,7 @@ class OC_Helper {
 		}
 
 		if (!$rootInfo) {
-			$rootInfo = \OC\Files\Filesystem::getFileInfo($path, $includeExtStorage ? 'ext' : false);
+			$rootInfo = \OC\Files\Filesystem::getFileInfo($path, self::$quotaIncludeExternalStorage ? 'ext' : false);
 		}
 		if (!$rootInfo instanceof \OCP\Files\FileInfo) {
 			throw new \OCP\Files\NotFoundException();
@@ -494,9 +503,9 @@ class OC_Helper {
 		$storage = $mount->getStorage();
 		$sourceStorage = $storage;
 		if ($storage->instanceOfStorage('\OCA\Files_Sharing\SharedStorage')) {
-			$includeExtStorage = false;
+			self::$quotaIncludeExternalStorage = false;
 		}
-		if ($includeExtStorage) {
+		if (self::$quotaIncludeExternalStorage) {
 			if ($storage->instanceOfStorage('\OC\Files\Storage\Home')
 				|| $storage->instanceOfStorage('\OC\Files\ObjectStore\HomeObjectStoreStorage')
 			) {
@@ -577,7 +586,7 @@ class OC_Helper {
 	/**
 	 * Get storage info including all mount points and quota
 	 */
-	private static function getGlobalStorageInfo(float $quota, IUser $user, IMountPoint $mount): array {
+	private static function getGlobalStorageInfo(int|float $quota, IUser $user, IMountPoint $mount): array {
 		$rootInfo = \OC\Files\Filesystem::getFileInfo('', 'ext');
 		$used = $rootInfo['size'];
 		if ($used < 0) {
@@ -616,11 +625,20 @@ class OC_Helper {
 		];
 	}
 
+	public static function clearStorageInfo(string $absolutePath): void {
+		/** @var ICacheFactory $cacheFactory */
+		$cacheFactory = \OC::$server->get(ICacheFactory::class);
+		$memcache = $cacheFactory->createLocal('storage_info');
+		$cacheKeyPrefix = Filesystem::normalizePath($absolutePath) . '::';
+		$memcache->remove($cacheKeyPrefix . 'include');
+		$memcache->remove($cacheKeyPrefix . 'exclude');
+	}
+
 	/**
 	 * Returns whether the config file is set manually to read-only
 	 * @return bool
 	 */
 	public static function isReadOnlyConfigEnabled() {
-		return \OC::$server->getConfig()->getSystemValue('config_is_read_only', false);
+		return \OC::$server->getConfig()->getSystemValueBool('config_is_read_only', false);
 	}
 }
