@@ -32,12 +32,11 @@ namespace OCP\Calendar;
  * @since 13.0.0
  */
 interface ICalendar {
-
 	/**
 	 * @return string defining the technical unique key
 	 * @since 13.0.0
 	 */
-	public function getKey();
+	public function getKey(): string;
 
 	/**
 	 * In comparison to getKey() this function returns a unique uri within the scope of the principal
@@ -50,30 +49,36 @@ interface ICalendar {
 	 * @return null|string
 	 * @since 13.0.0
 	 */
-	public function getDisplayName();
+	public function getDisplayName(): ?string;
 
 	/**
 	 * Calendar color
 	 * @return null|string
 	 * @since 13.0.0
 	 */
-	public function getDisplayColor();
+	public function getDisplayColor(): ?string;
 
 	/**
 	 * @param string $pattern which should match within the $searchProperties
 	 * @param array $searchProperties defines the properties within the query pattern should match
 	 * @param array $options - optional parameters:
 	 * 	['timerange' => ['start' => new DateTime(...), 'end' => new DateTime(...)]]
-	 * @param integer|null $limit - limit number of search results
-	 * @param integer|null $offset - offset for paging of search results
+	 * @param int|null $limit - limit number of search results
+	 * @param int|null $offset - offset for paging of search results
 	 * @return array an array of events/journals/todos which are arrays of key-value-pairs
 	 * @since 13.0.0
 	 */
-	public function search($pattern, array $searchProperties = [], array $options = [], $limit = null, $offset = null);
+	public function search(string $pattern, array $searchProperties = [], array $options = [], ?int $limit = null, ?int $offset = null): array;
 
 	/**
-	 * @return integer build up using \OCP\Constants
+	 * @return int build up using \OCP\Constants
 	 * @since 13.0.0
 	 */
-	public function getPermissions();
+	public function getPermissions(): int;
+
+	/**
+	 * Whether the calendar is deleted
+	 * @since 26.0.0
+	 */
+	public function isDeleted(): bool;
 }
