@@ -48,7 +48,6 @@ namespace OCP\Contacts;
  * @since 6.0.0
  */
 interface IManager {
-
 	/**
 	 * This function is used to search and find contacts within the users address books.
 	 * In case $pattern is empty all contacts will be returned.
@@ -96,7 +95,7 @@ interface IManager {
 	 * 	- 'limit' - Set a numeric limit for the search results
 	 * 	- 'offset' - Set the offset for the limited search results
 	 * 	- 'enumeration' - (since 23.0.0) Whether user enumeration on system address book is allowed
-	 * 	- 'fullmatch' - (since 23.0.0) Whether matching on full detail in system addresss book is allowed
+	 * 	- 'fullmatch' - (since 23.0.0) Whether matching on full detail in system address book is allowed
 	 * 	- 'strict_search' - (since 23.0.0) Whether the search pattern is full string or partial search
 	 * @psalm-param array{types?: bool, escape_like_param?: bool, limit?: int, offset?: int, enumeration?: bool, fullmatch?: bool, strict_search?: bool} $options
 	 * @return array an array of contacts which are arrays of key-value-pairs
@@ -161,15 +160,6 @@ interface IManager {
 	 */
 	public function register(\Closure $callable);
 
-	/**
-	 * Return a list of the user's addressbooks display names
-	 *
-	 * @return array
-	 * @since 6.0.0
-	 * @deprecated 16.0.0 - Use `$this->getUserAddressBooks()` instead
-	 */
-	public function getAddressBooks();
-
 	/**
 	 * Return a list of the user's addressbooks
 	 *
