@@ -28,5 +28,5 @@ namespace OCP\Files\Storage;
  *
  * @since 16.0.0
  */
-interface IDisableEncryptionStorage {
+interface IDisableEncryptionStorage extends IStorage {
 }
