@@ -28,12 +28,15 @@ declare(strict_types=1);
  */
 namespace OCP\Migration;
 
+use Closure;
+use OCP\DB\ISchemaWrapper;
+
 /**
  * @since 13.0.0
  */
 abstract class SimpleMigrationStep implements IMigrationStep {
 	/**
-	 * Human readable name of the migration step
+	 * Human-readable name of the migration step
 	 *
 	 * @return string
 	 * @since 14.0.0
@@ -43,7 +46,7 @@ abstract class SimpleMigrationStep implements IMigrationStep {
 	}
 
 	/**
-	 * Human readable description of the migration step
+	 * Human-readable description of the migration step
 	 *
 	 * @return string
 	 * @since 14.0.0
@@ -53,16 +56,21 @@ abstract class SimpleMigrationStep implements IMigrationStep {
 	}
 
 	/**
-	 * {@inheritDoc}
-	 *
+	 * @param IOutput $output
+	 * @param Closure $schemaClosure The `\Closure` returns a `ISchemaWrapper`
+	 * @psalm-param Closure():ISchemaWrapper $schemaClosure
+	 * @param array $options
 	 * @since 13.0.0
 	 */
 	public function preSchemaChange(IOutput $output, \Closure $schemaClosure, array $options) {
 	}
 
 	/**
-	 * {@inheritDoc}
-	 *
+	 * @param IOutput $output
+	 * @param Closure $schemaClosure The `\Closure` returns a `ISchemaWrapper`
+	 * @psalm-param Closure():ISchemaWrapper $schemaClosure
+	 * @param array $options
+	 * @return null|ISchemaWrapper
 	 * @since 13.0.0
 	 */
 	public function changeSchema(IOutput $output, \Closure $schemaClosure, array $options) {
@@ -70,8 +78,10 @@ abstract class SimpleMigrationStep implements IMigrationStep {
 	}
 
 	/**
-	 * {@inheritDoc}
-	 *
+	 * @param IOutput $output
+	 * @param Closure $schemaClosure The `\Closure` returns a `ISchemaWrapper`
+	 * @psalm-param Closure():ISchemaWrapper $schemaClosure
+	 * @param array $options
 	 * @since 13.0.0
 	 */
 	public function postSchemaChange(IOutput $output, \Closure $schemaClosure, array $options) {
